@@ -27,6 +27,7 @@
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
 #include <vcl/svapp.hxx>
 #include <vcl/controllayout.hxx>
+#include <vcl/settings.hxx>
 #include <toolkit/awt/vclxwindow.hxx>
 #include <toolkit/helper/convert.hxx>
 #include <unotools/accessiblestatesethelper.hxx>
@@ -41,30 +42,30 @@
 
 namespace
 {
-    void checkActionIndex_Impl( sal_Int32 _nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException)
+    void checkActionIndex_Impl( sal_Int32 _nIndex ) throw (css::lang::IndexOutOfBoundsException)
     {
         if ( _nIndex < 0 || _nIndex >= ACCESSIBLE_ACTION_COUNT )
             // only three actions
-            throw ::com::sun::star::lang::IndexOutOfBoundsException();
+            throw css::lang::IndexOutOfBoundsException();
     }
 }
 
-//........................................................................
+
 namespace accessibility
 {
 
-    // class AccessibleIconChoiceCtrlEntry -----------------------------------------------------
+    // class AccessibleIconChoiceCtrlEntry
 
     using namespace ::com::sun::star::accessibility;
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::lang;
     using namespace ::com::sun::star;
 
-    // -----------------------------------------------------------------------------
+
     // Ctor() and Dtor()
-    // -----------------------------------------------------------------------------
+
     AccessibleIconChoiceCtrlEntry::AccessibleIconChoiceCtrlEntry( SvtIconChoiceCtrl& _rIconCtrl,
-                                                                  sal_uLong _nPos,
+                                                                  sal_Int32 _nPos,
                                                                   const Reference< XAccessible >& _xParent ) :
 
         AccessibleIconChoiceCtrlEntry_BASE  ( m_aMutex ),
@@ -83,17 +84,17 @@ namespace accessibility
         }
         osl_atomic_decrement( &m_refCount );
     }
-    // -----------------------------------------------------------------------------
-    void AccessibleIconChoiceCtrlEntry::disposing( const EventObject& _rSource )
-throw(RuntimeException)
+
+    void AccessibleIconChoiceCtrlEntry::disposing( const css::lang::EventObject& _rSource )
+throw(RuntimeException, std::exception)
     {
         if ( _rSource.Source == m_xParent )
         {
             dispose();
-            OSL_ENSURE( !m_xParent.is() && ( NULL == m_pIconCtrl ), "" );
+            OSL_ENSURE( !m_xParent.is() && ( nullptr == m_pIconCtrl ), "" );
         }
     }
-    // -----------------------------------------------------------------------------
+
     AccessibleIconChoiceCtrlEntry::~AccessibleIconChoiceCtrlEntry()
     {
         if ( IsAlive_Impl() )
@@ -103,7 +104,7 @@ throw(RuntimeException)
             dispose();
         }
     }
-    // -----------------------------------------------------------------------------
+
     Rectangle AccessibleIconChoiceCtrlEntry::GetBoundingBox_Impl() const
     {
         Rectangle aRect;
@@ -113,7 +114,7 @@ throw(RuntimeException)
 
         return aRect;
     }
-    // -----------------------------------------------------------------------------
+
     Rectangle AccessibleIconChoiceCtrlEntry::GetBoundingBoxOnScreen_Impl() const
     {
         Rectangle aRect;
@@ -122,34 +123,35 @@ throw(RuntimeException)
         {
             aRect = m_pIconCtrl->GetBoundingBox( pEntry );
             Point aTopLeft = aRect.TopLeft();
-            aTopLeft += m_pIconCtrl->GetWindowExtentsRelative( NULL ).TopLeft();
+            aTopLeft += m_pIconCtrl->GetWindowExtentsRelative( nullptr ).TopLeft();
             aRect = Rectangle( aTopLeft, aRect.GetSize() );
         }
 
         return aRect;
     }
-    // -----------------------------------------------------------------------------
-    sal_Bool AccessibleIconChoiceCtrlEntry::IsAlive_Impl() const
+
+    bool AccessibleIconChoiceCtrlEntry::IsAlive_Impl() const
     {
         return ( !rBHelper.bDisposed && !rBHelper.bInDispose && m_pIconCtrl );
     }
-    // -----------------------------------------------------------------------------
-    sal_Bool AccessibleIconChoiceCtrlEntry::IsShowing_Impl() const
+
+    bool AccessibleIconChoiceCtrlEntry::IsShowing_Impl() const
     {
-        sal_Bool bShowing = sal_False;
-        Reference< XAccessibleContext > m_xParentContext =
+        bool bShowing = false;
+        Reference< XAccessibleContext > xParentContext =
             m_xParent.is() ? m_xParent->getAccessibleContext() : Reference< XAccessibleContext >();
-        if( m_xParentContext.is() )
+        if( xParentContext.is() )
         {
-            Reference< XAccessibleComponent > xParentComp( m_xParentContext, uno::UNO_QUERY );
+            Reference< XAccessibleComponent > xParentComp( xParentContext, uno::UNO_QUERY );
             if( xParentComp.is() )
                 bShowing = GetBoundingBox_Impl().IsOver( VCLRectangle( xParentComp->getBounds() ) );
         }
 
         return bShowing;
     }
-    // -----------------------------------------------------------------------------
-    Rectangle AccessibleIconChoiceCtrlEntry::GetBoundingBox() throw ( lang::DisposedException )
+
+    Rectangle AccessibleIconChoiceCtrlEntry::GetBoundingBox()
+        throw (lang::DisposedException, uno::RuntimeException)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -157,8 +159,9 @@ throw(RuntimeException)
         EnsureIsAlive();
         return GetBoundingBox_Impl();
     }
-    // -----------------------------------------------------------------------------
-    Rectangle AccessibleIconChoiceCtrlEntry::GetBoundingBoxOnScreen() throw ( lang::DisposedException )
+
+    Rectangle AccessibleIconChoiceCtrlEntry::GetBoundingBoxOnScreen()
+        throw (lang::DisposedException, uno::RuntimeException)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -166,13 +169,13 @@ throw(RuntimeException)
         EnsureIsAlive();
         return GetBoundingBoxOnScreen_Impl();
     }
-    // -----------------------------------------------------------------------------
+
     void AccessibleIconChoiceCtrlEntry::EnsureIsAlive() const throw ( lang::DisposedException )
     {
         if ( !IsAlive_Impl() )
             throw lang::DisposedException();
     }
-    // -----------------------------------------------------------------------------
+
     OUString AccessibleIconChoiceCtrlEntry::implGetText()
     {
         OUString sRet;
@@ -181,7 +184,7 @@ throw(RuntimeException)
             sRet = pEntry->GetDisplayText();
         return sRet;
     }
-    // -----------------------------------------------------------------------------
+
     Locale AccessibleIconChoiceCtrlEntry::implGetLocale()
     {
         Locale aLocale;
@@ -194,29 +197,17 @@ throw(RuntimeException)
         nStartIndex = 0;
         nEndIndex = 0;
     }
-    // -----------------------------------------------------------------------------
+
     // XTypeProvider
-    // -----------------------------------------------------------------------------
-    // -----------------------------------------------------------------------------
-    Sequence< sal_Int8 > AccessibleIconChoiceCtrlEntry::getImplementationId() throw (RuntimeException)
+
+
+    Sequence< sal_Int8 > AccessibleIconChoiceCtrlEntry::getImplementationId() throw (RuntimeException, std::exception)
     {
-        static ::cppu::OImplementationId* pId = NULL;
-
-        if ( !pId )
-        {
-            ::osl::Guard< ::osl::Mutex > aGuard( m_aMutex );
-
-            if ( !pId )
-            {
-                static ::cppu::OImplementationId aId;
-                pId = &aId;
-            }
-        }
-        return pId->getImplementationId();
+        return css::uno::Sequence<sal_Int8>();
     }
-    // -----------------------------------------------------------------------------
+
     // XComponent
-    // -----------------------------------------------------------------------------
+
     void SAL_CALL AccessibleIconChoiceCtrlEntry::disposing()
     {
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -233,30 +224,30 @@ throw(RuntimeException)
         if ( xComp.is() )
             xComp->removeEventListener( this );
 
-        m_pIconCtrl = NULL;
-        m_xParent = NULL;
+        m_pIconCtrl = nullptr;
+        m_xParent = nullptr;
     }
-    // -----------------------------------------------------------------------------
+
     // XServiceInfo
-    // -----------------------------------------------------------------------------
-    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getImplementationName() throw(RuntimeException)
+
+    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getImplementationName() throw(RuntimeException, std::exception)
     {
         return getImplementationName_Static();
     }
-    // -----------------------------------------------------------------------------
-    Sequence< OUString > SAL_CALL AccessibleIconChoiceCtrlEntry::getSupportedServiceNames() throw(RuntimeException)
+
+    Sequence< OUString > SAL_CALL AccessibleIconChoiceCtrlEntry::getSupportedServiceNames() throw(RuntimeException, std::exception)
     {
         return getSupportedServiceNames_Static();
     }
-    // -----------------------------------------------------------------------------
-    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::supportsService( const OUString& _rServiceName ) throw (RuntimeException)
+
+    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::supportsService( const OUString& _rServiceName ) throw (RuntimeException, std::exception)
     {
         return cppu::supportsService(this, _rServiceName);
     }
-    // -----------------------------------------------------------------------------
+
     // XServiceInfo - static methods
-    // -----------------------------------------------------------------------------
-    Sequence< OUString > AccessibleIconChoiceCtrlEntry::getSupportedServiceNames_Static(void) throw( RuntimeException )
+
+    Sequence< OUString > AccessibleIconChoiceCtrlEntry::getSupportedServiceNames_Static() throw( RuntimeException )
     {
         Sequence< OUString > aSupported(3);
         aSupported[0] = "com.sun.star.accessibility.AccessibleContext";
@@ -264,72 +255,73 @@ throw(RuntimeException)
         aSupported[2] = "com.sun.star.awt.AccessibleIconChoiceControlEntry";
         return aSupported;
     }
-    // -----------------------------------------------------------------------------
-    OUString AccessibleIconChoiceCtrlEntry::getImplementationName_Static(void) throw( RuntimeException )
+
+    OUString AccessibleIconChoiceCtrlEntry::getImplementationName_Static() throw( RuntimeException )
     {
         return OUString( "com.sun.star.comp.svtools.AccessibleIconChoiceControlEntry" );
     }
-    // -----------------------------------------------------------------------------
+
     // XAccessible
-    // -----------------------------------------------------------------------------
-    Reference< XAccessibleContext > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleContext(  ) throw (RuntimeException)
+
+    Reference< XAccessibleContext > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleContext(  ) throw (RuntimeException, std::exception)
     {
         EnsureIsAlive();
         return this;
     }
-    // -----------------------------------------------------------------------------
+
     // XAccessibleContext
-    // -----------------------------------------------------------------------------
-    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleChildCount(  ) throw (RuntimeException)
+
+    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleChildCount(  ) throw (RuntimeException, std::exception)
     {
         return 0; // no children
     }
-    // -----------------------------------------------------------------------------
-    Reference< XAccessible > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleChild( sal_Int32 ) throw (IndexOutOfBoundsException,RuntimeException)
+
+    Reference< XAccessible > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleChild( sal_Int32 ) throw (IndexOutOfBoundsException,RuntimeException, std::exception)
     {
         throw IndexOutOfBoundsException();
     }
-    // -----------------------------------------------------------------------------
-    Reference< XAccessible > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleParent(  ) throw (RuntimeException)
+
+    Reference< XAccessible > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleParent(  ) throw (RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
         EnsureIsAlive();
         return m_xParent;
     }
-    // -----------------------------------------------------------------------------
-    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleIndexInParent(  ) throw (RuntimeException)
+
+    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleIndexInParent(  ) throw (RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
         return m_nIndex;
     }
-    // -----------------------------------------------------------------------------
-    sal_Int16 SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleRole(  ) throw (RuntimeException)
+
+    sal_Int16 SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleRole(  ) throw (RuntimeException, std::exception)
     {
-        return AccessibleRole::LABEL;
+        //return AccessibleRole::LABEL;
+        return AccessibleRole::LIST_ITEM;
     }
-    // -----------------------------------------------------------------------------
-    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleDescription(  ) throw (RuntimeException)
+
+    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleDescription(  ) throw (RuntimeException, std::exception)
     {
         // no description for every item
         return OUString();
     }
-    // -----------------------------------------------------------------------------
-    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleName(  ) throw (RuntimeException)
+
+    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleName(  ) throw (RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
         EnsureIsAlive();
         return implGetText();
     }
-    // -----------------------------------------------------------------------------
-    Reference< XAccessibleRelationSet > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleRelationSet(  ) throw (RuntimeException)
+
+    Reference< XAccessibleRelationSet > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleRelationSet(  ) throw (RuntimeException, std::exception)
     {
         return new utl::AccessibleRelationSetHelper;
     }
-    // -----------------------------------------------------------------------------
-    Reference< XAccessibleStateSet > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleStateSet(  ) throw (RuntimeException)
+
+    Reference< XAccessibleStateSet > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleStateSet(  ) throw (RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -357,53 +349,53 @@ throw(RuntimeException)
 
         return xStateSet;
     }
-    // -----------------------------------------------------------------------------
-    Locale SAL_CALL AccessibleIconChoiceCtrlEntry::getLocale(  ) throw (IllegalAccessibleComponentStateException, RuntimeException)
+
+    Locale SAL_CALL AccessibleIconChoiceCtrlEntry::getLocale(  ) throw (IllegalAccessibleComponentStateException, RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
 
         return implGetLocale();
     }
-    // -----------------------------------------------------------------------------
+
     // XAccessibleComponent
-    // -----------------------------------------------------------------------------
-    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::containsPoint( const awt::Point& rPoint ) throw (RuntimeException)
+
+    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::containsPoint( const awt::Point& rPoint ) throw (RuntimeException, std::exception)
     {
         return Rectangle( Point(), GetBoundingBox().GetSize() ).IsInside( VCLPoint( rPoint ) );
     }
-    // -----------------------------------------------------------------------------
-    Reference< XAccessible > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleAtPoint( const awt::Point& ) throw (RuntimeException)
+
+    Reference< XAccessible > SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleAtPoint( const awt::Point& ) throw (RuntimeException, std::exception)
     {
         return Reference< XAccessible >();
     }
-    // -----------------------------------------------------------------------------
-    awt::Rectangle SAL_CALL AccessibleIconChoiceCtrlEntry::getBounds(  ) throw (RuntimeException)
+
+    awt::Rectangle SAL_CALL AccessibleIconChoiceCtrlEntry::getBounds(  ) throw (RuntimeException, std::exception)
     {
         return AWTRectangle( GetBoundingBox() );
     }
-    // -----------------------------------------------------------------------------
-    awt::Point SAL_CALL AccessibleIconChoiceCtrlEntry::getLocation(  ) throw (RuntimeException)
+
+    awt::Point SAL_CALL AccessibleIconChoiceCtrlEntry::getLocation(  ) throw (RuntimeException, std::exception)
     {
         return AWTPoint( GetBoundingBox().TopLeft() );
     }
-    // -----------------------------------------------------------------------------
-    awt::Point SAL_CALL AccessibleIconChoiceCtrlEntry::getLocationOnScreen(  ) throw (RuntimeException)
+
+    awt::Point SAL_CALL AccessibleIconChoiceCtrlEntry::getLocationOnScreen(  ) throw (RuntimeException, std::exception)
     {
         return AWTPoint( GetBoundingBoxOnScreen().TopLeft() );
     }
-    // -----------------------------------------------------------------------------
-    awt::Size SAL_CALL AccessibleIconChoiceCtrlEntry::getSize(  ) throw (RuntimeException)
+
+    awt::Size SAL_CALL AccessibleIconChoiceCtrlEntry::getSize(  ) throw (RuntimeException, std::exception)
     {
         return AWTSize( GetBoundingBox().GetSize() );
     }
-    // -----------------------------------------------------------------------------
-    void SAL_CALL AccessibleIconChoiceCtrlEntry::grabFocus(  ) throw (RuntimeException)
+
+    void SAL_CALL AccessibleIconChoiceCtrlEntry::grabFocus(  ) throw (RuntimeException, std::exception)
     {
         // do nothing, because no focus for each item
     }
-    // -----------------------------------------------------------------------------
-    sal_Int32 AccessibleIconChoiceCtrlEntry::getForeground( ) throw (RuntimeException)
+
+    sal_Int32 AccessibleIconChoiceCtrlEntry::getForeground( ) throw (RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -419,8 +411,8 @@ throw(RuntimeException)
 
         return nColor;
     }
-    // -----------------------------------------------------------------------------
-    sal_Int32 AccessibleIconChoiceCtrlEntry::getBackground(  ) throw (RuntimeException)
+
+    sal_Int32 AccessibleIconChoiceCtrlEntry::getBackground(  ) throw (RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -436,11 +428,11 @@ throw(RuntimeException)
 
         return nColor;
     }
-    // -----------------------------------------------------------------------------
+
     // XAccessibleText
-    // -----------------------------------------------------------------------------
-    // -----------------------------------------------------------------------------
-    awt::Rectangle SAL_CALL AccessibleIconChoiceCtrlEntry::getCharacterBounds( sal_Int32 _nIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+
+    awt::Rectangle SAL_CALL AccessibleIconChoiceCtrlEntry::getCharacterBounds( sal_Int32 _nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -459,8 +451,8 @@ throw(RuntimeException)
 
         return aBounds;
     }
-    // -----------------------------------------------------------------------------
-    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getIndexAtPoint( const awt::Point& aPoint ) throw (RuntimeException)
+
+    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getIndexAtPoint( const awt::Point& aPoint ) throw (RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -468,7 +460,7 @@ throw(RuntimeException)
         sal_Int32 nIndex = -1;
         if ( m_pIconCtrl )
         {
-            ::vcl::ControlLayoutData aLayoutData;
+            vcl::ControlLayoutData aLayoutData;
             Rectangle aItemRect = GetBoundingBox_Impl();
             m_pIconCtrl->RecordLayoutData( &aLayoutData, aItemRect );
             Point aPnt( VCLPoint( aPoint ) );
@@ -479,7 +471,7 @@ throw(RuntimeException)
             for ( long i = 0; i < nLen; ++i )
             {
                 Rectangle aRect = aLayoutData.GetCharacterBounds(i);
-                sal_Bool bInside = aRect.IsInside( aPnt );
+                bool bInside = aRect.IsInside( aPnt );
 
                 if ( bInside )
                     break;
@@ -488,8 +480,8 @@ throw(RuntimeException)
 
         return nIndex;
     }
-    // -----------------------------------------------------------------------------
-    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -502,12 +494,12 @@ throw(RuntimeException)
         sal_Int32 nLen = nEndIndex - nStartIndex + 1;
         ::svt::OStringTransfer::CopyString( sText.copy( nStartIndex, nLen ), m_pIconCtrl );
 
-        return sal_True;
+        return true;
     }
-    // -----------------------------------------------------------------------------
+
     // XAccessibleEventBroadcaster
-    // -----------------------------------------------------------------------------
-    void SAL_CALL AccessibleIconChoiceCtrlEntry::addAccessibleEventListener( const Reference< XAccessibleEventListener >& xListener ) throw (RuntimeException)
+
+    void SAL_CALL AccessibleIconChoiceCtrlEntry::addAccessibleEventListener( const Reference< XAccessibleEventListener >& xListener ) throw (RuntimeException, std::exception)
     {
         if (xListener.is())
         {
@@ -517,8 +509,8 @@ throw(RuntimeException)
             comphelper::AccessibleEventNotifier::addEventListener( m_nClientId, xListener );
         }
     }
-    // -----------------------------------------------------------------------------
-    void SAL_CALL AccessibleIconChoiceCtrlEntry::removeAccessibleEventListener( const Reference< XAccessibleEventListener >& xListener ) throw (RuntimeException)
+
+    void SAL_CALL AccessibleIconChoiceCtrlEntry::removeAccessibleEventListener( const Reference< XAccessibleEventListener >& xListener ) throw (RuntimeException, std::exception)
     {
         if (xListener.is())
         {
@@ -538,11 +530,11 @@ throw(RuntimeException)
         }
     }
 
-    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getCaretPosition(  ) throw (::com::sun::star::uno::RuntimeException)
+    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getCaretPosition(  ) throw (css::uno::RuntimeException, std::exception)
     {
         return -1;
     }
-    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::setCaretPosition ( sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException)
+    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::setCaretPosition ( sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -551,16 +543,16 @@ throw(RuntimeException)
         if ( !implIsValidRange( nIndex, nIndex, implGetText().getLength() ) )
             throw IndexOutOfBoundsException();
 
-        return sal_False;
+        return false;
     }
-    sal_Unicode SAL_CALL AccessibleIconChoiceCtrlEntry::getCharacter( sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException)
+    sal_Unicode SAL_CALL AccessibleIconChoiceCtrlEntry::getCharacter( sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
         EnsureIsAlive();
         return OCommonAccessibleText::getCharacter( nIndex );
     }
-    ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > SAL_CALL AccessibleIconChoiceCtrlEntry::getCharacterAttributes( sal_Int32 nIndex, const ::com::sun::star::uno::Sequence< OUString >& ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException)
+    css::uno::Sequence< css::beans::PropertyValue > SAL_CALL AccessibleIconChoiceCtrlEntry::getCharacterAttributes( sal_Int32 nIndex, const css::uno::Sequence< OUString >& ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -571,9 +563,9 @@ throw(RuntimeException)
         if ( !implIsValidIndex( nIndex, sText.getLength() ) )
             throw IndexOutOfBoundsException();
 
-        return ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >();
+        return css::uno::Sequence< css::beans::PropertyValue >();
     }
-    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getCharacterCount(  ) throw (::com::sun::star::uno::RuntimeException)
+    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getCharacterCount(  ) throw (css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -581,28 +573,28 @@ throw(RuntimeException)
         return OCommonAccessibleText::getCharacterCount(  );
     }
 
-    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getSelectedText(  ) throw (::com::sun::star::uno::RuntimeException)
+    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getSelectedText(  ) throw (css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
         EnsureIsAlive();
         return OCommonAccessibleText::getSelectedText(  );
     }
-    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getSelectionStart(  ) throw (::com::sun::star::uno::RuntimeException)
+    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getSelectionStart(  ) throw (css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
         EnsureIsAlive();
         return OCommonAccessibleText::getSelectionStart(  );
     }
-    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getSelectionEnd(  ) throw (::com::sun::star::uno::RuntimeException)
+    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getSelectionEnd(  ) throw (css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
         EnsureIsAlive();
         return OCommonAccessibleText::getSelectionEnd(  );
     }
-    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException)
+    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -611,37 +603,37 @@ throw(RuntimeException)
         if ( !implIsValidRange( nStartIndex, nEndIndex, implGetText().getLength() ) )
             throw IndexOutOfBoundsException();
 
-        return sal_False;
+        return false;
     }
-    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getText(  ) throw (::com::sun::star::uno::RuntimeException)
+    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getText(  ) throw (css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
         EnsureIsAlive();
         return OCommonAccessibleText::getText(  );
     }
-    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getTextRange( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException)
+    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getTextRange( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
         EnsureIsAlive();
         return OCommonAccessibleText::getTextRange( nStartIndex, nEndIndex );
     }
-    ::com::sun::star::accessibility::TextSegment SAL_CALL AccessibleIconChoiceCtrlEntry::getTextAtIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException)
+    css::accessibility::TextSegment SAL_CALL AccessibleIconChoiceCtrlEntry::getTextAtIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (css::lang::IndexOutOfBoundsException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
         EnsureIsAlive();
         return OCommonAccessibleText::getTextAtIndex( nIndex ,aTextType);
     }
-    ::com::sun::star::accessibility::TextSegment SAL_CALL AccessibleIconChoiceCtrlEntry::getTextBeforeIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException)
+    css::accessibility::TextSegment SAL_CALL AccessibleIconChoiceCtrlEntry::getTextBeforeIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (css::lang::IndexOutOfBoundsException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
         EnsureIsAlive();
         return OCommonAccessibleText::getTextBeforeIndex( nIndex ,aTextType);
     }
-    ::com::sun::star::accessibility::TextSegment SAL_CALL AccessibleIconChoiceCtrlEntry::getTextBehindIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException)
+    css::accessibility::TextSegment SAL_CALL AccessibleIconChoiceCtrlEntry::getTextBehindIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (css::lang::IndexOutOfBoundsException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -650,23 +642,23 @@ throw(RuntimeException)
         return OCommonAccessibleText::getTextBehindIndex( nIndex ,aTextType);
     }
 
-    // -----------------------------------------------------------------------------
+
     // XAccessibleAction
-    // -----------------------------------------------------------------------------
-    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleActionCount(  ) throw (RuntimeException)
+
+    sal_Int32 SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleActionCount(  ) throw (RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
         // three actions supported
         return ACCESSIBLE_ACTION_COUNT;
     }
-    // -----------------------------------------------------------------------------
-    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::doAccessibleAction( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    sal_Bool SAL_CALL AccessibleIconChoiceCtrlEntry::doAccessibleAction( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
 
-        sal_Bool bRet = sal_False;
+        bool bRet = false;
         checkActionIndex_Impl( nIndex );
         EnsureIsAlive();
 
@@ -675,13 +667,13 @@ throw(RuntimeException)
         {
             m_pIconCtrl->SetNoSelection();
             m_pIconCtrl->SetCursor( pEntry );
-            bRet = sal_True;
+            bRet = true;
         }
 
         return bRet;
     }
-    // -----------------------------------------------------------------------------
-    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleActionDescription( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    OUString SAL_CALL AccessibleIconChoiceCtrlEntry::getAccessibleActionDescription( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
     {
         SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -689,11 +681,10 @@ throw(RuntimeException)
         checkActionIndex_Impl( nIndex );
         EnsureIsAlive();
 
-        static const OUString sActionDesc( "Select" );
-        return sActionDesc;
+        return OUString( "Select" );
     }
-    // -----------------------------------------------------------------------------
-    Reference< XAccessibleKeyBinding > AccessibleIconChoiceCtrlEntry::getAccessibleActionKeyBinding( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    Reference< XAccessibleKeyBinding > AccessibleIconChoiceCtrlEntry::getAccessibleActionKeyBinding( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -702,8 +693,8 @@ throw(RuntimeException)
         // ... which key?
         return xRet;
     }
-//........................................................................
+
 }// namespace accessibility
-//........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
