@@ -34,9 +34,7 @@
 #include <vcl/unohelp2.hxx>
 #include <vcl/tabctrl.hxx>
 #include <vcl/tabpage.hxx>
-
-#include <memory>
-
+#include <vcl/settings.hxx>
 
 using namespace ::com::sun::star::accessibility;
 using namespace ::com::sun::star::uno;
@@ -46,9 +44,8 @@ using namespace ::com::sun::star;
 using namespace ::comphelper;
 
 
-// -----------------------------------------------------------------------------
 // class VCLXAccessibleTabPage
-// -----------------------------------------------------------------------------
+
 
 VCLXAccessibleTabPage::VCLXAccessibleTabPage( TabControl* pTabControl, sal_uInt16 nPageId )
     :AccessibleTextHelper_BASE( new VCLExternalSolarLock() )
@@ -61,15 +58,13 @@ VCLXAccessibleTabPage::VCLXAccessibleTabPage( TabControl* pTabControl, sal_uInt1
     m_sPageText = GetPageText();
 }
 
-// -----------------------------------------------------------------------------
 
 VCLXAccessibleTabPage::~VCLXAccessibleTabPage()
 {
     delete m_pExternalLock;
-    m_pExternalLock = NULL;
+    m_pExternalLock = nullptr;
 }
 
-// -----------------------------------------------------------------------------
 
 bool VCLXAccessibleTabPage::IsFocused()
 {
@@ -81,7 +76,6 @@ bool VCLXAccessibleTabPage::IsFocused()
     return bFocused;
 }
 
-// -----------------------------------------------------------------------------
 
 bool VCLXAccessibleTabPage::IsSelected()
 {
@@ -93,7 +87,6 @@ bool VCLXAccessibleTabPage::IsSelected()
     return bSelected;
 }
 
-// -----------------------------------------------------------------------------
 
 void VCLXAccessibleTabPage::SetFocused( bool bFocused )
 {
@@ -109,7 +102,6 @@ void VCLXAccessibleTabPage::SetFocused( bool bFocused )
     }
 }
 
-// -----------------------------------------------------------------------------
 
 void VCLXAccessibleTabPage::SetSelected( bool bSelected )
 {
@@ -125,7 +117,6 @@ void VCLXAccessibleTabPage::SetSelected( bool bSelected )
     }
 }
 
-// -----------------------------------------------------------------------------
 
 void VCLXAccessibleTabPage::SetPageText( const OUString& sPageText )
 {
@@ -141,7 +132,6 @@ void VCLXAccessibleTabPage::SetPageText( const OUString& sPageText )
     }
 }
 
-// -----------------------------------------------------------------------------
 
 OUString VCLXAccessibleTabPage::GetPageText()
 {
@@ -152,7 +142,6 @@ OUString VCLXAccessibleTabPage::GetPageText()
     return sText;
 }
 
-// -----------------------------------------------------------------------------
 
 void VCLXAccessibleTabPage::Update( bool bNew )
 {
@@ -175,7 +164,6 @@ void VCLXAccessibleTabPage::Update( bool bNew )
     }
 }
 
-// -----------------------------------------------------------------------------
 
 void VCLXAccessibleTabPage::FillAccessibleStateSet( utl::AccessibleStateSetHelper& rStateSet )
 {
@@ -197,9 +185,9 @@ void VCLXAccessibleTabPage::FillAccessibleStateSet( utl::AccessibleStateSetHelpe
         rStateSet.AddState( AccessibleStateType::SELECTED );
 }
 
-// -----------------------------------------------------------------------------
+
 // OCommonAccessibleComponent
-// -----------------------------------------------------------------------------
+
 
 awt::Rectangle VCLXAccessibleTabPage::implGetBounds() throw (RuntimeException)
 {
@@ -211,23 +199,21 @@ awt::Rectangle VCLXAccessibleTabPage::implGetBounds() throw (RuntimeException)
     return aBounds;
 }
 
-// -----------------------------------------------------------------------------
+
 // OCommonAccessibleText
-// -----------------------------------------------------------------------------
+
 
 OUString VCLXAccessibleTabPage::implGetText()
 {
     return GetPageText();
 }
 
-// -----------------------------------------------------------------------------
 
 lang::Locale VCLXAccessibleTabPage::implGetLocale()
 {
     return Application::GetSettings().GetLanguageTag().getLocale();
 }
 
-// -----------------------------------------------------------------------------
 
 void VCLXAccessibleTabPage::implGetSelection( sal_Int32& nStartIndex, sal_Int32& nEndIndex )
 {
@@ -235,71 +221,68 @@ void VCLXAccessibleTabPage::implGetSelection( sal_Int32& nStartIndex, sal_Int32&
     nEndIndex = 0;
 }
 
-// -----------------------------------------------------------------------------
+
 // XInterface
-// -----------------------------------------------------------------------------
+
 
 IMPLEMENT_FORWARD_XINTERFACE2( VCLXAccessibleTabPage, AccessibleTextHelper_BASE, VCLXAccessibleTabPage_BASE )
 
-// -----------------------------------------------------------------------------
+
 // XTypeProvider
-// -----------------------------------------------------------------------------
+
 
 IMPLEMENT_FORWARD_XTYPEPROVIDER2( VCLXAccessibleTabPage, AccessibleTextHelper_BASE, VCLXAccessibleTabPage_BASE )
 
-// -----------------------------------------------------------------------------
+
 // XComponent
-// -----------------------------------------------------------------------------
+
 
 void VCLXAccessibleTabPage::disposing()
 {
     AccessibleTextHelper_BASE::disposing();
 
-    m_pTabControl = NULL;
-    m_sPageText = OUString();
+    m_pTabControl = nullptr;
+    m_sPageText.clear();
 }
 
-// -----------------------------------------------------------------------------
-// XServiceInfo
-// -----------------------------------------------------------------------------
 
-OUString VCLXAccessibleTabPage::getImplementationName() throw (RuntimeException)
+// XServiceInfo
+
+
+OUString VCLXAccessibleTabPage::getImplementationName() throw (RuntimeException, std::exception)
 {
     return OUString( "com.sun.star.comp.toolkit.AccessibleTabPage" );
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Bool VCLXAccessibleTabPage::supportsService( const OUString& rServiceName ) throw (RuntimeException)
+sal_Bool VCLXAccessibleTabPage::supportsService( const OUString& rServiceName ) throw (RuntimeException, std::exception)
 {
     return cppu::supportsService(this, rServiceName);
 }
 
-// -----------------------------------------------------------------------------
 
-Sequence< OUString > VCLXAccessibleTabPage::getSupportedServiceNames() throw (RuntimeException)
+Sequence< OUString > VCLXAccessibleTabPage::getSupportedServiceNames() throw (RuntimeException, std::exception)
 {
-    Sequence< OUString > aNames(1);
-    aNames[0] = "com.sun.star.awt.AccessibleTabPage";
+    Sequence< OUString > aNames { "com.sun.star.awt.AccessibleTabPage" };
     return aNames;
 }
 
-// -----------------------------------------------------------------------------
-// XAccessible
-// -----------------------------------------------------------------------------
 
-Reference< XAccessibleContext > VCLXAccessibleTabPage::getAccessibleContext(  ) throw (RuntimeException)
+// XAccessible
+
+
+Reference< XAccessibleContext > VCLXAccessibleTabPage::getAccessibleContext(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return this;
 }
 
-// -----------------------------------------------------------------------------
-// XAccessibleContext
-// -----------------------------------------------------------------------------
 
-sal_Int32 VCLXAccessibleTabPage::getAccessibleChildCount() throw (RuntimeException)
+// XAccessibleContext
+
+
+sal_Int32 VCLXAccessibleTabPage::getAccessibleChildCount() throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -314,9 +297,8 @@ sal_Int32 VCLXAccessibleTabPage::getAccessibleChildCount() throw (RuntimeExcepti
     return nCount;
 }
 
-// -----------------------------------------------------------------------------
 
-Reference< XAccessible > VCLXAccessibleTabPage::getAccessibleChild( sal_Int32 i ) throw (IndexOutOfBoundsException, RuntimeException)
+Reference< XAccessible > VCLXAccessibleTabPage::getAccessibleChild( sal_Int32 i ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -334,9 +316,8 @@ Reference< XAccessible > VCLXAccessibleTabPage::getAccessibleChild( sal_Int32 i
     return xChild;
 }
 
-// -----------------------------------------------------------------------------
 
-Reference< XAccessible > VCLXAccessibleTabPage::getAccessibleParent(  ) throw (RuntimeException)
+Reference< XAccessible > VCLXAccessibleTabPage::getAccessibleParent(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -347,9 +328,8 @@ Reference< XAccessible > VCLXAccessibleTabPage::getAccessibleParent(  ) throw (R
     return xParent;
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Int32 VCLXAccessibleTabPage::getAccessibleIndexInParent(  ) throw (RuntimeException)
+sal_Int32 VCLXAccessibleTabPage::getAccessibleIndexInParent(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -360,18 +340,16 @@ sal_Int32 VCLXAccessibleTabPage::getAccessibleIndexInParent(  ) throw (RuntimeEx
     return nIndexInParent;
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Int16 VCLXAccessibleTabPage::getAccessibleRole(  ) throw (RuntimeException)
+sal_Int16 VCLXAccessibleTabPage::getAccessibleRole(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return AccessibleRole::PAGE_TAB;
 }
 
-// -----------------------------------------------------------------------------
 
-OUString VCLXAccessibleTabPage::getAccessibleDescription(    ) throw (RuntimeException)
+OUString VCLXAccessibleTabPage::getAccessibleDescription(    ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -382,18 +360,16 @@ OUString VCLXAccessibleTabPage::getAccessibleDescription(    ) throw (RuntimeExc
     return sDescription;
 }
 
-// -----------------------------------------------------------------------------
 
-OUString VCLXAccessibleTabPage::getAccessibleName(  ) throw (RuntimeException)
+OUString VCLXAccessibleTabPage::getAccessibleName(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return GetPageText();
 }
 
-// -----------------------------------------------------------------------------
 
-Reference< XAccessibleRelationSet > VCLXAccessibleTabPage::getAccessibleRelationSet(  ) throw (RuntimeException)
+Reference< XAccessibleRelationSet > VCLXAccessibleTabPage::getAccessibleRelationSet(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -402,9 +378,8 @@ Reference< XAccessibleRelationSet > VCLXAccessibleTabPage::getAccessibleRelation
     return xSet;
 }
 
-// -----------------------------------------------------------------------------
 
-Reference< XAccessibleStateSet > VCLXAccessibleTabPage::getAccessibleStateSet(  ) throw (RuntimeException)
+Reference< XAccessibleStateSet > VCLXAccessibleTabPage::getAccessibleStateSet(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -423,20 +398,19 @@ Reference< XAccessibleStateSet > VCLXAccessibleTabPage::getAccessibleStateSet(
     return xSet;
 }
 
-// -----------------------------------------------------------------------------
 
-Locale VCLXAccessibleTabPage::getLocale(  ) throw (IllegalAccessibleComponentStateException, RuntimeException)
+Locale VCLXAccessibleTabPage::getLocale(  ) throw (IllegalAccessibleComponentStateException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return Application::GetSettings().GetLanguageTag().getLocale();
 }
 
-// -----------------------------------------------------------------------------
-// XAccessibleComponent
-// -----------------------------------------------------------------------------
 
-Reference< XAccessible > VCLXAccessibleTabPage::getAccessibleAtPoint( const awt::Point& rPoint ) throw (RuntimeException)
+// XAccessibleComponent
+
+
+Reference< XAccessible > VCLXAccessibleTabPage::getAccessibleAtPoint( const awt::Point& rPoint ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -463,9 +437,8 @@ Reference< XAccessible > VCLXAccessibleTabPage::getAccessibleAtPoint( const awt:
     return xChild;
 }
 
-// -----------------------------------------------------------------------------
 
-void VCLXAccessibleTabPage::grabFocus(  ) throw (RuntimeException)
+void VCLXAccessibleTabPage::grabFocus(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -476,9 +449,8 @@ void VCLXAccessibleTabPage::grabFocus(  ) throw (RuntimeException)
     }
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Int32 VCLXAccessibleTabPage::getForeground( ) throw (RuntimeException)
+sal_Int32 VCLXAccessibleTabPage::getForeground( ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -494,9 +466,8 @@ sal_Int32 VCLXAccessibleTabPage::getForeground( ) throw (RuntimeException)
     return nColor;
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Int32 VCLXAccessibleTabPage::getBackground(  ) throw (RuntimeException)
+sal_Int32 VCLXAccessibleTabPage::getBackground(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -512,11 +483,11 @@ sal_Int32 VCLXAccessibleTabPage::getBackground(  ) throw (RuntimeException)
     return nColor;
 }
 
-// -----------------------------------------------------------------------------
-// XAccessibleExtendedComponent
-// -----------------------------------------------------------------------------
 
-Reference< awt::XFont > VCLXAccessibleTabPage::getFont(  ) throw (RuntimeException)
+// XAccessibleExtendedComponent
+
+
+Reference< awt::XFont > VCLXAccessibleTabPage::getFont(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -532,50 +503,46 @@ Reference< awt::XFont > VCLXAccessibleTabPage::getFont(  ) throw (RuntimeExcepti
     return xFont;
 }
 
-// -----------------------------------------------------------------------------
 
-OUString VCLXAccessibleTabPage::getTitledBorderText(  ) throw (RuntimeException)
+OUString VCLXAccessibleTabPage::getTitledBorderText(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return OUString();
 }
 
-// -----------------------------------------------------------------------------
 
-OUString VCLXAccessibleTabPage::getToolTipText(  ) throw (RuntimeException)
+OUString VCLXAccessibleTabPage::getToolTipText(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return OUString();
 }
 
-// -----------------------------------------------------------------------------
+
 // XAccessibleText
-// -----------------------------------------------------------------------------
 
-sal_Int32 VCLXAccessibleTabPage::getCaretPosition() throw (RuntimeException)
+
+sal_Int32 VCLXAccessibleTabPage::getCaretPosition() throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return -1;
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Bool VCLXAccessibleTabPage::setCaretPosition( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+sal_Bool VCLXAccessibleTabPage::setCaretPosition( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     if ( !implIsValidRange( nIndex, nIndex, implGetText().getLength() ) )
         throw IndexOutOfBoundsException();
 
-    return sal_False;
+    return false;
 }
 
-// -----------------------------------------------------------------------------
 
-Sequence< PropertyValue > VCLXAccessibleTabPage::getCharacterAttributes( sal_Int32 nIndex, const Sequence< OUString >& aRequestedAttributes ) throw (IndexOutOfBoundsException, RuntimeException)
+Sequence< PropertyValue > VCLXAccessibleTabPage::getCharacterAttributes( sal_Int32 nIndex, const Sequence< OUString >& aRequestedAttributes ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -587,19 +554,18 @@ Sequence< PropertyValue > VCLXAccessibleTabPage::getCharacterAttributes( sal_Int
 
     if ( m_pTabControl )
     {
-        Font aFont = m_pTabControl->GetFont();
+        vcl::Font aFont = m_pTabControl->GetFont();
         sal_Int32 nBackColor = getBackground();
         sal_Int32 nColor = getForeground();
-        ::std::auto_ptr< CharacterAttributesHelper > pHelper( new CharacterAttributesHelper( aFont, nBackColor, nColor ) );
-        aValues = pHelper->GetCharacterAttributes( aRequestedAttributes );
+        aValues = CharacterAttributesHelper( aFont, nBackColor, nColor )
+            .GetCharacterAttributes( aRequestedAttributes );
     }
 
     return aValues;
 }
 
-// -----------------------------------------------------------------------------
 
-awt::Rectangle VCLXAccessibleTabPage::getCharacterBounds( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+awt::Rectangle VCLXAccessibleTabPage::getCharacterBounds( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -618,9 +584,8 @@ awt::Rectangle VCLXAccessibleTabPage::getCharacterBounds( sal_Int32 nIndex ) thr
     return aBounds;
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Int32 VCLXAccessibleTabPage::getIndexAtPoint( const awt::Point& aPoint ) throw (RuntimeException)
+sal_Int32 VCLXAccessibleTabPage::getIndexAtPoint( const awt::Point& aPoint ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -639,25 +604,23 @@ sal_Int32 VCLXAccessibleTabPage::getIndexAtPoint( const awt::Point& aPoint ) thr
     return nIndex;
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Bool VCLXAccessibleTabPage::setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+sal_Bool VCLXAccessibleTabPage::setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     if ( !implIsValidRange( nStartIndex, nEndIndex, implGetText().getLength() ) )
         throw IndexOutOfBoundsException();
 
-    return sal_False;
+    return false;
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Bool VCLXAccessibleTabPage::copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+sal_Bool VCLXAccessibleTabPage::copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
-    sal_Bool bReturn = sal_False;
+    bool bReturn = false;
 
     if ( m_pTabControl )
     {
@@ -666,23 +629,21 @@ sal_Bool VCLXAccessibleTabPage::copyText( sal_Int32 nStartIndex, sal_Int32 nEndI
         {
             OUString sText( getTextRange( nStartIndex, nEndIndex ) );
 
-            ::vcl::unohelper::TextDataObject* pDataObj = new ::vcl::unohelper::TextDataObject( sText );
-            const sal_uInt32 nRef = Application::ReleaseSolarMutex();
-            xClipboard->setContents( pDataObj, NULL );
+            vcl::unohelper::TextDataObject* pDataObj = new vcl::unohelper::TextDataObject( sText );
+
+            SolarMutexReleaser aReleaser;
+            xClipboard->setContents( pDataObj, nullptr );
 
             Reference< datatransfer::clipboard::XFlushableClipboard > xFlushableClipboard( xClipboard, uno::UNO_QUERY );
             if( xFlushableClipboard.is() )
                 xFlushableClipboard->flushClipboard();
 
-            Application::AcquireSolarMutex( nRef );
-
-            bReturn = sal_True;
+            bReturn = true;
         }
     }
 
     return bReturn;
 }
 
-// -----------------------------------------------------------------------------
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
