@@ -39,8 +39,9 @@
 #include <com/sun/star/lang/XComponent.hpp>
 #include <com/sun/star/media/XManager.hpp>
 #include <vcl/sysdata.hxx>
+#if HAVE_FEATURE_OPENGL
 #include <vcl/opengl/OpenGLContext.hxx>
-
+#endif
 using namespace ::com::sun::star;
 
 namespace avmedia { namespace priv {
@@ -117,7 +118,7 @@ void MediaChildWindow::KeyUp( const KeyEvent& rKEvt )
 void MediaChildWindow::Command( const CommandEvent& rCEvt )
 {
     const CommandEvent aTransformedEvent( GetParent()->ScreenToOutputPixel( OutputToScreenPixel( rCEvt.GetMousePosPixel() ) ),
-                                            rCEvt.GetCommand(), rCEvt.IsMouseEvent(), rCEvt.GetEventData() );
+                                          rCEvt.GetCommand(), rCEvt.IsMouseEvent(), rCEvt.GetEventData() );
 
     SystemChildWindow::Command( rCEvt );
     GetParent()->Command( aTransformedEvent );
@@ -223,10 +224,12 @@ uno::Reference<media::XPlayer> MediaWindowImpl::createPlayer(const OUString& rUR
         }
     }
 #if HAVE_FEATURE_GLTF
+#if HAVE_FEATURE_OPENGL
     else if ( *pMimeType == AVMEDIA_MIMETYPE_JSON )
     {
         xPlayer = createPlayer(rURL, AVMEDIA_OPENGL_MANAGER_SERVICE_NAME, xContext);
     }
+#endif
 #endif
 
     return xPlayer;
@@ -234,7 +237,7 @@ uno::Reference<media::XPlayer> MediaWindowImpl::createPlayer(const OUString& rUR
 
 uno::Reference< media::XPlayer > MediaWindowImpl::createPlayer(
     const OUString& rURL, const OUString& rManagerServName,
-    uno::Reference< uno::XComponentContext > xContext)
+    const uno::Reference< uno::XComponentContext >& xContext)
 {
     uno::Reference< media::XPlayer > xPlayer;
     try
@@ -486,7 +489,7 @@ void MediaWindowImpl::onURLChanged()
 #if HAVE_FEATURE_GLTF
     else if (m_sMimeType == AVMEDIA_MIMETYPE_JSON)
     {
-        SystemWindowData aWinData = OpenGLContext::generateWinData(this, false);
+        SystemWindowData aWinData = OpenGLContext::Create()->generateWinData(this, false);
         mpChildWindow.disposeAndClear();
         mpChildWindow.reset(VclPtr<MediaChildWindow>::Create(this,&aWinData));
         mbEventTransparent = false;
