@@ -168,7 +168,7 @@ void LocalizationMgr::implEnableDisableResourceForAllLibraryDialogs( HandleResou
 OUString implCreatePureResourceId
     ( const OUString& aDialogName, const OUString& aCtrlName,
       const OUString& aPropName,
-      Reference< XStringResourceManager > xStringResourceManager )
+      const Reference< XStringResourceManager >& xStringResourceManager )
 {
     sal_Int32 nUniqueId = xStringResourceManager->getUniqueNumericId();
     OUString aPureIdStr = OUString::number( nUniqueId );
@@ -189,8 +189,8 @@ OUString implCreatePureResourceId
 // either the first one for mode SET_IDS or the last one for mode RESET_IDS
 sal_Int32 LocalizationMgr::implHandleControlResourceProperties
     (const Any& rControlAny, const OUString& aDialogName, const OUString& aCtrlName,
-        Reference< XStringResourceManager > xStringResourceManager,
-        Reference< XStringResourceResolver > xSourceStringResolver, HandleResourceMode eMode )
+        const Reference< XStringResourceManager >& xStringResourceManager,
+        const Reference< XStringResourceResolver >& xSourceStringResolver, HandleResourceMode eMode )
 {
     sal_Int32 nChangedCount = 0;
 
@@ -247,12 +247,10 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             xStringResourceManager->setStringForLocale( aPureIdStr, aPropStr, rLocale );
                         }
 
-                        OUString aPropIdStr = aEsc;
-                        aPropIdStr += aPureIdStr;
+                        OUString aPropIdStr = aEsc + aPureIdStr;
                         // TODO?: Change here and in toolkit
                         (void)aSemi;
-                        aPropAny <<= aPropIdStr;
-                        xPropertySet->setPropertyValue( aPropName, aPropAny );
+                        xPropertySet->setPropertyValue( aPropName, Any(aPropIdStr) );
                     }
                     // Replace id by string from StringResource
                     else if( eMode == RESET_IDS )
@@ -268,8 +266,7 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             catch(const MissingResourceException&)
                             {
                             }
-                            aPropAny <<= aNewPropStr;
-                            xPropertySet->setPropertyValue( aPropName, aPropAny );
+                            xPropertySet->setPropertyValue( aPropName, Any(aNewPropStr) );
                         }
                     }
                     // Remove Id for all locales
@@ -296,8 +293,7 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                     // Rename resource id
                     else if( eMode == RENAME_DIALOG_IDS || eMode == RENAME_CONTROL_IDS )
                     {
-                        OUString aSourceIdStr = aPropStr;
-                        OUString aPureSourceIdStr = aSourceIdStr.copy( 1 );
+                        OUString aPureSourceIdStr = aPropStr.copy( 1 );
 
                         OUString aPureIdStr = implCreatePureResourceId
                             ( aDialogName, aCtrlName, aPropName, xStringResourceManager );
@@ -319,18 +315,15 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             {}
                         }
 
-                        OUString aPropIdStr = aEsc;
-                        aPropIdStr += aPureIdStr;
+                        OUString aPropIdStr = aEsc + aPureIdStr;
                         // TODO?: Change here and in toolkit
                         (void)aSemi;
-                        aPropAny <<= aPropIdStr;
-                        xPropertySet->setPropertyValue( aPropName, aPropAny );
+                        xPropertySet->setPropertyValue( aPropName, Any(aPropIdStr) );
                     }
                     // Replace string by string from source StringResourceResolver
                     else if( eMode == MOVE_RESOURCES && xSourceStringResolver.is() )
                     {
-                        OUString aSourceIdStr = aPropStr;
-                        OUString aPureSourceIdStr = aSourceIdStr.copy( 1 );
+                        OUString aPureSourceIdStr = aPropStr.copy( 1 );
 
                         OUString aPureIdStr = implCreatePureResourceId
                             ( aDialogName, aCtrlName, aPropName, xStringResourceManager );
@@ -356,18 +349,15 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             xStringResourceManager->setStringForLocale( aPureIdStr, aResStr, rLocale );
                         }
 
-                        OUString aPropIdStr = aEsc;
-                        aPropIdStr += aPureIdStr;
+                        OUString aPropIdStr = aEsc + aPureIdStr;
                         // TODO?: Change here and in toolkit
                         (void)aSemi;
-                        aPropAny <<= aPropIdStr;
-                        xPropertySet->setPropertyValue( aPropName, aPropAny );
+                        xPropertySet->setPropertyValue( aPropName, Any(aPropIdStr) );
                     }
                     // Copy string from source to target resource
                     else if( eMode == COPY_RESOURCES && xSourceStringResolver.is() )
                     {
-                        OUString aSourceIdStr = aPropStr;
-                        OUString aPureSourceIdStr = aSourceIdStr.copy( 1 );
+                        OUString aPureSourceIdStr = aPropStr.copy( 1 );
 
                         const Locale& rDefaultLocale = xSourceStringResolver->getDefaultLocale();
 
@@ -444,8 +434,7 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             aPropIdStr += aPureIdStr;
                             pIdStrings[i] = aPropIdStr;
                         }
-                        aPropAny <<= aIdStrings;
-                        xPropertySet->setPropertyValue( aPropName, aPropAny );
+                        xPropertySet->setPropertyValue( aPropName, Any(aIdStrings) );
                     }
                     // Replace id by string from StringResource
                     else if( eMode == RESET_IDS )
@@ -472,8 +461,7 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             }
                             pNewPropStrings[i] = aNewPropStr;
                         }
-                        aPropAny <<= aNewPropStrings;
-                        xPropertySet->setPropertyValue( aPropName, aPropAny );
+                        xPropertySet->setPropertyValue( aPropName, Any(aNewPropStrings) );
                     }
                     // Remove Id for all locales
                     else if( eMode == REMOVE_IDS_FROM_RESOURCE )
@@ -548,8 +536,7 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             aPropIdStr += aPureIdStr;
                             pIdStrings[i] = aPropIdStr;
                         }
-                        aPropAny <<= aIdStrings;
-                        xPropertySet->setPropertyValue( aPropName, aPropAny );
+                        xPropertySet->setPropertyValue( aPropName, Any(aIdStrings) );
                     }
                     // Replace string by string from source StringResourceResolver
                     else if( eMode == MOVE_RESOURCES && xSourceStringResolver.is() )
@@ -599,8 +586,7 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             aPropIdStr += aPureIdStr;
                             pIdStrings[i] = aPropIdStr;
                         }
-                        aPropAny <<= aIdStrings;
-                        xPropertySet->setPropertyValue( aPropName, aPropAny );
+                        xPropertySet->setPropertyValue( aPropName, Any(aIdStrings) );
                     }
                     // Copy string from source to target resource
                     else if( eMode == COPY_RESOURCES && xSourceStringResolver.is() )
@@ -899,7 +885,7 @@ void LocalizationMgr::deleteControlResourceIDsForDeletedEditorObject( DlgEditor*
 }
 
 void LocalizationMgr::setStringResourceAtDialog( const ScriptDocument& rDocument, const OUString& aLibName,
-    const OUString& aDlgName, Reference< container::XNameContainer > xDialogModel )
+    const OUString& aDlgName, const Reference< container::XNameContainer >& xDialogModel )
 {
     static const char aResourceResolverPropName[] = "ResourceResolver";
 
@@ -924,14 +910,12 @@ void LocalizationMgr::setStringResourceAtDialog( const ScriptDocument& rDocument
         }
 
         Reference< beans::XPropertySet > xDlgPSet( xDialogModel, UNO_QUERY );
-        Any aStringResourceManagerAny;
-        aStringResourceManagerAny <<= xStringResourceManager;
-        xDlgPSet->setPropertyValue( aResourceResolverPropName, aStringResourceManagerAny );
+        xDlgPSet->setPropertyValue( aResourceResolverPropName, Any(xStringResourceManager) );
     }
 }
 
 void LocalizationMgr::renameStringResourceIDs( const ScriptDocument& rDocument, const OUString& aLibName,
-    const OUString& aDlgName, Reference< container::XNameContainer > xDialogModel )
+    const OUString& aDlgName, const Reference< container::XNameContainer >& xDialogModel )
 {
     // Get library
     Reference< container::XNameContainer > xDialogLib( rDocument.getLibrary( E_DIALOGS, aLibName, true ) );
@@ -962,7 +946,7 @@ void LocalizationMgr::renameStringResourceIDs( const ScriptDocument& rDocument,
 }
 
 void LocalizationMgr::removeResourceForDialog( const ScriptDocument& rDocument, const OUString& aLibName,
-    const OUString& aDlgName, Reference< container::XNameContainer > xDialogModel )
+    const OUString& aDlgName, const Reference< container::XNameContainer >& xDialogModel )
 {
     // Get library
     Reference< container::XNameContainer > xDialogLib( rDocument.getLibrary( E_DIALOGS, aLibName, true ) );
@@ -992,8 +976,8 @@ void LocalizationMgr::removeResourceForDialog( const ScriptDocument& rDocument,
     }
 }
 
-void LocalizationMgr::resetResourceForDialog( Reference< container::XNameContainer > xDialogModel,
-    Reference< XStringResourceManager > xStringResourceManager )
+void LocalizationMgr::resetResourceForDialog( const Reference< container::XNameContainer >& xDialogModel,
+    const Reference< XStringResourceManager >& xStringResourceManager )
 {
     if( !xStringResourceManager.is() )
         return;
@@ -1019,8 +1003,8 @@ void LocalizationMgr::resetResourceForDialog( Reference< container::XNameContain
     }
 }
 
-void LocalizationMgr::setResourceIDsForDialog( Reference< container::XNameContainer > xDialogModel,
-    Reference< XStringResourceManager > xStringResourceManager )
+void LocalizationMgr::setResourceIDsForDialog( const Reference< container::XNameContainer >& xDialogModel,
+    const Reference< XStringResourceManager >& xStringResourceManager )
 {
     if( !xStringResourceManager.is() )
         return;
@@ -1048,7 +1032,7 @@ void LocalizationMgr::setResourceIDsForDialog( Reference< container::XNameContai
 
 void LocalizationMgr::copyResourcesForPastedEditorObject( DlgEditor* pEditor,
     const Any& rControlAny, const OUString& aCtrlName,
-    Reference< XStringResourceResolver > xSourceStringResolver )
+    const Reference< XStringResourceResolver >& xSourceStringResolver )
 {
     // Get library for DlgEditor
     DialogWindow* pDlgWin = FindDialogWindowForEditor( pEditor );
@@ -1073,9 +1057,9 @@ void LocalizationMgr::copyResourcesForPastedEditorObject( DlgEditor* pEditor,
           xSourceStringResolver, MOVE_RESOURCES );
 }
 
-void LocalizationMgr::copyResourceForDroppedDialog( Reference< container::XNameContainer > xDialogModel,
-    const OUString& aDialogName, Reference< XStringResourceManager > xStringResourceManager,
-    Reference< XStringResourceResolver > xSourceStringResolver )
+void LocalizationMgr::copyResourceForDroppedDialog( const Reference< container::XNameContainer >& xDialogModel,
+    const OUString& aDialogName, const Reference< XStringResourceManager >& xStringResourceManager,
+    const Reference< XStringResourceResolver >& xSourceStringResolver )
 {
     if( !xStringResourceManager.is() )
         return;
@@ -1129,7 +1113,7 @@ void LocalizationMgr::copyResourceForDialog(
 }
 
 Reference< XStringResourceManager > LocalizationMgr::getStringResourceFromDialogLibrary
-    ( Reference< container::XNameContainer > xDialogLib )
+    ( const Reference< container::XNameContainer >& xDialogLib )
 {
     Reference< XStringResourceManager > xStringResourceManager;
     if( xDialogLib.is() )
