@@ -19,9 +19,9 @@
 
 #include <sal/config.h>
 
-#if defined(WNT)
-#include <windows.h>
-#undef GetObject
+#if defined(_WIN32)
+#include <prewin.h>
+#include <postwin.h>
 #endif
 
 #include <algorithm>
@@ -33,6 +33,7 @@
 #include <basic/sbx.hxx>
 #include <basic/sbxvar.hxx>
 #include <osl/thread.h>
+#include <osl/diagnose.h>
 #include <rtl/ref.hxx>
 #include <rtl/string.hxx>
 #include <rtl/ustring.hxx>
@@ -100,8 +101,12 @@ struct StringData: public UnmarshalData {
     bool special;
 };
 
-class MarshalData: private boost::noncopyable {
+class MarshalData {
 public:
+    MarshalData() = default;
+    MarshalData(const MarshalData&) = delete;
+    const MarshalData& operator=(const MarshalData&) = delete;
+
     std::vector< char > * newBlob() {
         blobs_.push_front(std::vector< char >());
         return &blobs_.front();
@@ -152,7 +157,7 @@ std::size_t alignment(SbxVariable * variable) {
         case SbxOBJECT:
             {
                 std::size_t n = 1;
-                SbxArray * props = PTR_CAST(SbxObject, variable->GetObject())->
+                SbxArray * props = dynamic_cast<SbxObject*>( variable->GetObject() )->
                     GetProperties();
                 for (sal_uInt16 i = 0; i < props->Count(); ++i) {
                     n = std::max(n, alignment(props->Get(i)));
@@ -167,7 +172,7 @@ std::size_t alignment(SbxVariable * variable) {
             return 1;
         }
     } else {
-        SbxDimArray * arr = PTR_CAST(SbxDimArray, variable->GetObject());
+        SbxDimArray * arr = dynamic_cast<SbxDimArray*>( variable->GetObject() );
         int dims = arr->GetDims();
         std::vector< sal_Int32 > low(dims);
         for (int i = 0; i < dims; ++i) {
@@ -203,7 +208,7 @@ SbError marshalStruct(
     MarshalData & data)
 {
     OSL_ASSERT(variable != 0);
-    SbxArray * props = PTR_CAST(SbxObject, variable->GetObject())->
+    SbxArray * props = dynamic_cast<SbxObject*>( variable->GetObject() )->
         GetProperties();
     for (sal_uInt16 i = 0; i < props->Count(); ++i) {
         SbError e = marshal(false, props->Get(i), false, blob, offset, data);
@@ -219,7 +224,7 @@ SbError marshalArray(
     MarshalData & data)
 {
     OSL_ASSERT(variable != 0);
-    SbxDimArray * arr = PTR_CAST(SbxDimArray, variable->GetObject());
+    SbxDimArray * arr = dynamic_cast<SbxDimArray*>( variable->GetObject() );
     int dims = arr->GetDims();
     std::vector< sal_Int32 > low(dims);
     std::vector< sal_Int32 > up(dims);
@@ -251,7 +256,7 @@ SbError marshal(
     std::vector< char > & blob, std::size_t offset, MarshalData & data)
 {
     OSL_ASSERT(variable != 0);
-    if ((variable->GetFlags() & SBX_REFERENCE) == 0) {
+    if (!(variable->GetFlags() & SbxFlagBits::Reference)) {
         if ((variable->GetType() & SbxARRAY) == 0) {
             switch (variable->GetType()) {
             case SbxINTEGER:
@@ -389,7 +394,7 @@ void const * unmarshal(SbxVariable * variable, void const * data) {
                     align(
                         reinterpret_cast< sal_uIntPtr >(data),
                         alignment(variable)));
-                SbxArray * props = PTR_CAST(SbxObject, variable->GetObject())->
+                SbxArray * props = dynamic_cast<SbxObject*>( variable->GetObject() )->
                     GetProperties();
                 for (sal_uInt16 i = 0; i < props->Count(); ++i) {
                     data = unmarshal(props->Get(i), data);
@@ -407,7 +412,7 @@ void const * unmarshal(SbxVariable * variable, void const * data) {
             break;
         }
     } else {
-        SbxDimArray * arr = PTR_CAST(SbxDimArray, variable->GetObject());
+        SbxDimArray * arr = dynamic_cast<SbxDimArray*>( variable->GetObject() );
         int dims = arr->GetDims();
         std::vector< sal_Int32 > low(dims);
         std::vector< sal_Int32 > up(dims);
@@ -595,7 +600,7 @@ SbError call(
         break;
     }
     for (int i = 1; i < (arguments == 0 ? 0 : arguments->Count()); ++i) {
-        arguments->Get(i)->ResetFlag(SBX_REFERENCE);
+        arguments->Get(i)->ResetFlag(SbxFlagBits::Reference);
             //TODO: skipped for errors?!?
     }
     for (std::vector< UnmarshalData >::iterator i(data.unmarshal.begin());
@@ -712,11 +717,15 @@ OUString fullDllName(OUString const & name) {
 
 }
 
-struct SbiDllMgr::Impl: private boost::noncopyable {
+struct SbiDllMgr::Impl{
 private:
     typedef std::map< OUString, ::rtl::Reference< Dll > > Dlls;
 
 public:
+    Impl() = default;
+    Impl(const Impl&) = delete;
+    const Impl& operator=(const Impl&) = delete;
+    
     Dll * getDll(OUString const & name);
 
     Dlls dlls;
