@@ -44,7 +44,7 @@ bool ChartTypeHelper::isSupportingAxisSideBySide(
     {
         bool bFound=false;
         bool bAmbiguous=false;
-        StackMode eStackMode = DiagramHelper::getStackModeFromChartType( xChartType, bFound, bAmbiguous, 0 );
+        StackMode eStackMode = DiagramHelper::getStackModeFromChartType( xChartType, bFound, bAmbiguous, nullptr );
         if( eStackMode == StackMode_NONE && !bAmbiguous )
         {
             OUString aChartTypeName = xChartType->getChartType();
@@ -56,7 +56,7 @@ bool ChartTypeHelper::isSupportingAxisSideBySide(
     return bResult;
 }
 
-sal_Bool ChartTypeHelper::isSupportingGeometryProperties( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
+bool ChartTypeHelper::isSupportingGeometryProperties( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
 {
     //form tab only for 3D-bar and 3D-column charts.
 
@@ -66,16 +66,16 @@ sal_Bool ChartTypeHelper::isSupportingGeometryProperties( const uno::Reference<
         if(nDimensionCount==3)
         {
             OUString aChartTypeName = xChartType->getChartType();
-            if( aChartTypeName.equals(CHART2_SERVICE_NAME_CHARTTYPE_BAR) )
-                return sal_True;
-            if( aChartTypeName.equals(CHART2_SERVICE_NAME_CHARTTYPE_COLUMN) )
-                return sal_True;
+            if( aChartTypeName == CHART2_SERVICE_NAME_CHARTTYPE_BAR )
+                return true;
+            if( aChartTypeName == CHART2_SERVICE_NAME_CHARTTYPE_COLUMN )
+                return true;
         }
     }
-    return sal_False;
+    return false;
 }
 
-sal_Bool ChartTypeHelper::isSupportingStatisticProperties( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
+bool ChartTypeHelper::isSupportingStatisticProperties( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
 {
     //3D charts, pie, net and stock do not support statistic properties
 
@@ -83,30 +83,30 @@ sal_Bool ChartTypeHelper::isSupportingStatisticProperties( const uno::Reference<
     if(xChartType.is())
     {
         if(nDimensionCount==3)
-            return sal_False;
+            return false;
 
         OUString aChartTypeName = xChartType->getChartType();
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_PIE) )
-            return sal_False;
+            return false;
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_NET) )
-            return sal_False;
+            return false;
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_FILLED_NET) )
-            return sal_False;
+            return false;
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_CANDLESTICK) )
-            return sal_False;
+            return false;
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_BUBBLE) ) //todo: BubbleChart support error bars and trend lines
-            return sal_False;
+            return false;
     }
-    return sal_True;
+    return true;
 }
 
-sal_Bool ChartTypeHelper::isSupportingRegressionProperties( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
+bool ChartTypeHelper::isSupportingRegressionProperties( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
 {
     // note: old chart: only scatter chart
     return isSupportingStatisticProperties( xChartType, nDimensionCount );
 }
 
-sal_Bool ChartTypeHelper::isSupportingAreaProperties( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
+bool ChartTypeHelper::isSupportingAreaProperties( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
 {
     //2D line charts, net and stock do not support area properties
 
@@ -117,19 +117,19 @@ sal_Bool ChartTypeHelper::isSupportingAreaProperties( const uno::Reference< XCha
         {
             OUString aChartTypeName = xChartType->getChartType();
             if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_LINE) )
-                return sal_False;
+                return false;
             if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_SCATTER) )
-                return sal_False;
+                return false;
             if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_NET) )
-                return sal_False;
+                return false;
             if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_CANDLESTICK) )
-                return sal_False;
+                return false;
         }
     }
-    return sal_True;
+    return true;
 }
 
-sal_Bool ChartTypeHelper::isSupportingSymbolProperties( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
+bool ChartTypeHelper::isSupportingSymbolProperties( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
 {
     //2D line charts, 2D scatter charts and 2D net charts do support symbols
 
@@ -137,20 +137,20 @@ sal_Bool ChartTypeHelper::isSupportingSymbolProperties( const uno::Reference< XC
     if(xChartType.is())
     {
         if(nDimensionCount==3)
-            return sal_False;
+            return false;
 
         OUString aChartTypeName = xChartType->getChartType();
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_LINE) )
-            return sal_True;
+            return true;
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_SCATTER) )
-            return sal_True;
+            return true;
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_NET) )
-            return sal_True;
+            return true;
     }
-    return sal_False;
+    return false;
 }
 
-sal_Bool ChartTypeHelper::isSupportingMainAxis( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount, sal_Int32 nDimensionIndex )
+bool ChartTypeHelper::isSupportingMainAxis( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount, sal_Int32 nDimensionIndex )
 {
     //pie charts do not support axis at all
     //no 3rd axis for 2D charts
@@ -160,15 +160,15 @@ sal_Bool ChartTypeHelper::isSupportingMainAxis( const uno::Reference< XChartType
     {
         OUString aChartTypeName = xChartType->getChartType();
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_PIE) )
-            return sal_False;
+            return false;
 
         if( nDimensionIndex == 2 )
             return nDimensionCount == 3;
     }
-    return sal_True;
+    return true;
 }
 
-sal_Bool ChartTypeHelper::isSupportingSecondaryAxis( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount, sal_Int32 /*nDimensionIndex*/ )
+bool ChartTypeHelper::isSupportingSecondaryAxis( const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount, sal_Int32 /*nDimensionIndex*/ )
 {
     //3D, pie and net charts do not support a secondary axis at all
 
@@ -176,20 +176,20 @@ sal_Bool ChartTypeHelper::isSupportingSecondaryAxis( const uno::Reference< XChar
     if(xChartType.is())
     {
          if(nDimensionCount==3)
-            return sal_False;
+            return false;
 
         OUString aChartTypeName = xChartType->getChartType();
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_PIE) )
-            return sal_False;
+            return false;
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_NET) )
-            return sal_False;
+            return false;
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_FILLED_NET) )
-            return sal_False;
+            return false;
     }
-    return sal_True;
+    return true;
 }
 
-sal_Bool ChartTypeHelper::isSupportingOverlapAndGapWidthProperties(
+bool ChartTypeHelper::isSupportingOverlapAndGapWidthProperties(
         const uno::Reference< XChartType >& xChartType, sal_Int32 nDimensionCount )
 {
     //2D bar charts do support a this special properties
@@ -198,18 +198,18 @@ sal_Bool ChartTypeHelper::isSupportingOverlapAndGapWidthProperties(
     if(xChartType.is())
     {
          if(nDimensionCount==3)
-            return sal_False;
+            return false;
 
         OUString aChartTypeName = xChartType->getChartType();
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_COLUMN) )
-            return sal_True;
+            return true;
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_BAR) )
-            return sal_True;
+            return true;
     }
-    return sal_False;
+    return false;
 }
 
-sal_Bool ChartTypeHelper::isSupportingBarConnectors(
+bool ChartTypeHelper::isSupportingBarConnectors(
     const uno::Reference< chart2::XChartType >& xChartType, sal_Int32 nDimensionCount )
 {
     //2D bar charts with stacked series support this
@@ -218,25 +218,25 @@ sal_Bool ChartTypeHelper::isSupportingBarConnectors(
     if(xChartType.is())
     {
         if(nDimensionCount==3)
-            return sal_False;
+            return false;
 
         bool bFound=false;
         bool bAmbiguous=false;
-        StackMode eStackMode = DiagramHelper::getStackModeFromChartType( xChartType, bFound, bAmbiguous, 0 );
+        StackMode eStackMode = DiagramHelper::getStackModeFromChartType( xChartType, bFound, bAmbiguous, nullptr );
         if( eStackMode != StackMode_Y_STACKED || bAmbiguous )
-            return sal_False;
+            return false;
 
         OUString aChartTypeName = xChartType->getChartType();
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_COLUMN) )
-            return sal_True;
+            return true;
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_BAR) )
-            return sal_True;  // note: old chart was false here
+            return true;  // note: old chart was false here
     }
-    return sal_False;
+    return false;
 }
 
 uno::Sequence < sal_Int32 > ChartTypeHelper::getSupportedLabelPlacements( const uno::Reference< chart2::XChartType >& xChartType
-                                                                         , sal_Int32 nDimensionCount, sal_Bool bSwapXAndY
+                                                                         , sal_Int32 nDimensionCount, bool bSwapXAndY
                                                                          , const uno::Reference< chart2::XDataSeries >& xSeries )
 {
     (void)nDimensionCount;
@@ -257,16 +257,16 @@ uno::Sequence < sal_Int32 > ChartTypeHelper::getSupportedLabelPlacements( const
         {
             aRet.realloc(4);
             sal_Int32* pSeq = aRet.getArray();
-            *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::AVOID_OVERLAP;
-            *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::OUTSIDE;
-            *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::INSIDE;
-            *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::CENTER;
+            *pSeq++ = css::chart::DataLabelPlacement::AVOID_OVERLAP;
+            *pSeq++ = css::chart::DataLabelPlacement::OUTSIDE;
+            *pSeq++ = css::chart::DataLabelPlacement::INSIDE;
+            *pSeq++ = css::chart::DataLabelPlacement::CENTER;
         }
         else
         {
             aRet.realloc(1);
             sal_Int32* pSeq = aRet.getArray();
-            *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::CENTER;
+            *pSeq++ = css::chart::DataLabelPlacement::CENTER;
         }
     }
     else if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_SCATTER)
@@ -276,11 +276,11 @@ uno::Sequence < sal_Int32 > ChartTypeHelper::getSupportedLabelPlacements( const
     {
         aRet.realloc(5);
         sal_Int32* pSeq = aRet.getArray();
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::TOP;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::BOTTOM;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::LEFT;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::RIGHT;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::CENTER;
+        *pSeq++ = css::chart::DataLabelPlacement::TOP;
+        *pSeq++ = css::chart::DataLabelPlacement::BOTTOM;
+        *pSeq++ = css::chart::DataLabelPlacement::LEFT;
+        *pSeq++ = css::chart::DataLabelPlacement::RIGHT;
+        *pSeq++ = css::chart::DataLabelPlacement::CENTER;
     }
     else if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_COLUMN)
         || aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_BAR) )
@@ -300,49 +300,49 @@ uno::Sequence < sal_Int32 > ChartTypeHelper::getSupportedLabelPlacements( const
         {
             if(bSwapXAndY)
             {
-                *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::RIGHT;
-                *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::LEFT;
+                *pSeq++ = css::chart::DataLabelPlacement::RIGHT;
+                *pSeq++ = css::chart::DataLabelPlacement::LEFT;
             }
             else
             {
-                *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::TOP;
-                *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::BOTTOM;
+                *pSeq++ = css::chart::DataLabelPlacement::TOP;
+                *pSeq++ = css::chart::DataLabelPlacement::BOTTOM;
             }
         }
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::CENTER;
+        *pSeq++ = css::chart::DataLabelPlacement::CENTER;
         if(!bStacked)
-            *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::OUTSIDE;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::INSIDE;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::NEAR_ORIGIN;
+            *pSeq++ = css::chart::DataLabelPlacement::OUTSIDE;
+        *pSeq++ = css::chart::DataLabelPlacement::INSIDE;
+        *pSeq++ = css::chart::DataLabelPlacement::NEAR_ORIGIN;
     }
     else if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_AREA) )
     {
         aRet.realloc(1);
         sal_Int32* pSeq = aRet.getArray();
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::TOP;
+        *pSeq++ = css::chart::DataLabelPlacement::TOP;
     }
     else if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_NET) )
     {
         aRet.realloc(6);
         sal_Int32* pSeq = aRet.getArray();
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::OUTSIDE;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::TOP;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::BOTTOM;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::LEFT;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::RIGHT;
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::CENTER;
+        *pSeq++ = css::chart::DataLabelPlacement::OUTSIDE;
+        *pSeq++ = css::chart::DataLabelPlacement::TOP;
+        *pSeq++ = css::chart::DataLabelPlacement::BOTTOM;
+        *pSeq++ = css::chart::DataLabelPlacement::LEFT;
+        *pSeq++ = css::chart::DataLabelPlacement::RIGHT;
+        *pSeq++ = css::chart::DataLabelPlacement::CENTER;
     }
     else if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_FILLED_NET) )
     {
         aRet.realloc(1);
         sal_Int32* pSeq = aRet.getArray();
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::OUTSIDE;
+        *pSeq++ = css::chart::DataLabelPlacement::OUTSIDE;
     }
     else if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_CANDLESTICK) )
     {
         aRet.realloc( 1 );
         sal_Int32* pSeq = aRet.getArray();
-        *pSeq++ = ::com::sun::star::chart::DataLabelPlacement::OUTSIDE;
+        *pSeq++ = css::chart::DataLabelPlacement::OUTSIDE;
     }
     else
     {
@@ -352,15 +352,15 @@ uno::Sequence < sal_Int32 > ChartTypeHelper::getSupportedLabelPlacements( const
     return aRet;
 }
 
-sal_Bool ChartTypeHelper::isSupportingRightAngledAxes( const uno::Reference< chart2::XChartType >& xChartType )
+bool ChartTypeHelper::isSupportingRightAngledAxes( const uno::Reference< chart2::XChartType >& xChartType )
 {
     if(xChartType.is())
     {
         OUString aChartTypeName = xChartType->getChartType();
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_PIE) )
-            return sal_False;
+            return false;
     }
-    return sal_True;
+    return true;
 }
 
 bool ChartTypeHelper::isSupportingStartingAngle( const uno::Reference< chart2::XChartType >& xChartType )
@@ -441,9 +441,9 @@ bool ChartTypeHelper::noBordersForSimpleScheme( const uno::Reference< chart2::XC
     {
         OUString aChartTypeName = xChartType->getChartType();
         if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_PIE) )
-            return sal_True;
+            return true;
     }
-    return sal_False;
+    return false;
 }
 
 sal_Int32 ChartTypeHelper::getDefaultDirectLightColor( bool bSimple, const uno::Reference< chart2::XChartType >& xChartType )
@@ -452,15 +452,15 @@ sal_Int32 ChartTypeHelper::getDefaultDirectLightColor( bool bSimple, const uno::
     if( xChartType .is() )
     {
         OUString aChartType = xChartType->getChartType();
-        if( aChartType.equals(CHART2_SERVICE_NAME_CHARTTYPE_PIE) )
+        if( aChartType == CHART2_SERVICE_NAME_CHARTTYPE_PIE )
         {
             if( bSimple )
                 nRet = static_cast< sal_Int32 >( 0x333333 ); // grey80
             else
                 nRet = static_cast< sal_Int32 >( 0xb3b3b3 ); // grey30
         }
-        else if( aChartType.equals(CHART2_SERVICE_NAME_CHARTTYPE_LINE)
-            || aChartType.equals(CHART2_SERVICE_NAME_CHARTTYPE_SCATTER) )
+        else if( aChartType == CHART2_SERVICE_NAME_CHARTTYPE_LINE
+            || aChartType == CHART2_SERVICE_NAME_CHARTTYPE_SCATTER )
             nRet = static_cast< sal_Int32 >( 0x666666 ); // grey60
     }
     return nRet;
@@ -472,7 +472,7 @@ sal_Int32 ChartTypeHelper::getDefaultAmbientLightColor( bool bSimple, const uno:
     if( xChartType .is() )
     {
         OUString aChartType = xChartType->getChartType();
-        if( aChartType.equals(CHART2_SERVICE_NAME_CHARTTYPE_PIE) )
+        if( aChartType == CHART2_SERVICE_NAME_CHARTTYPE_PIE )
         {
             if( bSimple )
                 nRet = static_cast< sal_Int32 >( 0xcccccc ); // grey20
@@ -489,10 +489,10 @@ drawing::Direction3D ChartTypeHelper::getDefaultSimpleLightDirection( const uno:
     if( xChartType .is() )
     {
         OUString aChartType = xChartType->getChartType();
-        if( aChartType.equals(CHART2_SERVICE_NAME_CHARTTYPE_PIE) )
+        if( aChartType == CHART2_SERVICE_NAME_CHARTTYPE_PIE )
             aRet = drawing::Direction3D(0.0, 0.8, 0.5);
-        else if( aChartType.equals(CHART2_SERVICE_NAME_CHARTTYPE_LINE)
-            || aChartType.equals(CHART2_SERVICE_NAME_CHARTTYPE_SCATTER) )
+        else if( aChartType == CHART2_SERVICE_NAME_CHARTTYPE_LINE
+            || aChartType == CHART2_SERVICE_NAME_CHARTTYPE_SCATTER )
             aRet = drawing::Direction3D(0.9, 0.5, 0.05);
     }
     return aRet;
@@ -504,10 +504,10 @@ drawing::Direction3D ChartTypeHelper::getDefaultRealisticLightDirection( const u
     if( xChartType .is() )
     {
         OUString aChartType = xChartType->getChartType();
-        if( aChartType.equals(CHART2_SERVICE_NAME_CHARTTYPE_PIE) )
+        if( aChartType == CHART2_SERVICE_NAME_CHARTTYPE_PIE )
             aRet = drawing::Direction3D(0.6, 0.6, 0.6);
-        else if( aChartType.equals(CHART2_SERVICE_NAME_CHARTTYPE_LINE)
-            || aChartType.equals(CHART2_SERVICE_NAME_CHARTTYPE_SCATTER) )
+        else if( aChartType == CHART2_SERVICE_NAME_CHARTTYPE_LINE
+            || aChartType == CHART2_SERVICE_NAME_CHARTTYPE_SCATTER )
             aRet = drawing::Direction3D(0.9, 0.5, 0.05);
     }
     return aRet;
@@ -516,7 +516,7 @@ drawing::Direction3D ChartTypeHelper::getDefaultRealisticLightDirection( const u
 sal_Int32 ChartTypeHelper::getAxisType( const uno::Reference<
             XChartType >& xChartType, sal_Int32 nDimensionIndex )
 {
-    //retruned is a constant from constant group ::com::sun::star::chart2::AxisType
+    //retruned is a constant from constant group css::chart2::AxisType
 
     //@todo ask charttype itself --> need model change first
     if(!xChartType.is())
@@ -546,7 +546,7 @@ sal_Int32 ChartTypeHelper::getNumberOfDisplayedSeries(
         try
         {
             OUString aChartTypeName = xChartType->getChartType();
-            if( aChartTypeName.equals(CHART2_SERVICE_NAME_CHARTTYPE_PIE))
+            if( aChartTypeName == CHART2_SERVICE_NAME_CHARTTYPE_PIE )
             {
                 uno::Reference< beans::XPropertySet > xChartTypeProp( xChartType, uno::UNO_QUERY_THROW );
                 bool bDonut = false;
@@ -573,7 +573,7 @@ uno::Sequence < sal_Int32 > ChartTypeHelper::getSupportedMissingValueTreatments(
 
     bool bFound=false;
     bool bAmbiguous=false;
-    StackMode eStackMode = DiagramHelper::getStackModeFromChartType( xChartType, bFound, bAmbiguous, 0 );
+    StackMode eStackMode = DiagramHelper::getStackModeFromChartType( xChartType, bFound, bAmbiguous, nullptr );
     bool bStacked = bFound && (StackMode_Y_STACKED == eStackMode);
 
     OUString aChartTypeName = xChartType->getChartType();
@@ -583,16 +583,16 @@ uno::Sequence < sal_Int32 > ChartTypeHelper::getSupportedMissingValueTreatments(
     {
         aRet.realloc( 2 );
         sal_Int32* pSeq = aRet.getArray();
-        *pSeq++ = ::com::sun::star::chart::MissingValueTreatment::LEAVE_GAP;
-        *pSeq++ = ::com::sun::star::chart::MissingValueTreatment::USE_ZERO;
+        *pSeq++ = css::chart::MissingValueTreatment::LEAVE_GAP;
+        *pSeq++ = css::chart::MissingValueTreatment::USE_ZERO;
     }
     else if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_AREA) )
     {
         aRet.realloc( bStacked ? 1 : 2 );
         sal_Int32* pSeq = aRet.getArray();
-        *pSeq++ = ::com::sun::star::chart::MissingValueTreatment::USE_ZERO;
+        *pSeq++ = css::chart::MissingValueTreatment::USE_ZERO;
         if( !bStacked )
-            *pSeq++ = ::com::sun::star::chart::MissingValueTreatment::CONTINUE;
+            *pSeq++ = css::chart::MissingValueTreatment::CONTINUE;
     }
     else if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_LINE) ||
         aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_NET) ||
@@ -600,18 +600,18 @@ uno::Sequence < sal_Int32 > ChartTypeHelper::getSupportedMissingValueTreatments(
     {
         aRet.realloc( bStacked ? 2 : 3 );
         sal_Int32* pSeq = aRet.getArray();
-        *pSeq++ = ::com::sun::star::chart::MissingValueTreatment::LEAVE_GAP;
-        *pSeq++ = ::com::sun::star::chart::MissingValueTreatment::USE_ZERO;
+        *pSeq++ = css::chart::MissingValueTreatment::LEAVE_GAP;
+        *pSeq++ = css::chart::MissingValueTreatment::USE_ZERO;
         if( !bStacked )
-            *pSeq++ = ::com::sun::star::chart::MissingValueTreatment::CONTINUE;
+            *pSeq++ = css::chart::MissingValueTreatment::CONTINUE;
     }
     else if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_SCATTER) )
     {
         aRet.realloc( 3 );
         sal_Int32* pSeq = aRet.getArray();
-        *pSeq++ = ::com::sun::star::chart::MissingValueTreatment::CONTINUE;
-        *pSeq++ = ::com::sun::star::chart::MissingValueTreatment::LEAVE_GAP;
-        *pSeq++ = ::com::sun::star::chart::MissingValueTreatment::USE_ZERO;
+        *pSeq++ = css::chart::MissingValueTreatment::CONTINUE;
+        *pSeq++ = css::chart::MissingValueTreatment::LEAVE_GAP;
+        *pSeq++ = css::chart::MissingValueTreatment::USE_ZERO;
     }
     else if( aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_PIE) ||
         aChartTypeName.match(CHART2_SERVICE_NAME_CHARTTYPE_CANDLESTICK) )
