@@ -172,11 +172,10 @@ bool ODbaseIndex::openIndexFile()
     return m_pFileStream != nullptr;
 }
 
-OIndexIterator* ODbaseIndex::createIterator(OBoolOperator* pOp,
-                                            const OOperand* pOperand)
+OIndexIterator* ODbaseIndex::createIterator()
 {
     openIndexFile();
-    return new OIndexIterator(this, pOp, pOperand);
+    return new OIndexIterator(this, nullptr, nullptr);
 }
 
 bool ODbaseIndex::ConvertToKey(ONDXKey* rKey, sal_uInt32 nRec, const ORowSetValue& rValue)
@@ -285,7 +284,7 @@ void ODbaseIndex::Collect(ONDXPage* pPage)
 
 void ODbaseIndex::Release(bool bSave)
 {
-    // Release the Index-recources
+    // Release the Index-resources
     m_bUseCollector = false;
 
     if (m_aCurLeaf.Is())
@@ -301,8 +300,8 @@ void ODbaseIndex::Release(bool bSave)
         m_aRoot.Clear();
     }
     // Release all references, before the FileStream will be closed
-    for (sal_uIntPtr i = 0; i < m_aCollector.size(); i++)
-        m_aCollector[i]->QueryDelete();
+    for (auto& i : m_aCollector)
+        i->QueryDelete();
 
     m_aCollector.clear();
 
@@ -350,11 +349,29 @@ ONDXPage* ODbaseIndex::CreatePage(sal_uInt32 nPagePos, ONDXPage* pParent, bool b
     return pPage;
 }
 
+void connectivity::dbase::ReadHeader(
+        SvStream & rStream, ODbaseIndex::NDXHeader & rHeader)
+{
+#if !defined(NDEBUG)
+    sal_uInt64 const nOldPos(rStream.Tell());
+#endif
+    rStream.ReadUInt32(rHeader.db_rootpage);
+    rStream.ReadUInt32(rHeader.db_pagecount);
+    rStream.Read(&rHeader.db_frei, 4);
+    rStream.ReadUInt16(rHeader.db_keylen);
+    rStream.ReadUInt16(rHeader.db_maxkeys);
+    rStream.ReadUInt16(rHeader.db_keytype);
+    rStream.ReadUInt16(rHeader.db_keyrec);
+    rStream.Read(&rHeader.db_frei1, 3);
+    rStream.ReadUChar(rHeader.db_unique);
+    rStream.Read(&rHeader.db_name, 488);
+    assert(rStream.GetError() || rStream.Tell() == nOldPos + DINDEX_PAGE_SIZE);
+}
 
 SvStream& connectivity::dbase::operator >> (SvStream &rStream, ODbaseIndex& rIndex)
 {
     rStream.Seek(0);
-    rStream.Read(&rIndex.m_aHeader,DINDEX_PAGE_SIZE);
+    ReadHeader(rStream, rIndex.m_aHeader);
 
     rIndex.m_nRootPage = rIndex.m_aHeader.db_rootpage;
     rIndex.m_nPageCount = rIndex.m_aHeader.db_pagecount;
@@ -364,7 +381,18 @@ SvStream& connectivity::dbase::operator >> (SvStream &rStream, ODbaseIndex& rInd
 SvStream& connectivity::dbase::WriteODbaseIndex(SvStream &rStream, ODbaseIndex& rIndex)
 {
     rStream.Seek(0);
-    OSL_VERIFY( rStream.Write(&rIndex.m_aHeader,DINDEX_PAGE_SIZE) == DINDEX_PAGE_SIZE );
+    rStream.WriteUInt32(rIndex.m_aHeader.db_rootpage);
+    rStream.WriteUInt32(rIndex.m_aHeader.db_pagecount);
+    rStream.Write(&rIndex.m_aHeader.db_frei, 4);
+    rStream.WriteUInt16(rIndex.m_aHeader.db_keylen);
+    rStream.WriteUInt16(rIndex.m_aHeader.db_maxkeys);
+    rStream.WriteUInt16(rIndex.m_aHeader.db_keytype);
+    rStream.WriteUInt16(rIndex.m_aHeader.db_keyrec);
+    rStream.Write(&rIndex.m_aHeader.db_frei1, 3);
+    rStream.WriteUChar(rIndex.m_aHeader.db_unique);
+    rStream.Write(&rIndex.m_aHeader.db_name, 488);
+    assert(rStream.GetError() || rStream.Tell() == DINDEX_PAGE_SIZE);
+    SAL_WARN_IF(rStream.GetError(), "connectivity.dbase", "write error");
     return rStream;
 }
 
@@ -615,6 +643,4 @@ void SAL_CALL ODbaseIndex::release() throw()
 }
 
 
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
