@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <stdio.h>
 #include <osl/diagnose.h>
 #include <osl/thread.h>
 #include <rtl/ustring.hxx>
@@ -32,6 +31,7 @@
 #include "NDatabaseMetaData.hxx"
 #include "NResultSet.hxx"
 #include "resource/evoab2_res.hrc"
+#include "sqlbison.hxx"
 #include <resource/common_res.hrc>
 #include <connectivity/dbexception.hxx>
 #include <tools/diagnose_ex.h>
@@ -48,15 +48,35 @@ using namespace com::sun::star::container;
 using namespace com::sun::star::io;
 using namespace com::sun::star::util;
 
+namespace {
+
+EBookQuery * createTrue()
+{ // Not the world's most efficient unconditional true but ...
+    return e_book_query_from_string("(exists \"full_name\")");
+}
+
+EBookQuery * createTest( const OUString &aColumnName,
+                             EBookQueryTest eTest,
+                             const OUString &aMatch )
+{
+    OString sMatch = OUStringToOString( aMatch, RTL_TEXTENCODING_UTF8 );
+    OString sColumnName = OUStringToOString( aColumnName, RTL_TEXTENCODING_UTF8 );
+
+    return e_book_query_field_test( e_contact_field_id( sColumnName.getStr() ),
+                                    eTest, sMatch.getStr() );
+}
+
+}
+
 OCommonStatement::OCommonStatement(OEvoabConnection* _pConnection)
     : OCommonStatement_IBase(m_aMutex)
     , ::comphelper::OPropertyContainer(OCommonStatement_IBase::rBHelper)
-    , OStatement_CBase( (::cppu::OWeakObject*)_pConnection, this )
-    , m_xResultSet(NULL)
+    , OStatement_CBase( static_cast<cppu::OWeakObject*>(_pConnection), this )
+    , m_xResultSet(nullptr)
     , m_pConnection(_pConnection)
     , m_aParser(_pConnection->getDriver().getComponentContext())
-    , m_aSQLIterator( _pConnection, _pConnection->createCatalog()->getTables(), m_aParser, NULL )
-    , m_pParseTree(NULL)
+    , m_aSQLIterator( _pConnection, _pConnection->createCatalog()->getTables(), m_aParser, nullptr )
+    , m_pParseTree(nullptr)
     , m_nMaxFieldSize(0)
     , m_nMaxRows(0)
     , m_nQueryTimeOut(0)
@@ -74,7 +94,7 @@ OCommonStatement::OCommonStatement(OEvoabConnection* _pConnection)
         id, \
         0, \
         &member, \
-        ::getCppuType( &member ) \
+        cppu::UnoType<decltype(member)>::get() \
     );
 
     REGISTER_PROP( PROPERTY_ID_CURSORNAME, m_aCursorName );
@@ -109,7 +129,7 @@ void OCommonStatement::disposing()
 
     if (m_pConnection)
         m_pConnection->release();
-    m_pConnection = NULL;
+    m_pConnection = nullptr;
 
     dispose_ChildImpl();
     OCommonStatement_IBase::disposing();
@@ -151,27 +171,6 @@ void SAL_CALL OCommonStatement::close(  ) throw(SQLException, RuntimeException,
     dispose();
 }
 
-
-EBookQuery *
-OCommonStatement::createTrue()
-{ // Not the world's most efficient unconditional true but ...
-    return e_book_query_from_string("(exists \"full_name\")");
-}
-
-EBookQuery *
-OCommonStatement::createTest( const OUString &aColumnName,
-                             EBookQueryTest eTest,
-                             const OUString &aMatch )
-{
-    OString sMatch = OUStringToOString( aMatch, RTL_TEXTENCODING_UTF8 );
-    OString sColumnName = OUStringToOString( aColumnName, RTL_TEXTENCODING_UTF8 );
-
-    return e_book_query_field_test( e_contact_field_id( sColumnName.getStr() ),
-                                    eTest, sMatch.getStr() );
-}
-
-
-
 OUString OCommonStatement::impl_getColumnRefColumnName_throw( const OSQLParseNode& _rColumnRef )
 {
     ENSURE_OR_THROW( SQL_ISRULE( &_rColumnRef, column_ref ), "internal error: only column_refs supported as LHS" );
@@ -216,16 +215,16 @@ void OCommonStatement::orderByAnalysis( const OSQLParseNode* _pOrderByClause, So
     const OSQLParseNode* pOrderList = _pOrderByClause->getByRule( OSQLParseNode::ordering_spec_commalist );
     ENSURE_OR_THROW( pOrderList, "unexpected parse tree structure" );
 
-    for ( sal_uInt32 i=0; i<pOrderList->count(); ++i )
+    for ( size_t i=0; i<pOrderList->count(); ++i )
     {
         const OSQLParseNode* pOrderBy = pOrderList->getChild(i);
         if ( !pOrderBy || !SQL_ISRULE( pOrderBy, ordering_spec ) )
             continue;
-        const OSQLParseNode* pColumnRef = pOrderBy->count() == 2 ? pOrderBy->getChild(0) : NULL;
-        const OSQLParseNode* pAscDesc = pOrderBy->count() == 2 ? pOrderBy->getChild(1) : NULL;
+        const OSQLParseNode* pColumnRef = pOrderBy->count() == 2 ? pOrderBy->getChild(0) : nullptr;
+        const OSQLParseNode* pAscDesc = pOrderBy->count() == 2 ? pOrderBy->getChild(1) : nullptr;
         ENSURE_OR_THROW(
-                ( pColumnRef != NULL )
-            &&  ( pAscDesc != NULL )
+                ( pColumnRef != nullptr )
+            &&  ( pAscDesc != nullptr )
             &&  SQL_ISRULE( pAscDesc, opt_asc_desc )
             &&  ( pAscDesc->count() < 2 ),
             "ordering_spec structure error" );
@@ -249,7 +248,7 @@ void OCommonStatement::orderByAnalysis( const OSQLParseNode* _pOrderByClause, So
 
 EBookQuery *OCommonStatement::whereAnalysis( const OSQLParseNode* parseTree )
 {
-    EBookQuery *pResult = NULL;
+    EBookQuery *pResult = nullptr;
 
     ENSURE_OR_THROW( parseTree, "invalid parse tree" );
 
@@ -290,38 +289,38 @@ EBookQuery *OCommonStatement::whereAnalysis( const OSQLParseNode* parseTree )
         OSQLParseNode* pRHS = parseTree->getChild( 2 );
 
         if  (   (   !( SQL_ISRULE( pLHS, column_ref ) )         // on the LHS, we accept a column or a constant int value
-                &&  ( pLHS->getNodeType() != SQL_NODE_INTNUM )
+                &&  ( pLHS->getNodeType() != SQLNodeType::IntNum )
                 )
-            ||  (   ( pRHS->getNodeType() != SQL_NODE_STRING )  // on the RHS, certain literals are acceptable
-                &&  ( pRHS->getNodeType() != SQL_NODE_INTNUM )
-                &&  ( pRHS->getNodeType() != SQL_NODE_APPROXNUM )
+            ||  (   ( pRHS->getNodeType() != SQLNodeType::String )  // on the RHS, certain literals are acceptable
+                &&  ( pRHS->getNodeType() != SQLNodeType::IntNum )
+                &&  ( pRHS->getNodeType() != SQLNodeType::ApproxNum )
                 &&  !( SQL_ISTOKEN( pRHS, TRUE ) )
                 &&  !( SQL_ISTOKEN( pRHS, FALSE ) )
                 )
-            ||  (   ( pLHS->getNodeType() == SQL_NODE_INTNUM )  // an int on LHS requires an int on RHS
-                &&  ( pRHS->getNodeType() != SQL_NODE_INTNUM )
+            ||  (   ( pLHS->getNodeType() == SQLNodeType::IntNum )  // an int on LHS requires an int on RHS
+                &&  ( pRHS->getNodeType() != SQLNodeType::IntNum )
                 )
             )
         {
             m_pConnection->throwGenericSQLException( STR_QUERY_TOO_COMPLEX, *this );
         }
 
-        if  (   ( pPrec->getNodeType() != SQL_NODE_EQUAL )
-            &&  ( pPrec->getNodeType() != SQL_NODE_NOTEQUAL )
+        if  (   ( pPrec->getNodeType() != SQLNodeType::Equal )
+            &&  ( pPrec->getNodeType() != SQLNodeType::NotEqual )
             )
         {
             m_pConnection->throwGenericSQLException( STR_OPERATOR_TOO_COMPLEX, *this );
         }
 
         // recognize the special "0 = 1" condition
-        if  (   ( pLHS->getNodeType() == SQL_NODE_INTNUM )
-            &&  ( pRHS->getNodeType() == SQL_NODE_INTNUM )
-            &&  ( pPrec->getNodeType() == SQL_NODE_EQUAL )
+        if  (   ( pLHS->getNodeType() == SQLNodeType::IntNum )
+            &&  ( pRHS->getNodeType() == SQLNodeType::IntNum )
+            &&  ( pPrec->getNodeType() == SQLNodeType::Equal )
             )
         {
             const sal_Int32 nLHS = pLHS->getTokenValue().toInt64();
             const sal_Int32 nRHS = pRHS->getTokenValue().toInt64();
-            return ( nLHS == nRHS ) ? createTrue() : NULL;
+            return ( nLHS == nRHS ) ? createTrue() : nullptr;
         }
 
         OUString aColumnName( impl_getColumnRefColumnName_throw( *pLHS ) );
@@ -334,7 +333,7 @@ EBookQuery *OCommonStatement::whereAnalysis( const OSQLParseNode* parseTree )
 
         pResult = createTest( aColumnName, E_BOOK_QUERY_IS, aMatchString );
 
-        if ( pResult && ( pPrec->getNodeType() == SQL_NODE_NOTEQUAL ) )
+        if ( pResult && ( pPrec->getNodeType() == SQLNodeType::NotEqual ) )
             pResult = e_book_query_not( pResult, TRUE );
     }
     // SQL like
@@ -351,13 +350,15 @@ EBookQuery *OCommonStatement::whereAnalysis( const OSQLParseNode* parseTree )
         OSQLParseNode *pAtom      = pPart2->getChild( pPart2->count() - 2 );     // Match String
         bool bNotLike             = pPart2->getChild(0)->isToken();
 
-        if( !( pAtom->getNodeType() == SQL_NODE_STRING ||
-               pAtom->getNodeType() == SQL_NODE_NAME ||
+        if( !( pAtom->getNodeType() == SQLNodeType::String ||
+               pAtom->getNodeType() == SQLNodeType::Name ||
                SQL_ISRULE( pAtom,parameter ) ||
-               ( pAtom->getChild( 0 ) && pAtom->getChild( 0 )->getNodeType() == SQL_NODE_NAME ) ||
-               ( pAtom->getChild( 0 ) && pAtom->getChild( 0 )->getNodeType() == SQL_NODE_STRING ) ) )
+               ( pAtom->getChild( 0 ) && pAtom->getChild( 0 )->getNodeType() == SQLNodeType::Name ) ||
+               ( pAtom->getChild( 0 ) && pAtom->getChild( 0 )->getNodeType() == SQLNodeType::String ) ) )
         {
-            OSL_TRACE( "analyseSQL : pAtom->count() = %d", pAtom->count() );
+            SAL_INFO(
+                "connectivity.evoab2",
+                "analyseSQL : pAtom->count() = " << pAtom->count());
             m_pConnection->throwGenericSQLException(STR_QUERY_INVALID_LIKE_STRING,*this);
         }
 
@@ -367,11 +368,11 @@ EBookQuery *OCommonStatement::whereAnalysis( const OSQLParseNode* parseTree )
         aMatchString = pAtom->getTokenValue();
 
         // Determine where '%' character is...
-        if( aMatchString.equals( OUString( WILDCARD ) ) )
+        if( aMatchString == OUStringLiteral1<WILDCARD>() )
         {
             // String containing only a '%' and nothing else matches everything
             pResult = createTest( aColumnName, E_BOOK_QUERY_CONTAINS,
-                                  OUString("") );
+                                  "" );
         }
         else if( aMatchString.indexOf( WILDCARD ) == -1 )
         {   // Simple string , eg. "to match" "contains in evo"
@@ -387,18 +388,15 @@ EBookQuery *OCommonStatement::whereAnalysis( const OSQLParseNode* parseTree )
         }
         else if( (aMatchString.indexOf ( WILDCARD ) == aMatchString.lastIndexOf ( WILDCARD ) ) )
         {   // One occurrence of '%'  matches...
-            if ( aMatchString.startsWith( OUString(WILDCARD) ) )
+            if ( aMatchString.startsWith(OUStringLiteral1<WILDCARD>()) )
                 pResult = createTest( aColumnName, E_BOOK_QUERY_ENDS_WITH, aMatchString.copy( 1 ) );
             else if ( aMatchString.indexOf ( WILDCARD ) == aMatchString.getLength() - 1 )
                 pResult = createTest( aColumnName, E_BOOK_QUERY_BEGINS_WITH, aMatchString.copy( 0, aMatchString.getLength() - 1 ) );
             else
                 m_pConnection->throwGenericSQLException(STR_QUERY_LIKE_WILDCARD,*this);
-
-            if( pResult && bNotLike )
-                pResult = e_book_query_not( pResult, TRUE );
         }
         else if( aMatchString.getLength() >= 3 &&
-                 aMatchString.startsWith( OUString(WILDCARD) ) &&
+                 aMatchString.startsWith(OUStringLiteral1<WILDCARD>()) &&
                  aMatchString.indexOf ( WILDCARD, 1) == aMatchString.getLength() - 1 ) {
             // one '%' at the start and another at the end
             pResult = createTest( aColumnName, E_BOOK_QUERY_CONTAINS, aMatchString.copy (1, aMatchString.getLength() - 2) );
@@ -414,25 +412,25 @@ OUString OCommonStatement::getTableName()
 {
     OUString aTableName;
 
-    if( m_pParseTree && m_aSQLIterator.getStatementType() == SQL_STATEMENT_SELECT )
+    if( m_pParseTree && m_aSQLIterator.getStatementType() == OSQLStatementType::Select )
     {
         Any aCatalog;
         OUString aSchema;
         const OSQLParseNode *pSelectStmnt = m_aSQLIterator.getParseTree();
         const OSQLParseNode *pAllTableNames = pSelectStmnt->getChild( 3 )->getChild( 0 )->getChild( 1 );
 
-        if( m_aSQLIterator.isTableNode( pAllTableNames->getChild( 0 ) ) )
+        if( OSQLParseTreeIterator::isTableNode( pAllTableNames->getChild( 0 ) ) )
             OSQLParseNode::getTableComponents( pAllTableNames->getChild( 0 ),
-                                               aCatalog,aSchema, aTableName,NULL );
+                                               aCatalog,aSchema, aTableName,nullptr );
 
         else if( SQL_ISRULE( pAllTableNames->getChild( 0 ), table_ref ) )
         {
             OSQLParseNode *pNodeForTableName = pAllTableNames->getChild( 0 )->getChild( 0 );
-            if( m_aSQLIterator.isTableNode( pNodeForTableName ) )
+            if( OSQLParseTreeIterator::isTableNode( pNodeForTableName ) )
             {
                 aTableName = OSQLParseNode::getTableRange(pAllTableNames->getChild( 0 ));
                 if( !aTableName.getLength() )
-                    OSQLParseNode::getTableComponents( pNodeForTableName, aCatalog, aSchema, aTableName,NULL);
+                    OSQLParseNode::getTableComponents( pNodeForTableName, aCatalog, aSchema, aTableName,nullptr);
             }
             else
                 OSL_FAIL( "odd table layout" );
@@ -492,7 +490,6 @@ void OCommonStatement::parseSql( const OUString& sql, QueryData& _out_rQueryData
 }
 
 
-
 Reference< XConnection > SAL_CALL OStatement::getConnection(  ) throw(SQLException, RuntimeException, std::exception)
 {
     ::osl::MutexGuard aGuard( m_aMutex );
@@ -529,7 +526,7 @@ void SAL_CALL OCommonStatement::clearWarnings(  ) throw(SQLException, RuntimeExc
 
 ::cppu::IPropertyArrayHelper & OCommonStatement::getInfoHelper()
 {
-    return *const_cast< OCommonStatement* >( this )->getArrayHelper();
+    return *getArrayHelper();
 }
 
 
