@@ -93,7 +93,7 @@ void OSQLAnalyzer::start(OSQLParseNode* pSQLParseNode)
                     if  (   SQL_ISPUNCTUATION( pColumnRef, "*" )
                         ||  (   SQL_ISRULE( pColumnRef, column_ref )
                             &&  ( pColumnRef->count() == 3 )
-                            &&  ( pColumnRef->getChild(0)->getNodeType() == SQL_NODE_NAME )
+                            &&  ( pColumnRef->getChild(0)->getNodeType() == SQLNodeType::Name )
                             &&  SQL_ISPUNCTUATION( pColumnRef->getChild(1), "." )
                             &&  SQL_ISRULE( pColumnRef->getChild(2), column_val )
                             &&  SQL_ISPUNCTUATION( pColumnRef->getChild(2)->getChild(0), "*" )
@@ -132,7 +132,7 @@ void OSQLAnalyzer::bindRow(OCodeList& rCodeList,const OValueRefRow& _pRow)
 void OSQLAnalyzer::bindSelectRow(const OValueRefRow& _pRow)
 {
     // first the select part
-    for ( ::std::vector< TPredicates >::iterator aIter = m_aSelectionEvaluations.begin(); aIter != m_aSelectionEvaluations.end();++aIter)
+    for ( ::std::vector< TPredicates >::const_iterator aIter = m_aSelectionEvaluations.begin(); aIter != m_aSelectionEvaluations.end();++aIter)
     {
         if ( aIter->first.is() )
             bindRow(aIter->first->m_aCodeList,_pRow);
