@@ -18,13 +18,13 @@
  */
 
 #include "java/lang/Class.hxx"
-#include "connectivity/CommonTools.hxx"
+#include <connectivity/CommonTools.hxx>
 #include <com/sun/star/uno/Exception.hpp>
+#include <com/sun/star/lang/WrappedTargetRuntimeException.hpp>
 #include "java/tools.hxx"
 #include "java/sql/SQLException.hxx"
 #include <osl/mutex.hxx>
 #include <osl/thread.h>
-#include <com/sun/star/uno/Sequence.hxx>
 #include "java/LocalRef.hxx"
 #include "resource/jdbc_log.hrc"
 
@@ -40,16 +40,15 @@ using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::lang;
 
 
-// -----------------------------------------------------------------------------
 ::rtl::Reference< jvmaccess::VirtualMachine > getJavaVM2(const ::rtl::Reference< jvmaccess::VirtualMachine >& _rVM = ::rtl::Reference< jvmaccess::VirtualMachine >(),
-                                                        sal_Bool _bSet = sal_False)
+                                                        bool _bSet = false)
 {
     static ::rtl::Reference< jvmaccess::VirtualMachine > s_VM;
     if ( _rVM.is() || _bSet )
         s_VM = _rVM;
     return s_VM;
 }
-// -----------------------------------------------------------------------------
+
 ::rtl::Reference< jvmaccess::VirtualMachine > java_lang_Object::getVM(const Reference<XComponentContext >& _rxContext)
 {
     ::rtl::Reference< jvmaccess::VirtualMachine > xVM = getJavaVM2();
@@ -58,41 +57,41 @@ using namespace ::com::sun::star::lang;
 
     return xVM;
 }
-// -----------------------------------------------------------------------------
+
 SDBThreadAttach::SDBThreadAttach()
  : m_aGuard(java_lang_Object::getVM())
- , pEnv(NULL)
+ , pEnv(nullptr)
 {
     pEnv = m_aGuard.getEnvironment();
     OSL_ENSURE(pEnv,"Environment is nULL!");
 }
-// -----------------------------------------------------------------------------
+
 SDBThreadAttach::~SDBThreadAttach()
 {
 }
-// -----------------------------------------------------------------------------
+
 oslInterlockedCount& getJavaVMRefCount()
 {
     static oslInterlockedCount s_nRefCount = 0;
     return s_nRefCount;
 }
-// -----------------------------------------------------------------------------
+
 void SDBThreadAttach::addRef()
 {
     osl_atomic_increment(&getJavaVMRefCount());
 }
-// -----------------------------------------------------------------------------
+
 void SDBThreadAttach::releaseRef()
 {
     osl_atomic_decrement(&getJavaVMRefCount());
     if ( getJavaVMRefCount() == 0 )
     {
-        getJavaVM2(::rtl::Reference< jvmaccess::VirtualMachine >(),sal_True);
+        getJavaVM2(::rtl::Reference< jvmaccess::VirtualMachine >(),true);
     }
 }
-// -----------------------------------------------------------------------------
+
 // static variables of the class
-jclass java_lang_Object::theClass = 0;
+jclass java_lang_Object::theClass = nullptr;
 
 jclass java_lang_Object::getMyClass() const
 {
@@ -102,14 +101,14 @@ jclass java_lang_Object::getMyClass() const
 }
 // the actual constructor
 java_lang_Object::java_lang_Object()
-            : object( 0 )
+            : object( nullptr )
 {
     SDBThreadAttach::addRef();
 }
 
 // the protected-constructor for the derived classes
 java_lang_Object::java_lang_Object( JNIEnv * pXEnv, jobject myObj )
-    : object( NULL )
+    : object( nullptr )
 {
     SDBThreadAttach::addRef();
     if( pXEnv && myObj )
@@ -130,7 +129,7 @@ void java_lang_Object::clearObject(JNIEnv& rEnv)
     if( object )
     {
         rEnv.DeleteGlobalRef( object );
-        object = NULL;
+        object = nullptr;
     }
 }
 
@@ -153,17 +152,17 @@ void java_lang_Object::saveRef( JNIEnv * pXEnv, jobject myObj )
 
 OUString java_lang_Object::toString() const
 {
-    static jmethodID mID(NULL);
+    static jmethodID mID(nullptr);
     return callStringMethod("toString",mID);
 }
 
-// --------------------------------------------------------------------------------
+
 namespace
 {
     bool    lcl_translateJNIExceptionToUNOException(
         JNIEnv* _pEnvironment, const Reference< XInterface >& _rxContext, SQLException& _out_rException )
     {
-        jthrowable jThrow = _pEnvironment ? _pEnvironment->ExceptionOccurred() : NULL;
+        jthrowable jThrow = _pEnvironment ? _pEnvironment->ExceptionOccurred() : nullptr;
         if ( !jThrow )
             return false;
 
@@ -172,14 +171,14 @@ namespace
 
         if ( _pEnvironment->IsInstanceOf( jThrow, java_sql_SQLException_BASE::st_getMyClass() ) )
         {
-            ::std::auto_ptr< java_sql_SQLException_BASE > pException( new java_sql_SQLException_BASE( _pEnvironment, jThrow ) );
+            std::unique_ptr< java_sql_SQLException_BASE > pException( new java_sql_SQLException_BASE( _pEnvironment, jThrow ) );
             _out_rException = SQLException( pException->getMessage(), _rxContext,
                 pException->getSQLState(), pException->getErrorCode(), Any() );
             return true;
         }
         else if ( _pEnvironment->IsInstanceOf( jThrow, java_lang_Throwable::st_getMyClass() ) )
         {
-            ::std::auto_ptr< java_lang_Throwable > pThrow( new java_lang_Throwable( _pEnvironment, jThrow ) );
+            std::unique_ptr< java_lang_Throwable > pThrow( new java_lang_Throwable( _pEnvironment, jThrow ) );
 #if OSL_DEBUG_LEVEL > 0
             pThrow->printStackTrace();
 #endif
@@ -197,7 +196,7 @@ namespace
     }
 }
 
-// --------------------------------------------------------------------------------
+
 void java_lang_Object::ThrowLoggedSQLException( const ::comphelper::ResourceBasedEventLogger& _rLogger, JNIEnv* _pEnvironment,
     const Reference< XInterface >& _rxContext )
 {
@@ -209,15 +208,26 @@ void java_lang_Object::ThrowLoggedSQLException( const ::comphelper::ResourceBase
     }
 }
 
-// --------------------------------------------------------------------------------
 void java_lang_Object::ThrowSQLException( JNIEnv* _pEnvironment, const Reference< XInterface>& _rxContext )
 {
     SQLException aException;
     if ( lcl_translateJNIExceptionToUNOException( _pEnvironment, _rxContext, aException ) )
         throw aException;
 }
-// -----------------------------------------------------------------------------
-void java_lang_Object::obtainMethodId(JNIEnv* _pEnv,const char* _pMethodName, const char* _pSignature,jmethodID& _inout_MethodID) const
+
+void java_lang_Object::ThrowRuntimeException( JNIEnv* _pEnvironment, const Reference< XInterface>& _rxContext )
+{
+    try
+    {
+        ThrowSQLException(_pEnvironment, _rxContext);
+    }
+    catch (const SQLException& e)
+    {
+        throw WrappedTargetRuntimeException(e.Message, e.Context, makeAny(e));
+    }
+}
+
+void java_lang_Object::obtainMethodId_throwSQL(JNIEnv* _pEnv,const char* _pMethodName, const char* _pSignature,jmethodID& _inout_MethodID) const
 {
     if  ( !_inout_MethodID )
     {
@@ -227,162 +237,216 @@ void java_lang_Object::obtainMethodId(JNIEnv* _pEnv,const char* _pMethodName, co
             throw SQLException();
     } // if  ( !_inout_MethodID )
 }
-// -----------------------------------------------------------------------------
-sal_Bool java_lang_Object::callBooleanMethod( const char* _pMethodName, jmethodID& _inout_MethodID ) const
+
+void java_lang_Object::obtainMethodId_throwRuntime(JNIEnv* _pEnv,const char* _pMethodName, const char* _pSignature,jmethodID& _inout_MethodID) const
 {
-    jboolean out( sal_False );
+    if  ( !_inout_MethodID )
+    {
+        _inout_MethodID  = _pEnv->GetMethodID( getMyClass(), _pMethodName, _pSignature );
+        OSL_ENSURE( _inout_MethodID, _pSignature );
+        if  ( !_inout_MethodID )
+            throw RuntimeException();
+    } // if  ( !_inout_MethodID )
+}
+
+
+bool java_lang_Object::callBooleanMethod( const char* _pMethodName, jmethodID& _inout_MethodID ) const
+{
+    jboolean out( false );
 
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callBooleanMethod: no Java enviroment anymore!" );
-    obtainMethodId(t.pEnv, _pMethodName,"()Z", _inout_MethodID);
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callBooleanMethod: no Java environment anymore!" );
+    obtainMethodId_throwSQL(t.pEnv, _pMethodName,"()Z", _inout_MethodID);
     // call method
     out = t.pEnv->CallBooleanMethod( object, _inout_MethodID );
-    ThrowSQLException( t.pEnv, NULL );
+    ThrowSQLException( t.pEnv, nullptr );
 
     return out;
 }
-// -----------------------------------------------------------------------------
-sal_Bool java_lang_Object::callBooleanMethodWithIntArg( const char* _pMethodName, jmethodID& _inout_MethodID, sal_Int32 _nArgument ) const
+
+bool java_lang_Object::callBooleanMethodWithIntArg( const char* _pMethodName, jmethodID& _inout_MethodID, sal_Int32 _nArgument ) const
 {
-    jboolean out( sal_False );
+    jboolean out( false );
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callBooleanMethodWithIntArg: no Java enviroment anymore!" );
-    obtainMethodId(t.pEnv, _pMethodName,"(I)Z", _inout_MethodID);
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callBooleanMethodWithIntArg: no Java environment anymore!" );
+    obtainMethodId_throwSQL(t.pEnv, _pMethodName,"(I)Z", _inout_MethodID);
     // call method
     out = t.pEnv->CallBooleanMethod( object, _inout_MethodID, _nArgument );
-    ThrowSQLException( t.pEnv, NULL );
+    ThrowSQLException( t.pEnv, nullptr );
 
     return out;
 }
-// -------------------------------------------------------------------------
+
 jobject java_lang_Object::callResultSetMethod( JNIEnv& _rEnv,const char* _pMethodName, jmethodID& _inout_MethodID ) const
 {
     // call method
     jobject out = callObjectMethod(&_rEnv,_pMethodName,"()Ljava/sql/ResultSet;", _inout_MethodID);
     return out;
 }
-// -------------------------------------------------------------------------
-sal_Int32 java_lang_Object::callIntMethod( const char* _pMethodName, jmethodID& _inout_MethodID,bool _bIgnoreException ) const
+
+sal_Int32 java_lang_Object::callIntMethod_ThrowSQL(const char* _pMethodName, jmethodID& _inout_MethodID) const
 {
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java enviroment anymore!" );
-    obtainMethodId(t.pEnv, _pMethodName,"()I", _inout_MethodID);
-
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwSQL(t.pEnv, _pMethodName,"()I", _inout_MethodID);
     // call method
     jint out( t.pEnv->CallIntMethod( object, _inout_MethodID ) );
-    if ( _bIgnoreException )
-        isExceptionOccurred(t.pEnv,sal_True);
-    else
-        ThrowSQLException( t.pEnv, NULL );
-
+    ThrowSQLException( t.pEnv, nullptr );
     return (sal_Int32)out;
 }
-// -------------------------------------------------------------------------
-sal_Int32 java_lang_Object::callIntMethodWithIntArg( const char* _pMethodName, jmethodID& _inout_MethodID,sal_Int32 _nArgument ) const
+
+sal_Int32 java_lang_Object::callIntMethod_ThrowRuntime(const char* _pMethodName, jmethodID& _inout_MethodID) const
 {
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java enviroment anymore!" );
-    obtainMethodId(t.pEnv, _pMethodName,"(I)I", _inout_MethodID);
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwRuntime(t.pEnv, _pMethodName,"()I", _inout_MethodID);
+    // call method
+    jint out( t.pEnv->CallIntMethod( object, _inout_MethodID ) );
+    ThrowRuntimeException(t.pEnv, nullptr);
+    return (sal_Int32)out;
+}
+
+sal_Int32 java_lang_Object::callIntMethodWithIntArg_ThrowSQL( const char* _pMethodName, jmethodID& _inout_MethodID,sal_Int32 _nArgument ) const
+{
+    SDBThreadAttach t;
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwSQL(t.pEnv, _pMethodName,"(I)I", _inout_MethodID);
     // call method
     jint out( t.pEnv->CallIntMethod( object, _inout_MethodID , _nArgument) );
-    ThrowSQLException( t.pEnv, NULL );
-
+    ThrowSQLException( t.pEnv, nullptr );
     return (sal_Int32)out;
 }
-// -------------------------------------------------------------------------
-void java_lang_Object::callVoidMethod( const char* _pMethodName, jmethodID& _inout_MethodID) const
+
+sal_Int32 java_lang_Object::callIntMethodWithIntArg_ThrowRuntime( const char* _pMethodName, jmethodID& _inout_MethodID,sal_Int32 _nArgument ) const
 {
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java enviroment anymore!" );
-    obtainMethodId(t.pEnv, _pMethodName,"()V", _inout_MethodID);
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwRuntime(t.pEnv, _pMethodName,"(I)I", _inout_MethodID);
+    // call method
+    jint out( t.pEnv->CallIntMethod( object, _inout_MethodID , _nArgument) );
+    ThrowRuntimeException(t.pEnv, nullptr);
+    return (sal_Int32)out;
+}
+
+void java_lang_Object::callVoidMethod_ThrowSQL( const char* _pMethodName, jmethodID& _inout_MethodID) const
+{
+    SDBThreadAttach t;
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwSQL(t.pEnv, _pMethodName,"()V", _inout_MethodID);
 
     // call method
     t.pEnv->CallVoidMethod( object, _inout_MethodID );
-    ThrowSQLException( t.pEnv, NULL );
+    ThrowSQLException( t.pEnv, nullptr );
 }
-// -------------------------------------------------------------------------
-void java_lang_Object::callVoidMethodWithIntArg( const char* _pMethodName, jmethodID& _inout_MethodID, sal_Int32 _nArgument,bool _bIgnoreException ) const
+
+void java_lang_Object::callVoidMethod_ThrowRuntime( const char* _pMethodName, jmethodID& _inout_MethodID) const
 {
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java enviroment anymore!" );
-    obtainMethodId(t.pEnv, _pMethodName,"(I)V", _inout_MethodID);
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwRuntime(t.pEnv, _pMethodName,"()V", _inout_MethodID);
+
+    // call method
+    t.pEnv->CallVoidMethod( object, _inout_MethodID );
+    ThrowRuntimeException(t.pEnv, nullptr);
+}
+
+void java_lang_Object::callVoidMethodWithIntArg_ThrowSQL( const char* _pMethodName, jmethodID& _inout_MethodID, sal_Int32 _nArgument ) const
+{
+    SDBThreadAttach t;
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwSQL(t.pEnv, _pMethodName,"(I)V", _inout_MethodID);
 
     // call method
     t.pEnv->CallVoidMethod( object, _inout_MethodID,_nArgument );
-    if ( _bIgnoreException )
-        isExceptionOccurred(t.pEnv,sal_True);
-    else
-        ThrowSQLException( t.pEnv, NULL );
+    ThrowSQLException( t.pEnv, nullptr );
 }
-// -------------------------------------------------------------------------
-void java_lang_Object::callVoidMethodWithBoolArg( const char* _pMethodName, jmethodID& _inout_MethodID, sal_Int32 _nArgument,bool _bIgnoreException ) const
+
+void java_lang_Object::callVoidMethodWithIntArg_ThrowRuntime( const char* _pMethodName, jmethodID& _inout_MethodID, sal_Int32 _nArgument ) const
 {
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java enviroment anymore!" );
-    obtainMethodId(t.pEnv, _pMethodName,"(Z)V", _inout_MethodID);
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwRuntime(t.pEnv, _pMethodName,"(I)V", _inout_MethodID);
+
     // call method
     t.pEnv->CallVoidMethod( object, _inout_MethodID,_nArgument );
-    if ( _bIgnoreException )
-        isExceptionOccurred(t.pEnv,sal_True);
-    else
-        ThrowSQLException( t.pEnv, NULL );
+    ThrowRuntimeException(t.pEnv, nullptr);
 }
-// -----------------------------------------------------------------------------
+
+void java_lang_Object::callVoidMethodWithBoolArg_ThrowSQL( const char* _pMethodName, jmethodID& _inout_MethodID, bool _nArgument ) const
+{
+    SDBThreadAttach t;
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwSQL(t.pEnv, _pMethodName,"(Z)V", _inout_MethodID);
+    // call method
+    t.pEnv->CallVoidMethod( object, _inout_MethodID,int(_nArgument) );
+    ThrowSQLException( t.pEnv, nullptr );
+}
+
+void java_lang_Object::callVoidMethodWithBoolArg_ThrowRuntime( const char* _pMethodName, jmethodID& _inout_MethodID, bool _nArgument ) const
+{
+    SDBThreadAttach t;
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwRuntime(t.pEnv, _pMethodName,"(Z)V", _inout_MethodID);
+    // call method
+    t.pEnv->CallVoidMethod( object, _inout_MethodID,int(_nArgument) );
+    ThrowRuntimeException(t.pEnv, nullptr);
+}
+
 OUString java_lang_Object::callStringMethod( const char* _pMethodName, jmethodID& _inout_MethodID ) const
 {
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callStringMethod: no Java enviroment anymore!" );
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callStringMethod: no Java environment anymore!" );
 
     // call method
-    jstring out = (jstring)callObjectMethod(t.pEnv,_pMethodName,"()Ljava/lang/String;", _inout_MethodID);
+    jstring out = static_cast<jstring>(callObjectMethod(t.pEnv,_pMethodName,"()Ljava/lang/String;", _inout_MethodID));
     return JavaString2String( t.pEnv, out );
 }
-// -----------------------------------------------------------------------------
+
 jobject java_lang_Object::callObjectMethod( JNIEnv * _pEnv,const char* _pMethodName,const char* _pSignature, jmethodID& _inout_MethodID ) const
 {
     // obtain method ID
-    obtainMethodId(_pEnv, _pMethodName,_pSignature, _inout_MethodID);
+    obtainMethodId_throwSQL(_pEnv, _pMethodName,_pSignature, _inout_MethodID);
     // call method
     jobject out = _pEnv->CallObjectMethod( object, _inout_MethodID);
-    ThrowSQLException( _pEnv, NULL );
+    ThrowSQLException( _pEnv, nullptr );
     return out;
 }
 
-// -----------------------------------------------------------------------------
+
 jobject java_lang_Object::callObjectMethodWithIntArg( JNIEnv * _pEnv,const char* _pMethodName,const char* _pSignature, jmethodID& _inout_MethodID , sal_Int32 _nArgument) const
 {
-    obtainMethodId(_pEnv, _pMethodName,_pSignature, _inout_MethodID);
+    obtainMethodId_throwSQL(_pEnv, _pMethodName,_pSignature, _inout_MethodID);
     // call method
     jobject out = _pEnv->CallObjectMethod( object, _inout_MethodID,_nArgument );
-    ThrowSQLException( _pEnv, NULL );
+    ThrowSQLException( _pEnv, nullptr );
     return out;
 }
-// -----------------------------------------------------------------------------
+
 OUString java_lang_Object::callStringMethodWithIntArg( const char* _pMethodName, jmethodID& _inout_MethodID , sal_Int32 _nArgument) const
 {
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callStringMethod: no Java enviroment anymore!" );
-    jstring out = (jstring)callObjectMethodWithIntArg(t.pEnv,_pMethodName,"(I)Ljava/lang/String;",_inout_MethodID,_nArgument);
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callStringMethod: no Java environment anymore!" );
+    jstring out = static_cast<jstring>(callObjectMethodWithIntArg(t.pEnv,_pMethodName,"(I)Ljava/lang/String;",_inout_MethodID,_nArgument));
     return JavaString2String( t.pEnv, out );
 }
-// -------------------------------------------------------------------------
+
 void java_lang_Object::callVoidMethodWithStringArg( const char* _pMethodName, jmethodID& _inout_MethodID,const OUString& _nArgument ) const
 {
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java enviroment anymore!" );
-    obtainMethodId(t.pEnv, _pMethodName,"(Ljava/lang/String;)V", _inout_MethodID);
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethod: no Java environment anymore!" );
+    obtainMethodId_throwSQL(t.pEnv, _pMethodName,"(Ljava/lang/String;)V", _inout_MethodID);
 
     jdbc::LocalRef< jstring > str( t.env(),convertwchar_tToJavaString(t.pEnv,_nArgument));
     // call method
     t.pEnv->CallVoidMethod( object, _inout_MethodID , str.get());
-    ThrowSQLException( t.pEnv, NULL );
+    ThrowSQLException( t.pEnv, nullptr );
 }
-// -------------------------------------------------------------------------
+
 sal_Int32 java_lang_Object::callIntMethodWithStringArg( const char* _pMethodName, jmethodID& _inout_MethodID,const OUString& _nArgument ) const
 {
     SDBThreadAttach t;
-    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethodWithStringArg: no Java enviroment anymore!" );
-    obtainMethodId(t.pEnv, _pMethodName,"(Ljava/lang/String;)I", _inout_MethodID);
+    OSL_ENSURE( t.pEnv, "java_lang_Object::callIntMethodWithStringArg: no Java environment anymore!" );
+    obtainMethodId_throwSQL(t.pEnv, _pMethodName,"(Ljava/lang/String;)I", _inout_MethodID);
 
     //TODO: Check if the code below is needed
             //jdbc::LocalRef< jstring > str( t.env(), convertwchar_tToJavaString( t.pEnv, sql ) );
@@ -396,10 +460,10 @@ sal_Int32 java_lang_Object::callIntMethodWithStringArg( const char* _pMethodName
     jdbc::LocalRef< jstring > str( t.env(),convertwchar_tToJavaString(t.pEnv,_nArgument));
     // call method
     jint out = t.pEnv->CallIntMethod( object, _inout_MethodID , str.get());
-    ThrowSQLException( t.pEnv, NULL );
+    ThrowSQLException( t.pEnv, nullptr );
     return (sal_Int32)out;
 }
-// -----------------------------------------------------------------------------
+
 jclass java_lang_Object::findMyClass(const char* _pClassName)
 {
     // the class must be fetched only once, therefore static
@@ -410,7 +474,7 @@ jclass java_lang_Object::findMyClass(const char* _pClassName)
         t.pEnv->ExceptionDescribe();
         t.pEnv->ExceptionClear();
     }
-    jclass globClass = (jclass)t.pEnv->NewGlobalRef( tempClass );
+    jclass globClass = static_cast<jclass>(t.pEnv->NewGlobalRef( tempClass ));
     t.pEnv->DeleteLocalRef( tempClass );
     return globClass;
 }
