@@ -68,7 +68,6 @@ using com::sun::star::sdbc::XRow;
 
 using com::sun::star::sdbcx::XColumnsSupplier;
 
-using com::sun::star::uno::RuntimeException;
 using com::sun::star::uno::UNO_QUERY;
 using com::sun::star::uno::UNO_QUERY_THROW;
 using com::sun::star::uno::Reference;
@@ -566,9 +565,6 @@ void splitConcatenatedIdentifier( const OUString & source, OUString *first, OUSt
     }
 }
 
-typedef std::vector< sal_Int32 > IntVector;
-
-
 OUString array2String( const com::sun::star::uno::Sequence< Any > &seq )
 {
     OUStringBuffer buf(128);
@@ -598,13 +594,8 @@ OUString array2String( const com::sun::star::uno::Sequence< Any > &seq )
     return buf.makeStringAndClear();
 }
 
-typedef
-std::vector
-<
-    com::sun::star::uno::Any
-> AnyVector;
 
-com::sun::star::uno::Sequence< Any > parseArray( const OUString & str ) throw( SQLException )
+std::vector< Any > parseArray( const OUString & str ) throw( SQLException )
 {
     int len = str.getLength();
     bool doubleQuote = false;
@@ -612,7 +603,7 @@ com::sun::star::uno::Sequence< Any > parseArray( const OUString & str ) throw( S
     int i = 0;
 
     OUStringBuffer current;
-    AnyVector elements;
+    std::vector<Any> elements;
     bool doubleQuotedValue = false;
     while( i < len )
     {
@@ -699,13 +690,13 @@ com::sun::star::uno::Sequence< Any > parseArray( const OUString & str ) throw( S
         }
         i++;
     }
-    return sequence_of_vector(elements);
+    return elements;
 }
 
-com::sun::star::uno::Sequence< sal_Int32 > parseIntArray( const OUString & str )
+std::vector< sal_Int32 > parseIntArray( const OUString & str )
 {
     sal_Int32 start = 0;
-    IntVector vec;
+    std::vector<sal_Int32> vec;
 //     printf( ">%s<\n" , OUStringToOString( str, RTL_TEXTENCODING_UTF8 ).getStr() );
     for( sal_Int32 i = str.indexOf( ' ' ) ; i != -1 ; i = str.indexOf( ' ', start) )
     {
@@ -715,7 +706,7 @@ com::sun::star::uno::Sequence< sal_Int32 > parseIntArray( const OUString & str )
     }
     vec.push_back( (sal_Int32)rtl_ustr_toInt32( &str.pData->buffer[start], 10 ) );
 //     printf( "found %d\n" , rtl_ustr_toInt32( &str.pData->buffer[start], 10 ));
-    return sequence_of_vector(vec);
+    return vec;
 }
 
 void fillAttnum2attnameMap(
@@ -959,8 +950,6 @@ OUString sqltype2string( const Reference< XPropertySet > & desc )
 }
 
 
-
-
 static void keyType2String( OUStringBuffer & buf, sal_Int32 keyType )
 {
     if( com::sun::star::sdbc::KeyRule::CASCADE == keyType )
@@ -1156,7 +1145,7 @@ OUString querySingleValue(
 
 
 // copied from connectivity/source/dbtools, can't use the function directly
-bool implSetObject(	const Reference< XParameters >& _rxParameters,
+bool implSetObject( const Reference< XParameters >& _rxParameters,
                         const sal_Int32 _nColumnIndex, const Any& _rValue)
 {
     bool bSuccessfullyReRouted = true;
@@ -1235,8 +1224,8 @@ bool implSetObject(	const Reference< XParameters >& _rxParameters,
                 _rxParameters->setBinaryStream(_nColumnIndex, xStream, xStream->available());
                 break;
             }
+            SAL_FALLTHROUGH;
         }
-            // run through
         default:
             bSuccessfullyReRouted = false;
 
