@@ -61,35 +61,35 @@ OParseColumn::OParseColumn(const Reference<XPropertySet>& _xColumn, bool _bCase)
 }
 
 
-OParseColumn::OParseColumn( const OUString& _Name,
-                    const OUString& _TypeName,
-                    const OUString& _DefaultValue,
-                    const OUString& _Description,
-                    sal_Int32       _IsNullable,
-                    sal_Int32       _Precision,
-                    sal_Int32       _Scale,
-                    sal_Int32       _Type,
-                    bool            _IsAutoIncrement,
-                    bool            _IsCurrency,
+OParseColumn::OParseColumn( const OUString& Name,
+                    const OUString& TypeName,
+                    const OUString& DefaultValue,
+                    const OUString& Description,
+                    sal_Int32       IsNullable,
+                    sal_Int32       Precision,
+                    sal_Int32       Scale,
+                    sal_Int32       Type,
+                    bool            IsAutoIncrement,
+                    bool            IsCurrency,
                     bool            _bCase,
-                    const OUString& _CatalogName,
-                    const OUString& _SchemaName,
-                    const OUString& _TableName
-                ) : connectivity::sdbcx::OColumn(_Name,
-                                  _TypeName,
-                                  _DefaultValue,
-                                  _Description,
-                                  _IsNullable,
-                                  _Precision,
-                                  _Scale,
-                                  _Type,
-                                  _IsAutoIncrement,
+                    const OUString& CatalogName,
+                    const OUString& SchemaName,
+                    const OUString& TableName
+                ) : connectivity::sdbcx::OColumn(Name,
+                                  TypeName,
+                                  DefaultValue,
+                                  Description,
+                                  IsNullable,
+                                  Precision,
+                                  Scale,
+                                  Type,
+                                  IsAutoIncrement,
                                   false,
-                                  _IsCurrency,
+                                  IsCurrency,
                                   _bCase,
-                                  _CatalogName,
-                                  _SchemaName,
-                                  _TableName)
+                                  CatalogName,
+                                  SchemaName,
+                                  TableName)
     , m_bFunction(false)
     , m_bDbasePrecisionChanged(false)
     , m_bAggregateFunction(false)
