@@ -41,14 +41,14 @@ using namespace ::com::sun::star::lang;
 
 namespace
 {
-    sal_Bool isGrabVclControlFocusAllowed(const UnoDataBrowserView* _pView)
+    bool isGrabVclControlFocusAllowed(const UnoDataBrowserView* _pView)
     {
-        sal_Bool bGrabFocus = sal_False;
+        bool bGrabFocus = false;
         SbaGridControl* pVclControl = _pView->getVclControl();
-        Reference< ::com::sun::star::awt::XControl > xGrid = _pView->getGridControl();
+        Reference< css::awt::XControl > xGrid = _pView->getGridControl();
         if (pVclControl && xGrid.is())
         {
-            bGrabFocus = sal_True;
+            bGrabFocus = true;
             if(!pVclControl->HasChildPathFocus())
             {
                 Reference<XChild> xChild(xGrid->getModel(),UNO_QUERY);
@@ -64,21 +64,19 @@ namespace
 
 // UnoDataBrowserView
 
-DBG_NAME(UnoDataBrowserView)
-UnoDataBrowserView::UnoDataBrowserView( Window* pParent,
+UnoDataBrowserView::UnoDataBrowserView( vcl::Window* pParent,
                                         IController& _rController,
-                                        const Reference< ::com::sun::star::uno::XComponentContext >& _rxContext)
+                                        const Reference< css::uno::XComponentContext >& _rxContext)
     :ODataView(pParent,_rController,_rxContext)
-    ,m_pTreeView(NULL)
-    ,m_pSplitter(NULL)
-    ,m_pVclControl(NULL)
-    ,m_pStatus(NULL)
+    ,m_pTreeView(nullptr)
+    ,m_pSplitter(nullptr)
+    ,m_pVclControl(nullptr)
+    ,m_pStatus(nullptr)
 {
-    DBG_CTOR(UnoDataBrowserView,NULL);
 
 }
 
-void UnoDataBrowserView::Construct(const Reference< ::com::sun::star::awt::XControlModel >& xModel)
+void UnoDataBrowserView::Construct(const Reference< css::awt::XControlModel >& xModel)
 {
     try
     {
@@ -91,23 +89,23 @@ void UnoDataBrowserView::Construct(const Reference< ::com::sun::star::awt::XCont
         m_xGrid = new SbaXGridControl( getORB() );
         OSL_ENSURE(m_xGrid.is(), "UnoDataBrowserView::Construct : could not create a grid control !");
         // in design mode (for the moment)
-        m_xGrid->setDesignMode(sal_True);
+        m_xGrid->setDesignMode(true);
 
-        Reference< ::com::sun::star::awt::XWindow >  xGridWindow(m_xGrid, UNO_QUERY);
-        xGridWindow->setVisible(sal_True);
-        xGridWindow->setEnable(sal_True);
+        Reference< css::awt::XWindow >  xGridWindow(m_xGrid, UNO_QUERY);
+        xGridWindow->setVisible(true);
+        xGridWindow->setEnable(true);
 
         // introduce the model to the grid
         m_xGrid->setModel(xModel);
         // introduce the container (me) to the grid
-        Reference< ::com::sun::star::beans::XPropertySet >  xModelSet(xModel, UNO_QUERY);
+        Reference< css::beans::XPropertySet >  xModelSet(xModel, UNO_QUERY);
         getContainer()->addControl(::comphelper::getString(xModelSet->getPropertyValue(PROPERTY_NAME)), m_xGrid);
 
         // get the VCL-control
-        m_pVclControl = NULL;
+        m_pVclControl = nullptr;
         getVclControl();
 
-        OSL_ENSURE(m_pVclControl != NULL, "UnoDataBrowserView::Construct : no real grid control !");
+        OSL_ENSURE(m_pVclControl != nullptr, "UnoDataBrowserView::Construct : no real grid control !");
     }
     catch(const Exception&)
     {
@@ -118,17 +116,15 @@ void UnoDataBrowserView::Construct(const Reference< ::com::sun::star::awt::XCont
 
 UnoDataBrowserView::~UnoDataBrowserView()
 {
-    {
-        ::std::auto_ptr<Splitter> aTemp(m_pSplitter);
-        m_pSplitter = NULL;
-    }
-    setTreeView(NULL);
+    disposeOnce();
+}
 
-    if ( m_pStatus )
-    {
-        delete m_pStatus;
-        m_pStatus = NULL;
-    }
+void UnoDataBrowserView::dispose()
+{
+    m_pSplitter.disposeAndClear();
+    setTreeView(nullptr);
+
+    m_pStatus.disposeAndClear();
 
     try
     {
@@ -137,17 +133,16 @@ UnoDataBrowserView::~UnoDataBrowserView()
     }
     catch(const Exception&)
     {}
-
-    DBG_DTOR(UnoDataBrowserView,NULL);
+    m_pTreeView.clear();
+    m_pVclControl.clear();
+    ODataView::dispose();
 }
 
-IMPL_LINK( UnoDataBrowserView, SplitHdl, void*, /*NOINTERESTEDIN*/ )
+IMPL_LINK_NOARG_TYPED( UnoDataBrowserView, SplitHdl, Splitter*, void )
 {
     long nYPos = m_pSplitter->GetPosPixel().Y();
     m_pSplitter->SetPosPixel( Point( m_pSplitter->GetSplitPosPixel(), nYPos ) );
     Resize();
-
-    return 0L;
 }
 
 void UnoDataBrowserView::setSplitter(Splitter* _pSplitter)
@@ -159,13 +154,9 @@ void UnoDataBrowserView::setSplitter(Splitter* _pSplitter)
 
 void UnoDataBrowserView::setTreeView(DBTreeView* _pTreeView)
 {
-    if (m_pTreeView != _pTreeView)
+    if (m_pTreeView.get() != _pTreeView)
     {
-        if (m_pTreeView)
-        {
-            ::std::auto_ptr<Window> aTemp(m_pTreeView);
-            m_pTreeView = NULL;
-        }
+        m_pTreeView.disposeAndClear();
         m_pTreeView = _pTreeView;
     }
 }
@@ -177,7 +168,7 @@ void UnoDataBrowserView::showStatus( const OUString& _rStatus )
     else
     {
         if (!m_pStatus)
-            m_pStatus = new FixedText(this);
+            m_pStatus = VclPtr<FixedText>::Create(this);
         m_pStatus->SetText(_rStatus);
         m_pStatus->Show();
         Resize();
@@ -241,10 +232,10 @@ void UnoDataBrowserView::resizeDocumentView(Rectangle& _rPlayground)
     }
 
     // set the size of grid control
-    Reference< ::com::sun::star::awt::XWindow >  xGridAsWindow(m_xGrid, UNO_QUERY);
+    Reference< css::awt::XWindow >  xGridAsWindow(m_xGrid, UNO_QUERY);
     if (xGridAsWindow.is())
         xGridAsWindow->setPosSize( aSplitPos.X() + aSplitSize.Width(), aPlaygroundPos.Y(),
-                                   aPlaygroundSize.Width() - aSplitSize.Width() - aSplitPos.X(), aPlaygroundSize.Height(), ::com::sun::star::awt::PosSize::POSSIZE);
+                                   aPlaygroundSize.Width() - aSplitSize.Width() - aSplitPos.X(), aPlaygroundSize.Height(), css::awt::PosSize::POSSIZE);
 
     // just for completeness: there is no space left, we occupied it all ...
     _rPlayground.SetPos( _rPlayground.BottomRight() );
@@ -263,14 +254,14 @@ SbaGridControl* UnoDataBrowserView::getVclControl() const
         OSL_ENSURE(m_xGrid.is(),"Grid not set!");
         if ( m_xGrid.is() )
         {
-            Reference< ::com::sun::star::awt::XWindowPeer >  xPeer = m_xGrid->getPeer();
+            Reference< css::awt::XWindowPeer >  xPeer = m_xGrid->getPeer();
             if ( xPeer.is() )
             {
                 SbaXGridPeer* pPeer = SbaXGridPeer::getImplementation(xPeer);
                 UnoDataBrowserView* pTHIS = const_cast<UnoDataBrowserView*>(this);
                 if ( pPeer )
                 {
-                    m_pVclControl = static_cast<SbaGridControl*>(pPeer->GetWindow());
+                    m_pVclControl = static_cast<SbaGridControl*>(pPeer->GetWindow().get());
                     pTHIS->startComponentListening(Reference<XComponent>(VCLUnoHelper::GetInterface(m_pVclControl),UNO_QUERY));
                 }
             }
@@ -286,7 +277,7 @@ void UnoDataBrowserView::GetFocus()
         m_pTreeView->GrabFocus();
     else if (m_pVclControl && m_xGrid.is())
     {
-        sal_Bool bGrabFocus = sal_False;
+        bool bGrabFocus = false;
         if(!m_pVclControl->HasChildPathFocus())
         {
             bGrabFocus = isGrabVclControlFocusAllowed(this);
@@ -298,24 +289,24 @@ void UnoDataBrowserView::GetFocus()
     }
 }
 
-void UnoDataBrowserView::_disposing( const ::com::sun::star::lang::EventObject& /*_rSource*/ )
+void UnoDataBrowserView::_disposing( const css::lang::EventObject& /*_rSource*/ )
 {
     stopComponentListening(Reference<XComponent>(VCLUnoHelper::GetInterface(m_pVclControl),UNO_QUERY));
-    m_pVclControl = NULL;
+    m_pVclControl = nullptr;
 }
 
-long UnoDataBrowserView::PreNotify( NotifyEvent& rNEvt )
+bool UnoDataBrowserView::PreNotify( NotifyEvent& rNEvt )
 {
-    long nDone = 0L;
-    if(rNEvt.GetType() == EVENT_KEYINPUT)
+    bool bDone = false;
+    if(rNEvt.GetType() == MouseNotifyEvent::KEYINPUT)
     {
-        sal_Bool bGrabAllowed = isGrabVclControlFocusAllowed(this);
+        bool bGrabAllowed = isGrabVclControlFocusAllowed(this);
         if ( bGrabAllowed )
         {
             const KeyEvent* pKeyEvt = rNEvt.GetKeyEvent();
-            const KeyCode& rKeyCode = pKeyEvt->GetKeyCode();
-            if (  ( rKeyCode == KeyCode( KEY_E, sal_True, sal_True, sal_False, sal_False ) )
-               || ( rKeyCode == KeyCode( KEY_TAB, sal_True, sal_False, sal_False, sal_False ) )
+            const vcl::KeyCode& rKeyCode = pKeyEvt->GetKeyCode();
+            if (  ( rKeyCode == vcl::KeyCode( KEY_E, true, true, false, false ) )
+               || ( rKeyCode == vcl::KeyCode( KEY_TAB, true, false, false, false ) )
                )
             {
                 if ( m_pTreeView && m_pVclControl && m_pTreeView->HasChildPathFocus() )
@@ -323,18 +314,16 @@ long UnoDataBrowserView::PreNotify( NotifyEvent& rNEvt )
                 else if ( m_pTreeView && m_pVclControl && m_pVclControl->HasChildPathFocus() )
                     m_pTreeView->GrabFocus();
 
-                nDone = 1L;
+                bDone = true;
             }
         }
     }
-    return nDone ? nDone : ODataView::PreNotify(rNEvt);
+    return bDone || ODataView::PreNotify(rNEvt);
 }
 
-DBG_NAME(BrowserViewStatusDisplay)
 BrowserViewStatusDisplay::BrowserViewStatusDisplay( UnoDataBrowserView* _pView, const OUString& _rStatus )
     :m_pView(_pView)
 {
-    DBG_CTOR(BrowserViewStatusDisplay,NULL);
 
     if (m_pView)
         m_pView->showStatus(_rStatus);
@@ -345,7 +334,6 @@ BrowserViewStatusDisplay::~BrowserViewStatusDisplay( )
     if (m_pView)
         m_pView->showStatus(OUString());
 
-    DBG_DTOR(BrowserViewStatusDisplay,NULL);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
