@@ -20,12 +20,6 @@
 #include <config_folders.h>
 #include "odbcconfig.hxx"
 
-#ifdef SYSTEM_ODBC_HEADERS
-#include <sqltypes.h>
-#else
-#include <odbc/sqltypes.h>
-#endif
-
 #include <rtl/bootstrap.hxx>
 #include <rtl/ustring.hxx>
 #include <rtl/ustrbuf.hxx>
@@ -37,7 +31,7 @@
 
 #ifdef HAVE_ODBC_SUPPORT
 
-#if defined WNT
+#if defined(_WIN32)
 #define ODBC_LIBRARY    "ODBC32.DLL"
 #endif
 #ifdef UNX
@@ -49,35 +43,7 @@
 #endif
 #endif
 
-// just to go with calling convention of windows
-// so don't touch this
-#if defined(WNT)
-#undef SQL_API
-#define SQL_API __stdcall
-// At least under some circumstances, the below #include <odbc/sqlext.h> re-
-// defines SQL_API to an empty string, leading to a compiler warning on MSC; to
-// not break the current behavior, this is worked around by locally disabling
-// that warning:
-#if defined _MSC_VER
-#pragma warning(push)
-#pragma warning(disable: 4005)
-#endif
-#endif // defined(WNT)
-
-#ifdef SYSTEM_ODBC_HEADERS
-#include <sqlext.h>
-#else
-#include <odbc/sqlext.h>
-#endif
-
-#if defined(WNT)
-#if defined _MSC_VER
-#pragma warning(pop)
-#endif
-#undef SQL_API
-#define SQL_API __stdcall
-#endif // defined(WNT)
-// from here on you can do what you want to
+#include <connectivity/odbc.hxx>
 
 #else
 
@@ -96,82 +62,64 @@ typedef SQLRETURN (SQL_API* TSQLSetEnvAttr) (SQLHENV EnvironmentHandle, SQLINTEG
 typedef SQLRETURN (SQL_API* TSQLDataSources) (SQLHENV EnvironmentHandle, SQLUSMALLINT   Direction, SQLCHAR* ServerName,
                                 SQLSMALLINT BufferLength1, SQLSMALLINT* NameLength1Ptr, SQLCHAR* Description, SQLSMALLINT BufferLength2, SQLSMALLINT* NameLength2Ptr);
 
-#define NSQLAllocHandle(a,b,c) (*(TSQLAllocHandle)(m_pAllocHandle))(a,b,c)
-#define NSQLFreeHandle(a,b) (*(TSQLFreeHandle)(m_pFreeHandle))(a,b)
-#define NSQLSetEnvAttr(a,b,c,d) (*(TSQLSetEnvAttr)(m_pSetEnvAttr))(a,b,c,d)
-#define NSQLDataSources(a,b,c,d,e,f,g,h) (*(TSQLDataSources)(m_pDataSources))(a,b,c,d,e,f,g,h)
+#define NSQLAllocHandle(a,b,c) (*reinterpret_cast<TSQLAllocHandle>(m_pAllocHandle))(a,b,c)
+#define NSQLFreeHandle(a,b) (*reinterpret_cast<TSQLFreeHandle>(m_pFreeHandle))(a,b)
+#define NSQLSetEnvAttr(a,b,c,d) (*reinterpret_cast<TSQLSetEnvAttr>(m_pSetEnvAttr))(a,b,c,d)
+#define NSQLDataSources(a,b,c,d,e,f,g,h) (*reinterpret_cast<TSQLDataSources>(m_pDataSources))(a,b,c,d,e,f,g,h)
 #endif
 
 // OOdbcLibWrapper
-DBG_NAME(OOdbcLibWrapper)
-#ifdef HAVE_ODBC_SUPPORT
-OOdbcLibWrapper::OOdbcLibWrapper()
-    :m_pOdbcLib(NULL)
-{
-    DBG_CTOR(OOdbcLibWrapper,NULL);
 
-}
-
-#endif
-
-sal_Bool OOdbcLibWrapper::load(const sal_Char* _pLibPath)
+bool OOdbcEnumeration::load(const sal_Char* _pLibPath)
 {
     m_sLibPath = OUString::createFromAscii(_pLibPath);
 #ifdef HAVE_ODBC_SUPPORT
     // load the module
     m_pOdbcLib = osl_loadModule(m_sLibPath.pData, SAL_LOADMODULE_NOW);
-    return (NULL != m_pOdbcLib);
+    return (nullptr != m_pOdbcLib);
 #else
     return sal_False;
 #endif
 }
 
-void OOdbcLibWrapper::unload()
+void OOdbcEnumeration::unload()
 {
 #ifdef HAVE_ODBC_SUPPORT
     if (isLoaded())
     {
         osl_unloadModule(m_pOdbcLib);
-        m_pOdbcLib = NULL;
+        m_pOdbcLib = nullptr;
     }
 #endif
 }
 
-oslGenericFunction OOdbcLibWrapper::loadSymbol(const sal_Char* _pFunctionName)
+oslGenericFunction OOdbcEnumeration::loadSymbol(const sal_Char* _pFunctionName)
 {
     return osl_getFunctionSymbol(m_pOdbcLib, OUString::createFromAscii(_pFunctionName).pData);
 }
 
-OOdbcLibWrapper::~OOdbcLibWrapper()
-{
-    unload();
 
-    DBG_DTOR(OOdbcLibWrapper,NULL);
-}
-
-// OOdbcEnumeration
 struct OdbcTypesImpl
 {
 #ifdef HAVE_ODBC_SUPPORT
     SQLHANDLE   hEnvironment;
-    OdbcTypesImpl() : hEnvironment(0) { }
+    OdbcTypesImpl() : hEnvironment(nullptr) { }
 #else
     void*       pDummy;
 #endif
 };
 
-DBG_NAME(OOdbcEnumeration)
 OOdbcEnumeration::OOdbcEnumeration()
+    :m_pOdbcLib(nullptr)
 #ifdef HAVE_ODBC_SUPPORT
-    :m_pAllocHandle(NULL)
-    ,m_pSetEnvAttr(NULL)
-    ,m_pDataSources(NULL)
+    ,m_pAllocHandle(nullptr)
+    ,m_pFreeHandle(nullptr)
+    ,m_pSetEnvAttr(nullptr)
+    ,m_pDataSources(nullptr)
     ,m_pImpl(new OdbcTypesImpl)
 #endif
 {
-    DBG_CTOR(OOdbcEnumeration,NULL);
-
-    sal_Bool bLoaded = load(ODBC_LIBRARY);
+    bool bLoaded = load(ODBC_LIBRARY);
 #ifdef ODBC_LIBRARY_1
     if ( !bLoaded )
         bLoaded = load(ODBC_LIBRARY_1);
@@ -190,7 +138,7 @@ OOdbcEnumeration::OOdbcEnumeration()
         if (!m_pAllocHandle || !m_pSetEnvAttr || !m_pDataSources || !m_pFreeHandle)
         {
             unload();
-            m_pAllocHandle = m_pFreeHandle = m_pSetEnvAttr = m_pDataSources = NULL;
+            m_pAllocHandle = m_pFreeHandle = m_pSetEnvAttr = m_pDataSources = nullptr;
         }
 #endif
     }
@@ -200,27 +148,27 @@ OOdbcEnumeration::~OOdbcEnumeration()
 {
     freeEnv();
     delete m_pImpl;
-
-    DBG_DTOR(OOdbcEnumeration,NULL);
+    unload();
 }
 
-sal_Bool OOdbcEnumeration::allocEnv()
+// OOdbcEnumeration
+bool OOdbcEnumeration::allocEnv()
 {
     OSL_ENSURE(isLoaded(), "OOdbcEnumeration::allocEnv: not loaded!");
     if (!isLoaded())
-        return sal_False;
+        return false;
 
 #ifdef HAVE_ODBC_SUPPORT
     if (m_pImpl->hEnvironment)
         // nothing to do
-        return sal_True;
+        return true;
     SQLRETURN nResult = NSQLAllocHandle(SQL_HANDLE_ENV, SQL_NULL_HANDLE, &m_pImpl->hEnvironment);
     if (SQL_SUCCESS != nResult)
         // can't do anything without environment
-        return sal_False;
+        return false;
 
-    NSQLSetEnvAttr(m_pImpl->hEnvironment, SQL_ATTR_ODBC_VERSION, (SQLPOINTER)SQL_OV_ODBC3, SQL_IS_INTEGER);
-    return sal_True;
+    NSQLSetEnvAttr(m_pImpl->hEnvironment, SQL_ATTR_ODBC_VERSION, reinterpret_cast<SQLPOINTER>(SQL_OV_ODBC3), SQL_IS_INTEGER);
+    return true;
 #else
     return sal_False;
 #endif
@@ -231,7 +179,7 @@ void OOdbcEnumeration::freeEnv()
 #ifdef HAVE_ODBC_SUPPORT
     if (m_pImpl->hEnvironment)
         NSQLFreeHandle(SQL_HANDLE_ENV, m_pImpl->hEnvironment);
-    m_pImpl->hEnvironment  = 0;
+    m_pImpl->hEnvironment  = nullptr;
 #endif
 }
 
@@ -280,11 +228,11 @@ void OOdbcEnumeration::getDatasourceNames(StringBag& _rNames)
 // ProcessTerminationWait
 class ProcessTerminationWait : public ::osl::Thread
 {
-    oslProcess  m_hProcessHandle;
-    Link        m_aFinishHdl;
+    oslProcess       m_hProcessHandle;
+    Link<void*,void> m_aFinishHdl;
 
 public:
-    ProcessTerminationWait( oslProcess _hProcessHandle, const Link& _rFinishHdl )
+    ProcessTerminationWait( oslProcess _hProcessHandle, const Link<void*,void>& _rFinishHdl )
         :m_hProcessHandle( _hProcessHandle )
         ,m_aFinishHdl( _rFinishHdl )
     {
@@ -293,6 +241,8 @@ public:
 protected:
     virtual void SAL_CALL run()
     {
+        osl_setThreadName("dbaui::ProcessTerminationWait");
+
         osl_joinProcess( m_hProcessHandle );
         osl_freeProcessHandle( m_hProcessHandle );
         Application::PostUserEvent( m_aFinishHdl );
@@ -300,9 +250,8 @@ protected:
 };
 
 // OOdbcManagement
-OOdbcManagement::OOdbcManagement( const Link& _rAsyncFinishCallback )
-    :m_pProcessWait( NULL )
-    ,m_aAsyncFinishCallback( _rAsyncFinishCallback )
+OOdbcManagement::OOdbcManagement(const Link<void*,void>& rAsyncFinishCallback)
+    : m_aAsyncFinishCallback(rAsyncFinishCallback)
 {
 }
 
