@@ -18,6 +18,7 @@
  */
 
 #include "textconnectionsettings.hxx"
+#include "uiservices.hxx"
 #include "dbu_reghelper.hxx"
 #include "moduledbu.hxx"
 #include "apitools.hxx"
@@ -31,19 +32,16 @@
 
 #include <comphelper/processfactory.hxx>
 #include <svtools/genericunodialog.hxx>
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 
 namespace dbaui
 {
 
     using ::com::sun::star::uno::Reference;
     using ::com::sun::star::uno::XInterface;
-    using ::com::sun::star::uno::UNO_QUERY;
-    using ::com::sun::star::uno::UNO_QUERY_THROW;
     using ::com::sun::star::uno::Exception;
     using ::com::sun::star::uno::RuntimeException;
     using ::com::sun::star::uno::Any;
-    using ::com::sun::star::uno::makeAny;
     using ::com::sun::star::uno::XComponentContext;
     using ::com::sun::star::beans::XPropertySetInfo;
     using ::com::sun::star::uno::Sequence;
@@ -55,54 +53,56 @@ namespace dbaui
     // OTextConnectionSettingsDialog
 
     class OTextConnectionSettingsDialog;
-    typedef ::cppu::ImplInheritanceHelper1  <   ODatabaseAdministrationDialog
-                                            ,   ::com::sun::star::sdb::XTextConnectionSettings
-                                            >   OTextConnectionSettingsDialog_BASE;
+    typedef ::cppu::ImplInheritanceHelper<   ODatabaseAdministrationDialog
+                                         ,   css::sdb::XTextConnectionSettings
+                                         >   OTextConnectionSettingsDialog_BASE;
     typedef ::comphelper::OPropertyArrayUsageHelper< OTextConnectionSettingsDialog >    OTextConnectionSettingsDialog_PBASE;
 
     class OTextConnectionSettingsDialog
             :public OTextConnectionSettingsDialog_BASE
             ,public OTextConnectionSettingsDialog_PBASE
-            ,public ::cppu::WeakImplHelper1< com::sun::star::sdb::XTextConnectionSettings >
+            ,public ::cppu::WeakImplHelper< css::sdb::XTextConnectionSettings >
     {
         OModuleClient   m_aModuleClient;
         PropertyValues  m_aPropertyValues;
 
     protected:
-        OTextConnectionSettingsDialog( const Reference<XComponentContext>& _rContext );
+        explicit OTextConnectionSettingsDialog( const Reference<XComponentContext>& _rContext );
         virtual ~OTextConnectionSettingsDialog();
 
     public:
-        DECLARE_IMPLEMENTATION_ID( );
+        virtual css::uno::Sequence<sal_Int8> SAL_CALL getImplementationId()
+            throw (css::uno::RuntimeException, std::exception) override;
+
         DECLARE_SERVICE_INFO_STATIC( );
         DECLARE_PROPERTYCONTAINER_DEFAULTS( );
 
-        virtual void SAL_CALL setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const Any& rValue ) throw(Exception);
-        virtual sal_Bool SAL_CALL convertFastPropertyValue( Any& rConvertedValue, Any& rOldValue, sal_Int32 nHandle, const Any& rValue) throw(IllegalArgumentException);
-        virtual void SAL_CALL getFastPropertyValue( Any& rValue, sal_Int32 nHandle ) const;
+        virtual void SAL_CALL setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const Any& rValue ) throw(Exception, std::exception) override;
+        virtual sal_Bool SAL_CALL convertFastPropertyValue( Any& rConvertedValue, Any& rOldValue, sal_Int32 nHandle, const Any& rValue) throw(IllegalArgumentException) override;
+        virtual void SAL_CALL getFastPropertyValue( Any& rValue, sal_Int32 nHandle ) const override;
 
         // Overrides to resolve inheritance ambiguity
-        virtual void SAL_CALL setPropertyValue(const OUString& p1, const css::uno::Any& p2) throw (css::uno::RuntimeException)
+        virtual void SAL_CALL setPropertyValue(const OUString& p1, const css::uno::Any& p2) throw (css::uno::RuntimeException, std::exception) override
             { ODatabaseAdministrationDialog::setPropertyValue(p1, p2); }
-        virtual css::uno::Any SAL_CALL getPropertyValue(const OUString& p1) throw (css::uno::RuntimeException)
+        virtual css::uno::Any SAL_CALL getPropertyValue(const OUString& p1) throw (css::uno::RuntimeException, std::exception) override
             { return ODatabaseAdministrationDialog::getPropertyValue(p1); }
-        virtual void SAL_CALL addPropertyChangeListener(const OUString& p1, const css::uno::Reference<css::beans::XPropertyChangeListener>& p2) throw (css::uno::RuntimeException)
+        virtual void SAL_CALL addPropertyChangeListener(const OUString& p1, const css::uno::Reference<css::beans::XPropertyChangeListener>& p2) throw (css::beans::UnknownPropertyException, css::uno::RuntimeException, std::exception) override
             { ODatabaseAdministrationDialog::addPropertyChangeListener(p1, p2); }
-        virtual void SAL_CALL removePropertyChangeListener(const OUString& p1, const css::uno::Reference<css::beans::XPropertyChangeListener>& p2) throw (css::uno::RuntimeException)
+        virtual void SAL_CALL removePropertyChangeListener(const OUString& p1, const css::uno::Reference<css::beans::XPropertyChangeListener>& p2) throw (css::beans::UnknownPropertyException, css::uno::RuntimeException, std::exception) override
             { ODatabaseAdministrationDialog::removePropertyChangeListener(p1, p2); }
-        virtual void SAL_CALL addVetoableChangeListener(const OUString& p1, const css::uno::Reference<css::beans::XVetoableChangeListener>& p2) throw (css::uno::RuntimeException)
+        virtual void SAL_CALL addVetoableChangeListener(const OUString& p1, const css::uno::Reference<css::beans::XVetoableChangeListener>& p2) throw (css::beans::UnknownPropertyException, css::uno::RuntimeException, std::exception) override
             { ODatabaseAdministrationDialog::addVetoableChangeListener(p1, p2); }
-        virtual void SAL_CALL removeVetoableChangeListener(const OUString& p1, const css::uno::Reference<css::beans::XVetoableChangeListener>& p2) throw (css::uno::RuntimeException)
+        virtual void SAL_CALL removeVetoableChangeListener(const OUString& p1, const css::uno::Reference<css::beans::XVetoableChangeListener>& p2) throw (css::beans::UnknownPropertyException, css::uno::RuntimeException, std::exception) override
             { ODatabaseAdministrationDialog::removeVetoableChangeListener(p1, p2); }
-        virtual void SAL_CALL setTitle(const OUString& p1) throw (css::uno::RuntimeException)
+        virtual void SAL_CALL setTitle(const OUString& p1) throw (css::uno::RuntimeException, std::exception) override
             { ODatabaseAdministrationDialog::setTitle(p1); }
-        virtual sal_Int16 SAL_CALL execute() throw (css::uno::RuntimeException)
+        virtual sal_Int16 SAL_CALL execute() throw (css::uno::RuntimeException, std::exception) override
             { return ODatabaseAdministrationDialog::execute(); }
 
     protected:
         // OGenericUnoDialog overridables
-        virtual Dialog* createDialog( Window* _pParent );
-        virtual void implInitialize( const com::sun::star::uno::Any& _rValue );
+        virtual VclPtr<Dialog> createDialog( vcl::Window* _pParent ) override;
+        virtual void implInitialize( const css::uno::Any& _rValue ) override;
     protected:
         using OTextConnectionSettingsDialog_BASE::getFastPropertyValue;
     };
@@ -118,19 +118,24 @@ namespace dbaui
     {
     }
 
-    IMPLEMENT_IMPLEMENTATION_ID( OTextConnectionSettingsDialog )
+    css::uno::Sequence<sal_Int8>
+    OTextConnectionSettingsDialog::getImplementationId()
+        throw (css::uno::RuntimeException, std::exception)
+    {
+        return css::uno::Sequence<sal_Int8>();
+    }
 
     IMPLEMENT_SERVICE_INFO_IMPLNAME_STATIC(OTextConnectionSettingsDialog, "com.sun.star.comp.dbaccess.OTextConnectionSettingsDialog")
     IMPLEMENT_SERVICE_INFO_SUPPORTS(OTextConnectionSettingsDialog)
     IMPLEMENT_SERVICE_INFO_GETSUPPORTED1_STATIC(OTextConnectionSettingsDialog, "com.sun.star.sdb.TextConnectionSettings")
 
-    ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >
-        SAL_CALL OTextConnectionSettingsDialog::Create(const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& _rxORB)
+    css::uno::Reference< css::uno::XInterface >
+        SAL_CALL OTextConnectionSettingsDialog::Create(const css::uno::Reference< css::lang::XMultiServiceFactory >& _rxORB)
     {
         return static_cast< XServiceInfo* >(new OTextConnectionSettingsDialog( comphelper::getComponentContext(_rxORB)));
     }
 
-    Reference< XPropertySetInfo >  SAL_CALL OTextConnectionSettingsDialog::getPropertySetInfo() throw(RuntimeException)
+    Reference< XPropertySetInfo >  SAL_CALL OTextConnectionSettingsDialog::getPropertySetInfo() throw(RuntimeException, std::exception)
     {
         return createPropertySetInfo( getInfoHelper() );
     }
@@ -196,9 +201,9 @@ namespace dbaui
         return new ::cppu::OPropertyArrayHelper( aProps );
     }
 
-    Dialog* OTextConnectionSettingsDialog::createDialog(Window* _pParent)
+    VclPtr<Dialog> OTextConnectionSettingsDialog::createDialog(vcl::Window* _pParent)
     {
-        return new TextConnectionSettingsDialog( _pParent, *m_pDatasourceItems );
+        return VclPtr<TextConnectionSettingsDialog>::Create( _pParent, *m_pDatasourceItems );
     }
 
     void OTextConnectionSettingsDialog::implInitialize(const Any& _rValue)
@@ -206,7 +211,7 @@ namespace dbaui
         OTextConnectionSettingsDialog_BASE::implInitialize( _rValue );
     }
 
-    void SAL_CALL OTextConnectionSettingsDialog::setFastPropertyValue_NoBroadcast( sal_Int32 _nHandle, const Any& _rValue ) throw(Exception)
+    void SAL_CALL OTextConnectionSettingsDialog::setFastPropertyValue_NoBroadcast( sal_Int32 _nHandle, const Any& _rValue ) throw(Exception, std::exception)
     {
         PropertyValues::const_iterator pos = m_aPropertyValues.find( _nHandle );
         if ( pos != m_aPropertyValues.end() )
@@ -221,7 +226,7 @@ namespace dbaui
 
     sal_Bool SAL_CALL OTextConnectionSettingsDialog::convertFastPropertyValue( Any& _rConvertedValue, Any& _rOldValue, sal_Int32 _nHandle, const Any& _rValue) throw(IllegalArgumentException)
     {
-        sal_Bool bModified = sal_False;
+        bool bModified = false;
 
         PropertyValues::const_iterator pos = m_aPropertyValues.find( _nHandle );
         if ( pos != m_aPropertyValues.end() )
@@ -229,7 +234,7 @@ namespace dbaui
             // we're lazy here ...
             _rConvertedValue = _rValue;
             pos->second->getPropertyValue( _rOldValue );
-            bModified = sal_True;
+            bModified = true;
         }
         else
         {
