@@ -27,12 +27,10 @@ using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
 
-
 namespace migration
 {
 
 
-
     #define sSourceUserBasic "/user/basic"
     #define sTargetUserBasic "/user/__basic_80"
 
@@ -46,7 +44,6 @@ namespace migration
     }
 
 
-
     Sequence< OUString > BasicMigration_getSupportedServiceNames()
     {
         Sequence< OUString > aNames { "com.sun.star.migration.Basic" };
@@ -62,13 +59,11 @@ namespace migration
     }
 
 
-
     BasicMigration::~BasicMigration()
     {
     }
 
 
-
     TStringVectorPtr BasicMigration::getFiles( const OUString& rBaseURL ) const
     {
         TStringVectorPtr aResult( new TStringVector );
@@ -105,8 +100,7 @@ namespace migration
     }
 
 
-
-    ::osl::FileBase::RC BasicMigration::checkAndCreateDirectory( INetURLObject& rDirURL )
+    void BasicMigration::checkAndCreateDirectory( INetURLObject& rDirURL )
     {
         ::osl::FileBase::RC aResult = ::osl::Directory::create( rDirURL.GetMainURL( INetURLObject::DECODE_TO_IURI ) );
         if ( aResult == ::osl::FileBase::E_NOENT )
@@ -114,16 +108,11 @@ namespace migration
             INetURLObject aBaseURL( rDirURL );
             aBaseURL.removeSegment();
             checkAndCreateDirectory( aBaseURL );
-            return ::osl::Directory::create( rDirURL.GetMainURL( INetURLObject::DECODE_TO_IURI ) );
-        }
-        else
-        {
-            return aResult;
+            ::osl::Directory::create( rDirURL.GetMainURL( INetURLObject::DECODE_TO_IURI ) );
         }
     }
 
 
-
     void BasicMigration::copyFiles()
     {
         OUString sTargetDir;
@@ -167,7 +156,6 @@ namespace migration
     }
 
 
-
     sal_Bool BasicMigration::supportsService(OUString const & ServiceName)
         throw (css::uno::RuntimeException, std::exception)
     {
@@ -175,7 +163,6 @@ namespace migration
     }
 
 
-
     Sequence< OUString > BasicMigration::getSupportedServiceNames() throw (RuntimeException, std::exception)
     {
         return BasicMigration_getSupportedServiceNames();
@@ -232,8 +219,6 @@ namespace migration
     }
 
 
-
-
 }   // namespace migration
 
 
