@@ -27,17 +27,14 @@ using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
 
-
 namespace migration
 {
 
 
-
     static const char sSourceSubDir[] = "/user/wordbook";
     static const char sTargetSubDir[] = "/user/wordbook";
 
 
-
     // component operations
 
 
@@ -47,7 +44,6 @@ namespace migration
     }
 
 
-
     Sequence< OUString > WordbookMigration_getSupportedServiceNames()
     {
         return Sequence< OUString > { "com.sun.star.migration.Wordbooks" };
@@ -62,13 +58,11 @@ namespace migration
     }
 
 
-
     WordbookMigration::~WordbookMigration()
     {
     }
 
 
-
     TStringVectorPtr WordbookMigration::getFiles( const OUString& rBaseURL ) const
     {
         TStringVectorPtr aResult( new TStringVector );
@@ -105,8 +99,7 @@ namespace migration
     }
 
 
-
-    ::osl::FileBase::RC WordbookMigration::checkAndCreateDirectory( INetURLObject& rDirURL )
+    void WordbookMigration::checkAndCreateDirectory( INetURLObject& rDirURL )
     {
         ::osl::FileBase::RC aResult = ::osl::Directory::create( rDirURL.GetMainURL( INetURLObject::DECODE_TO_IURI ) );
         if ( aResult == ::osl::FileBase::E_NOENT )
@@ -114,11 +107,7 @@ namespace migration
             INetURLObject aBaseURL( rDirURL );
             aBaseURL.removeSegment();
             checkAndCreateDirectory( aBaseURL );
-            return ::osl::Directory::create( rDirURL.GetMainURL( INetURLObject::DECODE_TO_IURI ) );
-        }
-        else
-        {
-            return aResult;
+            ::osl::Directory::create( rDirURL.GetMainURL( INetURLObject::DECODE_TO_IURI ) );
         }
     }
 
@@ -161,8 +150,6 @@ bool IsUserWordbook( const OUString& rFile )
 }
 
 
-
-
     void WordbookMigration::copyFiles()
     {
         OUString sTargetDir;
@@ -209,7 +196,6 @@ bool IsUserWordbook( const OUString& rFile )
     }
 
 
-
     sal_Bool WordbookMigration::supportsService(OUString const & ServiceName)
         throw (css::uno::RuntimeException, std::exception)
     {
@@ -217,7 +203,6 @@ bool IsUserWordbook( const OUString& rFile )
     }
 
 
-
     Sequence< OUString > WordbookMigration::getSupportedServiceNames() throw (RuntimeException, std::exception)
     {
         return WordbookMigration_getSupportedServiceNames();
@@ -274,8 +259,6 @@ bool IsUserWordbook( const OUString& rFile )
     }
 
 
-
-
 }   // namespace migration
 
 
