@@ -26,11 +26,9 @@
 #include <drawinglayer/primitive2d/drawinglayer_primitivetypes2d.hxx>
 
 
-
 using namespace com::sun::star;
 
 
-
 namespace drawinglayer
 {
     namespace primitive2d
@@ -66,7 +64,7 @@ namespace drawinglayer
 
             switch(getFillGradient().getStyle())
             {
-                case attribute::GRADIENTSTYLE_LINEAR:
+                case attribute::GradientStyle::Linear:
                 {
                     texture::GeoTexSvxGradientLinear aGradient(
                         getDefinitionRange(),
@@ -79,7 +77,7 @@ namespace drawinglayer
                     aGradient.appendTransformationsAndColors(rEntries, rOuterColor);
                     break;
                 }
-                case attribute::GRADIENTSTYLE_AXIAL:
+                case attribute::GradientStyle::Axial:
                 {
                     texture::GeoTexSvxGradientAxial aGradient(
                         getDefinitionRange(),
@@ -92,7 +90,7 @@ namespace drawinglayer
                     aGradient.appendTransformationsAndColors(rEntries, rOuterColor);
                     break;
                 }
-                case attribute::GRADIENTSTYLE_RADIAL:
+                case attribute::GradientStyle::Radial:
                 {
                     texture::GeoTexSvxGradientRadial aGradient(
                         getDefinitionRange(),
@@ -105,7 +103,7 @@ namespace drawinglayer
                     aGradient.appendTransformationsAndColors(rEntries, rOuterColor);
                     break;
                 }
-                case attribute::GRADIENTSTYLE_ELLIPTICAL:
+                case attribute::GradientStyle::Elliptical:
                 {
                     texture::GeoTexSvxGradientElliptical aGradient(
                         getDefinitionRange(),
@@ -119,7 +117,7 @@ namespace drawinglayer
                     aGradient.appendTransformationsAndColors(rEntries, rOuterColor);
                     break;
                 }
-                case attribute::GRADIENTSTYLE_SQUARE:
+                case attribute::GradientStyle::Square:
                 {
                     texture::GeoTexSvxGradientSquare aGradient(
                         getDefinitionRange(),
@@ -133,7 +131,7 @@ namespace drawinglayer
                     aGradient.appendTransformationsAndColors(rEntries, rOuterColor);
                     break;
                 }
-                case attribute::GRADIENTSTYLE_RECT:
+                case attribute::GradientStyle::Rect:
                 {
                     texture::GeoTexSvxGradientRect aGradient(
                         getDefinitionRange(),
@@ -150,13 +148,14 @@ namespace drawinglayer
             }
         }
 
-        Primitive2DSequence FillGradientPrimitive2D::createOverlappingFill(
+        Primitive2DContainer FillGradientPrimitive2D::createOverlappingFill(
             const std::vector< drawinglayer::texture::B2DHomMatrixAndBColor >& rEntries,
             const basegfx::BColor& rOuterColor,
             const basegfx::B2DPolygon& rUnitPolygon) const
         {
             // prepare return value
-            Primitive2DSequence aRetval(rEntries.size() + 1);
+            Primitive2DContainer aRetval;
+            aRetval.resize(rEntries.size() + 1);
 
             // create solid fill with outmost color
             aRetval[0] = Primitive2DReference(
@@ -183,13 +182,14 @@ namespace drawinglayer
             return aRetval;
         }
 
-        Primitive2DSequence FillGradientPrimitive2D::createNonOverlappingFill(
+        Primitive2DContainer FillGradientPrimitive2D::createNonOverlappingFill(
             const std::vector< drawinglayer::texture::B2DHomMatrixAndBColor >& rEntries,
             const basegfx::BColor& rOuterColor,
             const basegfx::B2DPolygon& rUnitPolygon) const
         {
             // prepare return value
-            Primitive2DSequence aRetval(rEntries.size() + 1);
+            Primitive2DContainer aRetval;
+            aRetval.resize(rEntries.size() + 1);
 
             // get outmost visible range from object
             basegfx::B2DRange aOutmostRange(getOutputRange());
@@ -245,20 +245,20 @@ namespace drawinglayer
             return aRetval;
         }
 
-        Primitive2DSequence FillGradientPrimitive2D::createFill(bool bOverlapping) const
+        Primitive2DContainer FillGradientPrimitive2D::createFill(bool bOverlapping) const
         {
             // prepare shape of the Unit Polygon
             basegfx::B2DPolygon aUnitPolygon;
 
             switch(getFillGradient().getStyle())
             {
-                case attribute::GRADIENTSTYLE_RADIAL:
-                case attribute::GRADIENTSTYLE_ELLIPTICAL:
+                case attribute::GradientStyle::Radial:
+                case attribute::GradientStyle::Elliptical:
                 {
                     aUnitPolygon = basegfx::tools::createPolygonFromCircle(basegfx::B2DPoint(0.0, 0.0), 1.0);
                     break;
                 }
-                default: // GRADIENTSTYLE_LINEAR, attribute::GRADIENTSTYLE_AXIAL, attribute::GRADIENTSTYLE_SQUARE, attribute::GRADIENTSTYLE_RECT
+                default: // GradientStyle::Linear, attribute::GradientStyle::Axial, attribute::GradientStyle::Square, attribute::GradientStyle::Rect
                 {
                     aUnitPolygon = basegfx::tools::createPolygonFromRect(basegfx::B2DRange(-1.0, -1.0, 1.0, 1.0));
                     break;
@@ -282,14 +282,14 @@ namespace drawinglayer
             }
         }
 
-        Primitive2DSequence FillGradientPrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
+        Primitive2DContainer FillGradientPrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
         {
             // default creates overlapping fill which works with AntiAliasing and without.
             // The non-overlapping version does not create single filled polygons, but
             // PolyPolygons where each one describes a 'ring' for the gradient such
             // that the rings will not overlap. This is useful for the old XOR-paint
             // 'trick' of VCL which is recorded in Metafiles; so this version may be
-            // used from the MetafilePrimitive2D in it's decomposition.
+            // used from the MetafilePrimitive2D in its decomposition.
 
             if(!getFillGradient().isDefault())
             {
@@ -299,7 +299,7 @@ namespace drawinglayer
             }
             else
             {
-                return Primitive2DSequence();
+                return Primitive2DContainer();
             }
         }
 
