@@ -30,27 +30,25 @@
 #include <drawinglayer/primitive3d/polygonprimitive3d.hxx>
 #include <drawinglayer/primitive3d/drawinglayer_primitivetypes3d.hxx>
 
-//////////////////////////////////////////////////////////////////////////////
 
 using namespace com::sun::star;
 
-//////////////////////////////////////////////////////////////////////////////
 
 namespace drawinglayer
 {
     namespace primitive3d
     {
-        Primitive3DSequence HatchTexturePrimitive3D::impCreate3DDecomposition() const
+        Primitive3DContainer HatchTexturePrimitive3D::impCreate3DDecomposition() const
         {
-            Primitive3DSequence aRetval;
+            Primitive3DContainer aRetval;
 
-            if(getChildren().hasElements())
+            if(!getChildren().empty())
             {
-                const Primitive3DSequence aSource(getChildren());
-                const sal_uInt32 nSourceCount(aSource.getLength());
+                const Primitive3DContainer aSource(getChildren());
+                const size_t nSourceCount(aSource.size());
                 std::vector< Primitive3DReference > aDestination;
 
-                for(sal_uInt32 a(0); a < nSourceCount; a++)
+                for(size_t a(0); a < nSourceCount; a++)
                 {
                     // get reference
                     const Primitive3DReference xReference(aSource[a]);
@@ -70,7 +68,7 @@ namespace drawinglayer
                                 {
                                     // polyPolygonMaterialPrimitive3D, check texturing and hatching
                                     const PolyPolygonMaterialPrimitive3D& rPrimitive = static_cast< const PolyPolygonMaterialPrimitive3D& >(*pBasePrimitive);
-                                    const basegfx::B3DPolyPolygon aFillPolyPolygon(rPrimitive.getB3DPolyPolygon());
+                                    const basegfx::B3DPolyPolygon& aFillPolyPolygon(rPrimitive.getB3DPolyPolygon());
 
                                     if(maHatch.isFillBackground())
                                     {
@@ -142,22 +140,41 @@ namespace drawinglayer
                                             // get hatch transformations
                                             switch(getHatch().getStyle())
                                             {
-                                                case attribute::HATCHSTYLE_TRIPLE:
+                                                case attribute::HatchStyle::Triple:
                                                 {
                                                     // rotated 45 degrees
-                                                    texture::GeoTexSvxHatch aHatch(aOutlineRange, getHatch().getDistance(), fAngle - F_PI4);
+                                                    texture::GeoTexSvxHatch aHatch(
+                                                        aOutlineRange,
+                                                        aOutlineRange,
+                                                        getHatch().getDistance(),
+                                                        fAngle - F_PI4);
+
                                                     aHatch.appendTransformations(aMatrices);
+
+                                                    SAL_FALLTHROUGH;
                                                 }
-                                                case attribute::HATCHSTYLE_DOUBLE:
+                                                case attribute::HatchStyle::Double:
                                                 {
                                                     // rotated 90 degrees
-                                                    texture::GeoTexSvxHatch aHatch(aOutlineRange, getHatch().getDistance(), fAngle - F_PI2);
+                                                    texture::GeoTexSvxHatch aHatch(
+                                                        aOutlineRange,
+                                                        aOutlineRange,
+                                                        getHatch().getDistance(),
+                                                        fAngle - F_PI2);
+
                                                     aHatch.appendTransformations(aMatrices);
+
+                                                    SAL_FALLTHROUGH;
                                                 }
-                                                case attribute::HATCHSTYLE_SINGLE:
+                                                case attribute::HatchStyle::Single:
                                                 {
                                                     // angle as given
-                                                    texture::GeoTexSvxHatch aHatch(aOutlineRange, getHatch().getDistance(), fAngle);
+                                                    texture::GeoTexSvxHatch aHatch(
+                                                        aOutlineRange,
+                                                        aOutlineRange,
+                                                        getHatch().getDistance(),
+                                                        fAngle);
+
                                                     aHatch.appendTransformations(aMatrices);
                                                 }
                                             }
@@ -168,9 +185,8 @@ namespace drawinglayer
                                             a2DUnitLine.append(basegfx::B2DPoint(0.0, 0.0));
                                             a2DUnitLine.append(basegfx::B2DPoint(1.0, 0.0));
 
-                                            for(sal_uInt32 c(0); c < aMatrices.size(); c++)
+                                            for(basegfx::B2DHomMatrix & rMatrix : aMatrices)
                                             {
-                                                const basegfx::B2DHomMatrix& rMatrix = aMatrices[c];
                                                 basegfx::B2DPolygon aNewLine(a2DUnitLine);
                                                 aNewLine.transform(rMatrix);
                                                 a2DHatchLines.append(aNewLine);
@@ -250,7 +266,7 @@ namespace drawinglayer
 
                 // prepare return value
                 const sal_uInt32 nDestSize(aDestination.size());
-                aRetval.realloc(nDestSize);
+                aRetval.resize(nDestSize);
 
                 for(sal_uInt32 b(0); b < nDestSize; b++)
                 {
@@ -263,7 +279,7 @@ namespace drawinglayer
 
         HatchTexturePrimitive3D::HatchTexturePrimitive3D(
             const attribute::FillHatchAttribute& rHatch,
-            const Primitive3DSequence& rChildren,
+            const Primitive3DContainer& rChildren,
             const basegfx::B2DVector& rTextureSize,
             bool bModulate,
             bool bFilter)
@@ -277,7 +293,7 @@ namespace drawinglayer
         {
             if(TexturePrimitive3D::operator==(rPrimitive))
             {
-                const HatchTexturePrimitive3D& rCompare = (HatchTexturePrimitive3D&)rPrimitive;
+                const HatchTexturePrimitive3D& rCompare = static_cast<const HatchTexturePrimitive3D&>(rPrimitive);
 
                 return (getHatch() == rCompare.getHatch());
             }
@@ -285,13 +301,13 @@ namespace drawinglayer
             return false;
         }
 
-        Primitive3DSequence HatchTexturePrimitive3D::get3DDecomposition(const geometry::ViewInformation3D& /*rViewInformation*/) const
+        Primitive3DContainer HatchTexturePrimitive3D::get3DDecomposition(const geometry::ViewInformation3D& /*rViewInformation*/) const
         {
             ::osl::MutexGuard aGuard( m_aMutex );
 
-            if(!getBuffered3DDecomposition().hasElements())
+            if(getBuffered3DDecomposition().empty())
             {
-                const Primitive3DSequence aNewSequence(impCreate3DDecomposition());
+                const Primitive3DContainer aNewSequence(impCreate3DDecomposition());
                 const_cast< HatchTexturePrimitive3D* >(this)->setBuffered3DDecomposition(aNewSequence);
             }
 
