@@ -19,6 +19,7 @@
 
 #include "defaultforminspection.hxx"
 #include "pcrcommon.hxx"
+#include "pcrservices.hxx"
 #include "propresid.hrc"
 #include "formresid.hrc"
 #include "modulepcr.hxx"
@@ -27,20 +28,19 @@
 
 #include <com/sun/star/ucb/AlreadyInitializedException.hpp>
 #include <com/sun/star/lang/IllegalArgumentException.hpp>
-#include <cppuhelper/implbase1.hxx>
 #include <osl/diagnose.h>
 #include <sal/macros.h>
 
-//------------------------------------------------------------------------
+
 extern "C" void SAL_CALL createRegistryInfo_DefaultFormComponentInspectorModel()
 {
     ::pcr::OAutoRegistration< ::pcr::DefaultFormComponentInspectorModel > aAutoRegistration;
 }
 
-//........................................................................
+
 namespace pcr
 {
-//........................................................................
+
 
     using ::com::sun::star::uno::Reference;
     using ::com::sun::star::uno::Sequence;
@@ -49,16 +49,10 @@ namespace pcr
     using ::com::sun::star::uno::XInterface;
     using ::com::sun::star::uno::XComponentContext;
     using ::com::sun::star::uno::Exception;
-    using ::com::sun::star::lang::EventObject;
     using ::com::sun::star::inspection::PropertyCategoryDescriptor;
-    using ::com::sun::star::beans::UnknownPropertyException;
     using ::com::sun::star::ucb::AlreadyInitializedException;
     using ::com::sun::star::lang::IllegalArgumentException;
 
-    //====================================================================
-    //= DefaultFormComponentInspectorModel
-    //====================================================================
-    //--------------------------------------------------------------------
     DefaultFormComponentInspectorModel::DefaultFormComponentInspectorModel( bool _bUseFormFormComponentHandlers )
         :ImplInspectorModel()
         ,m_bUseFormComponentHandlers( _bUseFormFormComponentHandlers )
@@ -67,45 +61,44 @@ namespace pcr
     {
     }
 
-    //------------------------------------------------------------------------
+
     DefaultFormComponentInspectorModel::~DefaultFormComponentInspectorModel()
     {
     }
 
-    //------------------------------------------------------------------------
-    OUString SAL_CALL DefaultFormComponentInspectorModel::getImplementationName(  ) throw(RuntimeException)
+
+    OUString SAL_CALL DefaultFormComponentInspectorModel::getImplementationName(  ) throw(RuntimeException, std::exception)
     {
         return getImplementationName_static();
     }
 
-    //------------------------------------------------------------------------
-    Sequence< OUString > SAL_CALL DefaultFormComponentInspectorModel::getSupportedServiceNames(  ) throw(RuntimeException)
+
+    Sequence< OUString > SAL_CALL DefaultFormComponentInspectorModel::getSupportedServiceNames(  ) throw(RuntimeException, std::exception)
     {
         return getSupportedServiceNames_static();
     }
 
-    //------------------------------------------------------------------------
+
     OUString DefaultFormComponentInspectorModel::getImplementationName_static(  ) throw(RuntimeException)
     {
         return OUString("org.openoffice.comp.extensions.DefaultFormComponentInspectorModel");
     }
 
-    //------------------------------------------------------------------------
+
     Sequence< OUString > DefaultFormComponentInspectorModel::getSupportedServiceNames_static(  ) throw(RuntimeException)
     {
-        Sequence< OUString > aSupported(1);
-        aSupported[0] = "com.sun.star.form.inspection.DefaultFormComponentInspectorModel";
+        Sequence< OUString > aSupported { "com.sun.star.form.inspection.DefaultFormComponentInspectorModel" };
         return aSupported;
     }
 
-    //------------------------------------------------------------------------
+
     Reference< XInterface > SAL_CALL DefaultFormComponentInspectorModel::Create( const Reference< XComponentContext >& )
     {
         return *new DefaultFormComponentInspectorModel();
     }
 
-    //--------------------------------------------------------------------
-    Sequence< Any > SAL_CALL DefaultFormComponentInspectorModel::getHandlerFactories() throw (RuntimeException)
+
+    Sequence< Any > SAL_CALL DefaultFormComponentInspectorModel::getHandlerFactories() throw (RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -159,8 +152,8 @@ namespace pcr
         return aReturn;
     }
 
-    //--------------------------------------------------------------------
-    Sequence< PropertyCategoryDescriptor > SAL_CALL DefaultFormComponentInspectorModel::describeCategories(  ) throw (RuntimeException)
+
+    Sequence< PropertyCategoryDescriptor > SAL_CALL DefaultFormComponentInspectorModel::describeCategories(  ) throw (RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -188,8 +181,8 @@ namespace pcr
         return aReturn;
     }
 
-    //--------------------------------------------------------------------
-    ::sal_Int32 SAL_CALL DefaultFormComponentInspectorModel::getPropertyOrderIndex( const OUString& _rPropertyName ) throw (RuntimeException)
+
+    ::sal_Int32 SAL_CALL DefaultFormComponentInspectorModel::getPropertyOrderIndex( const OUString& _rPropertyName ) throw (RuntimeException, std::exception)
     {
         sal_Int32 nPropertyId( m_pInfoService->getPropertyId( _rPropertyName ) );
         if ( nPropertyId == -1 )
@@ -204,8 +197,8 @@ namespace pcr
         return m_pInfoService->getPropertyPos( nPropertyId );
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL DefaultFormComponentInspectorModel::initialize( const Sequence< Any >& _arguments ) throw (Exception, RuntimeException)
+
+    void SAL_CALL DefaultFormComponentInspectorModel::initialize( const Sequence< Any >& _arguments ) throw (Exception, RuntimeException, std::exception)
     {
         if ( m_bConstructed )
             throw AlreadyInitializedException();
@@ -229,13 +222,13 @@ namespace pcr
         throw IllegalArgumentException( OUString(), *this, 0 );
     }
 
-    //--------------------------------------------------------------------
+
     void DefaultFormComponentInspectorModel::createDefault()
     {
         m_bConstructed = true;
     }
 
-    //--------------------------------------------------------------------
+
     void DefaultFormComponentInspectorModel::createWithHelpSection( sal_Int32 _nMinHelpTextLines, sal_Int32 _nMaxHelpTextLines )
     {
         if ( ( _nMinHelpTextLines <= 0 ) || ( _nMaxHelpTextLines <= 0 ) || ( _nMinHelpTextLines > _nMaxHelpTextLines ) )
@@ -245,8 +238,8 @@ namespace pcr
         m_bConstructed = true;
     }
 
-//........................................................................
+
 } // namespace pcr
-//........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
