@@ -22,22 +22,18 @@
 #include "formresid.hrc"
 #include "propctrlr.hrc"
 #include <svtools/localresaccess.hxx>
-#include <tools/debug.hxx>
 #include <comphelper/extract.hxx>
 #include <sal/macros.h>
 #include <algorithm>
 #include <functional>
 
-//............................................................................
 namespace pcr
 {
-//............................................................................
-
     using namespace ::com::sun::star::uno;
 
-    //========================================================================
+
     //= OPropertyInfoImpl
-    //========================================================================
+
     struct OPropertyInfoImpl
     {
         OUString        sName;
@@ -56,7 +52,7 @@ namespace pcr
                         sal_uInt32                  _nUIFlags);
     };
 
-    //------------------------------------------------------------------------
+
     OPropertyInfoImpl::OPropertyInfoImpl(const OUString& _rName, sal_Int32 _nId,
                                    const OUString& aString, sal_uInt16 nP, const OString& sHid, sal_uInt32 _nUIFlags)
        :sName(_rName)
@@ -68,7 +64,7 @@ namespace pcr
     {
     }
 
-    //------------------------------------------------------------------------
+
     // Compare PropertyInfo
     struct PropertyInfoLessByName : public ::std::binary_function< OPropertyInfoImpl, OPropertyInfoImpl, bool >
     {
@@ -78,9 +74,9 @@ namespace pcr
         }
     };
 
-    //========================================================================
+
     //= OPropertyInfoService
-    //========================================================================
+
 #define DEF_INFO( ident, uinameres, pos, helpid, flags )       \
     OPropertyInfoImpl( PROPERTY_##ident, PROPERTY_ID_##ident, \
             PcrRes( RID_STR_##uinameres ).toString(), pos, HID_PROP_##helpid, flags )
@@ -98,8 +94,8 @@ namespace pcr
     DEF_INFO( ident, uinameres, pos, helpid, PROP_FLAG_##flag1 | PROP_FLAG_##flag2 | PROP_FLAG_##flag3 | PROP_FLAG_##flag4 )
 
     sal_uInt16              OPropertyInfoService::s_nCount = 0;
-    OPropertyInfoImpl*      OPropertyInfoService::s_pPropertyInfos = NULL;
-    //------------------------------------------------------------------------
+    OPropertyInfoImpl*      OPropertyInfoService::s_pPropertyInfos = nullptr;
+
     const OPropertyInfoImpl* OPropertyInfoService::getPropertyInfo()
     {
         if ( s_pPropertyInfos )
@@ -285,7 +281,7 @@ namespace pcr
         DEF_INFO_3( FONT,              FONT,               142, FONT,              FORM_VISIBLE, DIALOG_VISIBLE, COMPOSEABLE ),
         DEF_INFO_4( VISUALEFFECT,      VISUALEFFECT,       143, VISUALEFFECT,      FORM_VISIBLE, DIALOG_VISIBLE, ENUM_ONE, COMPOSEABLE ),
         DEF_INFO_4( ALIGN,             ALIGN,              144, ALIGN,             FORM_VISIBLE, DIALOG_VISIBLE, ENUM, COMPOSEABLE ),
-        DEF_INFO_3( VERTICAL_ALIGN,    VERTICAL_ALIGN,     145, VERTICAL_ALIGN,    FORM_VISIBLE, ENUM, COMPOSEABLE ),
+        DEF_INFO_4( VERTICAL_ALIGN,    VERTICAL_ALIGN,     145, VERTICAL_ALIGN,    FORM_VISIBLE, DIALOG_VISIBLE, ENUM, COMPOSEABLE ),
         DEF_INFO_3( ROWHEIGHT,         ROWHEIGHT,          146, ROWHEIGHT,         FORM_VISIBLE, DIALOG_VISIBLE, COMPOSEABLE ),
         DEF_INFO_3( BACKGROUNDCOLOR,   BACKGROUNDCOLOR,    147, BACKGROUNDCOLOR,   FORM_VISIBLE, DIALOG_VISIBLE, COMPOSEABLE ),
         DEF_INFO_3( SYMBOLCOLOR,       SYMBOLCOLOR,        148, SYMBOLCOLOR,       FORM_VISIBLE, DIALOG_VISIBLE, COMPOSEABLE ),
@@ -362,49 +358,42 @@ namespace pcr
         return s_pPropertyInfos;
     }
 
-    //------------------------------------------------------------------------
+
     sal_Int32 OPropertyInfoService::getPropertyId(const OUString& _rName) const
     {
         const OPropertyInfoImpl* pInfo = getPropertyInfo(_rName);
         return pInfo ? pInfo->nId : -1;
     }
 
-    //------------------------------------------------------------------------
-    OUString OPropertyInfoService::getPropertyName( sal_Int32 _nPropId )
-    {
-        const OPropertyInfoImpl* pInfo = getPropertyInfo(_nPropId);
-        return pInfo ? pInfo->sName : OUString();
-    }
 
-    //------------------------------------------------------------------------
     OUString OPropertyInfoService::getPropertyTranslation(sal_Int32 _nId) const
     {
         const OPropertyInfoImpl* pInfo = getPropertyInfo(_nId);
         return (pInfo) ? pInfo->sTranslation : OUString();
     }
 
-    //------------------------------------------------------------------------
+
     OString OPropertyInfoService::getPropertyHelpId(sal_Int32 _nId) const
     {
         const OPropertyInfoImpl* pInfo = getPropertyInfo(_nId);
         return (pInfo) ? pInfo->sHelpId : OString();
     }
 
-    //------------------------------------------------------------------------
+
     sal_Int16 OPropertyInfoService::getPropertyPos(sal_Int32 _nId) const
     {
         const OPropertyInfoImpl* pInfo = getPropertyInfo(_nId);
         return (pInfo) ? pInfo->nPos : 0xFFFF;
     }
 
-    //------------------------------------------------------------------------
+
     sal_uInt32 OPropertyInfoService::getPropertyUIFlags(sal_Int32 _nId) const
     {
         const OPropertyInfoImpl* pInfo = getPropertyInfo(_nId);
         return (pInfo) ? pInfo->nUIFlags : 0;
     }
 
-    //------------------------------------------------------------------------
+
     ::std::vector< OUString > OPropertyInfoService::getPropertyEnumRepresentations(sal_Int32 _nId) const
     {
         OSL_ENSURE( ( ( getPropertyUIFlags( _nId ) & PROP_FLAG_ENUM ) != 0 ) || ( _nId == PROPERTY_ID_TARGET_FRAME ),
@@ -528,18 +517,18 @@ namespace pcr
         return aReturn;
     }
 
-    //------------------------------------------------------------------------
-    sal_Bool OPropertyInfoService::isComposeable( const OUString& _rPropertyName ) const
+
+    bool OPropertyInfoService::isComposeable( const OUString& _rPropertyName ) const
     {
         sal_Int32 nId = getPropertyId( _rPropertyName );
         if ( nId == -1 )
-            return sal_False;
+            return false;
 
         sal_uInt32 nFlags = getPropertyUIFlags( nId );
         return ( nFlags & PROP_FLAG_COMPOSEABLE ) != 0;
     }
 
-    //------------------------------------------------------------------------
+
     const OPropertyInfoImpl* OPropertyInfoService::getPropertyInfo(const OUString& _rName)
     {
         // Initialization
@@ -551,16 +540,15 @@ namespace pcr
             s_pPropertyInfos, s_pPropertyInfos + s_nCount, aSearch, PropertyInfoLessByName() );
 
         if ( pInfo == s_pPropertyInfos + s_nCount )
-            return NULL;
+            return nullptr;
 
         if ( pInfo->sName != _rName )
-            return NULL;
+            return nullptr;
 
         return pInfo;
     }
 
 
-    //------------------------------------------------------------------------
     const OPropertyInfoImpl* OPropertyInfoService::getPropertyInfo(sal_Int32 _nId)
     {
         // Initialization
@@ -572,36 +560,32 @@ namespace pcr
             if (s_pPropertyInfos[i].nId == _nId)
                 return &s_pPropertyInfos[i];
 
-        return NULL;
+        return nullptr;
     }
 
-    //====================================================================
+
     //= DefaultEnumRepresentation
-    //====================================================================
-    DBG_NAME( DefaultEnumRepresentation )
-    //--------------------------------------------------------------------
+
+
     DefaultEnumRepresentation::DefaultEnumRepresentation( const IPropertyInfoService& _rInfo, const Type& _rType, sal_Int32 _nPropertyId )
-        :m_refCount( 0 )
-        ,m_rMetaData( _rInfo )
+        :m_rMetaData( _rInfo )
         ,m_aType( _rType )
         ,m_nPropertyId( _nPropertyId )
     {
-        DBG_CTOR( DefaultEnumRepresentation, NULL );
     }
 
-    //--------------------------------------------------------------------
+
     DefaultEnumRepresentation::~DefaultEnumRepresentation()
     {
-        DBG_DTOR( DefaultEnumRepresentation, NULL );
     }
 
-    //--------------------------------------------------------------------
+
     ::std::vector< OUString > SAL_CALL DefaultEnumRepresentation::getDescriptions() const
     {
         return m_rMetaData.getPropertyEnumRepresentations( m_nPropertyId );
     }
 
-    //--------------------------------------------------------------------
+
     void SAL_CALL DefaultEnumRepresentation::getValueFromDescription( const OUString& _rDescription, Any& _out_rValue ) const
     {
         sal_uInt32  nPropertyUIFlags = m_rMetaData.getPropertyUIFlags( m_nPropertyId );
@@ -644,7 +628,7 @@ namespace pcr
         }
     }
 
-    //--------------------------------------------------------------------
+
     OUString SAL_CALL DefaultEnumRepresentation::getDescriptionForValue( const Any& _rEnumValue ) const
     {
         OUString sReturn;
@@ -668,25 +652,8 @@ namespace pcr
         return sReturn;
     }
 
-    //--------------------------------------------------------------------
-    oslInterlockedCount SAL_CALL DefaultEnumRepresentation::acquire()
-    {
-        return osl_atomic_increment( &m_refCount );
-    }
 
-    //--------------------------------------------------------------------
-    oslInterlockedCount SAL_CALL DefaultEnumRepresentation::release()
-    {
-        if ( 0 == osl_atomic_decrement( &m_refCount ) )
-        {
-           delete this;
-           return 0;
-        }
-        return m_refCount;
-    }
-
-//............................................................................
 } // namespace pcr
-//............................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
