@@ -20,8 +20,8 @@
 #include <sal/config.h>
 
 #include <vcl/FilterConfigItem.hxx>
-#include <vcl/graphic.hxx>
-#include <vcl/bmpacc.hxx>
+#include <vcl/graph.hxx>
+#include <vcl/bitmapaccess.hxx>
 #include <vcl/animate.hxx>
 #include <tools/fract.hxx>
 #include "lzwdecom.hxx"
@@ -345,7 +345,7 @@ void TIFFReader::ReadTagData( sal_uInt16 nTagType, sal_uInt32 nDataLen)
             SAL_INFO("filter.tiff","Compression: " << nCompression);
             break;
 
-        case 0x0106:   // Photometric Interpreation
+        case 0x0106:   // Photometric Interpretation
             nPhotometricInterpretation = ReadIntData();
             SAL_INFO("filter.tiff","PhotometricInterpretation: " << nPhotometricInterpretation);
             break;
@@ -537,7 +537,6 @@ void TIFFReader::ReadTagData( sal_uInt16 nTagType, sal_uInt32 nDataLen)
 }
 
 
-
 bool TIFFReader::ReadMap()
 {
     if ( nCompression == 1 || nCompression == 32771 )
@@ -787,7 +786,6 @@ sal_uLong TIFFReader::GetBits( const sal_uInt8 * pSrc, sal_uLong nBitsPos, sal_u
 }
 
 
-
 bool TIFFReader::ConvertScanline(sal_Int32 nY)
 {
     sal_uInt32  nRed, nGreen, nBlue, ns, nVal, nByteCount;
@@ -1092,7 +1090,6 @@ bool TIFFReader::ConvertScanline(sal_Int32 nY)
 }
 
 
-
 void TIFFReader::MakePalCol()
 {
     if ( nDstBitsPerPixel <= 8 )
@@ -1143,7 +1140,6 @@ void TIFFReader::MakePalCol()
 }
 
 
-
 void TIFFReader::ReadHeader()
 {
     sal_uInt8 nbyte1(0), nbyte2(0);
@@ -1173,7 +1169,6 @@ bool TIFFReader::HasAlphaChannel() const
 }
 
 
-
 bool TIFFReader::ReadTIFF(SvStream & rTIFF, Graphic & rGraphic )
 {
     sal_uInt16  i, nNumTags(0), nTagType(0);
@@ -1374,15 +1369,15 @@ bool TIFFReader::ReadTIFF(SvStream & rTIFF, Graphic & rGraphic )
                     {
                         nBytesPerRow = ( nImageWidth * nSamplesPerPixel / nPlanes * nBitsPerSample + 7 ) >> 3;
 
-                        for ( sal_uLong j = 0; j < 4; j++ )
+                        for (sal_uInt8*& j : pMap)
                         {
                             try
                             {
-                                pMap[ j ] = new sal_uInt8[ nBytesPerRow ];
+                                j = new sal_uInt8[ nBytesPerRow ];
                             }
                             catch (const std::bad_alloc &)
                             {
-                                pMap[ j ] = nullptr;
+                                j = nullptr;
                                 bStatus = false;
                                 break;
                             }
@@ -1425,7 +1420,7 @@ bool TIFFReader::ReadTIFF(SvStream & rTIFF, Graphic & rGraphic )
                                 aImage = aBitmap;
 
                             AnimationBitmap aAnimationBitmap( aImage, Point( 0, 0 ), aBitmap.GetSizePixel(),
-                                                              ANIMATION_TIMEOUT_ON_CLICK, DISPOSE_BACK );
+                                                              ANIMATION_TIMEOUT_ON_CLICK, Disposal::Back );
 
                             aAnimation.Insert( aAnimationBitmap );
                         }
