@@ -18,7 +18,7 @@
  */
 
 #include <accelerators/acceleratorconfiguration.hxx>
-
+#include <accelerators/keymapping.hxx>
 #include <accelerators/presethandler.hxx>
 
 #include <xml/saxnamespacefilter.hxx>
@@ -57,19 +57,19 @@ namespace framework
     const char CFG_ENTRY_SECONDARY[] = "SecondaryKeys";
     const char CFG_PROP_COMMAND[] = "Command";
 
-    OUString lcl_getKeyString(salhelper::SingletonRef<framework::KeyMapping>& _rKeyMapping, const css::awt::KeyEvent& aKeyEvent)
+    OUString lcl_getKeyString(const css::awt::KeyEvent& aKeyEvent)
     {
         const sal_Int32 nBeginIndex = 4; // "KEY_" is the prefix of a identifier...
-        OUStringBuffer sKeyBuffer((_rKeyMapping->mapCodeToIdentifier(aKeyEvent.KeyCode)).copy(nBeginIndex));
+        OUStringBuffer sKeyBuffer((KeyMapping::get().mapCodeToIdentifier(aKeyEvent.KeyCode)).copy(nBeginIndex));
 
         if ( (aKeyEvent.Modifiers & css::awt::KeyModifier::SHIFT) == css::awt::KeyModifier::SHIFT )
-            sKeyBuffer.appendAscii("_SHIFT");
+            sKeyBuffer.append("_SHIFT");
         if ( (aKeyEvent.Modifiers & css::awt::KeyModifier::MOD1 ) == css::awt::KeyModifier::MOD1  )
-            sKeyBuffer.appendAscii("_MOD1");
+            sKeyBuffer.append("_MOD1");
         if ( (aKeyEvent.Modifiers & css::awt::KeyModifier::MOD2 ) == css::awt::KeyModifier::MOD2  )
-            sKeyBuffer.appendAscii("_MOD2");
+            sKeyBuffer.append("_MOD2");
         if ( (aKeyEvent.Modifiers & css::awt::KeyModifier::MOD3 ) == css::awt::KeyModifier::MOD3  )
-            sKeyBuffer.appendAscii("_MOD3");
+            sKeyBuffer.append("_MOD3");
 
         return sKeyBuffer.makeStringAndClear();
     }
@@ -77,7 +77,7 @@ namespace framework
 XMLBasedAcceleratorConfiguration::XMLBasedAcceleratorConfiguration(const css::uno::Reference< css::uno::XComponentContext >& xContext)
     : m_xContext      (xContext                     )
     , m_aPresetHandler(xContext                     )
-    , m_pWriteCache   (0                            )
+    , m_pWriteCache   (nullptr                            )
 {
 }
 
@@ -178,7 +178,7 @@ css::uno::Sequence< css::uno::Any > SAL_CALL XMLBasedAcceleratorConfiguration::g
 
     sal_Int32                           i              = 0;
     sal_Int32                           c              = lCommandList.getLength();
-    css::uno::Sequence< css::uno::Any > lPreferredOnes (c); // dont pack list!
+    css::uno::Sequence< css::uno::Any > lPreferredOnes (c); // don't pack list!
     AcceleratorCache&                   rCache         = impl_getCFG();
 
     for (i=0; i<c; ++i)
@@ -232,10 +232,11 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::reload()
     css::uno::Reference< css::io::XStream > xStreamNoLang;
     {
         SolarMutexGuard g;
-        xStream = m_aPresetHandler.openTarget(TARGET_CURRENT, true); // sal_True => open or create!
+        xStream = m_aPresetHandler.openTarget(TARGET_CURRENT,
+                css::embed::ElementModes::READ);
         try
         {
-            xStreamNoLang = m_aPresetHandler.openPreset(PRESET_DEFAULT, true);
+            xStreamNoLang = m_aPresetHandler.openPreset(PRESET_DEFAULT);
         }
         catch(const css::io::IOException&) {} // does not have to exist
     }
@@ -273,7 +274,8 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::store()
     css::uno::Reference< css::io::XStream > xStream;
     {
         SolarMutexGuard g;
-        xStream = m_aPresetHandler.openTarget(TARGET_CURRENT, true); // sal_True => open or create!
+        xStream = m_aPresetHandler.openTarget(TARGET_CURRENT,
+               css::embed::ElementModes::READWRITE); // open or create!
     }
 
     css::uno::Reference< css::io::XOutputStream > xOut;
@@ -320,7 +322,7 @@ sal_Bool SAL_CALL XMLBasedAcceleratorConfiguration::isModified()
     throw(css::uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
-    return (m_pWriteCache != 0);
+    return (m_pWriteCache != nullptr);
 }
 
 sal_Bool SAL_CALL XMLBasedAcceleratorConfiguration::isReadOnly()
@@ -329,7 +331,8 @@ sal_Bool SAL_CALL XMLBasedAcceleratorConfiguration::isReadOnly()
     css::uno::Reference< css::io::XStream > xStream;
     {
         SolarMutexGuard g;
-        xStream = m_aPresetHandler.openTarget(TARGET_CURRENT, true); // sal_True => open or create!
+        xStream = m_aPresetHandler.openTarget(TARGET_CURRENT,
+                css::embed::ElementModes::READWRITE); // open or create!
     }
 
     css::uno::Reference< css::io::XOutputStream > xOut;
@@ -348,7 +351,7 @@ sal_Bool SAL_CALL XMLBasedAcceleratorConfiguration::hasStorage()
     throw(css::uno::RuntimeException, std::exception)
 {
     SAL_INFO("fwk", "XMLBasedAcceleratorConfiguration::hasStorage(): implement this HACK .-)");
-    return sal_False;
+    return false;
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::addConfigurationListener(const css::uno::Reference< css::ui::XUIConfigurationListener >& /*xListener*/)
@@ -387,7 +390,7 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::removeResetListener(const css::u
 }
 
 // IStorageListener
-void XMLBasedAcceleratorConfiguration::changesOccurred(const OUString& /*sPath*/)
+void XMLBasedAcceleratorConfiguration::changesOccurred()
 {
     reload();
 }
@@ -402,7 +405,7 @@ void XMLBasedAcceleratorConfiguration::impl_ts_load(const css::uno::Reference< c
         {
             // be aware of reentrance problems - use temp variable for calling delete ... :-)
             AcceleratorCache* pTemp = m_pWriteCache;
-            m_pWriteCache = 0;
+            m_pWriteCache = nullptr;
             delete pTemp;
         }
     }
@@ -440,7 +443,7 @@ void XMLBasedAcceleratorConfiguration::impl_ts_save(const css::uno::Reference< c
     css::uno::Reference< css::uno::XComponentContext > xContext;
     {
         SolarMutexGuard g;
-        bChanged = (m_pWriteCache != 0);
+        bChanged = (m_pWriteCache != nullptr);
         if (bChanged)
             aCache.takeOver(*m_pWriteCache);
         else
@@ -473,7 +476,7 @@ void XMLBasedAcceleratorConfiguration::impl_ts_save(const css::uno::Reference< c
         m_aReadCache.takeOver(*m_pWriteCache);
         // live with reentrance .-)
         AcceleratorCache* pTemp = m_pWriteCache;
-        m_pWriteCache = 0;
+        m_pWriteCache = nullptr;
         delete pTemp;
     }
 }
@@ -517,12 +520,12 @@ OUString XMLBasedAcceleratorConfiguration::impl_ts_getLocale() const
 
 XCUBasedAcceleratorConfiguration::XCUBasedAcceleratorConfiguration(const css::uno::Reference< css::uno::XComponentContext >& xContext)
                                 : m_xContext      (xContext                     )
-                                , m_pPrimaryWriteCache(0                        )
-                                , m_pSecondaryWriteCache(0                      )
+                                , m_pPrimaryWriteCache(nullptr                        )
+                                , m_pSecondaryWriteCache(nullptr                      )
 {
     const OUString CFG_ENTRY_ACCELERATORS("org.openoffice.Office.Accelerators");
-    m_xCfg = css::uno::Reference< css::container::XNameAccess > (
-             ::comphelper::ConfigurationHelper::openConfig( m_xContext, CFG_ENTRY_ACCELERATORS, ::comphelper::ConfigurationHelper::E_ALL_LOCALES ),
+    m_xCfg.set(
+             ::comphelper::ConfigurationHelper::openConfig( m_xContext, CFG_ENTRY_ACCELERATORS, ::comphelper::EConfigurationModes::AllLocales ),
              css::uno::UNO_QUERY );
 }
 
@@ -746,7 +749,7 @@ css::uno::Sequence< css::uno::Any > SAL_CALL XCUBasedAcceleratorConfiguration::g
 
     sal_Int32                           i              = 0;
     sal_Int32                           c              = lCommandList.getLength();
-    css::uno::Sequence< css::uno::Any > lPreferredOnes (c); // dont pack list!
+    css::uno::Sequence< css::uno::Any > lPreferredOnes (c); // don't pack list!
     AcceleratorCache&                   rCache         = impl_getCFG(true);
 
     for (i=0; i<c; ++i)
@@ -820,7 +823,7 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::reload()
     {
         // be aware of reentrance problems - use temp variable for calling delete ... :-)
         AcceleratorCache* pTemp = m_pPrimaryWriteCache;
-        m_pPrimaryWriteCache = 0;
+        m_pPrimaryWriteCache = nullptr;
         delete pTemp;
     }
     m_xCfg->getByName(CFG_ENTRY_PRIMARY) >>= xAccess;
@@ -832,7 +835,7 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::reload()
     {
         // be aware of reentrance problems - use temp variable for calling delete ... :-)
         AcceleratorCache* pTemp = m_pSecondaryWriteCache;
-        m_pSecondaryWriteCache = 0;
+        m_pSecondaryWriteCache = nullptr;
         delete pTemp;
     }
     m_xCfg->getByName(CFG_ENTRY_SECONDARY) >>= xAccess;
@@ -872,11 +875,11 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::storeToStorage(const css::uno::R
         return;
 
     long nOpenModes = css::embed::ElementModes::READWRITE;
-    css::uno::Reference< css::embed::XStorage > xAcceleratorTypeStorage = xStorage->openStorageElement(OUString("accelerator"), nOpenModes);
+    css::uno::Reference< css::embed::XStorage > xAcceleratorTypeStorage = xStorage->openStorageElement("accelerator", nOpenModes);
     if (!xAcceleratorTypeStorage.is())
         return;
 
-    css::uno::Reference< css::io::XStream > xStream = xAcceleratorTypeStorage->openStreamElement(OUString("current"), nOpenModes);
+    css::uno::Reference< css::io::XStream > xStream = xAcceleratorTypeStorage->openStreamElement("current", nOpenModes);
     css::uno::Reference< css::io::XOutputStream > xOut;
     if (xStream.is())
         xOut = xStream->getOutputStream();
@@ -885,20 +888,20 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::storeToStorage(const css::uno::R
         OUString("Could not open accelerator configuration for saving."),
         static_cast< ::cppu::OWeakObject* >(this));
 
-    // the original m_aCache has been split into primay cache and secondary cache...
+    // the original m_aCache has been split into primary cache and secondary cache...
     // we should merge them before storing to storage
     AcceleratorCache aCache;
     {
         SolarMutexGuard g;
 
-        if (m_pPrimaryWriteCache != 0)
+        if (m_pPrimaryWriteCache != nullptr)
             aCache.takeOver(*m_pPrimaryWriteCache);
         else
             aCache.takeOver(m_aPrimaryReadCache);
 
         AcceleratorCache::TKeyList lKeys;
         AcceleratorCache::TKeyList::const_iterator pIt;
-        if (m_pSecondaryWriteCache!=0)
+        if (m_pSecondaryWriteCache!=nullptr)
         {
             lKeys = m_pSecondaryWriteCache->getAllKeys();
             for ( pIt=lKeys.begin(); pIt!=lKeys.end(); ++pIt )
@@ -930,13 +933,13 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::storeToStorage(const css::uno::R
 sal_Bool SAL_CALL XCUBasedAcceleratorConfiguration::isModified()
     throw(css::uno::RuntimeException, std::exception)
 {
-    return sal_False;
+    return false;
 }
 
 sal_Bool SAL_CALL XCUBasedAcceleratorConfiguration::isReadOnly()
     throw(css::uno::RuntimeException, std::exception)
 {
-    return sal_False;
+    return false;
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::setStorage(const css::uno::Reference< css::embed::XStorage >& /*xStorage*/)
@@ -949,7 +952,7 @@ sal_Bool SAL_CALL XCUBasedAcceleratorConfiguration::hasStorage()
     throw(css::uno::RuntimeException, std::exception)
 {
     SAL_INFO("fwk", "XCUBasedAcceleratorConfiguration::hasStorage(): implement this HACK .-)");
-        return sal_False;
+        return false;
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::addConfigurationListener(const css::uno::Reference< css::ui::XUIConfigurationListener >& /*xListener*/)
@@ -971,15 +974,15 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::reset()
     OUString sConfig = xNamed->getName();
     if ( sConfig == "Global" )
     {
-        m_xCfg = css::uno::Reference< css::container::XNameAccess > (
-            ::comphelper::ConfigurationHelper::openConfig( m_xContext, CFG_ENTRY_GLOBAL, ::comphelper::ConfigurationHelper::E_ALL_LOCALES ),
+        m_xCfg.set(
+            ::comphelper::ConfigurationHelper::openConfig( m_xContext, CFG_ENTRY_GLOBAL, ::comphelper::EConfigurationModes::AllLocales ),
             css::uno::UNO_QUERY );
         XCUBasedAcceleratorConfiguration::reload();
     }
     else if ( sConfig == "Modules" )
     {
-        m_xCfg = css::uno::Reference< css::container::XNameAccess > (
-            ::comphelper::ConfigurationHelper::openConfig( m_xContext, CFG_ENTRY_MODULES, ::comphelper::ConfigurationHelper::E_ALL_LOCALES ),
+        m_xCfg.set(
+            ::comphelper::ConfigurationHelper::openConfig( m_xContext, CFG_ENTRY_MODULES, ::comphelper::EConfigurationModes::AllLocales ),
             css::uno::UNO_QUERY );
         XCUBasedAcceleratorConfiguration::reload();
     }
@@ -1059,13 +1062,13 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::dispose()
     // nop
 }
 
-void SAL_CALL XCUBasedAcceleratorConfiguration::addEventListener( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& /*xListener*/ )
+void SAL_CALL XCUBasedAcceleratorConfiguration::addEventListener( const css::uno::Reference< css::lang::XEventListener >& /*xListener*/ )
     throw(css::uno::RuntimeException, std::exception)
 {
     // nop
 }
 
-void SAL_CALL XCUBasedAcceleratorConfiguration::removeEventListener( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& /*xListener*/ )
+void SAL_CALL XCUBasedAcceleratorConfiguration::removeEventListener( const css::uno::Reference< css::lang::XEventListener >& /*xListener*/ )
     throw(css::uno::RuntimeException, std::exception)
 {
     // nop
@@ -1135,7 +1138,7 @@ void XCUBasedAcceleratorConfiguration::impl_ts_load( bool bPreferred, const css:
             sal_Int32 nIndex = 0;
             OUString sKeyCommand = sKey.getToken(0, '_', nIndex);
             OUString sPrefix("KEY_");
-            aKeyEvent.KeyCode = m_rKeyMapping->mapIdentifierToCode(sPrefix + sKeyCommand);
+            aKeyEvent.KeyCode = KeyMapping::get().mapIdentifierToCode(sPrefix + sKeyCommand);
 
             css::uno::Sequence< OUString > sToken(4);
             const sal_Int32 nToken = 4;
@@ -1215,7 +1218,7 @@ void XCUBasedAcceleratorConfiguration::impl_ts_save(bool bPreferred, const css::
         {
             m_aPrimaryReadCache.takeOver(*m_pPrimaryWriteCache);
             AcceleratorCache* pTemp = m_pPrimaryWriteCache;
-            m_pPrimaryWriteCache = 0;
+            m_pPrimaryWriteCache = nullptr;
             delete pTemp;
         }
     }
@@ -1254,7 +1257,7 @@ void XCUBasedAcceleratorConfiguration::impl_ts_save(bool bPreferred, const css::
         {
             m_aSecondaryReadCache.takeOver(*m_pSecondaryWriteCache);
             AcceleratorCache* pTemp = m_pSecondaryWriteCache;
-            m_pSecondaryWriteCache = 0;
+            m_pSecondaryWriteCache = nullptr;
             delete pTemp;
         }
     }
@@ -1282,19 +1285,19 @@ void XCUBasedAcceleratorConfiguration::insertKeyToConfiguration( const css::awt:
         xAccess->getByName(CFG_ENTRY_MODULES) >>= xModules;
         if ( !xModules->hasByName(m_sModuleCFG) )
         {
-            xFac = css::uno::Reference< css::lang::XSingleServiceFactory >(xModules, css::uno::UNO_QUERY);
+            xFac.set(xModules, css::uno::UNO_QUERY);
             xInst = xFac->createInstance();
             xModules->insertByName(m_sModuleCFG, css::uno::makeAny(xInst));
         }
         xModules->getByName(m_sModuleCFG) >>= xContainer;
     }
 
-    const OUString sKey = lcl_getKeyString(m_rKeyMapping,aKeyEvent);
+    const OUString sKey = lcl_getKeyString(aKeyEvent);
     css::uno::Reference< css::container::XNameAccess > xKey;
     css::uno::Reference< css::container::XNameContainer > xCommand;
     if ( !xContainer->hasByName(sKey) )
     {
-        xFac = css::uno::Reference< css::lang::XSingleServiceFactory >(xContainer, css::uno::UNO_QUERY);
+        xFac.set(xContainer, css::uno::UNO_QUERY);
         xInst = xFac->createInstance();
         xContainer->insertByName(sKey, css::uno::makeAny(xInst));
     }
@@ -1329,7 +1332,7 @@ void XCUBasedAcceleratorConfiguration::removeKeyFromConfiguration( const css::aw
         xModules->getByName(m_sModuleCFG) >>= xContainer;
     }
 
-    const OUString sKey = lcl_getKeyString(m_rKeyMapping,aKeyEvent);
+    const OUString sKey = lcl_getKeyString(aKeyEvent);
     xContainer->removeByName(sKey);
 }
 
@@ -1355,7 +1358,7 @@ void XCUBasedAcceleratorConfiguration::reloadChanged( const OUString& sPrimarySe
 
     sal_Int32 nIndex = 0;
     sKeyIdentifier = sKey.getToken(0, '_', nIndex);
-    aKeyEvent.KeyCode = m_rKeyMapping->mapIdentifierToCode("KEY_"+sKeyIdentifier);
+    aKeyEvent.KeyCode = KeyMapping::get().mapIdentifierToCode("KEY_"+sKeyIdentifier);
 
     css::uno::Sequence< OUString > sToken(3);
     const sal_Int32 nToken = 3;
