@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <com/sun/star/uno/Reference.h>
 #include <cppuhelper/factory.hxx>
 #include <cppuhelper/supportsservice.hxx>
@@ -55,9 +54,6 @@ using namespace com::sun::star::uno;
 using namespace com::sun::star::linguistic2;
 using namespace linguistic;
 
-
-///////////////////////////////////////////////////////////////////////////
-
 static uno::Reference< XLinguServiceManager2 > GetLngSvcMgr_Impl()
 {
     uno::Reference< XComponentContext > xContext( comphelper::getProcessComponentContext() );
@@ -69,16 +65,16 @@ Thesaurus::Thesaurus() :
     aEvtListeners   ( GetLinguMutex() )
 {
     bDisposing = false;
-    pPropHelper = NULL;
-    aThes = NULL;
-    aCharSetInfo = NULL;
-    aTEncs = NULL;
-    aTLocs = NULL;
-    aTNames = NULL;
+    pPropHelper = nullptr;
+    aThes = nullptr;
+    aCharSetInfo = nullptr;
+    aTEncs = nullptr;
+    aTLocs = nullptr;
+    aTNames = nullptr;
     numthes = 0;
+    prevLocale = LANGUAGE_DONTKNOW;
 }
 
-
 Thesaurus::~Thesaurus()
 {
     if (aThes)
@@ -86,28 +82,28 @@ Thesaurus::~Thesaurus()
         for (int i = 0; i < numthes; i++)
         {
             if (aThes[i]) delete aThes[i];
-            aThes[i] = NULL;
+            aThes[i] = nullptr;
         }
         delete[] aThes;
     }
-    aThes = NULL;
+    aThes = nullptr;
     if (aCharSetInfo)
     {
         for (int i = 0; i < numthes; i++)
         {
             if (aCharSetInfo[i]) delete aCharSetInfo[i];
-            aCharSetInfo[i] = NULL;
+            aCharSetInfo[i] = nullptr;
         }
         delete[] aCharSetInfo;
     }
-    aCharSetInfo = NULL;
+    aCharSetInfo = nullptr;
     numthes = 0;
     if (aTEncs) delete[] aTEncs;
-    aTEncs = NULL;
+    aTEncs = nullptr;
     if (aTLocs) delete[] aTLocs;
-    aTLocs = NULL;
+    aTLocs = nullptr;
     if (aTNames) delete[] aTNames;
-    aTNames = NULL;
+    aTNames = nullptr;
 
     if (pPropHelper)
     {
@@ -116,28 +112,25 @@ Thesaurus::~Thesaurus()
     }
 }
 
-
 PropertyHelper_Thesaurus& Thesaurus::GetPropHelper_Impl()
 {
     if (!pPropHelper)
     {
         Reference< XLinguProperties >   xPropSet( GetLinguProperties(), UNO_QUERY );
 
-        pPropHelper = new PropertyHelper_Thesaurus( (XThesaurus *) this, xPropSet );
+        pPropHelper = new PropertyHelper_Thesaurus( static_cast<XThesaurus *>(this), xPropSet );
         pPropHelper->AddAsPropListener();   //! after a reference is established
     }
     return *pPropHelper;
 }
 
-
 Sequence< Locale > SAL_CALL Thesaurus::getLocales()
-        throw(RuntimeException)
+        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
     // this routine should return the locales supported by the installed
     // dictionaries.
-
     if (!numthes)
     {
         SvtLinguConfig aLinguCfg;
@@ -219,11 +212,11 @@ Sequence< Locale > SAL_CALL Thesaurus::getLocales()
 
                     // currently only one language per dictionary is supported in the actual implementation...
                     // Thus here we work-around this by adding the same dictionary several times.
-                    // Once for each of it's supported locales.
+                    // Once for each of its supported locales.
                     for (sal_Int32 i = 0;  i < nLocales;  ++i)
                     {
                         LanguageTag aLanguageTag( aDictIt->aLocaleNames[i] );
-                        aThes[k]  = NULL;
+                        aThes[k]  = nullptr;
                         aTEncs[k]  = RTL_TEXTENCODING_DONTKNOW;
                         aTLocs[k]  = aLanguageTag.getLocale();
                         aCharSetInfo[k] = new CharClass( aLanguageTag );
@@ -245,11 +238,11 @@ Sequence< Locale > SAL_CALL Thesaurus::getLocales()
         {
             /* no dictionary found so register no dictionaries */
             numthes = 0;
-            aThes  = NULL;
-            aTEncs  = NULL;
-            aTLocs  = NULL;
-            aTNames = NULL;
-            aCharSetInfo = NULL;
+            aThes  = nullptr;
+            aTEncs  = nullptr;
+            aTLocs  = nullptr;
+            aTNames = nullptr;
+            aCharSetInfo = nullptr;
             aSuppLocales.realloc(0);
         }
     }
@@ -257,14 +250,12 @@ Sequence< Locale > SAL_CALL Thesaurus::getLocales()
     return aSuppLocales;
 }
 
-
-
 sal_Bool SAL_CALL Thesaurus::hasLocale(const Locale& rLocale)
-        throw(RuntimeException)
+        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
-    sal_Bool bRes = sal_False;
+    bool bRes = false;
     if (!aSuppLocales.getLength())
         getLocales();
     sal_Int32 nLen = aSuppLocales.getLength();
@@ -273,18 +264,17 @@ sal_Bool SAL_CALL Thesaurus::hasLocale(const Locale& rLocale)
         const Locale *pLocale = aSuppLocales.getConstArray();
         if (rLocale == pLocale[i])
         {
-            bRes = sal_True;
+            bRes = true;
             break;
         }
     }
     return bRes;
 }
 
-
-Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thesaurus::queryMeanings(
+Sequence < Reference < css::linguistic2::XMeaning > > SAL_CALL Thesaurus::queryMeanings(
     const OUString& qTerm, const Locale& rLocale,
     const PropertyValues& rProperties)
-    throw(IllegalArgumentException, RuntimeException)
+    throw(IllegalArgumentException, RuntimeException, std::exception)
 {
     MutexGuard      aGuard( GetLinguMutex() );
 
@@ -293,15 +283,15 @@ Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thes
     uno::Reference< XLinguServiceManager2 > xLngSvcMgr( GetLngSvcMgr_Impl() );
     uno::Reference< XSpellChecker1 > xSpell;
 
-    OUString rTerm(qTerm);
-    OUString pTerm(qTerm);
-    sal_uInt16 ct = CAPTYPE_UNKNOWN;
+    OUString aRTerm(qTerm);
+    OUString aPTerm(qTerm);
+    CapType ct = CapType::UNKNOWN;
     sal_Int32 stem = 0;
     sal_Int32 stem2 = 0;
 
     sal_Int16 nLanguage = LinguLocaleToLanguage( rLocale );
 
-    if (LinguIsUnspecified( nLanguage) || rTerm.isEmpty())
+    if (LinguIsUnspecified( nLanguage) || aRTerm.isEmpty())
         return noMeanings;
 
     if (!hasLocale( rLocale ))
@@ -314,15 +304,15 @@ Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thes
     if (prevTerm == qTerm && prevLocale == nLanguage)
         return prevMeanings;
 
-    mentry * pmean = NULL;
+    mentry * pmean = nullptr;
     sal_Int32 nmean = 0;
 
     PropertyHelper_Thesaurus &rHelper = GetPropHelper();
     rHelper.SetTmpPropVals( rProperties );
 
-    MyThes * pTH = NULL;
+    MyThes * pTH = nullptr;
     rtl_TextEncoding eEnc = RTL_TEXTENCODING_DONTKNOW;
-    CharClass * pCC = NULL;
+    CharClass * pCC = nullptr;
 
     // find the first thesaurus that matches the locale
     for (int i =0; i < numthes; i++)
@@ -338,16 +328,14 @@ Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thes
                 OUString nidx;
                 osl::FileBase::getSystemPathFromFileURL(datpath,ndat);
                 osl::FileBase::getSystemPathFromFileURL(idxpath,nidx);
+
+#if defined(_WIN32)
+                // MyThes waits UTF-8 encoded paths with \\?\ long path prefix.
+                OString aTmpidx = Win_AddLongPathPrefix(OUStringToOString(nidx, RTL_TEXTENCODING_UTF8));
+                OString aTmpdat = Win_AddLongPathPrefix(OUStringToOString(ndat, RTL_TEXTENCODING_UTF8));
+#else
                 OString aTmpidx(OU2ENC(nidx,osl_getThreadTextEncoding()));
                 OString aTmpdat(OU2ENC(ndat,osl_getThreadTextEncoding()));
-
-#if defined(WNT)
-                // workaround for Windows specifc problem that the
-                // path length in calls to 'fopen' is limted to somewhat
-                // about 120+ characters which will usually be exceed when
-                // using dictionaries as extensions.
-                aTmpidx = Win_GetShortPathName( nidx );
-                aTmpdat = Win_GetShortPathName( ndat );
 #endif
 
                 aThes[i] = new MyThes(aTmpidx.getStr(),aTmpdat.getStr());
@@ -375,8 +363,8 @@ Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thes
     {
         // convert word to all lower case for searching
         if (!stem)
-            ct = capitalType(rTerm, pCC);
-        OUString nTerm(makeLowerCase(rTerm, pCC));
+            ct = capitalType(aRTerm, pCC);
+        OUString nTerm(makeLowerCase(aRTerm, pCC));
         OString aTmp( OU2ENC(nTerm, eEnc) );
         nmean = pTH->Lookup(aTmp.getStr(),aTmp.getLength(),&pmean);
 
@@ -390,7 +378,7 @@ Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thes
         if (stem)
         {
             xTmpRes2 = xSpell->spell( "<?xml?><query type='analyze'><word>" +
-            pTerm + "</word></query>", nLanguage, rProperties );
+                                      aPTerm + "</word></query>", nLanguage, rProperties );
             if (xTmpRes2.is())
             {
                 Sequence<OUString>seq = xTmpRes2->getAlternatives();
@@ -414,9 +402,7 @@ Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thes
                 {
                     OUString sTerm(pe->psyns[i],strlen(pe->psyns[i]),eEnc );
                     sal_Int32 catpos = sTerm.indexOf('(');
-                    sal_Int32 catpos2 = 0;
                     OUString catst;
-                    OUString catst2;
                     if (catpos > 2)
                     {
                         // remove category name for affixation and casing
@@ -437,19 +423,17 @@ Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thes
                                 sTerm = seq[0];
                         }
                     }
-                    if (catpos2)
-                        sTerm = catst2 + sTerm;
 
-                    sal_uInt16 ct1 = capitalType(sTerm, pCC);
-                    if (CAPTYPE_MIXED == ct1)
+                    CapType ct1 = capitalType(sTerm, pCC);
+                    if (CapType::MIXED == ct1)
                         ct = ct1;
                     OUString cTerm;
                     switch (ct)
                     {
-                        case CAPTYPE_ALLCAP:
+                        case CapType::ALLCAP:
                             cTerm = makeUpperCase(sTerm, pCC);
                             break;
-                        case CAPTYPE_INITCAP:
+                        case CapType::INITCAP:
                             cTerm = makeInitCap(sTerm, pCC);
                             break;
                         default:
@@ -459,7 +443,7 @@ Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thes
                     OUString aAlt( cTerm + catst);
                     pStr[i] = aAlt;
                 }
-                Meaning * pMn = new Meaning(rTerm,nLanguage);
+                Meaning * pMn = new Meaning(aRTerm);
                 OUString dTerm(pe->defn,strlen(pe->defn),eEnc );
                 pMn->SetMeaning(dTerm);
                 pMn->SetSynonyms(aStr);
@@ -482,36 +466,36 @@ Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thes
             return noMeanings;
         stem = 1;
 
-        xSpell = uno::Reference< XSpellChecker1 >( xLngSvcMgr->getSpellChecker(), UNO_QUERY );
+        xSpell.set( xLngSvcMgr->getSpellChecker(), UNO_QUERY );
         if (!xSpell.is() || !xSpell->isValid( SPELLML_SUPPORT, nLanguage, rProperties ))
             return noMeanings;
         Reference< XSpellAlternatives > xTmpRes;
         xTmpRes = xSpell->spell( "<?xml?><query type='stem'><word>" +
-            rTerm + "</word></query>", nLanguage, rProperties );
+            aRTerm + "</word></query>", nLanguage, rProperties );
         if (xTmpRes.is())
         {
             Sequence<OUString>seq = xTmpRes->getAlternatives();
             if (seq.getLength() > 0)
             {
-                rTerm = seq[0];  // XXX Use only the first stem
+                aRTerm = seq[0];  // XXX Use only the first stem
                 continue;
             }
         }
 
         // stem the last word of the synonym (for categories after affixation)
-        rTerm = rTerm.trim();
-        sal_Int32 pos = rTerm.lastIndexOf(' ');
+        aRTerm = aRTerm.trim();
+        sal_Int32 pos = aRTerm.lastIndexOf(' ');
         if (!pos)
             return noMeanings;
         xTmpRes = xSpell->spell( "<?xml?><query type='stem'><word>" +
-            rTerm.copy(pos + 1) + "</word></query>", nLanguage, rProperties );
+            aRTerm.copy(pos + 1) + "</word></query>", nLanguage, rProperties );
         if (xTmpRes.is())
         {
             Sequence<OUString>seq = xTmpRes->getAlternatives();
             if (seq.getLength() > 0)
             {
-                pTerm = rTerm.copy(pos + 1);
-                rTerm = rTerm.copy(0, pos + 1) + seq[0];
+                aPTerm = aRTerm.copy(pos + 1);
+                aRTerm = aRTerm.copy(0, pos + 1) + seq[0];
 #if  0
                 for (int i = 0; i < seq.getLength(); i++)
                 {
@@ -527,26 +511,23 @@ Sequence < Reference < ::com::sun::star::linguistic2::XMeaning > > SAL_CALL Thes
     return noMeanings;
 }
 
-
 Reference< XInterface > SAL_CALL Thesaurus_CreateInstance(
             const Reference< XMultiServiceFactory > & /*rSMgr*/ )
         throw(Exception)
 {
-    Reference< XInterface > xService = (cppu::OWeakObject*) new Thesaurus;
+    Reference< XInterface > xService = static_cast<cppu::OWeakObject*>(new Thesaurus);
     return xService;
 }
 
-
 OUString SAL_CALL Thesaurus::getServiceDisplayName( const Locale& /*rLocale*/ )
-        throw(RuntimeException)
+        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
     return OUString( "OpenOffice.org New Thesaurus" );
 }
 
-
 void SAL_CALL Thesaurus::initialize( const Sequence< Any >& rArguments )
-        throw(Exception, RuntimeException)
+        throw(Exception, RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
@@ -562,7 +543,7 @@ void SAL_CALL Thesaurus::initialize( const Sequence< Any >& rArguments )
             //! And the reference to the UNO-functions while increasing
             //! the ref-count and will implicitly free the memory
             //! when the object is not longer used.
-            pPropHelper = new PropertyHelper_Thesaurus( (XThesaurus *) this, xPropSet );
+            pPropHelper = new PropertyHelper_Thesaurus( static_cast<XThesaurus *>(this), xPropSet );
             pPropHelper->AddAsPropListener();   //! after a reference is established
         }
         else
@@ -570,8 +551,6 @@ void SAL_CALL Thesaurus::initialize( const Sequence< Any >& rArguments )
     }
 }
 
-
-
 OUString SAL_CALL Thesaurus::makeLowerCase(const OUString& aTerm, CharClass * pCC)
 {
     if (pCC)
@@ -579,7 +558,6 @@ OUString SAL_CALL Thesaurus::makeLowerCase(const OUString& aTerm, CharClass * pC
     return aTerm;
 }
 
-
 OUString SAL_CALL Thesaurus::makeUpperCase(const OUString& aTerm, CharClass * pCC)
 {
     if (pCC)
@@ -587,7 +565,6 @@ OUString SAL_CALL Thesaurus::makeUpperCase(const OUString& aTerm, CharClass * pC
     return aTerm;
 }
 
-
 OUString SAL_CALL Thesaurus::makeInitCap(const OUString& aTerm, CharClass * pCC)
 {
     sal_Int32 tlen = aTerm.getLength();
@@ -605,30 +582,27 @@ OUString SAL_CALL Thesaurus::makeInitCap(const OUString& aTerm, CharClass * pCC)
     return aTerm;
 }
 
-
-
 void SAL_CALL Thesaurus::dispose()
-        throw(RuntimeException)
+        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
     if (!bDisposing)
     {
         bDisposing = true;
-        EventObject aEvtObj( (XThesaurus *) this );
+        EventObject aEvtObj( static_cast<XThesaurus *>(this) );
         aEvtListeners.disposeAndClear( aEvtObj );
         if (pPropHelper)
         {
             pPropHelper->RemoveAsPropListener();
             delete pPropHelper;
-            pPropHelper = NULL;
+            pPropHelper = nullptr;
         }
     }
 }
 
-
 void SAL_CALL Thesaurus::addEventListener( const Reference< XEventListener >& rxListener )
-        throw(RuntimeException)
+        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
@@ -636,9 +610,8 @@ void SAL_CALL Thesaurus::addEventListener( const Reference< XEventListener >& rx
         aEvtListeners.addInterface( rxListener );
 }
 
-
 void SAL_CALL Thesaurus::removeEventListener( const Reference< XEventListener >& rxListener )
-        throw(RuntimeException)
+        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
@@ -648,40 +621,34 @@ void SAL_CALL Thesaurus::removeEventListener( const Reference< XEventListener >&
 
 // Service specific part
 OUString SAL_CALL Thesaurus::getImplementationName()
-        throw(RuntimeException)
+        throw(RuntimeException, std::exception)
 {
-    MutexGuard  aGuard( GetLinguMutex() );
     return getImplementationName_Static();
 }
 
-
 sal_Bool SAL_CALL Thesaurus::supportsService( const OUString& ServiceName )
-        throw(RuntimeException)
+        throw(RuntimeException, std::exception)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 Sequence< OUString > SAL_CALL Thesaurus::getSupportedServiceNames()
-        throw(RuntimeException)
+        throw(RuntimeException, std::exception)
 {
-    MutexGuard  aGuard( GetLinguMutex() );
     return getSupportedServiceNames_Static();
 }
 
 Sequence< OUString > Thesaurus::getSupportedServiceNames_Static()
         throw()
 {
-    MutexGuard  aGuard( GetLinguMutex() );
-
-    Sequence< OUString > aSNS( 1 ); // auch mehr als 1 Service moeglich
-    aSNS.getArray()[0] = SN_THESAURUS;
+    Sequence< OUString > aSNS { SN_THESAURUS };
     return aSNS;
 }
 
 void * SAL_CALL Thesaurus_getFactory( const sal_Char * pImplName,
             XMultiServiceFactory * pServiceManager, void *  )
 {
-    void * pRet = 0;
+    void * pRet = nullptr;
     if ( Thesaurus::getImplementationName_Static().equalsAscii( pImplName ) )
     {
 
@@ -698,7 +665,4 @@ void * SAL_CALL Thesaurus_getFactory( const sal_Char * pImplName,
     return pRet;
 }
 
-
-///////////////////////////////////////////////////////////////////////////
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
