@@ -1,3 +1,4 @@
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  *  The Contents of this file are made available subject to the terms of
@@ -70,7 +71,7 @@ public class CalcHelper
         initSpreadSheet();
     }
 
-    // ____________________
+
 
     public XSpreadsheet getChartSheet() throws RuntimeException
     {
@@ -93,7 +94,7 @@ public class CalcHelper
         return aSheet;
     }
 
-    // ____________________
+
 
     public XSpreadsheet getDataSheet() throws RuntimeException
     {
@@ -119,7 +120,7 @@ public class CalcHelper
         return aSheet;
     }
 
-    // ____________________
+
 
     /** Insert a chart using the given name as name of the OLE object and the range as correspoding
         range of data to be used for rendering.  The chart is placed in the sheet for charts at
@@ -197,7 +198,7 @@ public class CalcHelper
         return aResult;
     }
 
-    // ____________________
+
 
     /** Fill a rectangular range with random numbers.
         The first column has increasing values
@@ -263,7 +264,7 @@ public class CalcHelper
         return aRange;
     }
 
-    // ____________________
+
 
     public XCellRange insertFormulaRange( int nColumnCount, int nRowCount )
     {
@@ -281,7 +282,7 @@ public class CalcHelper
 
             int nCol, nRow;
             double fValue;
-            double fFactor = 2.0 * java.lang.Math.PI / (nRowCount - 1);
+            double fFactor = 2.0 * Math.PI / (nRowCount - 1);
             String aFormula;
 
             // set variable factor for cos formula
@@ -303,7 +304,7 @@ public class CalcHelper
                     }
                     else
                     {
-                        aFormula = new String( "=" );
+                        aFormula = "=";
                         if( nCol % 2 == 0 )
                             aFormula += "SIN";
                         else
@@ -323,7 +324,7 @@ public class CalcHelper
         return aRange;
     }
 
-    // ____________________
+
 
     /** Bring the sheet containing charts visually to the foreground
      */
@@ -339,13 +340,13 @@ public class CalcHelper
 
     // __________ private members and methods __________
 
-    private final String  msDataSheetName  = "Data";
-    private final String  msChartSheetName = "Chart";
+    private static final String  msDataSheetName  = "Data";
+    private static final String  msChartSheetName = "Chart";
+
+    private final XSpreadsheetDocument   maSpreadSheetDoc;
 
-    private XSpreadsheetDocument   maSpreadSheetDoc;
 
 
-    // ____________________
 
     /** create two sheets, one for data and one for charts in the document
      */
@@ -391,3 +392,5 @@ public class CalcHelper
         }
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
