@@ -486,6 +486,17 @@ private:
         catch (const uno::Exception&)
         {
             mpEntry->setParallelDeflateException(::cppu::getCaughtException());
+            try
+            {
+                if (mpEntry->m_xOutStream.is())
+                    mpEntry->closeBufferFile();
+                if (!mpEntry->m_aTempURL.isEmpty())
+                    mpEntry->deleteBufferFile();
+            }
+            catch (uno::Exception const&)
+            {
+            }
+            mpEntry->setFinished();
         }
     }
 };
@@ -759,7 +770,7 @@ bool ZipPackageStream::saveChild(
     }
     else
     {
-        // This stream is defenitly not a raw stream
+        // This stream is definitely not a raw stream
 
         // If nonseekable access is used the stream should be at the beginning and
         // is useless after the storing. Thus if the storing fails the package should
@@ -830,9 +841,9 @@ bool ZipPackageStream::saveChild(
                 {
                     // tdf#93553 limit to a useful amount of threads. Taking number of available
                     // cores and allow 4-times the amount for having the queue well filled. The
-                    // 2nd pparameter is the time to wait beweeen cleanups in 10th of a second.
+                    // 2nd parameter is the time to wait between cleanups in 10th of a second.
                     // Both values may be added to the configuration settings if needed.
-                    static sal_Int32 nAllowedThreads(std::max(std::thread::hardware_concurrency(), 1U) * 4);
+                    static sal_Int32 nAllowedThreads(comphelper::ThreadPool::getPreferredConcurrency() * 4);
                     rZipOut.reduceScheduledThreadsToGivenNumberOrLess(nAllowedThreads, 1);
 
                     // Start a new thread deflating this zip entry
@@ -1339,41 +1350,33 @@ void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName,
 Any SAL_CALL ZipPackageStream::getPropertyValue( const OUString& PropertyName )
         throw( beans::UnknownPropertyException, WrappedTargetException, RuntimeException, std::exception )
 {
-    Any aAny;
     if ( PropertyName == "MediaType" )
     {
-        aAny <<= msMediaType;
-        return aAny;
+        return Any(msMediaType);
     }
     else if ( PropertyName == "Size" )
     {
-        aAny <<= aEntry.nSize;
-        return aAny;
+        return Any(aEntry.nSize);
     }
     else if ( PropertyName == "Encrypted" )
     {
-        aAny <<= ((m_nStreamMode == PACKAGE_STREAM_RAW) || m_bToBeEncrypted);
-        return aAny;
+        return Any((m_nStreamMode == PACKAGE_STREAM_RAW) || m_bToBeEncrypted);
     }
     else if ( PropertyName == "WasEncrypted" )
     {
-        aAny <<= m_bIsEncrypted;
-        return aAny;
+        return Any(m_bIsEncrypted);
     }
     else if ( PropertyName == "Compressed" )
     {
-        aAny <<= m_bToBeCompressed;
-        return aAny;
+        return Any(m_bToBeCompressed);
     }
     else if ( PropertyName == ENCRYPTION_KEY_PROPERTY )
     {
-        aAny <<= m_aEncryptionKey;
-        return aAny;
+        return Any(m_aEncryptionKey);
     }
     else if ( PropertyName == STORAGE_ENCRYPTION_KEYS_PROPERTY )
     {
-        aAny <<= m_aStorageEncryptionKeys;
-        return aAny;
+        return Any(m_aStorageEncryptionKeys);
     }
     else
         throw beans::UnknownPropertyException(THROW_WHERE );
