@@ -20,7 +20,6 @@ package mod._xmloff.Draw;
 
 import java.io.PrintWriter;
 
-import lib.StatusException;
 import lib.TestCase;
 import lib.TestEnvironment;
 import lib.TestParameters;
@@ -67,31 +66,27 @@ public class XMLMetaExporter extends TestCase {
     /**
     * New draw document created.
     */
-    protected void initialize( TestParameters tParam, PrintWriter log ) {
+    @Override
+    protected void initialize( TestParameters tParam, PrintWriter log ) throws Exception {
 
         // get a soffice factory object
-        SOfficeFactory SOF = SOfficeFactory.getFactory( (XMultiServiceFactory)tParam.getMSF());
+        SOfficeFactory SOF = SOfficeFactory.getFactory( tParam.getMSF());
 
-        try {
-            log.println( "creating a drawdocument" );
-            xDrawDoc = SOF.createDrawDoc(null);
-        } catch ( Exception e ) {
-            // Some exception occurs.FAILED
-            e.printStackTrace( log );
-            throw new StatusException( "Couldn't create document", e );
-        }
+        log.println( "creating a drawdocument" );
+        xDrawDoc = SOF.createDrawDoc(null);
     }
 
     /**
     * Document disposed here.
     */
+    @Override
     protected void cleanup( TestParameters tParam, PrintWriter log ) {
         log.println( "    disposing xDrawDoc " );
         xDrawDoc.dispose();
     }
 
     /**
-    * Creating a Testenvironment for the interfaces to be tested.
+    * Creating a TestEnvironment for the interfaces to be tested.
     * Creates an instance of the service
     * <code>com.sun.star.comp.Draw.XMLMetaExporter</code> with
     * argument which is an implementation of <code>XDocumentHandler</code>
@@ -111,32 +106,27 @@ public class XMLMetaExporter extends TestCase {
     *      {@link ifc.document._XExporter} interface </li>
     * </ul>
     */
-    public synchronized TestEnvironment createTestEnvironment
-            (TestParameters tParam, PrintWriter log ) throws StatusException {
+    @Override
+    public TestEnvironment createTestEnvironment
+            (TestParameters tParam, PrintWriter log ) throws Exception {
 
-        XMultiServiceFactory xMSF = (XMultiServiceFactory)tParam.getMSF() ;
+        XMultiServiceFactory xMSF = tParam.getMSF() ;
         XInterface oObj = null;
         final String TITLE = "XMLMetaExporter";
 
         FilterChecker filter = new FilterChecker(log) ;
         Any arg = new Any(new Type(XDocumentHandler.class),filter);
 
-        try {
-            oObj = (XInterface) xMSF.createInstanceWithArguments(
-                "com.sun.star.comp.Draw.XMLMetaExporter", new Object[] {arg});
-            XExporter xEx = UnoRuntime.queryInterface(XExporter.class, oObj);
-            xEx.setSourceDocument(xDrawDoc);
+        oObj = (XInterface) xMSF.createInstanceWithArguments(
+            "com.sun.star.comp.Draw.XMLMetaExporter", new Object[] {arg});
+        XExporter xEx = UnoRuntime.queryInterface(XExporter.class, oObj);
+        xEx.setSourceDocument(xDrawDoc);
 
-            //set some meta data
-            XDocumentPropertiesSupplier xPropSup = UnoRuntime.queryInterface
-                (XDocumentPropertiesSupplier.class, xDrawDoc);
-            final XDocumentProperties xDocProps = xPropSup.getDocumentProperties();
-            xDocProps.setTitle(TITLE);
-
-        } catch (com.sun.star.uno.Exception e) {
-            e.printStackTrace(log) ;
-            throw new StatusException("Can't create component.", e) ;
-        }
+        //set some meta data
+        XDocumentPropertiesSupplier xPropSup = UnoRuntime.queryInterface
+            (XDocumentPropertiesSupplier.class, xDrawDoc);
+        final XDocumentProperties xDocProps = xPropSup.getDocumentProperties();
+        xDocProps.setTitle(TITLE);
 
         // Checking Head Tag existence and that property has changed
         filter.addTag(new XMLTools.Tag ("office:document-meta"));
@@ -168,14 +158,14 @@ public class XMLMetaExporter extends TestCase {
      * to log specified.
      * @see ifc.document._XFilter
      */
-    protected class FilterChecker extends XMLTools.XMLChecker
+    private class FilterChecker extends XMLTools.XMLChecker
         implements ifc.document._XFilter.FilterChecker {
 
         /**
          * Creates a class which will write information
          * into log specified.
          */
-        public FilterChecker(PrintWriter log) {
+        private FilterChecker(PrintWriter log) {
             super(log, true) ;
         }
 
