@@ -41,27 +41,23 @@ namespace rptxml
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::xml::sax;
 
-      sal_uInt16 lcl_getReportPrintOption(const OUString& _sValue)
+    sal_uInt16 lcl_getReportPrintOption(const OUString& _sValue)
     {
         sal_uInt16 nRet = report::ReportPrintOption::ALL_PAGES;
         const SvXMLEnumMapEntry* aXML_EnumMap = OXMLHelper::GetReportPrintOptions();
-        SvXMLUnitConverter::convertEnum( nRet, _sValue, aXML_EnumMap );
+        (void)SvXMLUnitConverter::convertEnum( nRet, _sValue, aXML_EnumMap );
         return nRet;
     }
 
 
-DBG_NAME( rpt_OXMLSection )
-
 OXMLSection::OXMLSection( ORptFilter& rImport,
                 sal_uInt16 nPrfx, const OUString& _sLocalName,
                 const uno::Reference< xml::sax::XAttributeList > & _xAttrList
                 ,const uno::Reference< report::XSection >& _xSection
-                ,sal_Bool _bPageHeader)
+                ,bool _bPageHeader)
 :SvXMLImportContext( rImport, nPrfx, _sLocalName )
 ,m_xSection(_xSection)
-,m_bPageHeader(_bPageHeader)
 {
-    DBG_CTOR( rpt_OXMLSection,NULL);
 
     OSL_ENSURE(_xAttrList.is(),"Attribute list is NULL!");
     const SvXMLNamespaceMap& rMap = rImport.GetNamespaceMap();
@@ -101,19 +97,18 @@ OXMLSection::OXMLSection( ORptFilter& rImport,
         OSL_FAIL("Exception catched while filling the section props");
     }
 }
-// -----------------------------------------------------------------------------
+
 OXMLSection::~OXMLSection()
 {
-    DBG_DTOR( rpt_OXMLSection,NULL);
 }
-// -----------------------------------------------------------------------------
+
 
 SvXMLImportContext* OXMLSection::CreateChildContext(
         sal_uInt16 _nPrefix,
         const OUString& _rLocalName,
         const uno::Reference< xml::sax::XAttributeList > & xAttrList )
 {
-    SvXMLImportContext *pContext = 0;
+    SvXMLImportContext *pContext = nullptr;
     ORptFilter& rImport = GetOwnImport();
     const SvXMLTokenMap&    rTokenMap   = rImport.GetSectionElemTokenMap();
 
@@ -131,14 +126,14 @@ SvXMLImportContext* OXMLSection::CreateChildContext(
 
     return pContext;
 }
-// -----------------------------------------------------------------------------
+
 ORptFilter& OXMLSection::GetOwnImport()
 {
     return static_cast<ORptFilter&>(GetImport());
 }
-// -----------------------------------------------------------------------------
-// -----------------------------------------------------------------------------
+
+
 } // namespace rptxml
-// -----------------------------------------------------------------------------
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
