@@ -50,7 +50,7 @@ namespace rptxml
     {
         sal_uInt16 nRet = report::ForceNewPage::NONE;
         const SvXMLEnumMapEntry* aXML_EnumMap = OXMLHelper::GetForceNewPageOptions();
-        SvXMLUnitConverter::convertEnum( nRet,_sValue,aXML_EnumMap );
+        (void)SvXMLUnitConverter::convertEnum( nRet,_sValue,aXML_EnumMap );
         return nRet;
     }
 
@@ -123,7 +123,7 @@ SvXMLImportContext* OXMLTable::CreateChildContext(
         const OUString& _rLocalName,
         const Reference< XAttributeList > & xAttrList )
 {
-    SvXMLImportContext *pContext = 0;
+    SvXMLImportContext *pContext = nullptr;
     ORptFilter& rImport = GetOwnImport();
     const SvXMLTokenMap&    rTokenMap   = rImport.GetColumnTokenMap();
 
@@ -171,7 +171,7 @@ void OXMLTable::EndElement()
                 const SvXMLStylesContext* pAutoStyles = GetImport().GetAutoStyles();
                 if ( pAutoStyles )
                 {
-                    XMLPropStyleContext* pAutoStyle = PTR_CAST(XMLPropStyleContext,pAutoStyles->FindStyleChildContext(XML_STYLE_FAMILY_TABLE_TABLE,m_sStyleName));
+                    XMLPropStyleContext* pAutoStyle = const_cast<XMLPropStyleContext*>(dynamic_cast< const XMLPropStyleContext *>(pAutoStyles->FindStyleChildContext(XML_STYLE_FAMILY_TABLE_TABLE,m_sStyleName)));
                     if ( pAutoStyle )
                     {
                         pAutoStyle->FillPropertySet(m_xSection.get());
@@ -179,8 +179,8 @@ void OXMLTable::EndElement()
                 }
             }
             // set height
-            ::std::vector<sal_Int32>::iterator aIter = m_aHeight.begin();
-            ::std::vector<sal_Int32>::iterator aEnd = m_aHeight.end();
+            ::std::vector<sal_Int32>::const_iterator aIter = m_aHeight.begin();
+            ::std::vector<sal_Int32>::const_iterator aEnd = m_aHeight.end();
             sal_Int32 nHeight = 0;
             for (; aIter != aEnd; ++aIter)
                 nHeight += *aIter;
@@ -189,19 +189,19 @@ void OXMLTable::EndElement()
             sal_Int32 nLeftMargin = rptui::getStyleProperty<sal_Int32>(m_xSection->getReportDefinition(),PROPERTY_LEFTMARGIN);
             sal_Int32 nPosY = 0;
             ::std::vector< ::std::vector<TCell> >::iterator aRowIter = m_aGrid.begin();
-            ::std::vector< ::std::vector<TCell> >::iterator aRowEnd = m_aGrid.end();
+            ::std::vector< ::std::vector<TCell> >::const_iterator aRowEnd = m_aGrid.end();
             for (sal_Int32 i = 0; aRowIter != aRowEnd; ++aRowIter,++i)
             {
                 sal_Int32 nPosX = nLeftMargin;
                 ::std::vector<TCell>::iterator aColIter = (*aRowIter).begin();
-                ::std::vector<TCell>::iterator aColEnd = (*aRowIter).end();
+                ::std::vector<TCell>::const_iterator aColEnd = (*aRowIter).end();
                 for (sal_Int32 j = 0; aColIter != aColEnd; ++aColIter,++j)
                 {
                     TCell& rCell = *aColIter;
                     if ( !rCell.xElements.empty())
                     {
-                        ::std::vector< uno::Reference< report::XReportComponent> >::iterator aCellIter = rCell.xElements.begin();
-                        const ::std::vector< uno::Reference< report::XReportComponent> >::iterator aCellEnd = rCell.xElements.end();
+                        ::std::vector< uno::Reference< report::XReportComponent> >::const_iterator aCellIter = rCell.xElements.begin();
+                        const ::std::vector< uno::Reference< report::XReportComponent> >::const_iterator aCellEnd = rCell.xElements.end();
                         for (;aCellIter != aCellEnd ; ++aCellIter)
                         {
                             uno::Reference<report::XShape> xShape(*aCellIter,uno::UNO_QUERY);
@@ -215,7 +215,7 @@ void OXMLTable::EndElement()
                                 sal_Int32 nColSpan = rCell.nColSpan;
                                 if ( nColSpan > 1 )
                                 {
-                                    ::std::vector<TCell>::iterator aWidthIter = aColIter + 1;
+                                    ::std::vector<TCell>::const_iterator aWidthIter = aColIter + 1;
                                     while ( nColSpan > 1 )
                                     {
                                         nWidth += (aWidthIter++)->nWidth;
@@ -226,7 +226,7 @@ void OXMLTable::EndElement()
                                 sal_Int32 nRowSpan = rCell.nRowSpan;
                                 if ( nRowSpan > 1 )
                                 {
-                                    ::std::vector< ::std::vector<TCell> >::iterator aHeightIter = aRowIter + 1;
+                                    ::std::vector< ::std::vector<TCell> >::const_iterator aHeightIter = aRowIter + 1;
                                     while( nRowSpan > 1)
                                     {
                                         nHeight += (*aHeightIter)[j].nHeight;
