@@ -18,7 +18,6 @@
  */
 #include "AddField.hxx"
 #include "UITools.hxx"
-#include <boost/noncopyable.hpp>
 #include <svx/dbaexchange.hxx>
 #include <svx/svdpagv.hxx>
 #include <com/sun/star/sdb/CommandType.hpp>
@@ -62,20 +61,21 @@ using namespace ::svx;
 
 class OAddFieldWindowListBox: public SvTreeListBox
 {
-    OAddFieldWindow*                    m_pTabWin;
+    VclPtr<OAddFieldWindow>                    m_pTabWin;
 
 public:
-    OAddFieldWindowListBox( OAddFieldWindow* _pParent );
+    explicit OAddFieldWindowListBox( OAddFieldWindow* _pParent );
     virtual ~OAddFieldWindowListBox();
+    virtual void dispose() override;
 
-    sal_Int8 AcceptDrop( const AcceptDropEvent& rEvt ) SAL_OVERRIDE;
-    sal_Int8 ExecuteDrop( const ExecuteDropEvent& rEvt ) SAL_OVERRIDE;
+    sal_Int8 AcceptDrop( const AcceptDropEvent& rEvt ) override;
+    sal_Int8 ExecuteDrop( const ExecuteDropEvent& rEvt ) override;
 
     uno::Sequence< beans::PropertyValue > getSelectedFieldDescriptors();
 
 protected:
     // DragSourceHelper
-    virtual void StartDrag( sal_Int8 nAction, const Point& rPosPixel ) SAL_OVERRIDE;
+    virtual void StartDrag( sal_Int8 nAction, const Point& rPosPixel ) override;
 
 private:
     using SvTreeListBox::ExecuteDrop;
@@ -89,7 +89,7 @@ uno::Sequence< beans::PropertyValue > OAddFieldWindowListBox::getSelectedFieldDe
     while( pSelected )
     {
         // build a descriptor for the currently selected field
-        ::svx::ODataAccessDescriptor aDescriptor;
+        svx::ODataAccessDescriptor aDescriptor;
         m_pTabWin->fillDescriptor(pSelected,aDescriptor);
         aArgs[i++].Value <<= aDescriptor.createPropertyValueSequence();
         pSelected = NextSelected(pSelected);
@@ -106,15 +106,21 @@ OAddFieldWindowListBox::OAddFieldWindowListBox( OAddFieldWindow* _pParent )
 {
     SetHelpId( HID_RPT_FIELD_SEL );
     SetSelectionMode(MULTIPLE_SELECTION);
-    SetDragDropMode( 0xFFFF );
+    SetDragDropMode( DragDropMode::ALL );
     SetHighlightRange( );
 }
 
 
 OAddFieldWindowListBox::~OAddFieldWindowListBox()
 {
+    disposeOnce();
 }
 
+void OAddFieldWindowListBox::dispose()
+{
+    m_pTabWin.clear();
+    SvTreeListBox::dispose();
+}
 
 sal_Int8 OAddFieldWindowListBox::AcceptDrop( const AcceptDropEvent& /*rEvt*/ )
 {
@@ -151,27 +157,27 @@ OAddFieldWindow::OAddFieldWindow(vcl::Window* pParent
             ,::comphelper::OPropertyChangeListener(m_aMutex)
             ,::comphelper::OContainerListener(m_aMutex)
             ,m_xRowSet(_xRowSet)
-            ,m_aActions(this,ModuleRes(RID_TB_SORTING))
-            ,m_pListBox(new OAddFieldWindowListBox( this ))
-            ,m_aFixedLine(this, ModuleRes(ADDFIELD_FL_HELP_SEPARATOR) )
-            ,m_aHelpText(this, ModuleRes(ADDFIELD_HELP_FIELD) )
-            ,m_aInsertButton(this, WB_TABSTOP|WB_CENTER)
+            ,m_aActions(VclPtr<ToolBox>::Create(this,ModuleRes(RID_TB_SORTING)))
+            ,m_pListBox(VclPtr<OAddFieldWindowListBox>::Create( this ))
+            ,m_aFixedLine(VclPtr<FixedLine>::Create(this, ModuleRes(ADDFIELD_FL_HELP_SEPARATOR) ))
+            ,m_aHelpText(VclPtr<FixedText>::Create(this, ModuleRes(ADDFIELD_HELP_FIELD) ))
+            ,m_aInsertButton(VclPtr<PushButton>::Create(this, WB_TABSTOP|WB_CENTER))
             ,m_nCommandType(0)
             ,m_bEscapeProcessing(false)
-            ,m_pChangeListener(NULL)
-            ,m_pContainerListener(NULL)
+            ,m_pChangeListener(nullptr)
+            ,m_pContainerListener(nullptr)
 {
     SetHelpId( HID_RPT_FIELD_SEL_WIN );
     SetBackground( Wallpaper( Application::GetSettings().GetStyleSettings().GetFaceColor()) );
     SetMinOutputSizePixel(Size(STD_WIN_SIZE_X,STD_WIN_SIZE_Y));
 
-    m_aActions.SetStyle(m_aActions.GetStyle()|WB_LINESPACING);
-    m_aActions.SetBackground( Wallpaper( Application::GetSettings().GetStyleSettings().GetFaceColor()) );
+    m_aActions->SetStyle(m_aActions->GetStyle()|WB_LINESPACING);
+    m_aActions->SetBackground( Wallpaper( Application::GetSettings().GetStyleSettings().GetFaceColor()) );
 
-    m_aActions.SetSelectHdl(LINK(this, OAddFieldWindow, OnSortAction));
-    setToolBox(&m_aActions);
-    m_aActions.CheckItem(SID_FM_SORTUP);
-    m_aActions.EnableItem(SID_ADD_CONTROL_PAIR, false);
+    m_aActions->SetSelectHdl(LINK(this, OAddFieldWindow, OnSortAction));
+    setToolBox(m_aActions.get());
+    m_aActions->CheckItem(SID_FM_SORTUP);
+    m_aActions->EnableItem(SID_ADD_CONTROL_PAIR, false);
 
     m_pListBox->SetDoubleClickHdl(LINK( this, OAddFieldWindow, OnDoubleClickHdl ) );
     m_pListBox->SetSelectHdl(LINK( this, OAddFieldWindow, OnSelectHdl ) );
@@ -179,12 +185,12 @@ OAddFieldWindow::OAddFieldWindow(vcl::Window* pParent
     m_pListBox->SetDoubleClickHdl(LINK( this, OAddFieldWindow, OnDoubleClickHdl ) );
     m_pListBox->Show();
     const OUString sTitle(ModuleRes(RID_STR_INSERT));
-    m_aInsertButton.SetText(sTitle);
-    m_aInsertButton.SetClickHdl(LINK( this, OAddFieldWindow, OnDoubleClickHdl ) );
-    m_aInsertButton.Show();
+    m_aInsertButton->SetText(sTitle);
+    m_aInsertButton->SetClickHdl(LINK( this, OAddFieldWindow, OnClickHdl ) );
+    m_aInsertButton->Show();
 
-    m_aFixedLine.SetControlBackground( GetSettings().GetStyleSettings().GetFaceColor() );
-    m_aHelpText.SetControlBackground( GetSettings().GetStyleSettings().GetFaceColor() );
+    m_aFixedLine->SetControlBackground( GetSettings().GetStyleSettings().GetFaceColor() );
+    m_aHelpText->SetControlBackground( GetSettings().GetStyleSettings().GetFaceColor() );
 
     SetSizePixel(Size(STD_WIN_SIZE_X,STD_WIN_SIZE_Y));
 
@@ -208,6 +214,11 @@ OAddFieldWindow::OAddFieldWindow(vcl::Window* pParent
 
 
 OAddFieldWindow::~OAddFieldWindow()
+{
+    disposeOnce();
+}
+
+void OAddFieldWindow::dispose()
 {
     if ( m_pListBox.get() )
     {
@@ -222,6 +233,13 @@ OAddFieldWindow::~OAddFieldWindow()
         m_pChangeListener->dispose();
     if ( m_pContainerListener.is() )
         m_pContainerListener->dispose();
+
+    m_aActions.disposeAndClear();
+    m_aFixedLine.disposeAndClear();
+    m_aHelpText.disposeAndClear();
+    m_aInsertButton.disposeAndClear();
+    m_pListBox.disposeAndClear();
+    FloatingWindow::dispose();
 }
 
 
@@ -241,14 +259,14 @@ uno::Sequence< beans::PropertyValue > OAddFieldWindow::getSelectedFieldDescripto
 
 bool OAddFieldWindow::PreNotify( NotifyEvent& _rNEvt )
 {
-    if ( EVENT_KEYINPUT == _rNEvt.GetType() )
+    if ( MouseNotifyEvent::KEYINPUT == _rNEvt.GetType() )
     {
         const vcl::KeyCode& rKeyCode = _rNEvt.GetKeyEvent()->GetKeyCode();
         if ( ( 0 == rKeyCode.GetModifier() ) && ( KEY_RETURN == rKeyCode.GetCode() ) )
         {
             if ( m_aCreateLink.IsSet() )
             {
-                m_aCreateLink.Call(this);
+                m_aCreateLink.Call(*this);
                 return true;
             }
         }
@@ -257,7 +275,7 @@ bool OAddFieldWindow::PreNotify( NotifyEvent& _rNEvt )
     return FloatingWindow::PreNotify( _rNEvt );
 }
 
-void OAddFieldWindow::_propertyChanged( const beans::PropertyChangeEvent& _evt ) throw( uno::RuntimeException )
+void OAddFieldWindow::_propertyChanged( const beans::PropertyChangeEvent& _evt ) throw( uno::RuntimeException, std::exception )
 {
     OSL_ENSURE( _evt.Source == m_xRowSet, "OAddFieldWindow::_propertyChanged: where did this come from?" );
     (void)_evt;
@@ -272,7 +290,7 @@ namespace
         const OUString* pEntries = _rEntries.getConstArray();
         sal_Int32 nEntries = _rEntries.getLength();
         for ( sal_Int32 i = 0; i < nEntries; ++i, ++pEntries )
-            _rListBox.InsertEntry( *pEntries,NULL,false,TREELIST_APPEND,new ColumnInfo(*pEntries) );
+            _rListBox.InsertEntry( *pEntries,nullptr,false,TREELIST_APPEND,new ColumnInfo(*pEntries) );
     }
     void lcl_addToList( OAddFieldWindowListBox& _rListBox, const uno::Reference< container::XNameAccess>& i_xColumns )
     {
@@ -286,9 +304,9 @@ namespace
             if ( xColumn->getPropertySetInfo()->hasPropertyByName(PROPERTY_LABEL) )
                 xColumn->getPropertyValue(PROPERTY_LABEL) >>= sLabel;
             if ( !sLabel.isEmpty() )
-                _rListBox.InsertEntry( sLabel,NULL,false,TREELIST_APPEND,new ColumnInfo(*pEntries,sLabel) );
+                _rListBox.InsertEntry( sLabel,nullptr,false,TREELIST_APPEND,new ColumnInfo(*pEntries,sLabel) );
             else
-                _rListBox.InsertEntry( *pEntries,NULL,false,TREELIST_APPEND,new ColumnInfo(*pEntries,sLabel) );
+                _rListBox.InsertEntry( *pEntries,nullptr,false,TREELIST_APPEND,new ColumnInfo(*pEntries,sLabel) );
         }
     }
 }
@@ -300,17 +318,17 @@ void OAddFieldWindow::Update()
 
     if ( m_pContainerListener.is() )
         m_pContainerListener->dispose();
-    m_pContainerListener = NULL;
+    m_pContainerListener = nullptr;
     m_xColumns.clear();
 
     try
     {
         // ListBox loeschen
         m_pListBox->Clear();
-        const sal_uInt16 nItemCount = m_aActions.GetItemCount();
+        const sal_uInt16 nItemCount = m_aActions->GetItemCount();
         for (sal_uInt16 j = 0; j< nItemCount; ++j)
         {
-            m_aActions.EnableItem(m_aActions.GetItemId(j),false);
+            m_aActions->EnableItem(m_aActions->GetItemId(j),false);
         }
 
         OUString aTitle(ModuleRes(RID_STR_FIELDSELECTION));
@@ -345,7 +363,7 @@ void OAddFieldWindow::Update()
             }
 
             // add the parameter columns to the list
-            uno::Reference< ::com::sun::star::sdbc::XRowSet > xRowSet(m_xRowSet,uno::UNO_QUERY);
+            uno::Reference< css::sdbc::XRowSet > xRowSet(m_xRowSet,uno::UNO_QUERY);
             Sequence< OUString > aParamNames( getParameterNames( xRowSet ) );
             lcl_addToList( *m_pListBox, aParamNames );
 
@@ -356,10 +374,10 @@ void OAddFieldWindow::Update()
             {
                 for (sal_uInt16 i = 0; i < nItemCount; ++i)
                 {
-                    m_aActions.EnableItem(m_aActions.GetItemId(i));
+                    m_aActions->EnableItem(m_aActions->GetItemId(i));
                 }
             }
-                OnSelectHdl(NULL);
+                OnSelectHdl(nullptr);
         }
     }
     catch( const Exception& )
@@ -380,15 +398,15 @@ void OAddFieldWindow::Resize()
     const Size aFixedTextSize(LogicToPixel( Size( FIXEDTEXT_WIDTH, FIXEDTEXT_HEIGHT ), MAP_APPFONT ));
 
     // ToolBar
-    Size aToolbarSize( m_aActions.GetSizePixel() );
+    Size aToolbarSize( m_aActions->GetSizePixel() );
     Point aToolbarPos( aRelated.Width(), aRelated.Height());
-    m_aActions.SetPosPixel(Point(aToolbarPos.X(), aToolbarPos.Y()));
+    m_aActions->SetPosPixel(Point(aToolbarPos.X(), aToolbarPos.Y()));
 
     Size aLBSize( aWindowSize );
     aLBSize.Width()  -= ( 2 * aRelated.Width() );
 
     // help text
-    const Size aHelpTextSize = m_aHelpText.CalcMinimumSize(aLBSize.Width());
+    const Size aHelpTextSize = m_aHelpText->CalcMinimumSize(aLBSize.Width());
 
     // ListBox
     Point aLBPos( aRelated.Width(), aRelated.Height() + aToolbarSize.Height() + aRelated.Height() );
@@ -402,11 +420,11 @@ void OAddFieldWindow::Resize()
     // FixedLine
     Size aFLSize( aLBSize.Width(),aFixedTextSize.Height() );
     Point aFLPos( aRelated.Width(), aLBPos.Y() + aLBSize.Height() + aRelated.Height());
-    m_aFixedLine.SetPosSizePixel( aFLPos, aFLSize );
+    m_aFixedLine->SetPosSizePixel( aFLPos, aFLSize );
 
     // Help text
     Point aFTPos( aRelated.Width(), aFLPos.Y() + aFLSize.Height() + aRelated.Height() );
-    m_aHelpText.SetPosSizePixel( aFTPos, aHelpTextSize );
+    m_aHelpText->SetPosSizePixel( aFTPos, aHelpTextSize );
 }
 
 uno::Reference< sdbc::XConnection> OAddFieldWindow::getConnection() const
@@ -414,7 +432,7 @@ uno::Reference< sdbc::XConnection> OAddFieldWindow::getConnection() const
     return uno::Reference< sdbc::XConnection>(m_xRowSet->getPropertyValue( PROPERTY_ACTIVECONNECTION ),uno::UNO_QUERY);
 }
 
-void OAddFieldWindow::fillDescriptor(SvTreeListEntry* _pSelected,::svx::ODataAccessDescriptor& _rDescriptor)
+void OAddFieldWindow::fillDescriptor(SvTreeListEntry* _pSelected,svx::ODataAccessDescriptor& _rDescriptor)
 {
     if ( _pSelected && m_xColumns.is() )
     {
@@ -430,19 +448,19 @@ void OAddFieldWindow::fillDescriptor(SvTreeListEntry* _pSelected,::svx::ODataAcc
             }
         }
 
-        _rDescriptor[ ::svx::daCommand ]            <<= GetCommand();
-        _rDescriptor[ ::svx::daCommandType ]        <<= GetCommandType();
-        _rDescriptor[ ::svx::daEscapeProcessing ]   <<= GetEscapeProcessing();
-        _rDescriptor[ ::svx::daConnection ]         <<= getConnection();
+        _rDescriptor[ svx::daCommand ]            <<= GetCommand();
+        _rDescriptor[ svx::daCommandType ]        <<= GetCommandType();
+        _rDescriptor[ svx::daEscapeProcessing ]   <<= GetEscapeProcessing();
+        _rDescriptor[ svx::daConnection ]         <<= getConnection();
 
         ColumnInfo* pInfo = static_cast<ColumnInfo*>(_pSelected->GetUserData());
-        _rDescriptor[ ::svx::daColumnName ]         <<= pInfo->sColumnName;
+        _rDescriptor[ svx::daColumnName ]         <<= pInfo->sColumnName;
         if ( m_xColumns->hasByName( pInfo->sColumnName ) )
-            _rDescriptor[ ::svx::daColumnObject ] <<= m_xColumns->getByName(pInfo->sColumnName);
+            _rDescriptor[ svx::daColumnObject ] <<= m_xColumns->getByName(pInfo->sColumnName);
     }
 }
 
-void OAddFieldWindow::_elementInserted( const container::ContainerEvent& _rEvent )  throw(::com::sun::star::uno::RuntimeException, std::exception)
+void OAddFieldWindow::_elementInserted( const container::ContainerEvent& _rEvent )  throw(css::uno::RuntimeException, std::exception)
 {
     if ( m_pListBox.get() )
     {
@@ -454,14 +472,14 @@ void OAddFieldWindow::_elementInserted( const container::ContainerEvent& _rEvent
             if ( xColumn->getPropertySetInfo()->hasPropertyByName(PROPERTY_LABEL) )
                 xColumn->getPropertyValue(PROPERTY_LABEL) >>= sLabel;
             if ( !sLabel.isEmpty() )
-                m_pListBox->InsertEntry( sLabel,NULL,false,TREELIST_APPEND,new ColumnInfo(sName,sLabel) );
+                m_pListBox->InsertEntry( sLabel,nullptr,false,TREELIST_APPEND,new ColumnInfo(sName,sLabel) );
             else
-                m_pListBox->InsertEntry( sName,NULL,false,TREELIST_APPEND,new ColumnInfo(sName,sLabel) );
+                m_pListBox->InsertEntry( sName,nullptr,false,TREELIST_APPEND,new ColumnInfo(sName,sLabel) );
         }
     }
 }
 
-void OAddFieldWindow::_elementRemoved( const container::ContainerEvent& /*_rEvent*/ ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void OAddFieldWindow::_elementRemoved( const container::ContainerEvent& /*_rEvent*/ ) throw(css::uno::RuntimeException, std::exception)
 {
     if ( m_pListBox.get() )
     {
@@ -471,23 +489,25 @@ void OAddFieldWindow::_elementRemoved( const container::ContainerEvent& /*_rEven
     }
 }
 
-void OAddFieldWindow::_elementReplaced( const container::ContainerEvent& /*_rEvent*/ ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void OAddFieldWindow::_elementReplaced( const container::ContainerEvent& /*_rEvent*/ ) throw(css::uno::RuntimeException, std::exception)
 {
 }
 
-IMPL_LINK( OAddFieldWindow, OnSelectHdl, void* ,/*_pAddFieldDlg*/)
+IMPL_LINK_NOARG_TYPED( OAddFieldWindow, OnSelectHdl, SvTreeListBox*, void )
 {
-    m_aActions.EnableItem(SID_ADD_CONTROL_PAIR, ( m_pListBox.get() && m_pListBox->GetSelectionCount() > 0 ));
-
-    return 0L;
+    m_aActions->EnableItem(SID_ADD_CONTROL_PAIR, ( m_pListBox.get() && m_pListBox->GetSelectionCount() > 0 ));
 }
 
-IMPL_LINK( OAddFieldWindow, OnDoubleClickHdl, void* ,/*_pAddFieldDlg*/)
+IMPL_LINK_NOARG_TYPED( OAddFieldWindow, OnClickHdl, Button*, void )
 {
-    if ( m_aCreateLink.IsSet() )
-        m_aCreateLink.Call(this);
+    OnDoubleClickHdl(nullptr);
+}
 
-    return 0L;
+IMPL_LINK_NOARG_TYPED( OAddFieldWindow, OnDoubleClickHdl, SvTreeListBox*, bool )
+{
+    m_aCreateLink.Call(*this);
+
+    return false;
 }
 
 void OAddFieldWindow::setImageList(sal_Int16 _eBitmapSet)
@@ -495,7 +515,7 @@ void OAddFieldWindow::setImageList(sal_Int16 _eBitmapSet)
     sal_Int16 nN = IMG_ADDFIELD_DLG_SC;
     if ( _eBitmapSet == SFX_SYMBOLS_SIZE_LARGE )
         nN = IMG_ADDFIELD_DLG_LC;
-    m_aActions.SetImageList(ImageList(ModuleRes(nN)));
+    m_aActions->SetImageList(ImageList(ModuleRes(nN)));
 }
 
 void OAddFieldWindow::resizeControls(const Size& _rDiff)
@@ -507,29 +527,29 @@ void OAddFieldWindow::resizeControls(const Size& _rDiff)
     }
 }
 
-IMPL_LINK( OAddFieldWindow, OnSortAction, ToolBox*, /*NOTINTERESTEDIN*/ )
+IMPL_LINK_NOARG_TYPED( OAddFieldWindow, OnSortAction, ToolBox*, void )
 {
-    const sal_uInt16 nCurItem = m_aActions.GetCurItemId();
+    const sal_uInt16 nCurItem = m_aActions->GetCurItemId();
     if ( SID_ADD_CONTROL_PAIR == nCurItem )
-        OnDoubleClickHdl(NULL);
+        OnDoubleClickHdl(nullptr);
     else
     {
-        if ( SID_FM_REMOVE_FILTER_SORT == nCurItem || !m_aActions.IsItemChecked(nCurItem) )
+        if ( SID_FM_REMOVE_FILTER_SORT == nCurItem || !m_aActions->IsItemChecked(nCurItem) )
         {
-            const sal_uInt16 nItemCount = m_aActions.GetItemCount();
+            const sal_uInt16 nItemCount = m_aActions->GetItemCount();
             for (sal_uInt16 j = 0; j< nItemCount; ++j)
             {
-                const sal_uInt16 nItemId = m_aActions.GetItemId(j);
+                const sal_uInt16 nItemId = m_aActions->GetItemId(j);
                 if ( nCurItem != nItemId )
-                    m_aActions.CheckItem(nItemId,false);
+                    m_aActions->CheckItem(nItemId,false);
             }
             SvSortMode eSortMode = SortNone;
             if ( SID_FM_REMOVE_FILTER_SORT != nCurItem )
             {
-                m_aActions.CheckItem(nCurItem,!m_aActions.IsItemChecked(nCurItem));
-                if ( m_aActions.IsItemChecked(SID_FM_SORTUP) )
+                m_aActions->CheckItem(nCurItem,!m_aActions->IsItemChecked(nCurItem));
+                if ( m_aActions->IsItemChecked(SID_FM_SORTUP) )
                     eSortMode = SortAscending;
-                else if ( m_aActions.IsItemChecked(SID_FM_SORTDOWN) )
+                else if ( m_aActions->IsItemChecked(SID_FM_SORTDOWN) )
                     eSortMode = SortDescending;
             }
 
@@ -540,7 +560,6 @@ IMPL_LINK( OAddFieldWindow, OnSortAction, ToolBox*, /*NOTINTERESTEDIN*/ )
             m_pListBox->GetModel()->Resort();
         }
     }
-    return 0L;
 }
 
 
