@@ -51,10 +51,7 @@ using ::com::sun::star::uno::Sequence;
 using ::com::sun::star::sheet::TablePageBreakData;
 using ::std::set;
 
-// STATIC DATA -----------------------------------------------------------
-
-#define GET_SCALEVALUE(set,id)  ((const SfxUInt16Item&)(set.Get( id ))).GetValue()
-
+#define GET_SCALEVALUE(set,id)  static_cast<const SfxUInt16Item&>(set.Get( id )).GetValue()
 
 void ScTable::UpdatePageBreaks( const ScRange* pUserArea )
 {
@@ -75,7 +72,7 @@ void ScTable::UpdatePageBreaks( const ScRange* pUserArea )
     }
 
     SfxStyleSheetBase* pStyle = pDocument->GetStyleSheetPool()->
-                                    Find( aPageStyle, SFX_STYLE_FAMILY_PAGE );
+                                    Find( aPageStyle, SfxStyleFamily::Page );
     if ( !pStyle )
     {
         OSL_FAIL("UpdatePageBreaks: Style not found");
@@ -101,7 +98,7 @@ void ScTable::UpdatePageBreaks( const ScRange* pUserArea )
         sal_uInt16 nAreaCount = GetPrintRangeCount();
         if ( nAreaCount > 1 )
         {
-            //  bei mehreren Bereichen nichts anzeigen:
+            // Show nothing, when multiple ranges
 
             for (nX=0; nX<MAXCOL; nX++)
                 RemoveColBreak(nX, true, false);
@@ -120,7 +117,7 @@ void ScTable::UpdatePageBreaks( const ScRange* pUserArea )
                 nEndCol = pArea->aEnd.Col();
                 nEndRow = pArea->aEnd.Row();
             }
-        }           // sonst alles
+        }           // otherwise show everything
     }
 
     // get bSkipColBreaks/bSkipRowBreaks flags:
@@ -132,13 +129,13 @@ void ScTable::UpdatePageBreaks( const ScRange* pUserArea )
 
     if (!mbForceBreaks)
     {
-         if ( pStyleSet->GetItemState( ATTR_PAGE_SCALETOPAGES, false, &pItem ) == SFX_ITEM_SET )
+         if ( pStyleSet->GetItemState( ATTR_PAGE_SCALETOPAGES, false, &pItem ) == SfxItemState::SET )
          {
-              OSL_ENSURE( pItem->ISA(SfxUInt16Item), "invalid Item" );
-              bSkipColBreaks = bSkipRowBreaks = ( ((const SfxUInt16Item*)pItem)->GetValue() > 0 );
+              OSL_ENSURE( dynamic_cast<const SfxUInt16Item*>( pItem) !=  nullptr, "invalid Item" );
+              bSkipColBreaks = bSkipRowBreaks = static_cast<const SfxUInt16Item*>(pItem)->GetValue() > 0;
          }
 
-         if ( !bSkipColBreaks && pStyleSet->GetItemState(ATTR_PAGE_SCALETO, false, &pItem) == SFX_ITEM_SET )
+         if ( !bSkipColBreaks && pStyleSet->GetItemState(ATTR_PAGE_SCALETO, false, &pItem) == SfxItemState::SET )
          {
               // #i54993# when fitting to width or height, ignore only manual breaks in that direction
               const ScPageScaleToItem* pScaleToItem = static_cast<const ScPageScaleToItem*>(pItem);
@@ -152,7 +149,7 @@ void ScTable::UpdatePageBreaks( const ScRange* pUserArea )
     long nPageSizeX = aPageSizeTwips.Width();
     long nPageSizeY = aPageSizeTwips.Height();
 
-        //  Anfang: Breaks loeschen
+        //  Beginning: Remove breaks
 
     for (nX=0; nX<nStartCol; nX++)
         RemoveColBreak(nX, true, false);
@@ -163,7 +160,7 @@ void ScTable::UpdatePageBreaks( const ScRange* pUserArea )
     if (nStartRow > 0)
         SetRowBreak(nStartRow, true, false);  // AREABREAK
 
-        //  Mittelteil: Breaks verteilen
+        //  Middle part: Distribute breaks
 
     bool bRepeatCol = ( nRepeatStartX != SCCOL_REPEAT_NONE );
     bool bColFound = false;
@@ -225,7 +222,7 @@ void ScTable::UpdatePageBreaks( const ScRange* pUserArea )
         {
             bManualBreak = (nY == nNextManualBreak);
             if (nY >= nNextManualBreak)
-                // Query the next menual break position.
+                // Query the next manual break position.
                 nNextManualBreak = GetNextManualBreak(nY+1);
         }
 
@@ -289,7 +286,7 @@ void ScTable::UpdatePageBreaks( const ScRange* pUserArea )
         nSizeY += nThisY;
     }
 
-        //  Ende: Breaks loeschen
+        //  End: Remove Break
 
     if (nEndCol < MAXCOL)
     {
@@ -560,7 +557,7 @@ bool ScTable::HasHiddenRows(SCROW nStartRow, SCROW nEndRow) const
     while (nRow <= nEndRow)
     {
         SCROW nLastRow = -1;
-        bool bHidden = RowHidden(nRow, NULL, &nLastRow);
+        bool bHidden = RowHidden(nRow, nullptr, &nLastRow);
         if (bHidden)
             return true;
 
@@ -603,7 +600,7 @@ bool ScTable::SetRowHidden(SCROW nStartRow, SCROW nEndRow, bool bHidden)
     return bChanged;
 }
 
-bool ScTable::SetColHidden(SCCOL nStartCol, SCCOL nEndCol, bool bHidden)
+void ScTable::SetColHidden(SCCOL nStartCol, SCCOL nEndCol, bool bHidden)
 {
     bool bChanged = false;
     if (bHidden)
@@ -616,8 +613,6 @@ bool ScTable::SetColHidden(SCCOL nStartCol, SCCOL nEndCol, bool bHidden)
         if (IsStreamValid())
             SetStreamValid(false);
     }
-
-    return bChanged;
 }
 
 void ScTable::CopyColHidden(ScTable& rTable, SCCOL nStartCol, SCCOL nEndCol)
@@ -625,8 +620,8 @@ void ScTable::CopyColHidden(ScTable& rTable, SCCOL nStartCol, SCCOL nEndCol)
     SCCOL nCol = nStartCol;
     while (nCol <= nEndCol)
     {
-        SCCOL nLastCol;
-        bool bHidden = rTable.ColHidden(nCol, NULL, &nLastCol);
+        SCCOL nLastCol = -1;
+        bool bHidden = rTable.ColHidden(nCol, nullptr, &nLastCol);
         if (nLastCol > nEndCol)
             nLastCol = nEndCol;
 
@@ -641,7 +636,7 @@ void ScTable::CopyRowHidden(ScTable& rTable, SCROW nStartRow, SCROW nEndRow)
     while (nRow <= nEndRow)
     {
         SCROW nLastRow = -1;
-        bool bHidden = rTable.RowHidden(nRow, NULL, &nLastRow);
+        bool bHidden = rTable.RowHidden(nRow, nullptr, &nLastRow);
         if (nLastRow > nEndRow)
             nLastRow = nEndRow;
         SetRowHidden(nRow, nLastRow, bHidden);
@@ -776,7 +771,7 @@ SCCOLROW ScTable::LastHiddenColRow(SCCOLROW nPos, bool bCol) const
     {
         SCROW nRow = static_cast<SCROW>(nPos);
         SCROW nLastRow;
-        if (RowHidden(nRow, NULL, &nLastRow))
+        if (RowHidden(nRow, nullptr, &nLastRow))
             return static_cast<SCCOLROW>(nLastRow);
     }
     return ::std::numeric_limits<SCCOLROW>::max();
@@ -824,7 +819,7 @@ bool ScTable::HasFilteredRows(SCROW nStartRow, SCROW nEndRow) const
     while (nRow <= nEndRow)
     {
         SCROW nLastRow = nRow;
-        bool bFiltered = RowFiltered(nRow, NULL, &nLastRow);
+        bool bFiltered = RowFiltered(nRow, nullptr, &nLastRow);
         if (bFiltered)
             return true;
 
@@ -838,8 +833,8 @@ void ScTable::CopyColFiltered(ScTable& rTable, SCCOL nStartCol, SCCOL nEndCol)
     SCCOL nCol = nStartCol;
     while (nCol <= nEndCol)
     {
-        SCCOL nLastCol;
-        bool bFiltered = rTable.ColFiltered(nCol, NULL, &nLastCol);
+        SCCOL nLastCol = -1;
+        bool bFiltered = rTable.ColFiltered(nCol, nullptr, &nLastCol);
         if (nLastCol > nEndCol)
             nLastCol = nEndCol;
 
@@ -854,7 +849,7 @@ void ScTable::CopyRowFiltered(ScTable& rTable, SCROW nStartRow, SCROW nEndRow)
     while (nRow <= nEndRow)
     {
         SCROW nLastRow = -1;
-        bool bFiltered = rTable.RowFiltered(nRow, NULL, &nLastRow);
+        bool bFiltered = rTable.RowFiltered(nRow, nullptr, &nLastRow);
         if (nLastRow > nEndRow)
             nLastRow = nEndRow;
         SetRowFiltered(nRow, nLastRow, bFiltered);
@@ -1073,7 +1068,7 @@ Size ScTable::GetPageSize() const
     if ( bPageSizeValid )
         return aPageSizeTwips;
     else
-        return Size();  // leer
+        return Size();  // blank
 }
 
 void ScTable::SetRepeatArea( SCCOL nStartCol, SCCOL nEndCol, SCROW nStartRow, SCROW nEndRow )
@@ -1104,20 +1099,20 @@ void ScTable::EndListening( const ScAddress& rAddress, SvtListener* pListener )
     aCol[rAddress.Col()].EndListening( *pListener, rAddress.Row() );
 }
 
-void ScTable::StartListening( sc::StartListeningContext& rCxt, SCCOL nCol, SCROW nRow, SvtListener& rListener )
+void ScTable::StartListening( sc::StartListeningContext& rCxt, const ScAddress& rAddress, SvtListener& rListener )
 {
-    if (!ValidCol(nCol))
+    if (!ValidCol(rAddress.Col()))
         return;
 
-    aCol[nCol].StartListening(rCxt, nRow, rListener);
+    aCol[rAddress.Col()].StartListening(rCxt, rAddress, rListener);
 }
 
-void ScTable::EndListening( sc::EndListeningContext& rCxt, SCCOL nCol, SCROW nRow, SvtListener& rListener )
+void ScTable::EndListening( sc::EndListeningContext& rCxt, const ScAddress& rAddress, SvtListener& rListener )
 {
-    if (!ValidCol(nCol))
+    if (!ValidCol(rAddress.Col()))
         return;
 
-    aCol[nCol].EndListening(rCxt, nRow, rListener);
+    aCol[rAddress.Col()].EndListening(rCxt, rAddress, rListener);
 }
 
 void ScTable::SetPageStyle( const OUString& rName )
@@ -1126,17 +1121,17 @@ void ScTable::SetPageStyle( const OUString& rName )
     {
         OUString           aStrNew    = rName;
         SfxStyleSheetBasePool*  pStylePool = pDocument->GetStyleSheetPool();
-        SfxStyleSheetBase*      pNewStyle  = pStylePool->Find( aStrNew, SFX_STYLE_FAMILY_PAGE );
+        SfxStyleSheetBase*      pNewStyle  = pStylePool->Find( aStrNew, SfxStyleFamily::Page );
 
         if ( !pNewStyle )
         {
             aStrNew = ScGlobal::GetRscString(STR_STYLENAME_STANDARD);
-            pNewStyle = pStylePool->Find( aStrNew, SFX_STYLE_FAMILY_PAGE );
+            pNewStyle = pStylePool->Find( aStrNew, SfxStyleFamily::Page );
         }
 
         if ( aPageStyle != aStrNew )
         {
-            SfxStyleSheetBase* pOldStyle = pStylePool->Find( aPageStyle, SFX_STYLE_FAMILY_PAGE );
+            SfxStyleSheetBase* pOldStyle = pStylePool->Find( aPageStyle, SfxStyleFamily::Page );
 
             if ( pOldStyle && pNewStyle )
             {
@@ -1148,10 +1143,10 @@ void ScTable::SetPageStyle( const OUString& rName )
                 const sal_uInt16 nNewScaleToPages = GET_SCALEVALUE(rNewSet,ATTR_PAGE_SCALETOPAGES);
 
                 if ( (nOldScale != nNewScale) || (nOldScaleToPages != nNewScaleToPages) )
-                    InvalidateTextWidth(NULL, NULL, false, false);
+                    InvalidateTextWidth(nullptr, nullptr, false, false);
             }
 
-            if ( pNewStyle )            // auch ohne den alten (fuer UpdateStdNames)
+            if ( pNewStyle )            // also without the old one (for UpdateStdNames)
                 aPageStyle = aStrNew;
 
             if (IsStreamValid())
@@ -1163,7 +1158,7 @@ void ScTable::SetPageStyle( const OUString& rName )
 void ScTable::PageStyleModified( const OUString& rNewName )
 {
     aPageStyle = rNewName;
-    InvalidateTextWidth(NULL, NULL, false, false);      // don't know what was in the style before
+    InvalidateTextWidth(nullptr, nullptr, false, false);      // don't know what was in the style before
 }
 
 void ScTable::InvalidateTextWidth( const ScAddress* pAdrFrom, const ScAddress* pAdrTo,
@@ -1182,10 +1177,10 @@ void ScTable::InvalidateTextWidth( const ScAddress* pAdrFrom, const ScAddress* p
         rCol.SetTextWidth(nRow, TEXTWIDTH_DIRTY);
 
         if ( bNumFormatChanged )
-            rCol.SetScriptType(nRow, SC_SCRIPTTYPE_UNKNOWN);
+            rCol.SetScriptType(nRow, SvtScriptType::UNKNOWN);
 
         if ( bBroadcast )
-        {   // nur bei CalcAsShown
+        {   // Only with CalcAsShown
             switch (aCell.meType)
             {
                 case CELLTYPE_VALUE :
@@ -1222,10 +1217,10 @@ void ScTable::InvalidateTextWidth( const ScAddress* pAdrFrom, const ScAddress* p
                 continue;
 
             if ( bNumFormatChanged )
-                aCol[nCol].SetScriptType(nRow, SC_SCRIPTTYPE_UNKNOWN);
+                aCol[nCol].SetScriptType(nRow, SvtScriptType::UNKNOWN);
 
             if ( bBroadcast )
-            {   // nur bei CalcAsShown
+            {   // Only with CalcAsShown
                 switch (aCell.meType)
                 {
                     case CELLTYPE_VALUE :
@@ -1244,6 +1239,4 @@ void ScTable::InvalidateTextWidth( const ScAddress* pAdrFrom, const ScAddress* p
     }
 }
 
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
