@@ -26,10 +26,12 @@
 #include <osl/diagnose.h>
 #include <svl/intitem.hxx>
 #include <svl/sharedstringpool.hxx>
+#include <oox/core/filterbase.hxx>
 #include <oox/helper/attributelist.hxx>
 #include <oox/helper/containerhelper.hxx>
 #include <oox/helper/propertyset.hxx>
 #include <oox/token/properties.hxx>
+#include <oox/token/tokens.hxx>
 #include "addressconverter.hxx"
 #include "biffinputstream.hxx"
 #include "stylesbuffer.hxx"
@@ -104,18 +106,30 @@ const sal_uInt16 BIFF12_CFRULE_ABOVEAVERAGE         = 0x0004;
 const sal_uInt16 BIFF12_CFRULE_BOTTOM               = 0x0008;
 const sal_uInt16 BIFF12_CFRULE_PERCENT              = 0x0010;
 
+bool isValue(const OUString& rStr, double& rVal)
+{
+    sal_Int32 nEnd = -1;
+    rVal = rtl::math::stringToDouble(rStr.trim(), '.', ',', nullptr, &nEnd);
+
+    if (nEnd < rStr.getLength())
+        return false;
+
+    return true;
+}
+
 void SetCfvoData( ColorScaleRuleModelEntry* pEntry, const AttributeList& rAttribs )
 {
     OUString aType = rAttribs.getString( XML_type, OUString() );
+    OUString aVal = rAttribs.getString(XML_val, OUString());
 
-    if( aType == "formula" )
+    double nVal = 0.0;
+    bool bVal = isValue(aVal, nVal);
+    if( !bVal || aType == "formula" )
     {
-        OUString aFormula = rAttribs.getString( XML_val, OUString() );
-        pEntry->maFormula = aFormula;
+        pEntry->maFormula = aVal;
     }
     else
     {
-        double nVal = rAttribs.getDouble( XML_val, 0.0 );
         pEntry->mnVal = nVal;
     }
 
@@ -182,14 +196,17 @@ namespace {
     {
         sal_uInt32 nThemeIndex = rAttribs.getUnsigned( XML_theme, 0 );
 
-        // looks like an Excel bug
+        // Excel has a bug in the mapping of index 0, 1, 2 and 3.
         if (nThemeIndex == 0)
             nThemeIndex = 1;
         else if (nThemeIndex == 1)
             nThemeIndex = 0;
+        else if (nThemeIndex == 2)
+            nThemeIndex = 3;
+        else if (nThemeIndex == 3)
+            nThemeIndex = 2;
 
         nColor = rThemeBuffer.getColorByIndex( nThemeIndex );
-
     }
 
     ::Color aColor;
@@ -253,10 +270,8 @@ ScColorScaleEntry* ConvertToModel( const ColorScaleRuleModelEntry& rEntry, ScDoc
 
 void ColorScaleRule::AddEntries( ScColorScaleFormat* pFormat, ScDocument* pDoc, const ScAddress& rAddr )
 {
-    for(size_t i = 0; i < maColorScaleRuleEntries.size(); ++i)
+    for(ColorScaleRuleModelEntry & rEntry : maColorScaleRuleEntries)
     {
-        const ColorScaleRuleModelEntry& rEntry = maColorScaleRuleEntries[i];
-
         ScColorScaleEntry* pEntry = ConvertToModel( rEntry, pDoc, rAddr );
 
         pFormat->AddEntry( pEntry );
@@ -272,27 +287,9 @@ DataBarRule::DataBarRule( const CondFormat& rFormat ):
 
 void DataBarRule::importColor( const AttributeList& rAttribs )
 {
-    sal_uInt32 nColor = 0;
-    if( rAttribs.hasAttribute( XML_rgb ) )
-        nColor = rAttribs.getUnsignedHex( XML_rgb, UNSIGNED_RGB_TRANSPARENT );
-    else if( rAttribs.hasAttribute( XML_theme ) )
-    {
-        sal_uInt32 nThemeIndex = rAttribs.getUnsigned( XML_theme, 0 );
-        nColor = getTheme().getColorByIndex( nThemeIndex );
-    }
-
-    ::Color aColor;
-    double nTint = rAttribs.getDouble(XML_tint, 0.0);
-    if (nTint != 0.0)
-    {
-        oox::drawingml::Color aDMColor;
-        aDMColor.setSrgbClr(nColor);
-        aDMColor.addExcelTintTransformation(nTint);
-        nColor = aDMColor.getColor(getBaseFilter().getGraphicHelper());
-        aColor = ::Color(nColor);
-    }
-    else
-        aColor = ARgbToARgbComponents( nColor );
+    ThemeBuffer& rThemeBuffer = getTheme();
+    GraphicHelper& rGraphicHelper = getBaseFilter().getGraphicHelper();
+    ::Color aColor = importOOXColor(rAttribs, rThemeBuffer, rGraphicHelper);
 
     mxFormat->maPositiveColor = aColor;
 }
@@ -348,7 +345,7 @@ void IconSetRule::importCfvo( const AttributeList& rAttribs )
 
 void IconSetRule::importAttribs( const AttributeList& rAttribs )
 {
-    maIconSetType = rAttribs.getString( XML_iconSet, OUString("3TrafficLights1") );
+    maIconSetType = rAttribs.getString( XML_iconSet, "3TrafficLights1" );
     mxFormatData->mbShowValue = rAttribs.getBool( XML_showValue, true );
     mxFormatData->mbReverse = rAttribs.getBool( XML_reverse, false );
     mbCustom = rAttribs.getBool(XML_custom, false);
@@ -357,11 +354,9 @@ void IconSetRule::importAttribs( const AttributeList& rAttribs )
 void IconSetRule::importFormula(const OUString& rFormula)
 {
     ColorScaleRuleModelEntry& rEntry = maEntries.back();
-    if (rEntry.mbNum ||
-            rEntry.mbPercent ||
-            rEntry.mbPercentile)
+    double nVal = 0.0;
+    if ((rEntry.mbNum || rEntry.mbPercent || rEntry.mbPercentile) && isValue(rFormula, nVal))
     {
-        double nVal = rFormula.toDouble();
         rEntry.mnVal = nVal;
     }
     else if (!rFormula.isEmpty())
@@ -403,10 +398,10 @@ void IconSetRule::importIcon(const AttributeList& rAttribs)
 
 void IconSetRule::SetData( ScIconSetFormat* pFormat, ScDocument* pDoc, const ScAddress& rPos )
 {
-    for(size_t i = 0; i < maEntries.size(); ++i)
+    for(ColorScaleRuleModelEntry & rEntry : maEntries)
     {
-        ScColorScaleEntry* pModelEntry = ConvertToModel( maEntries[i], pDoc, rPos );
-        mxFormatData->maEntries.push_back(pModelEntry);
+        ScColorScaleEntry* pModelEntry = ConvertToModel( rEntry, pDoc, rPos );
+        mxFormatData->m_Entries.push_back(std::unique_ptr<ScColorScaleEntry>(pModelEntry));
     }
 
     mxFormatData->eIconSetType = getType(maIconSetType);
@@ -479,7 +474,7 @@ void CondFormatRule::importCfRule( const AttributeList& rAttribs )
 
 void CondFormatRule::appendFormula( const OUString& rFormula )
 {
-    CellAddress aBaseAddr = mrCondFormat.getRanges().getBaseAddress();
+    ScAddress aBaseAddr = mrCondFormat.getRanges().getBaseAddress();
     ApiTokenSequence aTokens = getFormulaParser().importFormula( aBaseAddr, rFormula );
     maModel.maFormulas.push_back( aTokens );
 }
@@ -510,7 +505,7 @@ void CondFormatRule::importCfRule( SequenceInputStream& rStrm )
     SAL_WARN_IF( !( (nFmla1Size > 0) == (rStrm.getRemaining() >= 8) ), "sc.filter", "CondFormatRule::importCfRule - formula size mismatch" );
     if( rStrm.getRemaining() >= 8 )
     {
-        CellAddress aBaseAddr = mrCondFormat.getRanges().getBaseAddress();
+        ScAddress aBaseAddr = mrCondFormat.getRanges().getBaseAddress();
         ApiTokenSequence aTokens = getFormulaParser().importFormula( aBaseAddr, FORMULATYPE_CONDFORMAT, rStrm );
         maModel.maFormulas.push_back( aTokens );
 
@@ -852,15 +847,13 @@ void CondFormatRule::finalizeImport()
         eOperator = SC_COND_DIRECT;
     }
 
-    CellAddress aBaseAddr = mrCondFormat.getRanges().getBaseAddress();
-    ScAddress aPos;
-    ScUnoConversion::FillScAddress( aPos, aBaseAddr );
+    ScAddress aPos = mrCondFormat.getRanges().getBaseAddress();
 
     if( eOperator == SC_COND_ERROR || eOperator == SC_COND_NOERROR )
     {
         ScDocument& rDoc = getScDocument();
         OUString aStyleName = getStyles().createDxfStyle( maModel.mnDxfId );
-        ScCondFormatEntry* pNewEntry = new ScCondFormatEntry( eOperator, NULL, NULL, &rDoc, aPos, aStyleName );
+        ScCondFormatEntry* pNewEntry = new ScCondFormatEntry( eOperator, nullptr, nullptr, &rDoc, aPos, aStyleName );
         mpFormat->AddEntry(pNewEntry);
     }
     else if( eOperator == SC_COND_BEGINS_WITH || eOperator == SC_COND_ENDS_WITH ||
@@ -871,7 +864,7 @@ void CondFormatRule::finalizeImport()
         svl::SharedStringPool& rSPool = rDoc.GetSharedStringPool();
         aTokenArray.AddString(rSPool.intern(maModel.maText));
         OUString aStyleName = getStyles().createDxfStyle( maModel.mnDxfId );
-        ScCondFormatEntry* pNewEntry = new ScCondFormatEntry( eOperator, &aTokenArray, NULL, &rDoc, aPos, aStyleName );
+        ScCondFormatEntry* pNewEntry = new ScCondFormatEntry( eOperator, &aTokenArray, nullptr, &rDoc, aPos, aStyleName );
         mpFormat->AddEntry(pNewEntry);
     }
     else if( (eOperator != SC_COND_NONE) && !maModel.maFormulas.empty() )
@@ -898,7 +891,7 @@ void CondFormatRule::finalizeImport()
         ScTokenArray aTokenArray;
         aTokenArray.AddDouble( maModel.mnRank );
         OUString aStyleName = getStyles().createDxfStyle( maModel.mnDxfId );
-        ScCondFormatEntry* pNewEntry = new ScCondFormatEntry( eOperator, &aTokenArray, NULL, &rDoc, aPos, aStyleName );
+        ScCondFormatEntry* pNewEntry = new ScCondFormatEntry( eOperator, &aTokenArray, nullptr, &rDoc, aPos, aStyleName );
         mpFormat->AddEntry(pNewEntry);
     }
     else if( eOperator == SC_COND_ABOVE_AVERAGE || eOperator == SC_COND_BELOW_AVERAGE ||
@@ -909,14 +902,14 @@ void CondFormatRule::finalizeImport()
         ScTokenArray aTokenArrayDev;
         aTokenArrayDev.AddDouble( maModel.mnStdDev );
         OUString aStyleName = getStyles().createDxfStyle( maModel.mnDxfId );
-        ScCondFormatEntry* pNewEntry = new ScCondFormatEntry( eOperator, &aTokenArrayDev, NULL, &rDoc, aPos, aStyleName );
+        ScCondFormatEntry* pNewEntry = new ScCondFormatEntry( eOperator, &aTokenArrayDev, nullptr, &rDoc, aPos, aStyleName );
         mpFormat->AddEntry(pNewEntry);
     }
     else if( eOperator == SC_COND_DUPLICATE || eOperator == SC_COND_NOTDUPLICATE )
     {
         ScDocument& rDoc = getScDocument();
         OUString aStyleName = getStyles().createDxfStyle( maModel.mnDxfId );
-        ScCondFormatEntry* pNewEntry = new ScCondFormatEntry( eOperator, NULL, NULL, &rDoc, aPos, aStyleName );
+        ScCondFormatEntry* pNewEntry = new ScCondFormatEntry( eOperator, nullptr, nullptr, &rDoc, aPos, aStyleName );
         mpFormat->AddEntry(pNewEntry);
     }
     else if( maModel.mnType == XML_timePeriod )
@@ -1025,7 +1018,7 @@ CondFormatModel::CondFormatModel() :
 
 CondFormat::CondFormat( const WorksheetHelper& rHelper ) :
     WorksheetHelper( rHelper ),
-    mpFormat(NULL),
+    mpFormat(nullptr),
     mbReadyForFinalize(false)
 {
 }
@@ -1068,7 +1061,7 @@ void CondFormat::finalizeImport()
         return;
     ScDocument& rDoc = getScDocument();
     maRules.forEachMem( &CondFormatRule::finalizeImport );
-    SCTAB nTab = maModel.maRanges.getBaseAddress().Sheet;
+    SCTAB nTab = maModel.maRanges.getBaseAddress().Tab();
     sal_Int32 nIndex = getScDocument().AddCondFormat(mpFormat, nTab);
 
     ScRangeList aList;
@@ -1084,7 +1077,7 @@ void CondFormat::finalizeImport()
 
 CondFormatRuleRef CondFormat::createRule()
 {
-    return CondFormatRuleRef( new CondFormatRule( *this, mpFormat ) );
+    return std::make_shared<CondFormatRule>( *this, mpFormat );
 }
 
 void CondFormat::insertRule( CondFormatRuleRef xRule )
@@ -1113,15 +1106,15 @@ namespace {
 ScConditionalFormat* findFormatByRange(const ScRangeList& rRange, ScDocument* pDoc, SCTAB nTab)
 {
     ScConditionalFormatList* pList = pDoc->GetCondFormList(nTab);
-    for (auto itr = pList->begin(); itr != pList->end(); ++itr)
+    for (auto const& it : *pList)
     {
-        if (itr->GetRange() == rRange)
+        if (it->GetRange() == rRange)
         {
-            return &(*itr);
+            return it.get();
         }
     }
 
-    return NULL;
+    return nullptr;
 }
 
 }
@@ -1147,7 +1140,7 @@ void CondFormatBuffer::finalizeImport()
     {
         ScDocument* pDoc = &getScDocument();
 
-        const ScRangeList& rRange = itr->getRange();
+        const ScRangeList& rRange = (*itr)->getRange();
         SCTAB nTab = rRange.front()->aStart.Tab();
         ScConditionalFormat* pFormat = findFormatByRange(rRange, pDoc, nTab);
         if (!pFormat)
@@ -1159,10 +1152,10 @@ void CondFormatBuffer::finalizeImport()
             pDoc->AddCondFormatData(rRange, nTab, nKey);
         }
 
-        const boost::ptr_vector<ScFormatEntry>& rEntries = itr->getEntries();
+        const std::vector< std::unique_ptr<ScFormatEntry> >& rEntries = (*itr)->getEntries();
         for (auto i = rEntries.begin(); i != rEntries.end(); ++i)
         {
-            pFormat->AddEntry(i->Clone(pDoc));
+            pFormat->AddEntry((*i)->Clone(pDoc));
         }
     }
 }
@@ -1181,7 +1174,7 @@ ExtCfDataBarRuleRef CondFormatBuffer::createExtCfDataBarRule(ScDataBarFormatData
     return extRule;
 }
 
-boost::ptr_vector<ExtCfCondFormat>& CondFormatBuffer::importExtCondFormat()
+std::vector< std::unique_ptr<ExtCfCondFormat> >& CondFormatBuffer::importExtCondFormat()
 {
     return maExtCondFormats;
 }
@@ -1269,7 +1262,7 @@ void ExtCfDataBarRule::finalizeImport()
         case CFVO:
         {
             ScDataBarFormatData* pDataBar = mpTarget;
-            ScColorScaleEntry* pEntry = NULL;
+            ScColorScaleEntry* pEntry = nullptr;
             if(maModel.mbIsLower)
                 pEntry = pDataBar->mpLowerLimit.get();
             else
@@ -1328,10 +1321,10 @@ void ExtCfDataBarRule::importCfvo( const AttributeList& rAttribs )
     maModel.maColorScaleType = rAttribs.getString( XML_type, OUString() );
 }
 
-ExtCfCondFormat::ExtCfCondFormat(const ScRangeList& rRange, boost::ptr_vector<ScFormatEntry>& rEntries):
+ExtCfCondFormat::ExtCfCondFormat(const ScRangeList& rRange, std::vector< std::unique_ptr<ScFormatEntry> >& rEntries):
     maRange(rRange)
 {
-    maEntries.transfer(maEntries.begin(), rEntries.begin(), rEntries.end(), rEntries);
+    maEntries.swap(rEntries);
 }
 
 ExtCfCondFormat::~ExtCfCondFormat()
@@ -1343,7 +1336,7 @@ const ScRangeList& ExtCfCondFormat::getRange()
     return maRange;
 }
 
-const boost::ptr_vector<ScFormatEntry>& ExtCfCondFormat::getEntries()
+const std::vector< std::unique_ptr<ScFormatEntry> >& ExtCfCondFormat::getEntries()
 {
     return maEntries;
 }
