@@ -47,7 +47,6 @@
 #include <svl/languageoptions.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/dispatch.hxx>
-#include <sfx2/mnumgr.hxx>
 #include <svl/itemset.hxx>
 #include <svl/eitem.hxx>
 #include <svx/dlgutil.hxx>
@@ -77,7 +76,6 @@ MasterPagesSelector::MasterPagesSelector (
       mrDocument(rDocument),
       mrBase(rBase),
       mnDefaultClickAction(SID_TP_APPLY_TO_ALL_SLIDES),
-      maPreviewUpdateQueue(),
       maCurrentItemList(),
       maTokenToValueSetIndex(),
       maLockedMasterPages(),
@@ -448,6 +446,7 @@ void MasterPagesSelector::NotifyContainerChangeEvent (const MasterPageContainerC
         {
             int nIndex (GetIndexForToken(rEvent.maChildToken));
             SetItem(nIndex, MasterPageContainer::NIL_TOKEN);
+            break;
         }
 
         default:
