@@ -312,14 +312,14 @@ void SlideSorterModel::Resync()
 
 void SlideSorterModel::ClearDescriptorList()
 {
-    DescriptorContainer aDescriptors;
+    ::std::vector<SharedPageDescriptor> aDescriptors;
 
     {
         ::osl::MutexGuard aGuard (maMutex);
         aDescriptors.swap(maPageDescriptors);
     }
 
-    for (DescriptorContainer::iterator iDescriptor=aDescriptors.begin(), iEnd=aDescriptors.end();
+    for (::std::vector<SharedPageDescriptor>::iterator iDescriptor=aDescriptors.begin(), iEnd=aDescriptors.end();
          iDescriptor!=iEnd;
          ++iDescriptor)
     {
@@ -564,11 +564,10 @@ void SlideSorterModel::InsertSlide (SdPage* pPage)
     // Insert the given page at index nIndex
     maPageDescriptors.insert(
         maPageDescriptors.begin()+nIndex,
-        SharedPageDescriptor(
-            new PageDescriptor (
+        std::make_shared<PageDescriptor>(
                 Reference<drawing::XDrawPage>(mxSlides->getByIndex(nIndex),UNO_QUERY),
                 pPage,
-                nIndex)));
+                nIndex));
 
     // Update page indices.
     UpdateIndices(nIndex+1);
