@@ -31,7 +31,6 @@
 #include <com/sun/star/rendering/XBitmap.hpp>
 #include <com/sun/star/util/Color.hpp>
 #include <osl/diagnose.h>
-#include <boost/bind.hpp>
 #include <map>
 
 using namespace ::com::sun::star;
@@ -177,7 +176,6 @@ public:
     OUString msStyleName;
     std::shared_ptr<ViewStyle> mpParentStyle;
     PresenterTheme::SharedFontDescriptor mpFont;
-    std::shared_ptr<PresenterBitmapContainer> mpBitmaps;
     SharedBitmapDescriptor mpBackground;
 };
 
@@ -272,7 +270,6 @@ PresenterTheme::PresenterTheme (
     : mxContext(rxContext),
       msThemeName(rsThemeName),
       mpTheme(),
-      mpBitmapContainer(),
       mxCanvas(rxCanvas)
 {
     mpTheme = ReadTheme();
@@ -385,10 +382,11 @@ std::shared_ptr<PresenterConfigurationAccess> PresenterTheme::GetNodeForViewStyl
         "Presenter/Themes/" + mpTheme->msConfigurationNodeName + "/ViewStyles")))
     {
         pConfiguration->GoToChild(
-            ::boost::bind(&PresenterConfigurationAccess::IsStringPropertyEqual,
-                rsStyleName,
-                OUString("StyleName"),
-                _2));
+            [&rsStyleName] (OUString const&, uno::Reference<beans::XPropertySet> const& xProps)
+            {
+                return PresenterConfigurationAccess::IsStringPropertyEqual(
+                        rsStyleName, "StyleName", xProps);
+            });
     }
     return pConfiguration;
 }
@@ -655,8 +653,10 @@ void PresenterTheme::Theme::Read (
         UNO_QUERY);
     PresenterConfigurationAccess::ForAll(
         xFontNode,
-        ::boost::bind(&PresenterTheme::Theme::ProcessFont,
-            this, ::boost::ref(rReadContext), _1, _2));
+        [this, &rReadContext] (OUString const& rKey, uno::Reference<beans::XPropertySet> const& xProps)
+        {
+            return this->ProcessFont(rReadContext, rKey, xProps);
+        });
 }
 
 SharedPaneStyle PresenterTheme::Theme::GetPaneStyle (const OUString& rsStyleName) const
@@ -865,8 +865,10 @@ void PaneStyleContainer::Read (
         PresenterConfigurationAccess::ForAll(
             xPaneStyleList,
             aProperties,
-            ::boost::bind(&PaneStyleContainer::ProcessPaneStyle,
-                this, ::boost::ref(rReadContext), _1, _2));
+            [this, &rReadContext] (OUString const& rKey, std::vector<uno::Any> const& rValues)
+            {
+                return this->ProcessPaneStyle(rReadContext, rKey, rValues);
+            });
     }
 }
 
@@ -995,8 +997,10 @@ void ViewStyleContainer::Read (
     {
         PresenterConfigurationAccess::ForAll(
             xViewStyleList,
-            ::boost::bind(&ViewStyleContainer::ProcessViewStyle,
-                this, ::boost::ref(rReadContext), _2));
+            [this, &rReadContext] (OUString const&, uno::Reference<beans::XPropertySet> const& xProps)
+            {
+                return this->ProcessViewStyle(rReadContext, xProps);
+            });
     }
 }
 
@@ -1108,8 +1112,10 @@ void StyleAssociationContainer::Read (
         PresenterConfigurationAccess::ForAll(
             xStyleAssociationList,
             aProperties,
-            ::boost::bind(&StyleAssociationContainer::ProcessStyleAssociation,
-                this, ::boost::ref(rReadContext), _1, _2));
+            [this, &rReadContext] (OUString const& rKey, std::vector<uno::Any> const& rValues)
+            {
+                return this->ProcessStyleAssociation(rReadContext, rKey, rValues);
+            });
     }
 }
 
