@@ -67,14 +67,13 @@
 #include <comphelper/extract.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/sequenceashashmap.hxx>
-#include <comphelper/sequenceasvector.hxx>
 #include <comphelper/storagehelper.hxx>
 #include <comphelper/string.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <vcl/svapp.hxx>
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
+
 
-// --------------------------------------------------------------
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::frame;
@@ -84,10 +83,9 @@ using namespace ::com::sun::star::ucb;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::util;
 using namespace ::com::sun::star::system;
-using namespace ::rtl;
 
 // - class PrepareListener_Impl ------------------------------------------
-class PrepareListener_Impl : public ::cppu::WeakImplHelper1< css::frame::XStatusListener >
+class PrepareListener_Impl : public ::cppu::WeakImplHelper< css::frame::XStatusListener >
 {
     bool m_bState;
 public:
@@ -96,11 +94,11 @@ public:
 
         // css.frame.XStatusListener
         virtual void SAL_CALL statusChanged(const css::frame::FeatureStateEvent& aEvent)
-          throw(css::uno::RuntimeException);
+          throw(css::uno::RuntimeException, std::exception) override;
 
         // css.lang.XEventListener
         virtual void SAL_CALL disposing(const css::lang::EventObject& aEvent)
-          throw(css::uno::RuntimeException);
+          throw(css::uno::RuntimeException, std::exception) override;
 
         bool IsSet() const {return m_bState;}
 };
@@ -114,15 +112,15 @@ PrepareListener_Impl::~PrepareListener_Impl()
 {
 }
 
-void PrepareListener_Impl::statusChanged(const css::frame::FeatureStateEvent& rEvent) throw(css::uno::RuntimeException)
+void PrepareListener_Impl::statusChanged(const css::frame::FeatureStateEvent& rEvent) throw(css::uno::RuntimeException, std::exception)
 {
     if( rEvent.IsEnabled )
         rEvent.State >>= m_bState;
     else
-        m_bState = sal_False;
+        m_bState = false;
 }
 
-void PrepareListener_Impl::disposing(const css::lang::EventObject& /*rEvent*/) throw(css::uno::RuntimeException)
+void PrepareListener_Impl::disposing(const css::lang::EventObject& /*rEvent*/) throw(css::uno::RuntimeException, std::exception)
 {
 }
 
@@ -130,48 +128,22 @@ void PrepareListener_Impl::disposing(const css::lang::EventObject& /*rEvent*/) t
 
 static const char       PDF_DOCUMENT_TYPE[]   = "pdf_Portable_Document_Format";
 
-sal_Bool HasDocumentValidSignature( const css::uno::Reference< css::frame::XModel >& xModel )
-{
-    try
-    {
-        css::uno::Reference< css::beans::XPropertySet > xPropSet( xModel, css::uno::UNO_QUERY );
-        if ( xPropSet.is() )
-        {
-            Any a = xPropSet->getPropertyValue("HasValidSignatures");
-            sal_Bool bReturn = sal_Bool();
-            if ( a >>= bReturn )
-                return bReturn;
-        }
-    }
-    catch ( css::uno::RuntimeException& )
-    {
-        throw;
-    }
-    catch ( css::uno::Exception& )
-    {
-    }
-
-    return sal_False;
-}
-
 SfxMailModel::SaveResult SfxMailModel::ShowFilterOptionsDialog(
-    uno::Reference< lang::XMultiServiceFactory > xSMGR,
-    uno::Reference< frame::XModel > xModel,
+    const uno::Reference< lang::XMultiServiceFactory >& xSMGR,
+    const uno::Reference< frame::XModel >& xModel,
     const OUString& rFilterName,
     const OUString& rType,
     bool bModified,
     sal_Int32& rNumArgs,
-    ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >& rArgs )
+    css::uno::Sequence< css::beans::PropertyValue >& rArgs )
 {
     SaveResult eRet( SAVE_ERROR );
 
     try
     {
         uno::Sequence < beans::PropertyValue > aProps;
-            ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > xFilterCFG =
-                uno::Reference< container::XNameAccess >(
-                    xSMGR->createInstance(
-                        OUString("com.sun.star.document.FilterFactory") ), uno::UNO_QUERY );
+        css::uno::Reference< css::container::XNameAccess > xFilterCFG(
+                    xSMGR->createInstance( "com.sun.star.document.FilterFactory" ), uno::UNO_QUERY );
         css::uno::Reference< css::util::XModifiable > xModifiable( xModel, css::uno::UNO_QUERY );
 
         if ( !xFilterCFG.is() )
@@ -250,9 +222,9 @@ SfxMailModel::SaveResult SfxMailModel::ShowFilterOptionsDialog(
                                 {
                                     try
                                     {
-                                        xModifiable->setModified( sal_False );
+                                        xModifiable->setModified( false );
                                     }
-                                    catch( com::sun::star::beans::PropertyVetoException& )
+                                    catch( css::beans::PropertyVetoException& )
                                     {
                                     }
                                 }
@@ -276,7 +248,7 @@ SfxMailModel::SaveResult SfxMailModel::ShowFilterOptionsDialog(
     return eRet;
 }
 
-sal_Bool SfxMailModel::IsEmpty() const
+bool SfxMailModel::IsEmpty() const
 {
     return maAttachedDocuments.empty();
 }
@@ -336,7 +308,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
             OUString aLocation = xStorable->getLocation();
             INetURLObject aFileObj( aLocation );
 
-            bool bPrivateProtocol = ( aFileObj.GetProtocol() == INET_PROT_PRIV_SOFFICE );
+            bool bPrivateProtocol = ( aFileObj.GetProtocol() == INetProtocol::PrivSoffice );
 
             bHasLocation =  !aLocation.isEmpty() && !bPrivateProtocol;
             OSL_ASSERT( !bPrivateProtocol );
@@ -352,9 +324,8 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
             OUString aExtension;
 
             css::uno::Reference< css::container::XContainerQuery > xContainerQuery(
-                xSMGR->createInstance( OUString(
-                    "com.sun.star.document.FilterFactory" )),
-                    css::uno::UNO_QUERY );
+                xSMGR->createInstance( "com.sun.star.document.FilterFactory" ),
+                css::uno::UNO_QUERY );
 
             if ( bStoreTo )
             {
@@ -382,7 +353,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                 {
                     ::comphelper::SequenceAsHashMap aFilterPropsHM( xEnumeration->nextElement() );
                     aFilterName = aFilterPropsHM.getUnpackedValueOrDefault(
-                                                OUString("Name"),
+                                                "Name",
                                                 OUString() );
                 }
 
@@ -391,7 +362,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                     // Retrieve filter from media descriptor
                     ::comphelper::SequenceAsHashMap aMediaDescrPropsHM( xModel->getArgs() );
                     OUString aOrgFilterName = aMediaDescrPropsHM.getUnpackedValueOrDefault(
-                                    OUString( "FilterName" ),
+                                    "FilterName",
                                     OUString() );
                     if ( aOrgFilterName == aFilterName )
                     {
@@ -409,7 +380,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                     // Retrieve filter from media descriptor
                     ::comphelper::SequenceAsHashMap aMediaDescrPropsHM( xModel->getArgs() );
                     aFilterName = aMediaDescrPropsHM.getUnpackedValueOrDefault(
-                                    OUString( "FilterName" ),
+                                    "FilterName",
                                     OUString() );
                 }
 
@@ -420,7 +391,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                     {
                         ::comphelper::SequenceAsHashMap aFilterPropsHM( xModuleManager->getByName( aModule ) );
                         aFilterName = aFilterPropsHM.getUnpackedValueOrDefault(
-                                                    OUString("ooSetupFactoryDefaultFilter"),
+                                                    "ooSetupFactoryDefaultFilter",
                                                     OUString() );
                         css::uno::Reference< css::container::XNameAccess > xNameAccess(
                             xContainerQuery, css::uno::UNO_QUERY );
@@ -428,7 +399,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                         {
                             ::comphelper::SequenceAsHashMap aFilterPropsHM2( xNameAccess->getByName( aFilterName ) );
                             aTypeName = aFilterPropsHM2.getUnpackedValueOrDefault(
-                                                        OUString("Type"),
+                                                        "Type",
                                                         OUString() );
                         }
                     }
@@ -447,7 +418,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                 ( aTypeName.isEmpty()  && !bHasLocation ))
                 return eRet;
 
-            // Determine filen name and extension
+            // Determine file name and extension
             if ( bHasLocation && !bStoreTo )
             {
                 INetURLObject aFileObj( xStorable->getLocation() );
@@ -456,8 +427,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
             else
             {
                 css::uno::Reference< container::XNameAccess > xTypeDetection(
-                    xSMGR->createInstance( OUString(
-                        "com.sun.star.document.TypeDetection" )),
+                    xSMGR->createInstance( "com.sun.star.document.TypeDetection" ),
                     css::uno::UNO_QUERY );
 
 
@@ -467,7 +437,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                     {
                         ::comphelper::SequenceAsHashMap aTypeNamePropsHM( xTypeDetection->getByName( aTypeName ) );
                         uno::Sequence< OUString > aExtensions = aTypeNamePropsHM.getUnpackedValueOrDefault(
-                                                        OUString("Extensions"),
+                                                        "Extensions",
                                                         ::uno::Sequence< OUString >() );
                         if ( aExtensions.getLength() )
                             aExtension = aExtensions[0];
@@ -507,7 +477,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
             // This makes it possible to store the file for "send document as e-mail"
             // with the original file name. We cannot use the original file as
             // some mail programs need exclusive access.
-            ::utl::TempFile aTempDir( NULL, sal_True );
+            ::utl::TempFile aTempDir( nullptr, true );
 
             INetURLObject aFilePathObj( aTempDir.GetURL() );
             aFilePathObj.insertName( aFileName );
@@ -548,8 +518,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
 
                     if ( xDispatchProvider.is() )
                     {
-                        xPrepareDispatch = css::uno::Reference< css::frame::XDispatch >(
-                            xDispatchProvider->queryDispatch( aPrepareURL, OUString(), 0 ));
+                        xPrepareDispatch.set( xDispatchProvider->queryDispatch( aPrepareURL, OUString(), 0 ));
                         if ( xPrepareDispatch.is() )
                         {
                                 PrepareListener_Impl* pPrepareListener;
@@ -593,7 +562,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                         }
                     }
 
-                    //check if this is the pdf otput filter (i#64555)
+                    //check if this is the pdf output filter (i#64555)
                     if( bSendAsPDF )
                     {
                         SaveResult eShowPDFFilterDialog = ShowFilterOptionsDialog(
@@ -617,7 +586,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
 
                         if ( xDispatchProvider.is() )
                         {
-                            css::uno::Reference< css::frame::XDispatch > xDispatch = css::uno::Reference< css::frame::XDispatch >(
+                            css::uno::Reference< css::frame::XDispatch > xDispatch(
                                 xDispatchProvider->queryDispatch( aURL, OUString(), 0 ));
                             if ( xDispatch.is() )
                             {
@@ -643,14 +612,14 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                     {
                         try
                         {
-                            xModifiable->setModified( sal_False );
+                            xModifiable->setModified( false );
                         }
-                        catch( com::sun::star::beans::PropertyVetoException& )
+                        catch( css::beans::PropertyVetoException& )
                         {
                         }
                     }
                 }
-                catch ( com::sun::star::io::IOException& )
+                catch ( css::io::IOException& )
                 {
                     eRet = SAVE_ERROR;
                 }
@@ -660,7 +629,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                 // We need 1:1 copy of the document to preserve an added signature.
                 aArgs.realloc( ++nNumArgs );
                 aArgs[nNumArgs-1].Name = "CopyStreamIfPossible";
-                aArgs[nNumArgs-1].Value = css::uno::makeAny( (sal_Bool)sal_True );
+                aArgs[nNumArgs-1].Value = css::uno::makeAny( true );
 
                 try
                 {
@@ -668,7 +637,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                     rFileNamePath = aFileURL;
                     eRet = SAVE_SUCCESSFULL;
                 }
-                catch ( com::sun::star::io::IOException& )
+                catch ( css::io::IOException& )
                 {
                     eRet = SAVE_ERROR;
                 }
@@ -680,11 +649,9 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
 }
 
 SfxMailModel::SfxMailModel() :
-    mpToList    ( NULL ),
-    mpCcList    ( NULL ),
-    mpBccList   ( NULL ),
-    mePriority  ( PRIO_NORMAL ),
-    mbLoadDone  ( sal_True )
+    mpToList    ( nullptr ),
+    mpCcList    ( nullptr ),
+    mpBccList   ( nullptr )
 {
 }
 
@@ -700,7 +667,7 @@ void SfxMailModel::AddAddress( const OUString& rAddress, AddressRole eRole )
     // don't add a empty address
     if ( !rAddress.isEmpty() )
     {
-        AddressList_Impl* pList = NULL;
+        AddressList_Impl* pList = nullptr;
         if ( ROLE_TO == eRole )
         {
             if ( !mpToList )
@@ -849,19 +816,30 @@ SfxMailModel::SendMailResult SfxMailModel::Send( const css::uno::Reference< css:
                 Sequence< OUString > aAttachmentSeq(&(maAttachedDocuments[0]),maAttachedDocuments.size());
 
                 if ( xSimpleMailMessage->getSubject().isEmpty() ) {
-                    OUString baseName( maAttachedDocuments[0].copy( maAttachedDocuments[0].lastIndexOf( '/' ) + 1 ) );
-                    OUString subject( baseName );
+                    INetURLObject url(
+                        maAttachedDocuments[0], INetURLObject::WAS_ENCODED);
+                    OUString subject(
+                        url.getBase(
+                            INetURLObject::LAST_SEGMENT, false,
+#ifdef _WIN32
+                            INetURLObject::NO_DECODE)); // MAPISendMail does not accept Unicode
+#else
+                            INetURLObject::DECODE_WITH_CHARSET));
+#endif
+                    if (subject.isEmpty()) {
+                        subject = maAttachedDocuments[0];
+                    }
                     if ( maAttachedDocuments.size() > 1 )
                         subject += ", ...";
                     xSimpleMailMessage->setSubject( subject );
                 }
                 xSimpleMailMessage->setAttachement( aAttachmentSeq );
 
-                sal_Bool bSend( sal_False );
+                bool bSend( false );
                 try
                 {
                     xSimpleMailClient->sendSimpleMailMessage( xSimpleMailMessage, nSendFlags );
-                    bSend = sal_True;
+                    bSend = true;
                 }
                 catch ( IllegalArgumentException& )
                 {
@@ -870,15 +848,15 @@ SfxMailModel::SendMailResult SfxMailModel::Send( const css::uno::Reference< css:
                 {
                 }
 
-                if ( bSend == sal_False )
+                if ( !bSend )
                 {
                     css::uno::Reference< css::awt::XWindow > xParentWindow = xFrame->getContainerWindow();
 
                     SolarMutexGuard aGuard;
-                    Window* pParentWindow = VCLUnoHelper::GetWindow( xParentWindow );
+                    vcl::Window* pParentWindow = VCLUnoHelper::GetWindow( xParentWindow );
 
-                    MessageDialog aBox(pParentWindow, "ErrorFindEmailDialog", "sfx/ui/errorfindemaildialog.ui");
-                    aBox.Execute();
+                    ScopedVclPtrInstance< MessageDialog > aBox(pParentWindow, "ErrorFindEmailDialog", "sfx/ui/errorfindemaildialog.ui");
+                    aBox->Execute();
                     eResult = SEND_MAIL_CANCELLED;
                 }
                 else
@@ -913,7 +891,7 @@ SfxMailModel::SendMailResult SfxMailModel::SaveAndSend( const css::uno::Referenc
 
 // functions -------------------------------------------------------------
 
-sal_Bool CreateFromAddress_Impl( OUString& rFrom )
+bool CreateFromAddress_Impl( OUString& rFrom )
 
 /* [Description]
 
@@ -959,7 +937,7 @@ sal_Bool CreateFromAddress_Impl( OUString& rFrom )
         rFrom = rFrom + "<" + comphelper::string::strip(aEmailName, ' ') + ">";
     }
     else
-        rFrom = "";
+        rFrom.clear();
     return !rFrom.isEmpty();
 }
 
