@@ -49,6 +49,7 @@
 #include <svl/stritem.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <tools/diagnose_ex.h>
+#include <vcl/syswin.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -56,39 +57,31 @@ using namespace ::com::sun::star::frame;
 using namespace ::com::sun::star::util;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::beans;
-using ::com::sun::star::lang::XMultiServiceFactory;
-using ::com::sun::star::lang::XComponent;
 using ::com::sun::star::frame::XComponentLoader;
 
 
-
-class SfxFrameWindow_Impl : public Window
+class SfxFrameWindow_Impl : public vcl::Window
 {
 public:
     SfxFrame*           pFrame;
 
-    SfxFrameWindow_Impl( SfxFrame* pF, Window& i_rContainerWindow );
-    virtual ~SfxFrameWindow_Impl( );
+    SfxFrameWindow_Impl( SfxFrame* pF, vcl::Window& i_rContainerWindow );
 
-    virtual void        DataChanged( const DataChangedEvent& rDCEvt ) SAL_OVERRIDE;
-    virtual void        StateChanged( StateChangedType nStateChange ) SAL_OVERRIDE;
-    virtual bool        PreNotify( NotifyEvent& rNEvt ) SAL_OVERRIDE;
-    virtual bool        Notify( NotifyEvent& rEvt ) SAL_OVERRIDE;
-    virtual void        Resize() SAL_OVERRIDE;
-    virtual void        GetFocus() SAL_OVERRIDE;
+    virtual void        DataChanged( const DataChangedEvent& rDCEvt ) override;
+    virtual void        StateChanged( StateChangedType nStateChange ) override;
+    virtual bool        PreNotify( NotifyEvent& rNEvt ) override;
+    virtual bool        Notify( NotifyEvent& rEvt ) override;
+    virtual void        Resize() override;
+    virtual void        GetFocus() override;
     void                DoResize();
 };
 
-SfxFrameWindow_Impl::SfxFrameWindow_Impl( SfxFrame* pF, Window& i_rContainerWindow )
+SfxFrameWindow_Impl::SfxFrameWindow_Impl( SfxFrame* pF, vcl::Window& i_rContainerWindow )
         : Window( &i_rContainerWindow, WB_BORDER | WB_CLIPCHILDREN | WB_NODIALOGCONTROL | WB_3DLOOK )
         , pFrame( pF )
 {
 }
 
-SfxFrameWindow_Impl::~SfxFrameWindow_Impl( )
-{
-}
-
 void SfxFrameWindow_Impl::DataChanged( const DataChangedEvent& rDCEvt )
 {
     Window::DataChanged( rDCEvt );
@@ -106,7 +99,7 @@ bool SfxFrameWindow_Impl::Notify( NotifyEvent& rNEvt )
     if ( !pView || !pView->GetObjectShell() )
         return Window::Notify( rNEvt );
 
-    if ( rNEvt.GetType() == EVENT_GETFOCUS )
+    if ( rNEvt.GetType() == MouseNotifyEvent::GETFOCUS )
     {
         if ( pView->GetViewShell() && !pView->GetViewShell()->GetUIActiveIPClient_Impl() && !pFrame->IsInPlace() )
         {
@@ -119,17 +112,17 @@ bool SfxFrameWindow_Impl::Notify( NotifyEvent& rNEvt )
         pView->GetBindings().Invalidate( SID_PASTE_SPECIAL );
         return true;
     }
-    else if( rNEvt.GetType() == EVENT_KEYINPUT )
+    else if( rNEvt.GetType() == MouseNotifyEvent::KEYINPUT )
     {
         if ( pView->GetViewShell()->KeyInput( *rNEvt.GetKeyEvent() ) )
             return true;
     }
-    else if ( rNEvt.GetType() == EVENT_EXECUTEDIALOG /*|| rNEvt.GetType() == EVENT_INPUTDISABLE*/ )
+    else if ( rNEvt.GetType() == MouseNotifyEvent::EXECUTEDIALOG /*|| rNEvt.GetType() == MouseNotifyEvent::INPUTDISABLE*/ )
     {
         pView->SetModalMode( true );
         return true;
     }
-    else if ( rNEvt.GetType() == EVENT_ENDEXECUTEDIALOG /*|| rNEvt.GetType() == EVENT_INPUTENABLE*/ )
+    else if ( rNEvt.GetType() == MouseNotifyEvent::ENDEXECUTEDIALOG /*|| rNEvt.GetType() == MouseNotifyEvent::INPUTENABLE*/ )
     {
         pView->SetModalMode( false );
         return true;
@@ -140,28 +133,28 @@ bool SfxFrameWindow_Impl::Notify( NotifyEvent& rNEvt )
 
 bool SfxFrameWindow_Impl::PreNotify( NotifyEvent& rNEvt )
 {
-    sal_uInt16 nType = rNEvt.GetType();
-    if ( nType == EVENT_KEYINPUT || nType == EVENT_KEYUP )
+    MouseNotifyEvent nType = rNEvt.GetType();
+    if ( nType == MouseNotifyEvent::KEYINPUT || nType == MouseNotifyEvent::KEYUP )
     {
         SfxViewFrame* pView = pFrame->GetCurrentViewFrame();
-        SfxViewShell* pShell = pView ? pView->GetViewShell() : NULL;
+        SfxViewShell* pShell = pView ? pView->GetViewShell() : nullptr;
         if ( pShell && pShell->HasKeyListeners_Impl() && pShell->HandleNotifyEvent_Impl( rNEvt ) )
             return true;
     }
-    else if ( nType == EVENT_MOUSEBUTTONUP || nType == EVENT_MOUSEBUTTONDOWN )
+    else if ( nType == MouseNotifyEvent::MOUSEBUTTONUP || nType == MouseNotifyEvent::MOUSEBUTTONDOWN )
     {
-        Window* pWindow = rNEvt.GetWindow();
+        vcl::Window* pWindow = rNEvt.GetWindow();
         SfxViewFrame* pView = pFrame->GetCurrentViewFrame();
-        SfxViewShell* pShell = pView ? pView->GetViewShell() : NULL;
+        SfxViewShell* pShell = pView ? pView->GetViewShell() : nullptr;
         if ( pShell )
             if ( pWindow == pShell->GetWindow() || pShell->GetWindow()->IsChild( pWindow ) )
                 if ( pShell->HasMouseClickListeners_Impl() && pShell->HandleNotifyEvent_Impl( rNEvt ) )
                     return true;
     }
 
-    if ( nType == EVENT_MOUSEBUTTONDOWN )
+    if ( nType == MouseNotifyEvent::MOUSEBUTTONDOWN )
     {
-        Window* pWindow = rNEvt.GetWindow();
+        vcl::Window* pWindow = rNEvt.GetWindow();
         const MouseEvent* pMEvent = rNEvt.GetMouseEvent();
         Point aPos = pWindow->OutputToScreenPixel( pMEvent->GetPosPixel() );
         SfxWorkWindow *pWorkWin = pFrame->GetWorkWindow_Impl();
@@ -186,9 +179,9 @@ void SfxFrameWindow_Impl::Resize()
 
 void SfxFrameWindow_Impl::StateChanged( StateChangedType nStateChange )
 {
-    if ( nStateChange == STATE_CHANGE_INITSHOW )
+    if ( nStateChange == StateChangedType::InitShow )
     {
-        pFrame->pImp->bHidden = false;
+        pFrame->pImpl->bHidden = false;
         if ( pFrame->IsInPlace() )
             // TODO/MBA: workaround for bug in LayoutManager: the final resize does not get through because the
             // LayoutManager works asynchronously and between resize and time execution the DockingAcceptor was exchanged so that
@@ -206,7 +199,7 @@ void SfxFrameWindow_Impl::StateChanged( StateChangedType nStateChange )
 
 void SfxFrameWindow_Impl::DoResize()
 {
-    if ( !pFrame->pImp->bLockResize )
+    if ( !pFrame->pImpl->bLockResize )
         pFrame->Resize();
 }
 
@@ -225,9 +218,9 @@ Reference < XFrame > SfxFrame::CreateBlankFrame()
     return xFrame;
 }
 
-SfxFrame* SfxFrame::Create( SfxObjectShell& rDoc, Window& rWindow, sal_uInt16 nViewId, bool bHidden )
+SfxFrame* SfxFrame::Create( SfxObjectShell& rDoc, vcl::Window& rWindow, sal_uInt16 nViewId, bool bHidden )
 {
-    SfxFrame* pFrame = NULL;
+    SfxFrame* pFrame = nullptr;
     try
     {
         // create and initialize new top level frame for this window
@@ -259,7 +252,7 @@ SfxFrame* SfxFrame::Create( SfxObjectShell& rDoc, Window& rWindow, sal_uInt16 nV
         Reference< XComponentLoader > xLoader( xFrame, UNO_QUERY_THROW );
         xLoader->loadComponentFromURL(
             sLoaderURL,
-            OUString( "_self" ),
+            "_self",
             0,
             aLoadArgs
         );
@@ -287,27 +280,27 @@ SfxFrame* SfxFrame::Create( const Reference < XFrame >& i_rFrame )
 {
     // create a new TopFrame to an external XFrame object ( wrap controller )
     ENSURE_OR_THROW( i_rFrame.is(), "NULL frame not allowed" );
-    Window* pWindow = VCLUnoHelper::GetWindow( i_rFrame->getContainerWindow() );
+    vcl::Window* pWindow = VCLUnoHelper::GetWindow( i_rFrame->getContainerWindow() );
     ENSURE_OR_THROW( pWindow, "frame without container window not allowed" );
 
-    SfxFrame* pFrame = new SfxFrame( *pWindow, false );
+    SfxFrame* pFrame = new SfxFrame( *pWindow );
     pFrame->SetFrameInterface_Impl( i_rFrame );
     return pFrame;
 }
 
-SfxFrame::SfxFrame( Window& i_rContainerWindow, bool i_bHidden )
-    :pParentFrame( NULL )
-    ,pChildArr( NULL )
-    ,pImp( NULL )
-    ,pWindow( NULL )
+SfxFrame::SfxFrame( vcl::Window& i_rContainerWindow )
+    :SvCompatWeakBase<SfxFrame>( this )
+    ,pParentFrame( nullptr )
+    ,pChildArr( nullptr )
+    ,pWindow( nullptr )
 {
     Construct_Impl();
 
-    pImp->bHidden = i_bHidden;
+    pImpl->bHidden = false;
     InsertTopFrame_Impl( this );
-    pImp->pExternalContainerWindow = &i_rContainerWindow;
+    pImpl->pExternalContainerWindow = &i_rContainerWindow;
 
-    pWindow = new SfxFrameWindow_Impl( this, i_rContainerWindow );
+    pWindow = VclPtr<SfxFrameWindow_Impl>::Create( this, i_rContainerWindow );
 
     // always show pWindow, which is the ComponentWindow of the XFrame we live in
     // nowadays, since SfxFrames can be created with an XFrame only, hiding or showing the complete XFrame
@@ -319,10 +312,10 @@ SfxFrame::SfxFrame( Window& i_rContainerWindow, bool i_bHidden )
 void SfxFrame::SetPresentationMode( bool bSet )
 {
     if ( GetCurrentViewFrame() )
-        GetCurrentViewFrame()->GetWindow().SetBorderStyle( bSet ? WINDOW_BORDER_NOBORDER : WINDOW_BORDER_NORMAL );
+        GetCurrentViewFrame()->GetWindow().SetBorderStyle( bSet ? WindowBorderStyle::NOBORDER : WindowBorderStyle::NORMAL );
 
-    Reference< com::sun::star::beans::XPropertySet > xPropSet( GetFrameInterface(), UNO_QUERY );
-    Reference< ::com::sun::star::frame::XLayoutManager > xLayoutManager;
+    Reference< css::beans::XPropertySet > xPropSet( GetFrameInterface(), UNO_QUERY );
+    Reference< css::frame::XLayoutManager > xLayoutManager;
 
     if ( xPropSet.is() )
     {
@@ -347,16 +340,12 @@ SystemWindow* SfxFrame::GetSystemWindow() const
 
 SystemWindow* SfxFrame::GetTopWindow_Impl() const
 {
-    if ( pImp->pExternalContainerWindow->IsSystemWindow() )
-        return (SystemWindow*) pImp->pExternalContainerWindow;
+    if ( pImpl->pExternalContainerWindow->IsSystemWindow() )
+        return static_cast<SystemWindow*>( pImpl->pExternalContainerWindow.get() );
     else
-        return NULL;
+        return nullptr;
 }
 
-Window& SfxFrame::GetWindow() const
-{
-    return *pWindow;
-}
 
 bool SfxFrame::Close()
 {
@@ -366,15 +355,15 @@ bool SfxFrame::Close()
 
 void SfxFrame::LockResize_Impl( bool bLock )
 {
-    pImp->bLockResize = bLock;
+    pImpl->bLockResize = bLock;
 }
 
 void SfxFrame::SetMenuBarOn_Impl( bool bOn )
 {
-    pImp->bMenuBarOn = bOn;
+    pImpl->bMenuBarOn = bOn;
 
-    Reference< com::sun::star::beans::XPropertySet > xPropSet( GetFrameInterface(), UNO_QUERY );
-    Reference< ::com::sun::star::frame::XLayoutManager > xLayoutManager;
+    Reference< css::beans::XPropertySet > xPropSet( GetFrameInterface(), UNO_QUERY );
+    Reference< css::frame::XLayoutManager > xLayoutManager;
 
     if ( xPropSet.is() )
     {
@@ -395,7 +384,7 @@ void SfxFrame::SetMenuBarOn_Impl( bool bOn )
 
 bool SfxFrame::IsMenuBarOn_Impl() const
 {
-    return pImp->bMenuBarOn;
+    return pImpl->bMenuBarOn;
 }
 
 void SfxFrame::PrepareForDoc_Impl( SfxObjectShell& i_rDoc )
@@ -403,8 +392,8 @@ void SfxFrame::PrepareForDoc_Impl( SfxObjectShell& i_rDoc )
     const ::comphelper::NamedValueCollection aDocumentArgs( i_rDoc.GetModel()->getArgs() );
 
     // hidden?
-    OSL_ENSURE( !pImp->bHidden, "when does this happen?" );
-    pImp->bHidden = aDocumentArgs.getOrDefault( "Hidden", pImp->bHidden );
+    OSL_ENSURE( !pImpl->bHidden, "when does this happen?" );
+    pImpl->bHidden = aDocumentArgs.getOrDefault( "Hidden", pImpl->bHidden );
 
     // update our descriptor
     UpdateDescriptor( &i_rDoc );
@@ -417,7 +406,7 @@ void SfxFrame::PrepareForDoc_Impl( SfxObjectShell& i_rDoc )
 
 bool SfxFrame::IsMarkedHidden_Impl() const
 {
-    return pImp->bHidden;
+    return pImpl->bHidden;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
