@@ -43,7 +43,7 @@ namespace svgio
         :   SvgNode(SVGTokenRect, rDocument, pParent),
             maSvgStyleAttributes(*this),
             maSvgAspectRatio(),
-            mpaTransform(0),
+            mpaTransform(nullptr),
             maX(0),
             maY(0),
             maWidth(0),
@@ -57,12 +57,12 @@ namespace svgio
 
         SvgImageNode::~SvgImageNode()
         {
-            if(mpaTransform) delete mpaTransform;
+            delete mpaTransform;
         }
 
         const SvgStyleAttributes* SvgImageNode::getSvgStyleAttributes() const
         {
-            return checkForCssStyle(OUString("image"), maSvgStyleAttributes);
+            return checkForCssStyle("image", maSvgStyleAttributes);
         }
 
         void SvgImageNode::parseAttribute(const OUString& rTokenName, SVGToken aSVGToken, const OUString& aContent)
@@ -161,7 +161,7 @@ namespace svgio
 
         void extractFromGraphic(
             const Graphic& rGraphic,
-            drawinglayer::primitive2d::Primitive2DSequence& rEmbedded,
+            drawinglayer::primitive2d::Primitive2DContainer& rEmbedded,
             basegfx::B2DRange& rViewBox,
             BitmapEx& rBitmapEx)
         {
@@ -188,7 +188,7 @@ namespace svgio
             }
         }
 
-        void SvgImageNode::decomposeSvgNode(drawinglayer::primitive2d::Primitive2DSequence& rTarget, bool /*bReferenced*/) const
+        void SvgImageNode::decomposeSvgNode(drawinglayer::primitive2d::Primitive2DContainer& rTarget, bool /*bReferenced*/) const
         {
             // get size range and create path
             const SvgStyleAttributes* pStyle = getSvgStyleAttributes();
@@ -201,7 +201,7 @@ namespace svgio
                 if(fWidth > 0.0 && fHeight > 0.0)
                 {
                     BitmapEx aBitmapEx;
-                    drawinglayer::primitive2d::Primitive2DSequence aNewTarget;
+                    drawinglayer::primitive2d::Primitive2DContainer aNewTarget;
 
                     // prepare Target and ViewBox for evtl. AspectRatio mappings
                     const double fX(getX().isSet() ? getX().solve(*this, xcoordinate) : 0.0);
@@ -212,12 +212,12 @@ namespace svgio
                     if(!maMimeType.isEmpty() && !maData.isEmpty())
                     {
                         // use embedded base64 encoded data
-                        ::com::sun::star::uno::Sequence< sal_Int8 > aPass;
+                        css::uno::Sequence< sal_Int8 > aPass;
                         ::sax::Converter::decodeBase64(aPass, maData);
 
                         if(aPass.hasElements())
                         {
-                            SvMemoryStream aStream(aPass.getArray(), aPass.getLength(), STREAM_READ);
+                            SvMemoryStream aStream(aPass.getArray(), aPass.getLength(), StreamMode::READ);
                             Graphic aGraphic;
 
                             if(GRFILTER_OK == GraphicFilter::GetGraphicFilter().ImportGraphic(
@@ -242,7 +242,7 @@ namespace svgio
                                     << e.getMessage() << "\"");
                         }
 
-                        if (!aAbsUrl.isEmpty())
+                        if (!aAbsUrl.isEmpty() && !rPath.equals(aAbsUrl))
                         {
                             SvFileStream aStream(aAbsUrl, STREAM_STD_READ);
                             Graphic aGraphic;
@@ -258,86 +258,96 @@ namespace svgio
                     }
                     else if(!maXLink.isEmpty())
                     {
-                        const SvgNode* mpXLink = getDocument().findSvgNodeById(maXLink);
+                        const SvgNode* pXLink = getDocument().findSvgNodeById(maXLink);
 
-                        if(mpXLink && Display_none != mpXLink->getDisplay())
+                        if(pXLink && Display_none != pXLink->getDisplay())
                         {
-                            mpXLink->decomposeSvgNode(aNewTarget, true);
+                            pXLink->decomposeSvgNode(aNewTarget, true);
 
-                            if(aNewTarget.hasElements())
+                            if(!aNewTarget.empty())
                             {
-                                aViewBox = drawinglayer::primitive2d::getB2DRangeFromPrimitive2DSequence(
-                                    aNewTarget,
-                                    drawinglayer::geometry::ViewInformation2D());
+                                aViewBox = aNewTarget.getB2DRange(drawinglayer::geometry::ViewInformation2D());
                             }
                         }
                     }
 
-                    if(!aBitmapEx.IsEmpty())
+                    if(!aBitmapEx.IsEmpty() && 0 != aBitmapEx.GetSizePixel().Width()  && 0 != aBitmapEx.GetSizePixel().Height())
                     {
-                        // create content from created bitmap
-                        aNewTarget.realloc(1);
+                        // calculate centered unit size
+                        const double fAspectRatio = (double)aBitmapEx.GetSizePixel().Width() / (double)aBitmapEx.GetSizePixel().Height();
+
+                        if(basegfx::fTools::equal(fAspectRatio, 0.0))
+                        {
+                            // use unit range
+                            aViewBox = basegfx::B2DRange(0.0, 0.0, 1.0, 1.0);
+                        }
+                        else if(basegfx::fTools::more(fAspectRatio, 0.0))
+                        {
+                            // width bigger height
+                            const double fHalfHeight((1.0 / fAspectRatio) * 0.5);
+                            aViewBox = basegfx::B2DRange(
+                                0.0,
+                                0.5 - fHalfHeight,
+                                1.0,
+                                0.5 + fHalfHeight);
+                        }
+                        else
+                        {
+                            // height bigger width
+                            const double fHalfWidth(fAspectRatio * 0.5);
+                            aViewBox = basegfx::B2DRange(
+                                0.5 - fHalfWidth,
+                                0.0,
+                                0.5 + fHalfWidth,
+                                1.0);
+                        }
+
+                        // create content from created bitmap, use calculated unit range size
+                        // as transformation to map the picture data correctly
+                        aNewTarget.resize(1);
                         aNewTarget[0] = new drawinglayer::primitive2d::BitmapPrimitive2D(
                             aBitmapEx,
-                            basegfx::B2DHomMatrix());
-
-                        // fill aViewBox. No size set yet, use unit size
-                        aViewBox = basegfx::B2DRange(0.0, 0.0, 1.0, 1.0);
+                            basegfx::tools::createScaleTranslateB2DHomMatrix(
+                                aViewBox.getRange(),
+                                aViewBox.getMinimum()));
                     }
 
-                    if(aNewTarget.hasElements())
+                    if(!aNewTarget.empty())
                     {
                         if(aTarget.equal(aViewBox))
                         {
                             // just add to rTarget
-                            drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(rTarget, aNewTarget);
+                            rTarget.append(aNewTarget);
                         }
                         else
                         {
                             // create mapping
                             const SvgAspectRatio& rRatio = getSvgAspectRatio();
 
-                            if(rRatio.isSet())
+                            // even when ratio is not set, use the defaults
+                            // let mapping be created from SvgAspectRatio
+                            const basegfx::B2DHomMatrix aEmbeddingTransform(rRatio.createMapping(aTarget, aViewBox));
+
+                            if(!aEmbeddingTransform.isIdentity())
                             {
-                                // let mapping be created from SvgAspectRatio
-                                const basegfx::B2DHomMatrix aEmbeddingTransform(rRatio.createMapping(aTarget, aViewBox));
+                                const drawinglayer::primitive2d::Primitive2DReference xRef(
+                                    new drawinglayer::primitive2d::TransformPrimitive2D(
+                                        aEmbeddingTransform,
+                                        aNewTarget));
 
-                                if(!aEmbeddingTransform.isIdentity())
-                                {
-                                    const drawinglayer::primitive2d::Primitive2DReference xRef(
-                                        new drawinglayer::primitive2d::TransformPrimitive2D(
-                                            aEmbeddingTransform,
-                                            aNewTarget));
-
-                                    aNewTarget = drawinglayer::primitive2d::Primitive2DSequence(&xRef, 1);
-                                }
-
-                                if(!rRatio.isMeetOrSlice())
-                                {
-                                    // need to embed in MaskPrimitive2D to ensure clipping
-                                    const drawinglayer::primitive2d::Primitive2DReference xMask(
-                                        new drawinglayer::primitive2d::MaskPrimitive2D(
-                                            basegfx::B2DPolyPolygon(
-                                                basegfx::tools::createPolygonFromRect(aTarget)),
-                                            aNewTarget));
-
-                                    aNewTarget = drawinglayer::primitive2d::Primitive2DSequence(&xMask, 1);
-                                }
+                                aNewTarget = drawinglayer::primitive2d::Primitive2DContainer { xRef };
                             }
-                            else
+
+                            if(!rRatio.isMeetOrSlice())
                             {
-                                // choose default mapping
-                                const basegfx::B2DHomMatrix aEmbeddingTransform(SvgAspectRatio::createLinearMapping(aTarget, aViewBox));
+                                // need to embed in MaskPrimitive2D to ensure clipping
+                                const drawinglayer::primitive2d::Primitive2DReference xMask(
+                                    new drawinglayer::primitive2d::MaskPrimitive2D(
+                                        basegfx::B2DPolyPolygon(
+                                            basegfx::tools::createPolygonFromRect(aTarget)),
+                                        aNewTarget));
 
-                                if(!aEmbeddingTransform.isIdentity())
-                                {
-                                    const drawinglayer::primitive2d::Primitive2DReference xRef(
-                                        new drawinglayer::primitive2d::TransformPrimitive2D(
-                                            aEmbeddingTransform,
-                                            aNewTarget));
-
-                                    aNewTarget = drawinglayer::primitive2d::Primitive2DSequence(&xRef, 1);
-                                }
+                                aNewTarget = drawinglayer::primitive2d::Primitive2DContainer { xMask };
                             }
 
                             // embed and add to rTarget, take local extra-transform into account
