@@ -81,8 +81,8 @@ private:
     long       nMargin2;
     long       nLeftFrameMargin;
     long       nRightFrameMargin;
-    sal_uInt16 nMargin1Style;
-    sal_uInt16 nMargin2Style;
+    RulerMarginStyle nMargin1Style;
+    RulerMarginStyle nMargin2Style;
     bool       bAutoPageWidth;
     bool       bTextRTL;
 
@@ -104,8 +104,8 @@ ImplRulerData::ImplRulerData() :
     nMargin2          (0),
     nLeftFrameMargin  (0),
     nRightFrameMargin (0),
-    nMargin1Style     (0),
-    nMargin2Style     (0),
+    nMargin1Style     (RulerMarginStyle::NONE),
+    nMargin2Style     (RulerMarginStyle::NONE),
     bAutoPageWidth    (true), // Page width == EditWin width
     bTextRTL          (false)
 {
@@ -237,7 +237,7 @@ void Ruler::ImplInit( WinBits nWinBits )
     mnDragPos       = 0;                    // Drag-Position (Null point)
     mnUpdateEvtId   = nullptr;                    // Update event was not sent yet
     mnDragAryPos    = 0;                    // Drag-Array-Index
-    mnDragSize      = 0;                    // Did size change at dragging
+    mnDragSize      = RulerDragSize::Move;  // Did size change at dragging
     mnDragModifier  = 0;                    // Modifier key at dragging
     mnExtraStyle    = 0;                    // Style of Extra field
     mnExtraClicks   = 0;                    // No. of clicks for Extra field
@@ -253,8 +253,8 @@ void Ruler::ImplInit( WinBits nWinBits )
     mbActive        = true;                 // Is ruler active
     mnUpdateFlags   = 0;                    // What needs to be updated
     mpData          = mpSaveData;           // Pointer to normal data
-    meExtraType     = RULER_EXTRA_DONTKNOW; // What is in extra field
-    meDragType      = RULER_TYPE_DONTKNOW;  // Which element is dragged
+    meExtraType     = RulerExtra::DontKnow; // What is in extra field
+    meDragType      = RulerType::DontKnow;  // Which element is dragged
 
     // Initialize Units
     mnUnitIndex     = RULER_UNIT_CM;
@@ -403,7 +403,7 @@ void Ruler::ImplVDrawText(vcl::RenderContext& rRenderContext, long nX, long nY,
     }
 }
 
-void Ruler::ImplInvertLines(vcl::RenderContext& rRenderContext, bool bErase)
+void Ruler::ImplInvertLines(vcl::RenderContext& rRenderContext)
 {
     // Position lines
     if (!mpData->pLines.empty() && mbActive && !mbDrag && !mbFormat && !(mnUpdateFlags & RULER_UPDATE_LINES) )
@@ -421,9 +421,9 @@ void Ruler::ImplInvertLines(vcl::RenderContext& rRenderContext, bool bErase)
             aRect.Right() = nY;
 
         // Draw lines
-        for (size_t i = 0; i < mpData->pLines.size(); i++)
+        for (RulerLine & rLine : mpData->pLines)
         {
-            const long n = mpData->pLines[i].nPos + nNullWinOff;
+            const long n = rLine.nPos + nNullWinOff;
             if ((n >= nRulX1) && (n < nRulX2))
             {
                 if (mnWinStyle & WB_HORZ )
@@ -436,29 +436,26 @@ void Ruler::ImplInvertLines(vcl::RenderContext& rRenderContext, bool bErase)
                     aRect.Top()    = n;
                     aRect.Bottom() = n;
                 }
-                if (bErase)
+                Rectangle aTempRect = aRect;
+
+                if (mnWinStyle & WB_HORZ)
+                    aTempRect.Bottom() = RULER_OFF - 1;
+                else
+                    aTempRect.Right() = RULER_OFF - 1;
+
+                rRenderContext.Erase(aTempRect);
+
+                if (mnWinStyle & WB_HORZ)
                 {
-                    Rectangle aTempRect = aRect;
-
-                    if (mnWinStyle & WB_HORZ)
-                        aTempRect.Bottom() = RULER_OFF - 1;
-                    else
-                        aTempRect.Right() = RULER_OFF - 1;
-
-                    rRenderContext.Erase(aTempRect);
-
-                    if (mnWinStyle & WB_HORZ)
-                    {
-                        aTempRect.Bottom() = aRect.Bottom();
-                        aTempRect.Top()    = aTempRect.Bottom() - RULER_OFF + 1;
-                    }
-                    else
-                    {
-                        aTempRect.Right()  = aRect.Right();
-                        aTempRect.Left()   = aTempRect.Right() - RULER_OFF + 1;
-                    }
-                    rRenderContext.Erase(aTempRect);
+                    aTempRect.Bottom() = aRect.Bottom();
+                    aTempRect.Top()    = aTempRect.Bottom() - RULER_OFF + 1;
                 }
+                else
+                {
+                    aTempRect.Right()  = aRect.Right();
+                    aTempRect.Left()   = aTempRect.Right() - RULER_OFF + 1;
+                }
+                rRenderContext.Erase(aTempRect);
                 Invert(aRect);
             }
         }
@@ -606,7 +603,7 @@ void Ruler::ImplDrawTicks(vcl::RenderContext& rRenderContext, long nMin, long nM
                 if (nStart > nMin)
                 {
                     // 0 is only painted when Margin1 is not equal to zero
-                    if ((mpData->nMargin1Style & RULER_STYLE_INVISIBLE) || (mpData->nMargin1 != 0))
+                    if ((mpData->nMargin1Style & RulerMarginStyle::Invisible) || (mpData->nMargin1 != 0))
                     {
                         aNumString = "0";
                         ImplVDrawText(rRenderContext, nStart, nCenter, aNumString);
@@ -704,7 +701,7 @@ void Ruler::ImplDrawBorders(vcl::RenderContext& rRenderContext, long nMin, long
 
     for (i = 0; i < mpData->pBorders.size(); i++)
     {
-        if (mpData->pBorders[i].nStyle & RULER_STYLE_INVISIBLE)
+        if (mpData->pBorders[i].nStyle & RulerBorderStyle::Invisible)
             continue;
 
         n1 = mpData->pBorders[i].nPos + mpData->nNullVirOff;
@@ -730,7 +727,7 @@ void Ruler::ImplDrawBorders(vcl::RenderContext& rRenderContext, long nMin, long
                 rRenderContext.SetLineColor(rStyleSettings.GetDarkShadowColor());
                 ImplVDrawLine(rRenderContext, n2, nVirTop, n2, nVirBottom);
 
-                if (mpData->pBorders[i].nStyle & RULER_BORDER_VARIABLE)
+                if (mpData->pBorders[i].nStyle & RulerBorderStyle::Variable)
                 {
                     if (n2 - n1 > RULER_VAR_SIZE + 4)
                     {
@@ -757,7 +754,7 @@ void Ruler::ImplDrawBorders(vcl::RenderContext& rRenderContext, long nMin, long
                     }
                 }
 
-                if (mpData->pBorders[i].nStyle & RULER_BORDER_SIZEABLE)
+                if (mpData->pBorders[i].nStyle & RulerBorderStyle::Sizeable)
                 {
                     if (n2 - n1 > RULER_VAR_SIZE + 10)
                     {
@@ -775,9 +772,9 @@ void Ruler::ImplDrawBorders(vcl::RenderContext& rRenderContext, long nMin, long
                 n = n1 + ((n2 - n1) / 2);
                 rRenderContext.SetLineColor(rStyleSettings.GetShadowColor());
 
-                if (mpData->pBorders[i].nStyle & RULER_BORDER_SNAP)
+                if (mpData->pBorders[i].nStyle & RulerBorderStyle::Snap)
                     ImplVDrawLine(rRenderContext, n, nVirTop, n, nVirBottom);
-                else if (mpData->pBorders[i].nStyle & RULER_BORDER_MARGIN)
+                else if (mpData->pBorders[i].nStyle & RulerBorderStyle::Margin)
                     ImplVDrawLine(rRenderContext, n, nVirTop, n, nVirBottom);
                 else
                 {
@@ -792,13 +789,10 @@ void Ruler::ImplDrawBorders(vcl::RenderContext& rRenderContext, long nMin, long
     }
 }
 
-void Ruler::ImplDrawIndent(vcl::RenderContext& rRenderContext, const tools::Polygon& rPoly, sal_uInt16 nStyle, bool bIsHit)
+void Ruler::ImplDrawIndent(vcl::RenderContext& rRenderContext, const tools::Polygon& rPoly, bool bIsHit)
 {
     const StyleSettings& rStyleSettings = rRenderContext.GetSettings().GetStyleSettings();
 
-    if (nStyle & RULER_STYLE_INVISIBLE)
-        return;
-
     rRenderContext.SetLineColor(rStyleSettings.GetDarkShadowColor());
     rRenderContext.SetFillColor(bIsHit ? rStyleSettings.GetDarkShadowColor() : rStyleSettings.GetWorkspaceColor());
     tools::Polygon aPolygon(rPoly);
@@ -817,23 +811,22 @@ void Ruler::ImplDrawIndents(vcl::RenderContext& rRenderContext, long nMin, long
 
     for (j = 0; j < mpData->pIndents.size(); j++)
     {
-        if (mpData->pIndents[j].nStyle & RULER_STYLE_INVISIBLE)
+        if (mpData->pIndents[j].bInvisible)
             continue;
 
-        sal_uInt16  nStyle = mpData->pIndents[j].nStyle;
-        sal_uInt16  nIndentStyle = nStyle & RULER_INDENT_STYLE;
+        RulerIndentStyle nIndentStyle = mpData->pIndents[j].nStyle;
 
         n = mpData->pIndents[j].nPos+mpData->nNullVirOff;
 
         if ((n >= nMin) && (n <= nMax))
         {
-            if (nIndentStyle == RULER_INDENT_BORDER)
+            if (nIndentStyle == RulerIndentStyle::Border)
             {
                 const StyleSettings& rStyleSettings = rRenderContext.GetSettings().GetStyleSettings();
                 rRenderContext.SetLineColor(rStyleSettings.GetShadowColor());
                 ImplVDrawLine(rRenderContext, n, nVirTop + 1, n, nVirBottom - 1);
             }
-            else if (nIndentStyle == RULER_INDENT_BOTTOM)
+            else if (nIndentStyle == RulerIndentStyle::Bottom)
             {
                 aPoly.SetPoint(Point(n + 0, nVirBottom - nIndentHeight), 0);
                 aPoly.SetPoint(Point(n - nIndentWidth2, nVirBottom - 3), 1);
@@ -860,18 +853,18 @@ void Ruler::ImplDrawIndents(vcl::RenderContext& rRenderContext, long nMin, long
                     aPoly[i] = aSet;
                 }
             }
-            if (RULER_INDENT_BORDER != nIndentStyle)
+            if (RulerIndentStyle::Border != nIndentStyle)
             {
                 bool bIsHit = false;
-                if(mxCurrentHitTest.get() != nullptr && mxCurrentHitTest->eType == RULER_TYPE_INDENT)
+                if(mxCurrentHitTest.get() != nullptr && mxCurrentHitTest->eType == RulerType::Indent)
                 {
                     bIsHit = mxCurrentHitTest->nAryPos == j;
                 }
-                else if(mbDrag && meDragType == RULER_TYPE_INDENT)
+                else if(mbDrag && meDragType == RulerType::Indent)
                 {
                     bIsHit = mnDragAryPos == j;
                 }
-                ImplDrawIndent(rRenderContext, aPoly, nStyle, bIsHit);
+                ImplDrawIndent(rRenderContext, aPoly, bIsHit);
             }
         }
     }
@@ -1025,17 +1018,17 @@ void Ruler::ImplDrawTab(vcl::RenderContext& rRenderContext, const Point& rPos, s
 
 void Ruler::ImplDrawTabs(vcl::RenderContext& rRenderContext, long nMin, long nMax, long nVirTop, long nVirBottom)
 {
-    for (size_t i = 0; i < mpData->pTabs.size(); i++)
+    for (RulerTab & rTab : mpData->pTabs)
     {
-        if (mpData->pTabs[i].nStyle & RULER_STYLE_INVISIBLE)
+        if (rTab.nStyle & RULER_STYLE_INVISIBLE)
             continue;
 
         long aPosition;
-        aPosition = mpData->pTabs[i].nPos;
+        aPosition = rTab.nPos;
         aPosition += +mpData->nNullVirOff;
         long nTopBottom = (GetStyle() & WB_RIGHT_ALIGNED) ? nVirTop : nVirBottom;
         if (nMin <= aPosition && aPosition <= nMax)
-            ImplDrawTab(rRenderContext, Point( aPosition, nTopBottom ), mpData->pTabs[i].nStyle);
+            ImplDrawTab(rRenderContext, Point( aPosition, nTopBottom ), rTab.nStyle);
     }
 }
 
@@ -1054,8 +1047,8 @@ void Ruler::ApplySettings(vcl::RenderContext& rRenderContext)
 
     vcl::Font aFont = rStyleSettings.GetToolFont();
     // make the font a bit smaller than default
-    Size aSize(adjustSize(aFont.GetSize().Width()), adjustSize(aFont.GetSize().Height()));
-    aFont.SetSize(aSize);
+    Size aSize(adjustSize(aFont.GetFontSize().Width()), adjustSize(aFont.GetFontSize().Height()));
+    aFont.SetFontSize(aSize);
 
     ApplyControlFont(rRenderContext, aFont);
 
@@ -1076,8 +1069,8 @@ void Ruler::ImplInitSettings(bool bFont, bool bForeground, bool bBackground)
     {
         vcl::Font aFont = rStyleSettings.GetToolFont();
         // make the font a bit smaller than default
-        Size aSize(adjustSize(aFont.GetSize().Width()), adjustSize(aFont.GetSize().Height()));
-        aFont.SetSize(aSize);
+        Size aSize(adjustSize(aFont.GetFontSize().Width()), adjustSize(aFont.GetFontSize().Height()));
+        aFont.SetFontSize(aSize);
 
         ApplyControlFont(*this, aFont);
     }
@@ -1209,7 +1202,7 @@ void Ruler::ImplFormat(vcl::RenderContext& rRenderContext)
         maVirDev->Erase();
 
     // calculate margins
-    if (!(mpData->nMargin1Style & RULER_STYLE_INVISIBLE))
+    if (!(mpData->nMargin1Style & RulerMarginStyle::Invisible))
     {
         nM1 = mpData->nMargin1 + nNullVirOff;
         if (mpData->bAutoPageWidth)
@@ -1226,7 +1219,7 @@ void Ruler::ImplFormat(vcl::RenderContext& rRenderContext)
         nM1 = nVirLeft-1;
         nP1 = nM1;
     }
-    if (!(mpData->nMargin2Style & RULER_STYLE_INVISIBLE))
+    if (!(mpData->nMargin2Style & RulerMarginStyle::Invisible))
     {
         nM2 = mpData->nMargin2 + nNullVirOff;
         if (mpData->bAutoPageWidth)
@@ -1397,11 +1390,11 @@ void Ruler::ImplDraw(vcl::RenderContext& rRenderContext)
         rRenderContext.DrawOutDev(aOffPos, aVirDevSize, Point(), aVirDevSize, *maVirDev.get());
 
         // redraw positionlines
-        ImplInvertLines(rRenderContext, true);
+        ImplInvertLines(rRenderContext);
     }
 }
 
-void Ruler::ImplDrawExtra(vcl::RenderContext& rRenderContext, bool bPaint)
+void Ruler::ImplDrawExtra(vcl::RenderContext& rRenderContext)
 {
     const StyleSettings& rStyleSettings = rRenderContext.GetSettings().GetStyleSettings();
     Rectangle aRect = maExtraRect;
@@ -1412,19 +1405,11 @@ void Ruler::ImplDrawExtra(vcl::RenderContext& rRenderContext, bool bPaint)
     aRect.Right()  -= 2;
     aRect.Bottom() -= 2;
 
-    if (!bPaint && !(mnExtraStyle & RULER_STYLE_HIGHLIGHT))
+    if (mnExtraStyle & RULER_STYLE_HIGHLIGHT)
     {
-        rRenderContext.SetFillColor(rStyleSettings.GetWorkspaceColor());
+        rRenderContext.SetFillColor(rStyleSettings.GetCheckedColor());
         bEraseRect = true;
     }
-    else
-    {
-        if (mnExtraStyle & RULER_STYLE_HIGHLIGHT)
-        {
-            rRenderContext.SetFillColor(rStyleSettings.GetCheckedColor());
-            bEraseRect = true;
-        }
-    }
 
     if (bEraseRect)
     {
@@ -1433,7 +1418,7 @@ void Ruler::ImplDrawExtra(vcl::RenderContext& rRenderContext, bool bPaint)
     }
 
     // output content
-    if (meExtraType == RULER_EXTRA_NULLOFFSET)
+    if (meExtraType == RulerExtra::NullOffset)
     {
         rRenderContext.SetLineColor(rStyleSettings.GetButtonTextColor());
         rRenderContext.DrawLine(Point(aRect.Left() + 1, aRect.Top() + 4),
@@ -1441,7 +1426,7 @@ void Ruler::ImplDrawExtra(vcl::RenderContext& rRenderContext, bool bPaint)
         rRenderContext.DrawLine(Point(aRect.Left() + 4, aRect.Top() + 1),
                                 Point(aRect.Left() + 4, aRect.Bottom() - 1));
     }
-    else if (meExtraType == RULER_EXTRA_TAB)
+    else if (meExtraType == RulerExtra::Tab)
     {
         sal_uInt16 nTabStyle = mnExtraStyle & RULER_TAB_STYLE;
         if (mpData->bTextRTL)
@@ -1489,7 +1474,7 @@ void Ruler::ImplUpdate( bool bMustCalc )
 }
 
 bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
-                         bool bRequireStyle, sal_uInt16 nRequiredStyle ) const
+                         bool bRequireStyle, RulerIndentStyle nRequiredStyle ) const
 {
     sal_Int32   i;
     sal_uInt16  nStyle;
@@ -1517,7 +1502,7 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
 
     // #i32608#
     pHitTest->nAryPos = 0;
-    pHitTest->mnDragSize = 0;
+    pHitTest->mnDragSize = RulerDragSize::Move;
     pHitTest->bSize = false;
     pHitTest->bSizeBar = false;
 
@@ -1537,13 +1522,13 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
          (nY > nHitBottom) )
     {
         pHitTest->nPos = 0;
-        pHitTest->eType = RULER_TYPE_OUTSIDE;
+        pHitTest->eType = RulerType::Outside;
         return false;
     }
 
     nX -= mpData->nNullVirOff;
     pHitTest->nPos  = nX;
-    pHitTest->eType = RULER_TYPE_DONTKNOW;
+    pHitTest->eType = RulerType::DontKnow;
 
     // first test the tabs
     Rectangle aRect;
@@ -1582,7 +1567,7 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
 
                     if ( aRect.IsInside( Point( nX, nY ) ) )
                     {
-                        pHitTest->eType   = RULER_TYPE_TAB;
+                        pHitTest->eType   = RulerType::Tab;
                         pHitTest->nAryPos = i;
                         return true;
                     }
@@ -1599,14 +1584,13 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
 
         for ( i = mpData->pIndents.size(); i; i-- )
         {
-            nStyle = mpData->pIndents[i-1].nStyle;
-            if ( (! bRequireStyle || nStyle == nRequiredStyle) &&
-                 !(nStyle & RULER_STYLE_INVISIBLE) )
+            RulerIndentStyle nIndentStyle = mpData->pIndents[i-1].nStyle;
+            if ( (! bRequireStyle || nIndentStyle == nRequiredStyle) &&
+                 !mpData->pIndents[i-1].bInvisible )
             {
-                nStyle &= RULER_INDENT_STYLE;
                 n1 = mpData->pIndents[i-1].nPos;
 
-                if ( (nStyle == RULER_INDENT_BOTTOM) != !bIsHori )
+                if ( (nIndentStyle == RulerIndentStyle::Bottom) != !bIsHori )
                 {
                     aRect.Left()    = n1-nIndentWidth2;
                     aRect.Right()   = n1+nIndentWidth2;
@@ -1623,7 +1607,7 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
 
                 if ( aRect.IsInside( Point( nX, nY ) ) )
                 {
-                    pHitTest->eType     = RULER_TYPE_INDENT;
+                    pHitTest->eType     = RulerType::Indent;
                     pHitTest->nAryPos   = i-1;
                     return true;
                 }
@@ -1635,7 +1619,7 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
     if ( (nXTemp < mpData->nRulVirOff) || (nXTemp > mpData->nRulVirOff+mpData->nRulWidth) )
     {
         pHitTest->nPos = 0;
-        pHitTest->eType = RULER_TYPE_OUTSIDE;
+        pHitTest->eType = RulerType::Outside;
         return false;
     }
 
@@ -1661,18 +1645,18 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
 
         if ( (nX >= n1) && (nX <= n2) )
         {
-            nStyle = mpData->pBorders[i-1].nStyle;
-            if ( !(nStyle & RULER_STYLE_INVISIBLE) )
+            RulerBorderStyle nBorderStyle = mpData->pBorders[i-1].nStyle;
+            if ( !(nBorderStyle & RulerBorderStyle::Invisible) )
             {
-                pHitTest->eType     = RULER_TYPE_BORDER;
+                pHitTest->eType     = RulerType::Border;
                 pHitTest->nAryPos   = i-1;
 
-                if ( !(nStyle & RULER_BORDER_SIZEABLE) )
+                if ( !(nBorderStyle & RulerBorderStyle::Sizeable) )
                 {
-                    if ( nStyle & RULER_BORDER_MOVEABLE )
+                    if ( nBorderStyle & RulerBorderStyle::Moveable )
                     {
                         pHitTest->bSizeBar = true;
-                        pHitTest->mnDragSize = RULER_DRAGSIZE_MOVE;
+                        pHitTest->mnDragSize = RulerDragSize::Move;
                     }
                 }
                 else
@@ -1692,19 +1676,19 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
                     if ( nX <= n1+nMOff )
                     {
                         pHitTest->bSize = true;
-                        pHitTest->mnDragSize = RULER_DRAGSIZE_1;
+                        pHitTest->mnDragSize = RulerDragSize::N1;
                     }
                     else if ( nX >= n2-nMOff )
                     {
                         pHitTest->bSize = true;
-                        pHitTest->mnDragSize = RULER_DRAGSIZE_2;
+                        pHitTest->mnDragSize = RulerDragSize::N2;
                     }
                     else
                     {
-                        if ( nStyle & RULER_BORDER_MOVEABLE )
+                        if ( nBorderStyle & RulerBorderStyle::Moveable )
                         {
                             pHitTest->bSizeBar = true;
-                            pHitTest->mnDragSize = RULER_DRAGSIZE_MOVE;
+                            pHitTest->mnDragSize = RulerDragSize::Move;
                         }
                     }
                 }
@@ -1717,22 +1701,22 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
     // Margins
     int nMarginTolerance = pHitTest->bExpandTest ? nBorderTolerance : RULER_MOUSE_MARGINWIDTH;
 
-    if ( (mpData->nMargin1Style & (RULER_MARGIN_SIZEABLE | RULER_STYLE_INVISIBLE)) == RULER_MARGIN_SIZEABLE )
+    if ( (mpData->nMargin1Style & (RulerMarginStyle::Sizeable | RulerMarginStyle::Invisible)) == RulerMarginStyle::Sizeable )
     {
         n1 = mpData->nMargin1;
         if ( (nX >= n1 - nMarginTolerance) && (nX <= n1 + nMarginTolerance) )
         {
-            pHitTest->eType = RULER_TYPE_MARGIN1;
+            pHitTest->eType = RulerType::Margin1;
             pHitTest->bSize = true;
             return true;
         }
     }
-    if ( (mpData->nMargin2Style & (RULER_MARGIN_SIZEABLE | RULER_STYLE_INVISIBLE)) == RULER_MARGIN_SIZEABLE )
+    if ( (mpData->nMargin2Style & (RulerMarginStyle::Sizeable | RulerMarginStyle::Invisible)) == RulerMarginStyle::Sizeable )
     {
         n1 = mpData->nMargin2;
         if ( (nX >= n1 - nMarginTolerance) && (nX <= n1 + nMarginTolerance) )
         {
-            pHitTest->eType = RULER_TYPE_MARGIN2;
+            pHitTest->eType = RulerType::Margin2;
             pHitTest->bSize = true;
             return true;
         }
@@ -1777,7 +1761,7 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
 
                     if ( aRect.IsInside( Point( nX, nY ) ) )
                     {
-                        pHitTest->eType   = RULER_TYPE_TAB;
+                        pHitTest->eType   = RulerType::Tab;
                         pHitTest->nAryPos = i;
                         return true;
                     }
@@ -1794,12 +1778,12 @@ bool Ruler::ImplDocHitTest( const Point& rPos, RulerType eDragType,
 {
     Point aPos = rPos;
     bool bRequiredStyle = false;
-    sal_uInt16 nRequiredStyle = 0;
+    RulerIndentStyle nRequiredStyle = RulerIndentStyle::Top;
 
-    if (eDragType == RULER_TYPE_INDENT)
+    if (eDragType == RulerType::Indent)
     {
         bRequiredStyle = true;
-        nRequiredStyle = RULER_INDENT_BOTTOM;
+        nRequiredStyle = RulerIndentStyle::Bottom;
     }
 
     if ( mnWinStyle & WB_HORZ )
@@ -1807,7 +1791,7 @@ bool Ruler::ImplDocHitTest( const Point& rPos, RulerType eDragType,
     else
         aPos.Y() += mnWinOff;
 
-    if ( (eDragType == RULER_TYPE_INDENT) || (eDragType == RULER_TYPE_DONTKNOW) )
+    if ( (eDragType == RulerType::Indent) || (eDragType == RulerType::DontKnow) )
     {
         if ( mnWinStyle & WB_HORZ )
             aPos.Y() = RULER_OFF + 1;
@@ -1816,14 +1800,14 @@ bool Ruler::ImplDocHitTest( const Point& rPos, RulerType eDragType,
 
         if ( ImplHitTest( aPos, pHitTest, bRequiredStyle, nRequiredStyle ) )
         {
-            if ( (pHitTest->eType == eDragType) || (eDragType == RULER_TYPE_DONTKNOW) )
+            if ( (pHitTest->eType == eDragType) || (eDragType == RulerType::DontKnow) )
                 return true;
         }
     }
 
-    if ( (eDragType == RULER_TYPE_INDENT) ||
-         (eDragType == RULER_TYPE_TAB) ||
-         (eDragType == RULER_TYPE_DONTKNOW) )
+    if ( (eDragType == RulerType::Indent) ||
+         (eDragType == RulerType::Tab) ||
+         (eDragType == RulerType::DontKnow) )
     {
         if ( mnWinStyle & WB_HORZ )
             aPos.Y() = mnHeight - RULER_OFF - 1;
@@ -1832,13 +1816,13 @@ bool Ruler::ImplDocHitTest( const Point& rPos, RulerType eDragType,
 
         if ( ImplHitTest( aPos, pHitTest, bRequiredStyle, nRequiredStyle ) )
         {
-            if ( (pHitTest->eType == eDragType) || (eDragType == RULER_TYPE_DONTKNOW) )
+            if ( (pHitTest->eType == eDragType) || (eDragType == RulerType::DontKnow) )
                 return true;
         }
     }
 
-    if ( (eDragType == RULER_TYPE_MARGIN1) || (eDragType == RULER_TYPE_MARGIN2) ||
-         (eDragType == RULER_TYPE_BORDER) || (eDragType == RULER_TYPE_DONTKNOW) )
+    if ( (eDragType == RulerType::Margin1) || (eDragType == RulerType::Margin2) ||
+         (eDragType == RulerType::Border) || (eDragType == RulerType::DontKnow) )
     {
         if ( mnWinStyle & WB_HORZ )
             aPos.Y() = RULER_OFF + (mnVirHeight / 2);
@@ -1847,12 +1831,12 @@ bool Ruler::ImplDocHitTest( const Point& rPos, RulerType eDragType,
 
         if ( ImplHitTest( aPos, pHitTest ) )
         {
-            if ( (pHitTest->eType == eDragType) || (eDragType == RULER_TYPE_DONTKNOW) )
+            if ( (pHitTest->eType == eDragType) || (eDragType == RulerType::DontKnow) )
                 return true;
         }
     }
 
-    pHitTest->eType = RULER_TYPE_DONTKNOW;
+    pHitTest->eType = RulerType::DontKnow;
 
     return false;
 }
@@ -1860,7 +1844,7 @@ bool Ruler::ImplDocHitTest( const Point& rPos, RulerType eDragType,
 bool Ruler::ImplStartDrag( RulerSelection* pHitTest, sal_uInt16 nModifier )
 {
     // don't trigger drag if a border that was clicked can not be changed
-    if ( (pHitTest->eType == RULER_TYPE_BORDER) &&
+    if ( (pHitTest->eType == RulerType::Border) &&
          !pHitTest->bSize && !pHitTest->bSizeBar )
         return false;
 
@@ -1886,10 +1870,10 @@ bool Ruler::ImplStartDrag( RulerSelection* pHitTest, sal_uInt16 nModifier )
     else
     {
         // otherwise reset the data
-        meDragType      = RULER_TYPE_DONTKNOW;
+        meDragType      = RulerType::DontKnow;
         mnDragPos       = 0;
         mnDragAryPos    = 0;
-        mnDragSize      = 0;
+        mnDragSize      = RulerDragSize::Move;
         mnDragModifier  = 0;
         mpData          = mpSaveData;
     }
@@ -1987,10 +1971,10 @@ void Ruler::ImplEndDrag()
     EndDrag();
 
     // reset drag values
-    meDragType      = RULER_TYPE_DONTKNOW;
+    meDragType      = RulerType::DontKnow;
     mnDragPos       = 0;
     mnDragAryPos    = 0;
-    mnDragSize      = 0;
+    mnDragSize      = RulerDragSize::Move;
     mbDragCanceled  = false;
     mbDragDelete    = false;
     mnDragModifier  = 0;
@@ -2036,7 +2020,7 @@ void Ruler::MouseButtonDown( const MouseEvent& rMEvt )
                 else
                 {
                     // calculate position inside of ruler area
-                    if ( pHitTest->eType == RULER_TYPE_DONTKNOW )
+                    if ( pHitTest->eType == RulerType::DontKnow )
                     {
                         mnDragPos = pHitTest->nPos;
                         Click();
@@ -2059,7 +2043,7 @@ void Ruler::MouseButtonDown( const MouseEvent& rMEvt )
 
                 DoubleClick();
 
-                meDragType      = RULER_TYPE_DONTKNOW;
+                meDragType      = RulerType::DontKnow;
                 mnDragPos       = 0;
                 mnDragAryPos    = 0;
             }
@@ -2075,7 +2059,7 @@ void Ruler::MouseMove( const MouseEvent& rMEvt )
 
     mxCurrentHitTest.reset(new RulerSelection);
 
-    maHoverSelection.eType = RULER_TYPE_DONTKNOW;
+    maHoverSelection.eType = RulerType::DontKnow;
 
     if (ImplHitTest( rMEvt.GetPosPixel(), mxCurrentHitTest.get() ))
     {
@@ -2085,18 +2069,18 @@ void Ruler::MouseMove( const MouseEvent& rMEvt )
         {
             if (mnWinStyle & WB_HORZ)
             {
-                if (mxCurrentHitTest->mnDragSize == RULER_DRAGSIZE_1)
+                if (mxCurrentHitTest->mnDragSize == RulerDragSize::N1)
                     ePtrStyle = PointerStyle::TabSelectW;
-                else if (mxCurrentHitTest->mnDragSize == RULER_DRAGSIZE_2)
+                else if (mxCurrentHitTest->mnDragSize == RulerDragSize::N2)
                     ePtrStyle = PointerStyle::TabSelectE;
                 else
                     ePtrStyle = PointerStyle::ESize;
             }
             else
             {
-                if (mxCurrentHitTest->mnDragSize == RULER_DRAGSIZE_1)
+                if (mxCurrentHitTest->mnDragSize == RulerDragSize::N1)
                     ePtrStyle = PointerStyle::WindowNSize;
-                else if (mxCurrentHitTest->mnDragSize == RULER_DRAGSIZE_2)
+                else if (mxCurrentHitTest->mnDragSize == RulerDragSize::N2)
                     ePtrStyle = PointerStyle::WindowSSize;
                 else
                     ePtrStyle = PointerStyle::SSize;
@@ -2147,7 +2131,7 @@ void Ruler::Paint(vcl::RenderContext& rRenderContext, const Rectangle&)
 
     // consider extra field
     if (mnWinStyle & WB_EXTRAFIELD)
-        ImplDrawExtra(rRenderContext, true);
+        ImplDrawExtra(rRenderContext);
 }
 
 void Ruler::Resize()
@@ -2332,7 +2316,7 @@ bool Ruler::StartDocDrag( const MouseEvent& rMEvt, RulerType eDragType )
         sal_uInt16     nMouseModifier = rMEvt.GetModifier();
         RulerSelection aHitTest;
 
-        if(eDragType != RULER_TYPE_DONTKNOW)
+        if(eDragType != RulerType::DontKnow)
             aHitTest.bExpandTest = true;
 
         // update ruler
@@ -2563,7 +2547,7 @@ void Ruler::SetRightFrameMargin( long nPos )
     }
 }
 
-void Ruler::SetMargin1( long nPos, sal_uInt16 nMarginStyle )
+void Ruler::SetMargin1( long nPos, RulerMarginStyle nMarginStyle )
 {
     if ( (mpData->nMargin1 != nPos) || (mpData->nMargin1Style != nMarginStyle) )
     {
@@ -2573,11 +2557,11 @@ void Ruler::SetMargin1( long nPos, sal_uInt16 nMarginStyle )
     }
 }
 
-void Ruler::SetMargin2( long nPos, sal_uInt16 nMarginStyle )
+void Ruler::SetMargin2( long nPos, RulerMarginStyle nMarginStyle )
 {
     DBG_ASSERT( (nPos >= mpData->nMargin1) ||
-                (mpData->nMargin1Style & RULER_STYLE_INVISIBLE) ||
-                (mpData->nMargin2Style & RULER_STYLE_INVISIBLE),
+                (mpData->nMargin1Style & RulerMarginStyle::Invisible) ||
+                (mpData->nMargin2Style & RulerMarginStyle::Invisible),
                 "Ruler::SetMargin2() - Margin2 < Margin1" );
 
     if ( (mpData->nMargin2 != nPos) || (mpData->nMargin2Style != nMarginStyle) )
@@ -2823,7 +2807,7 @@ bool Ruler::GetTextRTL()
     return mpData->bTextRTL;
 }
 
-RulerUnitData Ruler::GetCurrentRulerUnit() const
+const RulerUnitData& Ruler::GetCurrentRulerUnit() const
 {
     return aImplRulerUnitTab[mnUnitIndex];
 }
