@@ -17,11 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <stdio.h>
-
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
 #include <vcl/builderfactory.hxx>
+#include <vcl/fontcharmap.hxx>
 #include <svtools/colorcfg.hxx>
 
 #include <rtl/textenc.h>
@@ -50,7 +49,7 @@ using namespace ::com::sun::star;
 
 sal_uInt32& SvxShowCharSet::getSelectedChar()
 {
-    static sal_uInt32 cSelectedChar = ' '; // keeps selected character over app livetime
+    static sal_uInt32 cSelectedChar = ' '; // keeps selected character over app lifetime
     return cSelectedChar;
 }
 
@@ -78,7 +77,7 @@ void SvxShowCharSet::init()
 
     SetStyle(GetStyle() | WB_CLIPCHILDREN);
     aVscrollSB->SetScrollHdl( LINK( this, SvxShowCharSet, VscrollHdl ) );
-    aVscrollSB->EnableDrag( true );
+    aVscrollSB->EnableDrag();
     // other settings like aVscroll depend on selected font => see RecalculateFont
 
     bDrag = false;
@@ -100,15 +99,13 @@ void SvxShowCharSet::GetFocus()
 }
 
 
-
 void SvxShowCharSet::LoseFocus()
 {
     Control::LoseFocus();
-    SelectIndex( nSelectedIndex, false );
+    SelectIndex( nSelectedIndex );
 }
 
 
-
 void SvxShowCharSet::StateChanged(StateChangedType nType)
 {
     if (nType == StateChangedType::ControlForeground)
@@ -123,7 +120,6 @@ void SvxShowCharSet::StateChanged(StateChangedType nType)
 }
 
 
-
 void SvxShowCharSet::DataChanged( const DataChangedEvent& rDCEvt )
 {
     if ((rDCEvt.GetType() == DataChangedEventType::SETTINGS)
@@ -139,7 +135,6 @@ void SvxShowCharSet::DataChanged( const DataChangedEvent& rDCEvt )
 }
 
 
-
 void SvxShowCharSet::MouseButtonDown( const MouseEvent& rMEvt )
 {
     if ( rMEvt.IsLeft() )
@@ -161,7 +156,6 @@ void SvxShowCharSet::MouseButtonDown( const MouseEvent& rMEvt )
 }
 
 
-
 void SvxShowCharSet::MouseButtonUp( const MouseEvent& rMEvt )
 {
     if ( bDrag && rMEvt.IsLeft() )
@@ -175,7 +169,6 @@ void SvxShowCharSet::MouseButtonUp( const MouseEvent& rMEvt )
 }
 
 
-
 void SvxShowCharSet::MouseMove( const MouseEvent& rMEvt )
 {
     if ( rMEvt.IsLeft() && bDrag )
@@ -199,29 +192,25 @@ void SvxShowCharSet::MouseMove( const MouseEvent& rMEvt )
 }
 
 
-
 void SvxShowCharSet::Command( const CommandEvent& rCEvt )
 {
-    if( !HandleScrollCommand( rCEvt, 0, aVscrollSB.get() ) )
+    if( !HandleScrollCommand( rCEvt, nullptr, aVscrollSB.get() ) )
         Control::Command( rCEvt );
 }
 
 
-
 sal_uInt16 SvxShowCharSet::GetRowPos(sal_uInt16 _nPos)
 {
     return _nPos / COLUMN_COUNT ;
 }
 
 
-
 sal_uInt16 SvxShowCharSet::GetColumnPos(sal_uInt16 _nPos)
 {
     return _nPos % COLUMN_COUNT ;
 }
 
 
-
 int SvxShowCharSet::FirstInView() const
 {
     int nIndex = 0;
@@ -231,19 +220,17 @@ int SvxShowCharSet::FirstInView() const
 }
 
 
-
 int SvxShowCharSet::LastInView() const
 {
     sal_uIntPtr nIndex = FirstInView();
     nIndex += ROW_COUNT * COLUMN_COUNT - 1;
-    sal_uIntPtr nCompare = sal::static_int_cast<sal_uIntPtr>(mpFontCharMap->GetCharCount() - 1);
+    sal_uIntPtr nCompare = sal::static_int_cast<sal_uIntPtr>(mxFontCharMap->GetCharCount() - 1);
     if (nIndex > nCompare)
         nIndex = nCompare;
     return nIndex;
 }
 
 
-
 inline Point SvxShowCharSet::MapIndexToPixel( int nIndex ) const
 {
     const int nBase = FirstInView();
@@ -260,7 +247,6 @@ int SvxShowCharSet::PixelToMapIndex( const Point& point) const
 }
 
 
-
 void SvxShowCharSet::KeyInput(const KeyEvent& rKEvt)
 {
     vcl::KeyCode aCode = rKEvt.GetKeyCode();
@@ -300,7 +286,7 @@ void SvxShowCharSet::KeyInput(const KeyEvent& rKEvt)
             tmpSelected = 0;
             break;
         case KEY_END:
-            tmpSelected = mpFontCharMap->GetCharCount() - 1;
+            tmpSelected = mxFontCharMap->GetCharCount() - 1;
             break;
         case KEY_TAB:   // some fonts have a character at these unicode control codes
         case KEY_ESCAPE:
@@ -311,8 +297,8 @@ void SvxShowCharSet::KeyInput(const KeyEvent& rKEvt)
         default:
             {
                 sal_UCS4 cChar = rKEvt.GetCharCode();
-                sal_UCS4 cNext = mpFontCharMap->GetNextChar(cChar - 1);
-                tmpSelected = mpFontCharMap->GetIndexFromChar(cNext);
+                sal_UCS4 cNext = mxFontCharMap->GetNextChar(cChar - 1);
+                tmpSelected = mxFontCharMap->GetIndexFromChar(cNext);
                 if (tmpSelected < 0 || (cChar != cNext))
                 {
                     Control::KeyInput(rKEvt);
@@ -329,7 +315,6 @@ void SvxShowCharSet::KeyInput(const KeyEvent& rKEvt)
 }
 
 
-
 void SvxShowCharSet::Paint( vcl::RenderContext& rRenderContext, const Rectangle& )
 {
     InitSettings(rRenderContext);
@@ -417,7 +402,7 @@ void SvxShowCharSet::DrawChars_Impl(vcl::RenderContext& rRenderContext, int n1,
         int y = pix.Y();
 
         OUStringBuffer buf;
-        buf.appendUtf32(mpFontCharMap->GetCharFromIndex(i));
+        buf.appendUtf32(mxFontCharMap->GetCharFromIndex(i));
         OUString aCharStr(buf.makeStringAndClear());
         int nTextWidth = rRenderContext.GetTextWidth(aCharStr);
         int tx = x + (nX - nTextWidth + 1) / 2;
@@ -495,7 +480,6 @@ void SvxShowCharSet::DrawChars_Impl(vcl::RenderContext& rRenderContext, int n1,
 }
 
 
-
 void SvxShowCharSet::InitSettings(vcl::RenderContext& rRenderContext)
 {
     const StyleSettings& rStyleSettings = rRenderContext.GetSettings().GetStyleSettings();
@@ -522,24 +506,22 @@ void SvxShowCharSet::InitSettings(vcl::RenderContext& rRenderContext)
 
     vcl::Font aFont(rRenderContext.GetFont());
     aFont.SetWeight(WEIGHT_LIGHT);
-    aFont.SetAlign(ALIGN_TOP);
-    aFont.SetSize(maFontSize);
+    aFont.SetAlignment(ALIGN_TOP);
+    aFont.SetFontSize(maFontSize);
     aFont.SetTransparent(true);
     rRenderContext.SetFont(aFont);
 
 }
 
 
-
 sal_UCS4 SvxShowCharSet::GetSelectCharacter() const
 {
     if( nSelectedIndex >= 0 )
-        getSelectedChar() = mpFontCharMap->GetCharFromIndex( nSelectedIndex );
+        getSelectedChar() = mxFontCharMap->GetCharFromIndex( nSelectedIndex );
     return getSelectedChar();
 }
 
 
-
 void SvxShowCharSet::RecalculateFont(vcl::RenderContext& rRenderContext)
 {
     if (!mbRecalculateFont)
@@ -547,7 +529,7 @@ void SvxShowCharSet::RecalculateFont(vcl::RenderContext& rRenderContext)
 
     // save last selected unicode
     if (nSelectedIndex >= 0)
-        getSelectedChar() = mpFontCharMap->GetCharFromIndex(nSelectedIndex);
+        getSelectedChar() = mxFontCharMap->GetCharFromIndex(nSelectedIndex);
 
     Size aSize(GetOutputSizePixel());
     long nSBWidth = aVscrollSB->GetOptimalSize().Width();
@@ -555,26 +537,26 @@ void SvxShowCharSet::RecalculateFont(vcl::RenderContext& rRenderContext)
 
     vcl::Font aFont = rRenderContext.GetFont();
     aFont.SetWeight(WEIGHT_LIGHT);
-    aFont.SetAlign(ALIGN_TOP);
+    aFont.SetAlignment(ALIGN_TOP);
     int nFontHeight = (aSize.Height() - 5) * 2 / (3 * ROW_COUNT);
     maFontSize = rRenderContext.PixelToLogic(Size(0, nFontHeight));
-    aFont.SetSize(maFontSize);
+    aFont.SetFontSize(maFontSize);
     aFont.SetTransparent(true);
     rRenderContext.SetFont(aFont);
-    rRenderContext.GetFontCharMap(mpFontCharMap);
+    rRenderContext.GetFontCharMap(mxFontCharMap);
 
     nX = aSize.Width() / COLUMN_COUNT;
     nY = aSize.Height() / ROW_COUNT;
 
     aVscrollSB->setPosSizePixel(aSize.Width(), 0, nSBWidth, aSize.Height());
     aVscrollSB->SetRangeMin(0);
-    int nLastRow = (mpFontCharMap->GetCharCount() - 1 + COLUMN_COUNT) / COLUMN_COUNT;
+    int nLastRow = (mxFontCharMap->GetCharCount() - 1 + COLUMN_COUNT) / COLUMN_COUNT;
     aVscrollSB->SetRangeMax(nLastRow);
     aVscrollSB->SetPageSize(ROW_COUNT - 1);
     aVscrollSB->SetVisibleSize(ROW_COUNT);
 
     // restore last selected unicode
-    int nMapIndex = mpFontCharMap->GetIndexFromChar(getSelectedChar());
+    int nMapIndex = mxFontCharMap->GetIndexFromChar(getSelectedChar());
     SelectIndex(nMapIndex);
 
     aVscrollSB->Show();
@@ -588,7 +570,6 @@ void SvxShowCharSet::RecalculateFont(vcl::RenderContext& rRenderContext)
 }
 
 
-
 void SvxShowCharSet::SelectIndex( int nNewIndex, bool bFocus )
 {
     if( !aVscrollSB )
@@ -597,8 +578,8 @@ void SvxShowCharSet::SelectIndex( int nNewIndex, bool bFocus )
     if( nNewIndex < 0 )
     {
         // need to scroll see closest unicode
-        sal_uInt32 cPrev = mpFontCharMap->GetPrevChar( getSelectedChar() );
-        int nMapIndex = mpFontCharMap->GetIndexFromChar( cPrev );
+        sal_uInt32 cPrev = mxFontCharMap->GetPrevChar( getSelectedChar() );
+        int nMapIndex = mxFontCharMap->GetIndexFromChar( cPrev );
         int nNewPos = nMapIndex / COLUMN_COUNT;
         aVscrollSB->SetThumbPos( nNewPos );
         nSelectedIndex = bFocus ? nMapIndex+1 : -1;
@@ -619,7 +600,7 @@ void SvxShowCharSet::SelectIndex( int nNewIndex, bool bFocus )
         int nOldPos = aVscrollSB->GetThumbPos();
         int nDelta = (nNewIndex - LastInView() + COLUMN_COUNT) / COLUMN_COUNT;
         aVscrollSB->SetThumbPos( nOldPos + nDelta );
-        if( nNewIndex < mpFontCharMap->GetCharCount() )
+        if( nNewIndex < mxFontCharMap->GetCharCount() )
         {
             nSelectedIndex = nNewIndex;
             Invalidate();
@@ -637,15 +618,15 @@ void SvxShowCharSet::SelectIndex( int nNewIndex, bool bFocus )
 
     if( nSelectedIndex >= 0 )
     {
-        getSelectedChar() = mpFontCharMap->GetCharFromIndex( nSelectedIndex );
+        getSelectedChar() = mxFontCharMap->GetCharFromIndex( nSelectedIndex );
         if( m_pAccessible )
         {
             svx::SvxShowCharSetItem* pItem = ImplGetItem(nSelectedIndex);
             // Don't fire the focus event.
             if ( bFocus )
-                m_pAccessible->fireEvent( AccessibleEventId::ACTIVE_DESCENDANT_CHANGED, Any(), makeAny(pItem->GetAccessible()) ); // this call asures that m_pItem is set
+                m_pAccessible->fireEvent( AccessibleEventId::ACTIVE_DESCENDANT_CHANGED, Any(), makeAny(pItem->GetAccessible()) ); // this call assures that m_pItem is set
             else
-                m_pAccessible->fireEvent( AccessibleEventId::ACTIVE_DESCENDANT_CHANGED_NOFOCUS, Any(), makeAny(pItem->GetAccessible()) ); // this call asures that m_pItem is set
+                m_pAccessible->fireEvent( AccessibleEventId::ACTIVE_DESCENDANT_CHANGED_NOFOCUS, Any(), makeAny(pItem->GetAccessible()) ); // this call assures that m_pItem is set
 
             assert(pItem->m_pItem && "No accessible created!");
             Any aOldAny, aNewAny;
@@ -662,28 +643,31 @@ void SvxShowCharSet::SelectIndex( int nNewIndex, bool bFocus )
 }
 
 
-
-void SvxShowCharSet::SelectCharacter( sal_UCS4 cNew, bool bFocus )
+void SvxShowCharSet::OutputIndex( int nNewIndex )
 {
-    if (mpFontCharMap == nullptr)
-        RecalculateFont(*this);
+    SelectIndex( nNewIndex, true );
+    aSelectHdl.Call( this );
 
-    // get next available char of current font
-    sal_UCS4 cNext = mpFontCharMap->GetNextChar( (cNew > 0) ? cNew - 1 : cNew );
-
-    int nMapIndex = mpFontCharMap->GetIndexFromChar( cNext );
-    SelectIndex( nMapIndex, bFocus );
-    if( !bFocus )
-    {
-        // move selected item to top row if not in focus
-        aVscrollSB->SetThumbPos( nMapIndex / COLUMN_COUNT );
-        Invalidate();
-    }
 }
 
 
+void SvxShowCharSet::SelectCharacter( sal_UCS4 cNew )
+{
+    if (mxFontCharMap == nullptr)
+        RecalculateFont(*this);
 
-IMPL_LINK_NOARG(SvxShowCharSet, VscrollHdl)
+    // get next available char of current font
+    sal_UCS4 cNext = mxFontCharMap->GetNextChar( (cNew > 0) ? cNew - 1 : cNew );
+
+    int nMapIndex = mxFontCharMap->GetIndexFromChar( cNext );
+    SelectIndex( nMapIndex );
+    // move selected item to top row if not in focus
+    aVscrollSB->SetThumbPos( nMapIndex / COLUMN_COUNT );
+    Invalidate();
+}
+
+
+IMPL_LINK_NOARG_TYPED(SvxShowCharSet, VscrollHdl, ScrollBar*, void)
 {
     if( nSelectedIndex < FirstInView() )
     {
@@ -693,7 +677,7 @@ IMPL_LINK_NOARG(SvxShowCharSet, VscrollHdl)
     {
         if( m_pAccessible )
         {
-            ::com::sun::star::uno::Any aOldAny, aNewAny;
+            css::uno::Any aOldAny, aNewAny;
             int nLast = LastInView();
             for ( ; nLast != nSelectedIndex; ++nLast)
             {
@@ -705,11 +689,9 @@ IMPL_LINK_NOARG(SvxShowCharSet, VscrollHdl)
     }
 
     Invalidate();
-    return 0;
 }
 
 
-
 SvxShowCharSet::~SvxShowCharSet()
 {
     disposeOnce();
@@ -726,11 +708,11 @@ void SvxShowCharSet::dispose()
 void SvxShowCharSet::ReleaseAccessible()
 {
     m_aItems.clear();
-    m_pAccessible = NULL;
-    m_xAccessible = NULL;
+    m_pAccessible = nullptr;
+    m_xAccessible = nullptr;
 }
 
-::com::sun::star::uno::Reference< XAccessible > SvxShowCharSet::CreateAccessible()
+css::uno::Reference< XAccessible > SvxShowCharSet::CreateAccessible()
 {
     OSL_ENSURE(!m_pAccessible,"Accessible already created!");
     m_pAccessible = new svx::SvxShowCharSetVirtualAcc(this);
@@ -748,7 +730,7 @@ svx::SvxShowCharSetItem* SvxShowCharSet::ImplGetItem( int _nPos )
             m_pAccessible->getTable(), sal::static_int_cast< sal_uInt16 >(_nPos)));
         aFind = m_aItems.insert(ItemsMap::value_type(_nPos, xItem)).first;
         OUStringBuffer buf;
-        buf.appendUtf32( mpFontCharMap->GetCharFromIndex( _nPos ) );
+        buf.appendUtf32( mxFontCharMap->GetCharFromIndex( _nPos ) );
         aFind->second->maText = buf.makeStringAndClear();
         Point pix = MapIndexToPixel( _nPos );
         aFind->second->maRect = Rectangle( Point( pix.X() + 1, pix.Y() + 1 ), Size(nX-1,nY-1) );
@@ -758,20 +740,19 @@ svx::SvxShowCharSetItem* SvxShowCharSet::ImplGetItem( int _nPos )
 }
 
 
-
 sal_Int32 SvxShowCharSet::getMaxCharCount() const
 {
-    return mpFontCharMap->GetCharCount();
+    return mxFontCharMap->GetCharCount();
 }
 
 // TODO: should be moved into Font Attributes stuff
 // we let it mature here though because it is currently the only use
 
-SubsetMap::SubsetMap( const FontCharMapPtr& rFontCharMap )
+SubsetMap::SubsetMap( const FontCharMapPtr& rxFontCharMap )
 :   Resource( SVX_RES(RID_SUBSETMAP) )
 {
     InitList();
-    ApplyCharMap(rFontCharMap);
+    ApplyCharMap(rxFontCharMap);
     FreeResource();
 }
 
@@ -780,7 +761,7 @@ const Subset* SubsetMap::GetNextSubset( bool bFirst ) const
     if( bFirst )
         maSubsetIterator = maSubsets.begin();
     if( maSubsetIterator == maSubsets.end() )
-        return NULL;
+        return nullptr;
     const Subset* s = &*(maSubsetIterator++);
     return s;
 }
@@ -791,7 +772,7 @@ const Subset* SubsetMap::GetSubsetByUnicode( sal_UCS4 cChar ) const
     for( const Subset* s = GetNextSubset( true ); s; s = GetNextSubset( false ) )
         if( (s->GetRangeMin() <= cChar) && (cChar <= s->GetRangeMax()) )
             return s;
-    return NULL;
+    return nullptr;
 }
 
 inline Subset::Subset( sal_UCS4 nMin, sal_UCS4 nMax, int resId)
@@ -1574,6 +1555,38 @@ void SubsetMap::InitList()
                     aAllSubsets.push_back( Subset( 0x118A0, 0x118FF, RID_SUBSETSTR_WARANG_CITI ) );
                     break;
 #endif
+#if U_ICU_VERSION_MAJOR_NUM >= 56
+                case UBLOCK_AHOM:
+                    aAllSubsets.push_back( Subset( 0x11700, 0x1173F, RID_SUBSETSTR_AHOM ) );
+                    break;
+                case UBLOCK_ANATOLIAN_HIEROGLYPHS:
+                    aAllSubsets.push_back( Subset( 0x14400, 0x1467F, RID_SUBSETSTR_ANATOLIAN_HIEROGLYPHS ) );
+                    break;
+                case UBLOCK_CHEROKEE_SUPPLEMENT:
+                    aAllSubsets.push_back( Subset( 0xAB70, 0xABBF, RID_SUBSETSTR_CHEROKEE_SUPPLEMENT ) );
+                    break;
+                case UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_E:
+                    aAllSubsets.push_back( Subset( 0x2B820, 0x2CEAF, RID_SUBSETSTR_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_E ) );
+                    break;
+                case UBLOCK_EARLY_DYNASTIC_CUNEIFORM:
+                    aAllSubsets.push_back( Subset( 0x12480, 0x1254F, RID_SUBSETSTR_EARLY_DYNASTIC_CUNEIFORM ) );
+                    break;
+                case UBLOCK_HATRAN:
+                    aAllSubsets.push_back( Subset( 0x108E0, 0x108FF, RID_SUBSETSTR_HATRAN ) );
+                    break;
+                case UBLOCK_MULTANI:
+                    aAllSubsets.push_back( Subset( 0x11280, 0x112AF, RID_SUBSETSTR_MULTANI ) );
+                    break;
+                case UBLOCK_OLD_HUNGARIAN:
+                    aAllSubsets.push_back( Subset( 0x10C80, 0x10CFF, RID_SUBSETSTR_OLD_HUNGARIAN ) );
+                    break;
+                case UBLOCK_SUPPLEMENTAL_SYMBOLS_AND_PICTOGRAPHS:
+                    aAllSubsets.push_back( Subset( 0x1F900, 0x1F9FF, RID_SUBSETSTR_SUPPLEMENTAL_SYMBOLS_AND_PICTOGRAPHS ) );
+                    break;
+                case UBLOCK_SUTTON_SIGNWRITING:
+                    aAllSubsets.push_back( Subset( 0x1D800, 0x1DAAF, RID_SUBSETSTR_SUTTON_SIGNWRITING ) );
+                    break;
+#endif
 
             }
 
@@ -1599,20 +1612,20 @@ void SubsetMap::InitList()
     maSubsets = aAllSubsets;
 }
 
-void SubsetMap::ApplyCharMap( const FontCharMapPtr& rFontCharMap )
+void SubsetMap::ApplyCharMap( const FontCharMapPtr& rxFontCharMap )
 {
-    if( !rFontCharMap )
+    if( !rxFontCharMap )
         return;
 
     // remove subsets that are not matched in any range
     SubsetList::iterator it = maSubsets.begin();
-    while( it != maSubsets.end() )
+    while(it != maSubsets.end())
     {
         const Subset& rSubset = *it;
         sal_uInt32 cMin = rSubset.GetRangeMin();
         sal_uInt32 cMax = rSubset.GetRangeMax();
 
-        int nCount =  rFontCharMap->CountCharsInRange( cMin, cMax );
+        int nCount =  rxFontCharMap->CountCharsInRange( cMin, cMax );
         if( nCount <= 0 )
             it = maSubsets.erase(it);
         else
