@@ -17,8 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <com/sun/star/util/SearchOptions.hpp>
+#include <memory>
+
+#include <com/sun/star/util/SearchOptions2.hpp>
 #include <com/sun/star/util/SearchFlags.hpp>
+#include <comphelper/lok.hxx>
 #include <comphelper/string.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/window.hxx>
@@ -47,6 +50,7 @@
 #include <docsh.hxx>
 #include <PostItMgr.hxx>
 #include <viewsh.hxx>
+#include <view.hxx>
 
 using namespace ::com::sun::star;
 using namespace util;
@@ -72,7 +76,7 @@ lcl_CleanStr(const SwTextNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
     {
         if ( bNewHint )
             nHintStart = pHts && n < pHts->Count() ?
-                         (*pHts)[n]->GetStart() :
+                         pHts->Get(n)->GetStart() :
                          -1;
 
         if ( bNewSoftHyphen )
@@ -116,7 +120,7 @@ lcl_CleanStr(const SwTextNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
 
         if ( bNewHint )
         {
-            const SwTextAttr* pHt = (*pHts)[n];
+            const SwTextAttr* pHt = pHts->Get(n);
             if ( pHt->HasDummyChar() && (nStt >= nStart) )
             {
                 switch( pHt->Which() )
@@ -140,7 +144,7 @@ lcl_CleanStr(const SwTextNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
                         const bool bEmpty =
                             ( pHt->Which() != RES_TXTATR_FIELD
                               && pHt->Which() != RES_TXTATR_ANNOTATION )
-                            || (static_txtattr_cast<SwTextField const*>(pHt)->GetFormatField().GetField()->ExpandField(true).isEmpty());;
+                            || (static_txtattr_cast<SwTextField const*>(pHt)->GetFormatField().GetField()->ExpandField(true).isEmpty());
                         if ( bEmpty && nStart == nAkt )
                         {
                             rArr.push_back( nAkt );
@@ -196,7 +200,7 @@ size_t GetPostIt(sal_Int32 aCount,const SwpHints *pHts)
         for (size_t i = 0; i < pHts->Count(); ++i )
         {
             aIndex++;
-            const SwTextAttr* pTextAttr = (*pHts)[i];
+            const SwTextAttr* pTextAttr = pHts->Get(i);
             if ( pTextAttr->Which() == RES_TXTATR_ANNOTATION )
             {
                 aCount--;
@@ -208,7 +212,7 @@ size_t GetPostIt(sal_Int32 aCount,const SwpHints *pHts)
     // throw away all following non postits
     for( size_t i = aIndex; i < pHts->Count(); ++i )
     {
-        const SwTextAttr* pTextAttr = (*pHts)[i];
+        const SwTextAttr* pTextAttr = pHts->Get(i);
         if ( pTextAttr->Which() == RES_TXTATR_ANNOTATION )
             break;
         else
@@ -217,7 +221,7 @@ size_t GetPostIt(sal_Int32 aCount,const SwpHints *pHts)
     return aIndex;
 }
 
-bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::TextSearch& rSText,
+bool SwPaM::Find( const SearchOptions2& rSearchOpt, bool bSearchInNotes , utl::TextSearch& rSText,
                   SwMoveFn fnMove, const SwPaM * pRegion,
                   bool bInReadOnly )
 {
@@ -235,14 +239,18 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
     bool bFirst = true;
     SwContentNode * pNode;
 
-    const bool bRegSearch = SearchAlgorithms_REGEXP == rSearchOpt.algorithmType;
+    const bool bRegSearch = SearchAlgorithms2::REGEXP == rSearchOpt.AlgorithmType2;
     const bool bChkEmptyPara = bRegSearch && 2 == rSearchOpt.searchString.getLength() &&
                         ( rSearchOpt.searchString == "^$" ||
                           rSearchOpt.searchString == "$^" );
     const bool bChkParaEnd = bRegSearch && rSearchOpt.searchString == "$";
 
+    SvxSearchItem aSearchItem(SID_SEARCH_ITEM); // this is a very expensive operation (calling configmgr etc.)
+    aSearchItem.SetSearchOptions(rSearchOpt);
+    aSearchItem.SetBackward(!bSrchForward);
+
     // LanguageType eLastLang = 0;
-    while( 0 != ( pNode = ::GetNode( *pPam, bFirst, fnMove, bInReadOnly ) ))
+    while( nullptr != ( pNode = ::GetNode( *pPam, bFirst, fnMove, bInReadOnly ) ))
     {
         if( pNode->IsTextNode() )
         {
@@ -273,7 +281,7 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
 
                 for( size_t i = 0; i < pHts->Count(); ++i )
                 {
-                    const SwTextAttr* pTextAttr = (*pHts)[i];
+                    const SwTextAttr* pTextAttr = pHts->Get(i);
                     if ( pTextAttr->Which()==RES_TXTATR_ANNOTATION )
                     {
                         const sal_Int32 aPos = pTextAttr->GetStart();
@@ -295,12 +303,8 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
             }
 
             SwDocShell *const pDocShell = pNode->GetDoc()->GetDocShell();
-            SwWrtShell *const pWrtShell = (pDocShell) ? pDocShell->GetWrtShell() : 0;
-            SwPostItMgr *const pPostItMgr = (pWrtShell) ? pWrtShell->GetPostItMgr() : 0;
-
-            SvxSearchItem aSearchItem(SID_SEARCH_ITEM);
-            aSearchItem.SetSearchOptions(rSearchOpt);
-            aSearchItem.SetBackward(!bSrchForward);
+            SwWrtShell *const pWrtShell = (pDocShell) ? pDocShell->GetWrtShell() : nullptr;
+            SwPostItMgr *const pPostItMgr = (pWrtShell) ? pWrtShell->GetPostItMgr() : nullptr;
 
             // If there is an active text edit, then search there.
             bool bEndedTextEdit = false;
@@ -315,7 +319,7 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
                     {
                         const SwPosition* pPosition = pFrameFormat->GetAnchor().GetContentAnchor();
                         if (!pPosition || pPosition->nNode.GetIndex() != pNode->GetIndex())
-                            pObject = 0;
+                            pObject = nullptr;
                     }
                 }
 
@@ -328,7 +332,7 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
                         pSdrView->SdrEndTextEdit();
                         const Point aPoint(pSdrView->GetAllMarkedRect().TopLeft());
                         pSdrView->UnmarkAll();
-                        pWrtShell->SetCursor(&aPoint, true);
+                        pWrtShell->CallSetCursor(&aPoint, true);
                         pWrtShell->Edit();
                         bEndedTextEdit = true;
                     }
@@ -340,31 +344,36 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
                 }
             }
 
-            // If we just finished search in shape text, don't attept to do that again.
-            if (!bEndedTextEdit)
+            if (comphelper::LibreOfficeKit::isActive())
             {
-                // If there are any shapes anchored to this node, search there.
-                SwPaM aPaM(pNode->GetDoc()->GetNodes().GetEndOfContent());
-                aPaM.GetPoint()->nNode = rTextNode;
-                aPaM.GetPoint()->nContent.Assign(aPaM.GetPoint()->nNode.GetNode().GetTextNode(), nStart);
-                aPaM.SetMark();
-                aPaM.GetMark()->nNode = rTextNode.GetIndex() + 1;
-                aPaM.GetMark()->nContent.Assign(aPaM.GetMark()->nNode.GetNode().GetTextNode(), 0);
-                if (pNode->GetDoc()->getIDocumentDrawModelAccess().Search(aPaM, aSearchItem) && pSdrView)
+                // Writer and editeng selections are not supported in parallel.
+                SvxSearchItem* pSearchItem = SwView::GetSearchItem();
+                // If we just finished search in shape text, don't attempt to do that again.
+                if (!bEndedTextEdit && !(pSearchItem && pSearchItem->GetCommand() == SvxSearchCmd::FIND_ALL))
                 {
-                    if (SdrObject* pObject = pSdrView->GetTextEditObject())
+                    // If there are any shapes anchored to this node, search there.
+                    SwPaM aPaM(pNode->GetDoc()->GetNodes().GetEndOfContent());
+                    aPaM.GetPoint()->nNode = rTextNode;
+                    aPaM.GetPoint()->nContent.Assign(aPaM.GetPoint()->nNode.GetNode().GetTextNode(), nStart);
+                    aPaM.SetMark();
+                    aPaM.GetMark()->nNode = rTextNode.GetIndex() + 1;
+                    aPaM.GetMark()->nContent.Assign(aPaM.GetMark()->nNode.GetNode().GetTextNode(), 0);
+                    if (pNode->GetDoc()->getIDocumentDrawModelAccess().Search(aPaM, aSearchItem) && pSdrView)
                     {
-                        if (SwFrameFormat* pFrameFormat = FindFrameFormat(pObject))
+                        if (SdrObject* pObject = pSdrView->GetTextEditObject())
                         {
-                            const SwPosition* pPosition = pFrameFormat->GetAnchor().GetContentAnchor();
-                            if (pPosition)
+                            if (SwFrameFormat* pFrameFormat = FindFrameFormat(pObject))
                             {
-                                // Set search position to the shape's anchor point.
-                                *GetPoint() = *pPosition;
-                                GetPoint()->nContent.Assign(pPosition->nNode.GetNode().GetContentNode(), 0);
-                                SetMark();
-                                bFound = true;
-                                break;
+                                const SwPosition* pPosition = pFrameFormat->GetAnchor().GetContentAnchor();
+                                if (pPosition)
+                                {
+                                    // Set search position to the shape's anchor point.
+                                    *GetPoint() = *pPosition;
+                                    GetPoint()->nContent.Assign(pPosition->nNode.GetNode().GetContentNode(), 0);
+                                    SetMark();
+                                    bFound = true;
+                                    break;
+                                }
                             }
                         }
                     }
@@ -384,7 +393,7 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
                         if (aNumberPostits)
                             --aNumberPostits;
                     }
-                    //search inside and finsih and put focus back into the doc
+                    //search inside, finish and put focus back into the doc
                     if (pPostItMgr->FinishSearchReplace(rSearchOpt,bSrchForward))
                     {
                         bFound = true ;
@@ -393,7 +402,7 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
                 }
                 else
                 {
-                    pPostItMgr->SetActiveSidebarWin(0);
+                    pPostItMgr->SetActiveSidebarWin(nullptr);
                 }
             }
 
@@ -408,14 +417,14 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
                 {
                     if (bSrchForward)
                     {
-                        nStartInside = aLoop==0 ? nStart : (*pHts)[GetPostIt(aLoop+aIgnore-1,pHts)]->GetStart()+1;
-                        nEndInside = aLoop==aNumberPostits ? nEnd : (*pHts)[GetPostIt(aLoop+aIgnore,pHts)]->GetStart();
+                        nStartInside = aLoop==0 ? nStart : pHts->Get(GetPostIt(aLoop+aIgnore-1,pHts))->GetStart()+1;
+                        nEndInside = aLoop==aNumberPostits ? nEnd : pHts->Get(GetPostIt(aLoop+aIgnore,pHts))->GetStart();
                         nTextLen = nEndInside - nStartInside;
                     }
                     else
                     {
-                        nStartInside =  aLoop==aNumberPostits ? nStart : (*pHts)[GetPostIt(aLoop+aIgnore,pHts)]->GetStart();
-                        nEndInside = aLoop==0 ? nEnd : (*pHts)[GetPostIt(aLoop+aIgnore-1,pHts)]->GetStart()+1;
+                        nStartInside =  aLoop==aNumberPostits ? nStart : pHts->Get(GetPostIt(aLoop+aIgnore,pHts))->GetStart();
+                        nEndInside = aLoop==0 ? nEnd : pHts->Get(GetPostIt(aLoop+aIgnore-1,pHts))->GetStart()+1;
                         nTextLen = nStartInside - nEndInside;
                     }
                     // search inside the text between a note
@@ -430,7 +439,9 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
                         // we should now be right in front of a note, search inside
                         if ( (bSrchForward && (GetPostIt(aLoop + aIgnore,pHts) < pHts->Count()) ) || ( !bSrchForward && (aLoop!=0) ))
                         {
-                            const SwTextAttr* pTextAttr = bSrchForward ?  (*pHts)[GetPostIt(aLoop+aIgnore,pHts)] : (*pHts)[GetPostIt(aLoop+aIgnore-1,pHts)];
+                            const SwTextAttr* pTextAttr = bSrchForward
+                                    ? pHts->Get(GetPostIt(aLoop+aIgnore,pHts))
+                                    : pHts->Get(GetPostIt(aLoop+aIgnore-1,pHts));
                             if (pPostItMgr && pPostItMgr->SearchReplace(
                                     static_txtattr_cast<SwTextField const*>(pTextAttr)->GetFormatField(),rSearchOpt,bSrchForward))
                             {
@@ -458,7 +469,7 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
     return bFound;
 }
 
-bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSText,
+bool SwPaM::DoSearch( const SearchOptions2& rSearchOpt, utl::TextSearch& rSText,
                       SwMoveFn fnMove, bool bSrchForward, bool bRegSearch,
                       bool bChkEmptyPara, bool bChkParaEnd,
                       sal_Int32 &nStart, sal_Int32 &nEnd, sal_Int32 nTextLen,
@@ -470,7 +481,7 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSText,
     OUString sCleanStr;
     std::vector<sal_Int32> aFltArr;
     LanguageType eLastLang = 0;
-    // if the search string contains a soft hypen,
+    // if the search string contains a soft hyphen,
     // we don't strip them from the text:
     bool bRemoveSoftHyphens = true;
 
@@ -499,11 +510,11 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSText,
         sCleanStr = lcl_CleanStr(*pNode->GetTextNode(), nEnd, nStart,
                         aFltArr, bRemoveSoftHyphens);
 
-    SwScriptIterator* pScriptIter = 0;
+    SwScriptIterator* pScriptIter = nullptr;
     sal_uInt16 nSearchScript = 0;
     sal_uInt16 nCurrScript = 0;
 
-    if ( SearchAlgorithms_APPROXIMATE == rSearchOpt.algorithmType &&
+    if ( SearchAlgorithms2::APPROXIMATE == rSearchOpt.AlgorithmType2 &&
          g_pBreakIt->GetBreakIter().is() )
     {
         pScriptIter = new SwScriptIterator( sCleanStr, nStart, bSrchForward );
@@ -533,7 +544,7 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSText,
                 {
                     const lang::Locale aLocale(
                             g_pBreakIt->GetLocale( eCurrLang ) );
-                    rSText.SetLocale( rSearchOpt, aLocale );
+                    rSText.SetLocale( utl::TextSearch::UpgradeToSearchOptions2( rSearchOpt), aLocale );
                     eLastLang = eCurrLang;
                 }
             }
@@ -542,7 +553,7 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSText,
         sal_Int32 nProxyStart = nStart;
         sal_Int32 nProxyEnd = nEnd;
         if( nSearchScript == nCurrScript &&
-                (rSText.*fnMove->fnSearch)( sCleanStr, &nProxyStart, &nProxyEnd, 0 ) &&
+                (rSText.*fnMove->fnSearch)( sCleanStr, &nProxyStart, &nProxyEnd, nullptr ) &&
                 !(bZeroMatch = (nProxyStart == nProxyEnd)))
         {
             nStart = nProxyStart;
@@ -621,17 +632,18 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSText,
 /// parameters for search and replace in text
 struct SwFindParaText : public SwFindParas
 {
-    const SearchOptions& rSearchOpt;
-    SwCursor& rCursor;
-    utl::TextSearch aSText;
-    bool bReplace;
-    bool bSearchInNotes;
+    const SearchOptions2& m_rSearchOpt;
+    SwCursor& m_rCursor;
+    utl::TextSearch m_aSText;
+    bool m_bReplace;
+    bool m_bSearchInNotes;
 
-    SwFindParaText( const SearchOptions& rOpt, bool bSearchNotes, bool bRepl, SwCursor& rCrsr )
-        : rSearchOpt( rOpt ), rCursor( rCrsr ), aSText( rOpt ), bReplace( bRepl ), bSearchInNotes( bSearchNotes )
+    SwFindParaText( const SearchOptions2& rOpt, bool bSearchInNotes, bool bRepl, SwCursor& rCursor )
+        : m_rSearchOpt( rOpt ), m_rCursor( rCursor ), m_aSText( utl::TextSearch::UpgradeToSearchOptions2( rOpt) ),
+        m_bReplace( bRepl ), m_bSearchInNotes( bSearchInNotes )
     {}
-    virtual int Find( SwPaM* , SwMoveFn , const SwPaM*, bool bInReadOnly ) SAL_OVERRIDE;
-    virtual bool IsReplaceMode() const SAL_OVERRIDE;
+    virtual int Find( SwPaM* , SwMoveFn , const SwPaM*, bool bInReadOnly ) override;
+    virtual bool IsReplaceMode() const override;
     virtual ~SwFindParaText();
 };
 
@@ -639,36 +651,36 @@ SwFindParaText::~SwFindParaText()
 {
 }
 
-int SwFindParaText::Find( SwPaM* pCrsr, SwMoveFn fnMove,
+int SwFindParaText::Find( SwPaM* pCursor, SwMoveFn fnMove,
                           const SwPaM* pRegion, bool bInReadOnly )
 {
-    if( bInReadOnly && bReplace )
+    if( bInReadOnly && m_bReplace )
         bInReadOnly = false;
 
-    const bool bFnd = pCrsr->Find( rSearchOpt, bSearchInNotes, aSText, fnMove, pRegion, bInReadOnly );
+    const bool bFnd = pCursor->Find( m_rSearchOpt, m_bSearchInNotes, m_aSText, fnMove, pRegion, bInReadOnly );
 
-    if( bFnd && bReplace ) // replace string
+    if( bFnd && m_bReplace ) // replace string
     {
         // use replace method in SwDoc
-        const bool bRegExp(SearchAlgorithms_REGEXP == rSearchOpt.algorithmType);
-        SwIndex& rSttCntIdx = pCrsr->Start()->nContent;
+        const bool bRegExp(SearchAlgorithms2::REGEXP == m_rSearchOpt.AlgorithmType2);
+        SwIndex& rSttCntIdx = pCursor->Start()->nContent;
         const sal_Int32 nSttCnt = rSttCntIdx.GetIndex();
         // add to shell-cursor-ring so that the regions will be moved eventually
         SwPaM* pPrev(nullptr);
         if( bRegExp )
         {
             pPrev = const_cast<SwPaM*>(pRegion)->GetPrev();
-            const_cast<SwPaM*>(pRegion)->GetRingContainer().merge( rCursor.GetRingContainer() );
+            const_cast<SwPaM*>(pRegion)->GetRingContainer().merge( m_rCursor.GetRingContainer() );
         }
 
-        boost::scoped_ptr<OUString> pRepl( (bRegExp)
-                ? ReplaceBackReferences( rSearchOpt, pCrsr ) : 0 );
+        std::unique_ptr<OUString> pRepl( (bRegExp)
+                ? ReplaceBackReferences( m_rSearchOpt, pCursor ) : nullptr );
         bool const bReplaced =
-            rCursor.GetDoc()->getIDocumentContentOperations().ReplaceRange(
-                *pCrsr,
-                (pRepl.get()) ? *pRepl : rSearchOpt.replaceString,
+            m_rCursor.GetDoc()->getIDocumentContentOperations().ReplaceRange(
+                *pCursor,
+                (pRepl.get()) ? *pRepl : m_rSearchOpt.replaceString,
                 bRegExp );
-        rCursor.SaveTableBoxContent( pCrsr->GetPoint() );
+        m_rCursor.SaveTableBoxContent( pCursor->GetPoint() );
 
         if( bRegExp )
         {
@@ -684,12 +696,12 @@ int SwFindParaText::Find( SwPaM* pCrsr, SwMoveFn fnMove,
         if (bRegExp && !bReplaced)
         {   // fdo#80715 avoid infinite loop if join failed
             bool bRet = ((fnMoveForward == fnMove) ? &GoNextPara : &GoPrevPara)
-                (*pCrsr, fnMove);
+                (*pCursor, fnMove);
             (void) bRet;
             assert(bRet); // if join failed, next node must be SwTextNode
         }
         else
-            pCrsr->Start()->nContent = nSttCnt;
+            pCursor->Start()->nContent = nSttCnt;
         return FIND_NO_RING;
     }
     return bFnd ? FIND_FOUND : FIND_NOT_FOUND;
@@ -697,22 +709,22 @@ int SwFindParaText::Find( SwPaM* pCrsr, SwMoveFn fnMove,
 
 bool SwFindParaText::IsReplaceMode() const
 {
-    return bReplace;
+    return m_bReplace;
 }
 
-sal_uLong SwCursor::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes,
+sal_uLong SwCursor::Find( const SearchOptions2& rSearchOpt, bool bSearchInNotes,
                           SwDocPositions nStart, SwDocPositions nEnd,
                           bool& bCancel, FindRanges eFndRngs, bool bReplace )
 {
     // switch off OLE-notifications
     SwDoc* pDoc = GetDoc();
-    Link<> aLnk( pDoc->GetOle2Link() );
-    pDoc->SetOle2Link( Link<>() );
+    Link<bool,void> aLnk( pDoc->GetOle2Link() );
+    pDoc->SetOle2Link( Link<bool,void>() );
 
     bool const bStartUndo = pDoc->GetIDocumentUndoRedo().DoesUndo() && bReplace;
     if (bStartUndo)
     {
-        pDoc->GetIDocumentUndoRedo().StartUndo( UNDO_REPLACE, NULL );
+        pDoc->GetIDocumentUndoRedo().StartUndo( UNDO_REPLACE, nullptr );
     }
 
     bool bSearchSel = 0 != (rSearchOpt.searchFlag & SearchFlags::REG_NOT_BEGINOFLINE);
@@ -733,16 +745,16 @@ sal_uLong SwCursor::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes,
     return nRet;
 }
 
-OUString *ReplaceBackReferences( const SearchOptions& rSearchOpt, SwPaM* pPam )
+OUString *ReplaceBackReferences( const SearchOptions2& rSearchOpt, SwPaM* pPam )
 {
-    OUString *pRet = 0;
+    OUString *pRet = nullptr;
     if( pPam && pPam->HasMark() &&
-        SearchAlgorithms_REGEXP == rSearchOpt.algorithmType )
+        SearchAlgorithms2::REGEXP == rSearchOpt.AlgorithmType2 )
     {
-        const SwContentNode* pTextNode = pPam->GetContentNode( true );
+        const SwContentNode* pTextNode = pPam->GetContentNode();
         if( pTextNode && pTextNode->IsTextNode() && pTextNode == pPam->GetContentNode( false ) )
         {
-            utl::TextSearch aSText( rSearchOpt );
+            utl::TextSearch aSText( utl::TextSearch::UpgradeToSearchOptions2( rSearchOpt) );
             const OUString& rStr = pTextNode->GetTextNode()->GetText();
             sal_Int32 nStart = pPam->Start()->nContent.GetIndex();
             sal_Int32 nEnd = pPam->End()->nContent.GetIndex();
