@@ -19,7 +19,7 @@
 
 #include <hintids.hxx>
 
-#include <vcl/graphic.hxx>
+#include <vcl/graph.hxx>
 #include <sot/formats.hxx>
 #include <sot/storage.hxx>
 #include <unotools/pathoptions.hxx>
@@ -225,7 +225,7 @@ bool SwFEShell::Copy( SwDoc* pClpDoc, const OUString* pNewClpText )
         bRet = true;
     }
     else
-        bRet = _CopySelToDoc( pClpDoc );     // copy the selections
+        bRet = CopySelToDoc( pClpDoc );     // copy the selections
 
     pClpDoc->getIDocumentRedlineAccess().SetRedlineMode_intern((RedlineMode_t)0 );
     pClpDoc->getIDocumentFieldsAccess().UnlockExpFields();
@@ -563,11 +563,11 @@ bool SwFEShell::Copy( SwFEShell* pDestShell, const Point& rSttPt,
                 {
                     //JP 12.05.98: should this be in SelectFlyFrame???
                     pDestShell->Imp()->GetDrawView()->UnmarkAll();
-                    pDestShell->SelectFlyFrame( *pFlyFrame, true );
+                    pDestShell->SelectFlyFrame( *pFlyFrame );
                 }
             }
 
-            if( this != pDestShell && !pDestShell->HasShFcs() )
+            if (this != pDestShell && !pDestShell->HasShellFocus())
                 pDestShell->Imp()->GetDrawView()->hideMarkHandles();
         }
     }
@@ -664,7 +664,7 @@ bool SwFEShell::Copy( SwFEShell* pDestShell, const Point& rSttPt,
             pDestShell->StartAllAction();
     }
     pDestShell->GetDoc()->getIDocumentFieldsAccess().UnlockExpFields();
-    pDestShell->GetDoc()->getIDocumentFieldsAccess().UpdateFields(nullptr, false);
+    pDestShell->GetDoc()->getIDocumentFieldsAccess().UpdateFields(false);
 
     pDestShell->EndAllAction();
     return bRet;
@@ -683,11 +683,10 @@ namespace {
     }
 }
 
-bool SwFEShell::Paste( SwDoc* pClpDoc, bool bIncludingPageFrames )
+bool SwFEShell::Paste( SwDoc* pClpDoc )
 {
     SET_CURR_SHELL( this );
     OSL_ENSURE( pClpDoc, "no clipboard document"  );
-    const sal_uInt16 nStartPageNumber = GetPhyPageNum();
     // then till end of the nodes array
     SwNodeIndex aIdx( pClpDoc->GetNodes().GetEndOfExtras(), 2 );
     SwPaM aCpyPam( aIdx ); //DocStart
@@ -754,15 +753,15 @@ bool SwFEShell::Paste( SwDoc* pClpDoc, bool bIncludingPageFrames )
             OSL_ENSURE( aIdx.GetNode().GetContentNode(), "Who filled the clipboard?!" );
             if( aIdx.GetNode().GetContentNode() ) // robust
             {
-                Insertion aInsertion( PaMPtr( new SwPaM( aIdx ) ),
-                    PositionPtr( new SwPosition( aInsertPos ) ) );
+                Insertion aInsertion( std::make_shared<SwPaM>( aIdx ),
+                    std::make_shared<SwPosition>( aInsertPos ) );
                 ++aIdx;
                 aInsertion.first->SetMark();
                 if( pStartCursor == pCurrCursor->GetNext() )
                 {   // Now we have to look for insertion positions...
                     if( !nMove ) // Annotate the last given insert position
                         aStartPos = aInsertPos;
-                    SwCursor aCursor( aStartPos, nullptr, false);
+                    SwCursor aCursor( aStartPos, nullptr);
                     // Check if we find another insert position by moving
                     // down the last given position
                     if( aCursor.UpDown( false, ++nMove, nullptr, 0 ) )
@@ -999,7 +998,7 @@ bool SwFEShell::Paste( SwDoc* pClpDoc, bool bIncludingPageFrames )
                                 SwFlyFrame* pFlyFrame = static_cast<SwFlyFrameFormat*>(pNew)->
                                                         GetFrame( &aPt );
                                 if( pFlyFrame )
-                                    SelectFlyFrame( *pFlyFrame, true );
+                                    SelectFlyFrame( *pFlyFrame );
                                 // always pick the first FlyFrame only; the others
                                 // were copied to the clipboard via Fly in Fly
                                 break;
@@ -1052,8 +1051,6 @@ bool SwFEShell::Paste( SwDoc* pClpDoc, bool bIncludingPageFrames )
                 // ** Update SwDoc::Append, if you change the following code **
                 // **
 
-                // find out if the clipboard document starts with a table
-                bool bStartWithTable = nullptr != aCpyPam.Start()->nNode.GetNode().FindTableNode();
                 SwPosition aInsertPosition( rInsPos );
 
                 {
@@ -1086,28 +1083,6 @@ bool SwFEShell::Paste( SwDoc* pClpDoc, bool bIncludingPageFrames )
                 }
 
                 SaveTableBoxContent( &rInsPos );
-                if(bIncludingPageFrames && bStartWithTable)
-                {
-                    //remove the paragraph in front of the table
-                    SwPaM aPara(aInsertPosition);
-                    GetDoc()->getIDocumentContentOperations().DelFullPara(aPara);
-                }
-                //additionally copy page bound frames
-                if( bIncludingPageFrames && pClpDoc->GetSpzFrameFormats()->size() )
-                {
-                    // create a draw view if necessary
-                    if( !Imp()->GetDrawView() )
-                        MakeDrawView();
-
-                    for ( auto pCpyFormat : *pClpDoc->GetSpzFrameFormats() )
-                    {
-                        SwFormatAnchor aAnchor( pCpyFormat->GetAnchor() );
-                        if ( FLY_AT_PAGE != aAnchor.GetAnchorId() )
-                            continue;
-                        aAnchor.SetPageNum( aAnchor.GetPageNum() + nStartPageNumber - 1 );
-                        GetDoc()->getIDocumentLayoutAccess().CopyLayoutFormat( *pCpyFormat, aAnchor, true, true );
-                    }
-                }
             }
         }
     }
@@ -1127,7 +1102,7 @@ bool SwFEShell::Paste( SwDoc* pClpDoc, bool bIncludingPageFrames )
             StartAllAction();
     }
     GetDoc()->getIDocumentFieldsAccess().UnlockExpFields();
-    GetDoc()->getIDocumentFieldsAccess().UpdateFields(nullptr, false);
+    GetDoc()->getIDocumentFieldsAccess().UpdateFields(false);
     EndAllAction();
 
     return bRet;
@@ -1212,7 +1187,7 @@ bool SwFEShell::PastePages( SwFEShell& rToFill, sal_uInt16 nStartPage, sal_uInt1
         }
     }
     GetDoc()->getIDocumentFieldsAccess().UnlockExpFields();
-    GetDoc()->getIDocumentFieldsAccess().UpdateFields(nullptr, false);
+    GetDoc()->getIDocumentFieldsAccess().UpdateFields(false);
     Pop(false);
     EndAllAction();
 
@@ -1527,7 +1502,7 @@ void SwFEShell::Paste( SvStream& rStrm, SwPasteSdr nAction, const Point* pPt )
         // #i50824#
         // method <lcl_RemoveOleObjsFromSdrModel> replaced by <lcl_ConvertSdrOle2ObjsToSdrGrafObjs>
         lcl_ConvertSdrOle2ObjsToSdrGrafObjs( pModel );
-        pView->Paste(*pModel, aPos, nullptr, SdrInsertFlags::NONE, OUString(), OUString());
+        pView->Paste(*pModel, aPos, nullptr, SdrInsertFlags::NONE);
 
         const size_t nCnt = pView->GetMarkedObjectList().GetMarkCount();
         if( nCnt )
