@@ -25,6 +25,7 @@
 #include <svx/svdogrp.hxx>
 #include <svx/svdouno.hxx>
 #include <svx/fmglob.hxx>
+#include <tools/globname.hxx>
 #include <com/sun/star/form/FormButtonType.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <fmtanchr.hxx>
@@ -177,7 +178,7 @@ static bool lcl_FindAnchorPos(
         }
 
         aNewAnch.SetType( nNew = FLY_AT_PAGE );
-        // no break
+        SAL_FALLTHROUGH;
 
     case FLY_AT_PAGE:
         pNewAnch = rFrame.FindPageFrame();
@@ -219,7 +220,7 @@ bool sw_ChkAndSetNewAnchor(
     return ::lcl_FindAnchorPos( *pDoc, rFly.Frame().Pos(), rFly, rSet );
 }
 
-void SwFEShell::SelectFlyFrame( SwFlyFrame& rFrame, bool bNew )
+void SwFEShell::SelectFlyFrame( SwFlyFrame& rFrame )
 {
     SET_CURR_SHELL( this );
 
@@ -231,7 +232,7 @@ void SwFEShell::SelectFlyFrame( SwFlyFrame& rFrame, bool bNew )
     // The frames should not be selected by the document position, because
     // it should have been selected!
     SwViewShellImp *pImpl = Imp();
-    if( GetWin() && (bNew || !pImpl->GetDrawView()->AreObjectsMarked()) )
+    if( GetWin() )
     {
         OSL_ENSURE( rFrame.IsFlyFrame(), "SelectFlyFrame will einen Fly" );
 
@@ -281,12 +282,12 @@ SwFlyFrame* SwFEShell::GetCurrFlyFrame(const bool bCalcFrame) const
 }
 
 // Get selected fly, but if none Get current fly in which the cursor is positioned
-SwFlyFrame* SwFEShell::GetSelectedOrCurrFlyFrame(const bool bCalcFrame) const
+SwFlyFrame* SwFEShell::GetSelectedOrCurrFlyFrame() const
 {
     SwFlyFrame *pFly = GetSelectedFlyFrame();
     if (pFly)
         return pFly;
-    return GetCurrFlyFrame(bCalcFrame);
+    return GetCurrFlyFrame();
 }
 
 // Returns non-null pointer, if the current Fly could be anchored to another one (so it is inside)
@@ -749,7 +750,7 @@ const SwFrameFormat *SwFEShell::NewFlyFrame( const SfxItemSet& rSet, bool bAnchV
     {
         SwFlyFrame* pFrame = pRet->GetFrame( &aPt );
         if( pFrame )
-            SelectFlyFrame( *pFrame, true );
+            SelectFlyFrame( *pFrame );
         else
         {
             GetLayout()->SetAssertFlyPages();
@@ -838,7 +839,7 @@ void SwFEShell::Insert( const OUString& rGrfName, const OUString& rFltName,
             pPageFrame->InvalidateFlyLayout();
             pPageFrame->InvalidateContent();
 
-            SelectFlyFrame( *pFrame, true );
+            SelectFlyFrame( *pFrame );
         }
         else
             GetLayout()->SetAssertFlyPages();
@@ -868,7 +869,7 @@ SwFlyFrameFormat* SwFEShell::InsertObject( const svt::EmbeddedObjectRef&  xObj,
         SwFlyFrame* pFrame = pFormat->GetFrame( &aPt );
 
         if( pFrame )
-            SelectFlyFrame( *pFrame, true );
+            SelectFlyFrame( *pFrame );
         else
             GetLayout()->SetAssertFlyPages();
     }
@@ -933,9 +934,9 @@ void SwFEShell::GetPageObjs( std::vector<SwFrameFormat*>& rFillArr )
     }
 }
 
-void SwFEShell::SetPageObjsNewPage( std::vector<SwFrameFormat*>& rFillArr, int nOffset )
+void SwFEShell::SetPageObjsNewPage( std::vector<SwFrameFormat*>& rFillArr )
 {
-    if( rFillArr.empty() || !nOffset )
+    if( rFillArr.empty() )
         return;
 
     StartAllAction();
@@ -953,7 +954,7 @@ void SwFEShell::SetPageObjsNewPage( std::vector<SwFrameFormat*>& rFillArr, int n
 
             SwFormatAnchor aNewAnchor( pFormat->GetAnchor() );
             if ((FLY_AT_PAGE != aNewAnchor.GetAnchorId()) ||
-                0 >= ( nNewPage = aNewAnchor.GetPageNum() + nOffset ) )
+                0 >= ( nNewPage = aNewAnchor.GetPageNum() + 1 ) )
                 // chaos::Anchor has been changed or invalid page number,
                 // therefore: do not change!
                 continue;
@@ -1051,7 +1052,7 @@ bool SwFEShell::SetFlyFrameAttr( SfxItemSet& rSet )
                 bRet = true;
                 SwFlyFrame* pFrame = pFlyFormat->GetFrame( &aPt );
                 if( pFrame )
-                    SelectFlyFrame( *pFrame, true );
+                    SelectFlyFrame( *pFrame );
                 else
                     GetLayout()->SetAssertFlyPages();
             }
@@ -1111,41 +1112,35 @@ bool SwFEShell::SetDrawingAttr( SfxItemSet& rSet )
     return bRet;
 }
 
-// Reset requested attributes or the ones contained in the set.
-bool SwFEShell::ResetFlyFrameAttr( sal_uInt16 nWhich, const SfxItemSet* pSet )
+// Reset attributes contained in the set.
+bool SwFEShell::ResetFlyFrameAttr( const SfxItemSet* pSet )
 {
     bool bRet = false;
 
-    if( RES_ANCHOR != nWhich && RES_CHAIN != nWhich && RES_CNTNT != nWhich )
+    SET_CURR_SHELL( this );
+
+    SwFlyFrame *pFly = GetSelectedOrCurrFlyFrame();
+    OSL_ENSURE( pFly, "SetFlyFrameAttr, no Fly selected." );
+    if( pFly )
     {
-        SET_CURR_SHELL( this );
+        StartAllAction();
 
-        SwFlyFrame *pFly = GetSelectedOrCurrFlyFrame();
-        OSL_ENSURE( pFly, "SetFlyFrameAttr, no Fly selected." );
-        if( pFly )
+        SfxItemIter aIter( *pSet );
+        const SfxPoolItem* pItem = aIter.FirstItem();
+        while( pItem )
         {
-            StartAllAction();
-
-            if( pSet )
+            if( !IsInvalidItem( pItem ) )
             {
-                SfxItemIter aIter( *pSet );
-                const SfxPoolItem* pItem = aIter.FirstItem();
-                while( pItem )
-                {
-                    if( !IsInvalidItem( pItem ) &&
-                        RES_ANCHOR != ( nWhich = pItem->Which() ) &&
-                        RES_CHAIN != nWhich && RES_CNTNT != nWhich )
-                        pFly->GetFormat()->ResetFormatAttr( nWhich );
-                    pItem = aIter.NextItem();
-                }
+                sal_uInt16 nWhich = pItem->Which();
+                if( RES_ANCHOR != nWhich && RES_CHAIN != nWhich && RES_CNTNT != nWhich )
+                    pFly->GetFormat()->ResetFormatAttr( nWhich );
             }
-            else
-                pFly->GetFormat()->ResetFormatAttr( nWhich );
-
-            bRet = true;
-            EndAllActionAndCall();
-            GetDoc()->getIDocumentState().SetModified();
+            pItem = aIter.NextItem();
         }
+
+        bRet = true;
+        EndAllActionAndCall();
+        GetDoc()->getIDocumentState().SetModified();
     }
     return bRet;
 }
@@ -1189,14 +1184,17 @@ void SwFEShell::SetFrameFormat( SwFrameFormat *pNewFormat, bool bKeepOrient, Poi
             pSet = new SfxItemSet( GetDoc()->GetAttrPool(), aFrameFormatSetRange );
             pSet->Put( *pItem );
             if( !sw_ChkAndSetNewAnchor( *pFly, *pSet ))
-                delete pSet, pSet = nullptr;
+            {
+                delete pSet;
+                pSet = nullptr;
+            }
         }
 
         if( GetDoc()->SetFrameFormatToFly( *pFlyFormat, *pNewFormat, pSet, bKeepOrient ))
         {
             SwFlyFrame* pFrame = pFlyFormat->GetFrame( &aPt );
             if( pFrame )
-                SelectFlyFrame( *pFrame, true );
+                SelectFlyFrame( *pFrame );
             else
                 GetLayout()->SetAssertFlyPages();
         }
@@ -1644,7 +1642,6 @@ ObjCntType SwFEShell::GetObjCntType( const SdrObject& rObj ) const
             uno::Reference< beans::XPropertySetInfo >  xInfo = xSet->getPropertySetInfo();
             if(xInfo->hasPropertyByName( sName ))
             {
-                beans::Property xProperty = xInfo->getPropertyByName( sName );
                 aVal = xSet->getPropertyValue( sName );
                 if( aVal.getValue() && form::FormButtonType_URL == *static_cast<form::FormButtonType const *>(aVal.getValue()) )
                     eType = OBJCNT_URLBUTTON;
@@ -1714,7 +1711,7 @@ ObjCntType SwFEShell::GetObjCntType( const Point &rPt, SdrObject *&rpObj ) const
     return eType;
 }
 
-ObjCntType SwFEShell::GetObjCntTypeOfSelection( SdrObject** ppObj ) const
+ObjCntType SwFEShell::GetObjCntTypeOfSelection() const
 {
     ObjCntType eType = OBJCNT_NONE;
 
@@ -1730,7 +1727,6 @@ ObjCntType SwFEShell::GetObjCntTypeOfSelection( SdrObject** ppObj ) const
             if( !i )
             {
                 eType = eTmp;
-                if( ppObj ) *ppObj = pObj;
             }
             else if( eTmp != eType )
             {
@@ -2001,7 +1997,7 @@ void SwFEShell::SetObjDescription( const OUString& rDescription )
     }
 }
 
-void SwFEShell::AlignFormulaToBaseline( const uno::Reference < embed::XEmbeddedObject >& xObj, SwFlyFrame * pFly )
+void SwFEShell::AlignFormulaToBaseline( const uno::Reference < embed::XEmbeddedObject >& xObj )
 {
 #if OSL_DEBUG_LEVEL > 0
     SvGlobalName aCLSID( xObj->getClassID() );
@@ -2012,8 +2008,7 @@ void SwFEShell::AlignFormulaToBaseline( const uno::Reference < embed::XEmbeddedO
         return;
 #endif
 
-    if (!pFly)
-        pFly = FindFlyFrame( xObj );
+    SwFlyFrame * pFly = FindFlyFrame( xObj );
     OSL_ENSURE( pFly , "No fly frame!" );
     SwFrameFormat * pFrameFormat = pFly ? pFly->GetFormat() : nullptr;
 
