@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "hintids.hxx"
 #include <comphelper/string.hxx>
 #include <editeng/lrspitem.hxx>
@@ -33,124 +32,104 @@
 #include "itrform2.hxx"
 #include "txtfrm.hxx"
 #include <numrule.hxx>
-// #i89179#
 #include <porfld.hxx>
+#include <memory>
 
-
-/*************************************************************************
- *                    SwLineInfo::GetTabStop()
- *************************************************************************/
-
-//#i24363# tab stops relative to indent
-/* Return the first tab stop that is > nSearchPos.
+/**
+ * #i24363# tab stops relative to indent
+ *
+ * Return the first tab stop that is > nSearchPos.
  * If the tab stop is outside the print area, we
- * return 0 if it is not the first tab stop.*/
-const SvxTabStop *SwLineInfo::GetTabStop( const SwTwips nSearchPos,
-                                         const SwTwips nRight ) const
+ * return 0 if it is not the first tab stop.
+ */
+const SvxTabStop *SwLineInfo::GetTabStop( const SwTwips nSearchPos, const SwTwips nRight ) const
 {
-    for( MSHORT i = 0; i < pRuler->Count(); ++i )
+    for( sal_uInt16 i = 0; i < pRuler->Count(); ++i )
     {
         const SvxTabStop &rTabStop = pRuler->operator[](i);
         if( rTabStop.GetTabPos() > SwTwips(nRight) )
-            return i ? 0 : &rTabStop;
+            return i ? nullptr : &rTabStop;
 
         if( rTabStop.GetTabPos() > nSearchPos )
             return &rTabStop;
     }
-    return 0;
+    return nullptr;
 }
 
-/*************************************************************************
- *                    SwLineInfo::NumberOfTabStops()
- *************************************************************************/
-
 sal_uInt16 SwLineInfo::NumberOfTabStops() const
 {
     return pRuler->Count();
 }
 
-/*************************************************************************
- *                      SwTxtFormatter::NewTabPortion()
- *************************************************************************/
-SwTabPortion *SwTxtFormatter::NewTabPortion( SwTxtFormatInfo &rInf, bool bAuto ) const
+SwTabPortion *SwTextFormatter::NewTabPortion( SwTextFormatInfo &rInf, bool bAuto ) const
 {
     sal_Unicode cFill = 0;
     sal_Unicode cDec = 0;
     SvxTabAdjust eAdj;
 
-    KSHORT nNewTabPos;
+    sal_uInt16 nNewTabPos;
     bool bAutoTabStop = true;
     {
-        const bool bRTL = pFrm->IsRightToLeft();
+        const bool bRTL = m_pFrame->IsRightToLeft();
         // #i24363# tab stops relative to indent
         // nTabLeft: The absolute value, the tab stops are relative to: Tabs origin.
-        //
+
         // #i91133#
         const bool bTabsRelativeToIndent =
-            pFrm->GetTxtNode()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::TABS_RELATIVE_TO_INDENT);
+            m_pFrame->GetTextNode()->getIDocumentSettingAccess()->get(DocumentSettingId::TABS_RELATIVE_TO_INDENT);
         const SwTwips nTabLeft = bRTL
-                                 ? pFrm->Frm().Right() -
+                                 ? m_pFrame->Frame().Right() -
                                    ( bTabsRelativeToIndent ? GetTabLeft() : 0 )
-                                 : pFrm->Frm().Left() +
+                                 : m_pFrame->Frame().Left() +
                                    ( bTabsRelativeToIndent ? GetTabLeft() : 0 );
 
-        //
-        // nLinePos: The absolute position, where we started the line formatting.
-        //
+        // The absolute position, where we started the line formatting
         SwTwips nLinePos = GetLeftMargin();
         if ( bRTL )
         {
             Point aPoint( nLinePos, 0 );
-            pFrm->SwitchLTRtoRTL( aPoint );
+            m_pFrame->SwitchLTRtoRTL( aPoint );
             nLinePos = aPoint.X();
         }
 
-        //
-        // nTabPos: The current position, relative to the line start.
-        //
+        // The current position, relative to the line start
         SwTwips nTabPos = rInf.GetLastTab() ? rInf.GetLastTab()->GetTabPos() : 0;
         if( nTabPos < rInf.X() )
         {
             nTabPos = rInf.X();
         }
 
-        //
-        // nCurrentAbsPos: The current position in absolute coordinates.
-        //
+        // The current position in absolute coordinates
         const SwTwips nCurrentAbsPos = bRTL ?
                                        nLinePos - nTabPos :
                                        nLinePos + nTabPos;
 
-       //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
         SwTwips nMyRight;
-        if ( pFrm->IsVertLR() )
+        if ( m_pFrame->IsVertLR() )
            nMyRight = Left();
         else
            nMyRight = Right();
 
-        if ( pFrm->IsVertical() )
+        if ( m_pFrame->IsVertical() )
         {
-            Point aRightTop( nMyRight, pFrm->Frm().Top() );
-            pFrm->SwitchHorizontalToVertical( aRightTop );
+            Point aRightTop( nMyRight, m_pFrame->Frame().Top() );
+            m_pFrame->SwitchHorizontalToVertical( aRightTop );
             nMyRight = aRightTop.Y();
         }
 
         SwTwips nNextPos = 0;
 
         // #i24363# tab stops relative to indent
-        // nSearchPos: The current position relative to the tabs origin.
-        //
+        // nSearchPos: The current position relative to the tabs origin
         const SwTwips nSearchPos = bRTL ?
                                    nTabLeft - nCurrentAbsPos :
                                    nCurrentAbsPos - nTabLeft;
 
-        //
         // First, we examine the tab stops set at the paragraph style or
         // any hard set tab stops:
         // Note: If there are no user defined tab stops, there is always a
         // default tab stop.
-        //
-        const SvxTabStop* pTabStop = aLineInf.GetTabStop( nSearchPos, nMyRight );
+        const SvxTabStop* pTabStop = m_aLineInf.GetTabStop( nSearchPos, nMyRight );
         if ( pTabStop )
         {
             cFill = ' ' != pTabStop->GetFill() ? pTabStop->GetFill() : 0;
@@ -166,17 +145,17 @@ SwTabPortion *SwTxtFormatter::NewTabPortion( SwTxtFormatInfo &rInf, bool bAuto )
         }
         else
         {
-            KSHORT nDefTabDist = aLineInf.GetDefTabStop();
-            if( KSHRT_MAX == nDefTabDist )
+            sal_uInt16 nDefTabDist = m_aLineInf.GetDefTabStop();
+            if( USHRT_MAX == nDefTabDist )
             {
                 const SvxTabStopItem& rTab =
-                    (const SvxTabStopItem &)pFrm->GetAttrSet()->
-                    GetPool()->GetDefaultItem( RES_PARATR_TABSTOP );
+                    static_cast<const SvxTabStopItem &>(m_pFrame->GetAttrSet()->
+                      GetPool()->GetDefaultItem( RES_PARATR_TABSTOP ));
                 if( rTab.Count() )
-                    nDefTabDist = (KSHORT)rTab[0].GetTabPos();
+                    nDefTabDist = (sal_uInt16)rTab[0].GetTabPos();
                 else
                     nDefTabDist = SVX_TAB_DEFDIST;
-                aLineInf.SetDefTabStop( nDefTabDist );
+                m_aLineInf.SetDefTabStop( nDefTabDist );
             }
             SwTwips nCount = nSearchPos;
 
@@ -188,8 +167,9 @@ SwTabPortion *SwTxtFormatter::NewTabPortion( SwTxtFormatInfo &rInf, bool bAuto )
             nNextPos = ( nCount < 0 || ( !nCount && nSearchPos <= 0 ) )
                        ? ( nCount * nDefTabDist )
                        : ( ( nCount + 1 ) * nDefTabDist );
+
             // --> FME 2004-09-21 #117919 Minimum tab stop width is 1 or 51 twips:
-            const SwTwips nMinimumTabWidth = pFrm->GetTxtNode()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::TAB_COMPAT) ? 0 : 50;
+            const SwTwips nMinimumTabWidth = m_pFrame->GetTextNode()->getIDocumentSettingAccess()->get(DocumentSettingId::TAB_COMPAT) ? 0 : 50;
             if( (  bRTL && nTabLeft - nNextPos >= nCurrentAbsPos - nMinimumTabWidth ) ||
                  ( !bRTL && nNextPos + nTabLeft <= nCurrentAbsPos + nMinimumTabWidth  ) )
             {
@@ -214,17 +194,17 @@ SwTabPortion *SwTxtFormatter::NewTabPortion( SwTxtFormatInfo &rInf, bool bAuto )
                     if ( bRTL )
                     {
                         Point aPoint( Left(), 0 );
-                        pFrm->SwitchLTRtoRTL( aPoint );
-                        nLeftMarginTabPos = pFrm->Frm().Right() - aPoint.X();
+                        m_pFrame->SwitchLTRtoRTL( aPoint );
+                        nLeftMarginTabPos = m_pFrame->Frame().Right() - aPoint.X();
                     }
                     else
                     {
-                        nLeftMarginTabPos = Left() - pFrm->Frm().Left();
+                        nLeftMarginTabPos = Left() - m_pFrame->Frame().Left();
                     }
                 }
-                if( pCurr->HasForcedLeftMargin() )
+                if( m_pCurr->HasForcedLeftMargin() )
                 {
-                    SwLinePortion* pPor = pCurr->GetPortion();
+                    SwLinePortion* pPor = m_pCurr->GetPortion();
                     while( pPor && !pPor->IsFlyPortion() )
                     {
                         pPor = pPor->GetPortion();
@@ -246,12 +226,12 @@ SwTabPortion *SwTxtFormatter::NewTabPortion( SwTxtFormatInfo &rInf, bool bAuto )
                 // a tab stop at the left margin can be applied. If this condition is
                 // not hold, it is overruled by compatibility option TAB_AT_LEFT_INDENT_FOR_PARA_IN_LIST.
                 const bool bTabAtLeftMarginAllowed =
-                    ( !aLineInf.IsListTabStopIncluded() ||
+                    ( !m_aLineInf.IsListTabStopIncluded() ||
                       !pTabStop ||
-                      nNextPos != aLineInf.GetListTabStopPosition() ) ||
+                      nNextPos != m_aLineInf.GetListTabStopPosition() ) ||
                     // compatibility option TAB_AT_LEFT_INDENT_FOR_PARA_IN_LIST:
-                    pFrm->GetTxtNode()->getIDocumentSettingAccess()->
-                        get(IDocumentSettingAccess::TAB_AT_LEFT_INDENT_FOR_PARA_IN_LIST);
+                    m_pFrame->GetTextNode()->getIDocumentSettingAccess()->
+                        get(DocumentSettingId::TAB_AT_LEFT_INDENT_FOR_PARA_IN_LIST);
                 if ( bTabAtLeftMarginAllowed )
                 {
                     if ( !pTabStop || eAdj == SVX_TAB_ADJUST_DEFAULT ||
@@ -267,15 +247,14 @@ SwTabPortion *SwTxtFormatter::NewTabPortion( SwTxtFormatInfo &rInf, bool bAuto )
 
         nNextPos += bRTL ? nLinePos - nTabLeft : nTabLeft - nLinePos;
         OSL_ENSURE( nNextPos >= 0, "GetTabStop: Don't go back!" );
-        nNewTabPos = KSHORT(nNextPos);
+        nNewTabPos = sal_uInt16(nNextPos);
     }
 
-    SwTabPortion *pTabPor = 0;
+    SwTabPortion *pTabPor = nullptr;
     if ( bAuto )
     {
         if ( SVX_TAB_ADJUST_DECIMAL == eAdj &&
-             // #127428#
-             1 == aLineInf.NumberOfTabStops() )
+             1 == m_aLineInf.NumberOfTabStops() )
             pTabPor = new SwAutoTabDecimalPortion( nNewTabPos, cDec, cFill );
     }
     else
@@ -300,7 +279,7 @@ SwTabPortion *SwTxtFormatter::NewTabPortion( SwTxtFormatInfo &rInf, bool bAuto )
         default:
             {
                 OSL_ENSURE( SVX_TAB_ADJUST_LEFT == eAdj || SVX_TAB_ADJUST_DEFAULT == eAdj,
-                    "+SwTxtFormatter::NewTabPortion: unknown adjustment" );
+                    "+SwTextFormatter::NewTabPortion: unknown adjustment" );
                 pTabPor = new SwTabLeftPortion( nNewTabPos, cFill, bAutoTabStop );
                 break;
             }
@@ -310,28 +289,18 @@ SwTabPortion *SwTxtFormatter::NewTabPortion( SwTxtFormatInfo &rInf, bool bAuto )
     return pTabPor;
 }
 
-/*************************************************************************
- *                SwTabPortion::SwTabPortion()
- *************************************************************************/
-
-// Die Basisklasse wird erstmal ohne alles initialisiert.
-
-
-SwTabPortion::SwTabPortion( const KSHORT nTabPosition, const sal_Unicode cFillChar, const bool bAutoTab )
-    : SwFixPortion( 0, 0 ), nTabPos(nTabPosition), cFill(cFillChar), bAutoTabStop( bAutoTab )
+/**
+ * The base class is initialized without setting anything
+ */
+SwTabPortion::SwTabPortion( const sal_uInt16 nTabPosition, const sal_Unicode cFillChar, const bool bAutoTab )
+    : SwFixPortion(), nTabPos(nTabPosition), cFill(cFillChar), bAutoTabStop( bAutoTab )
 {
     nLineLength = 1;
     OSL_ENSURE(!IsFilled() || ' ' != cFill, "SwTabPortion::CTOR: blanks ?!");
     SetWhichPor( POR_TAB );
 }
 
-/*************************************************************************
- *                 virtual SwTabPortion::Format()
- *************************************************************************/
-
-
-
-sal_Bool SwTabPortion::Format( SwTxtFormatInfo &rInf )
+bool SwTabPortion::Format( SwTextFormatInfo &rInf )
 {
     SwTabPortion *pLastTab = rInf.GetLastTab();
     if( pLastTab == this )
@@ -341,33 +310,21 @@ sal_Bool SwTabPortion::Format( SwTxtFormatInfo &rInf )
     return PreFormat( rInf );
 }
 
-/*************************************************************************
- *                 virtual SwTabPortion::FormatEOL()
- *************************************************************************/
-
-
-
-void SwTabPortion::FormatEOL( SwTxtFormatInfo &rInf )
+void SwTabPortion::FormatEOL( SwTextFormatInfo &rInf )
 {
     if( rInf.GetLastTab() == this && !IsTabLeftPortion() )
         PostFormat( rInf );
 }
 
-/*************************************************************************
- *                    SwTabPortion::PreFormat()
- *************************************************************************/
-
-
-
-sal_Bool SwTabPortion::PreFormat( SwTxtFormatInfo &rInf )
+bool SwTabPortion::PreFormat( SwTextFormatInfo &rInf )
 {
     OSL_ENSURE( rInf.X() <= GetTabPos(), "SwTabPortion::PreFormat: rush hour" );
 
     // Here we settle down ...
-    Fix( static_cast<sal_uInt16>(rInf.X()) );
+    SetFix( static_cast<sal_uInt16>(rInf.X()) );
 
-    const bool bTabCompat = rInf.GetTxtFrm()->GetTxtNode()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::TAB_COMPAT);
-    const bool bTabOverflow = rInf.GetTxtFrm()->GetTxtNode()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::TAB_OVERFLOW);
+    const bool bTabCompat = rInf.GetTextFrame()->GetTextNode()->getIDocumentSettingAccess()->get(DocumentSettingId::TAB_COMPAT);
+    const bool bTabOverflow = rInf.GetTextFrame()->GetTextNode()->getIDocumentSettingAccess()->get(DocumentSettingId::TAB_OVERFLOW);
 
     // The minimal width of a tab is one blank at least.
     // #i37686# In compatibility mode, the minimum width
@@ -378,9 +335,7 @@ sal_Bool SwTabPortion::PreFormat( SwTxtFormatInfo &rInf )
         // #i89179#
         // tab portion representing the list tab of a list label gets the
         // same font as the corresponding number portion
-        SAL_WNODEPRECATED_DECLARATIONS_PUSH
-        std::auto_ptr< SwFontSave > pSave( 0 );
-        SAL_WNODEPRECATED_DECLARATIONS_POP
+        std::unique_ptr< SwFontSave > pSave;
         if ( GetLen() == 0 &&
              rInf.GetLast() && rInf.GetLast()->InNumberGrp() &&
              static_cast<SwNumberPortion*>(rInf.GetLast())->HasFont() )
@@ -390,23 +345,23 @@ sal_Bool SwTabPortion::PreFormat( SwTxtFormatInfo &rInf )
             pSave.reset( new SwFontSave( rInf, const_cast<SwFont*>(pNumberPortionFont) ) );
         }
         OUString aTmp( ' ' );
-        SwTxtSizeInfo aInf( rInf, &aTmp );
-        nMinimumTabWidth = aInf.GetTxtSize().Width();
+        SwTextSizeInfo aInf( rInf, &aTmp );
+        nMinimumTabWidth = aInf.GetTextSize().Width();
     }
     PrtWidth( nMinimumTabWidth );
 
     // Break tab stop to next line if:
     // 1. Minmal width does not fit to line anymore.
     // 2. An underflow event was called for the tab portion.
-    bool bFull = ( bTabCompat && rInf.IsUnderFlow() ) ||
+    bool bFull = ( bTabCompat && rInf.IsUnderflow() ) ||
                      ( rInf.Width() <= rInf.X() + PrtWidth() && rInf.X() <= rInf.Width() ) ;
 
     // #95477# Rotated tab stops get the width of one blank
-    const sal_uInt16 nDir = rInf.GetFont()->GetOrientation( rInf.GetTxtFrm()->IsVertical() );
+    const sal_uInt16 nDir = rInf.GetFont()->GetOrientation( rInf.GetTextFrame()->IsVertical() );
 
     if( ! bFull && 0 == nDir )
     {
-        const MSHORT nWhich = GetWhichPor();
+        const sal_uInt16 nWhich = GetWhichPor();
         switch( nWhich )
         {
             case POR_TABRIGHT:
@@ -415,7 +370,7 @@ sal_Bool SwTabPortion::PreFormat( SwTxtFormatInfo &rInf )
             {
                 if( POR_TABDECIMAL == nWhich )
                     rInf.SetTabDecimal(
-                        ((SwTabDecimalPortion*)this)->GetTabDecimal());
+                        static_cast<SwTabDecimalPortion*>(this)->GetTabDecimal());
                 rInf.SetLastTab( this );
                 break;
             }
@@ -427,19 +382,19 @@ sal_Bool SwTabPortion::PreFormat( SwTxtFormatInfo &rInf )
                 // In tabulator compatibility mode, we reset the bFull flag
                 // if the tabulator is at the end of the paragraph and the
                 // tab stop position is outside the frame:
-                bool bAtParaEnd = rInf.GetIdx() + GetLen() == rInf.GetTxt().getLength();
+                bool bAtParaEnd = rInf.GetIdx() + GetLen() == rInf.GetText().getLength();
                 if ( bFull && bTabCompat &&
                      ( ( bTabOverflow && ( rInf.IsTabOverflow() || !IsAutoTabStop() ) ) || bAtParaEnd ) &&
-                     GetTabPos() >= rInf.GetTxtFrm()->Frm().Width() )
+                     GetTabPos() >= rInf.GetTextFrame()->Frame().Width() )
                 {
                     bFull = false;
                     if ( bTabOverflow && !IsAutoTabStop() )
-                        rInf.SetTabOverflow( sal_True );
+                        rInf.SetTabOverflow( true );
                 }
 
                 break;
             }
-            default: OSL_ENSURE( !this, "SwTabPortion::PreFormat: unknown adjustment" );
+            default: OSL_ENSURE( false, "SwTabPortion::PreFormat: unknown adjustment" );
         }
     }
 
@@ -460,48 +415,42 @@ sal_Bool SwTabPortion::PreFormat( SwTxtFormatInfo &rInf )
             Width( 0 );
             SetLen( 0 );
             SetAscent( 0 );
-            SetPortion( NULL ); //?????
+            SetPortion( nullptr ); //?????
         }
-        return sal_True;
+        return true;
     }
     else
     {
         // A trick with impact: The new Tabportions now behave like
-        // FlyFrms, located in the line - including adjustment !
+        // FlyFrames, located in the line - including adjustment !
         SetFixWidth( PrtWidth() );
-        return sal_False;
+        return false;
     }
 }
 
-/*************************************************************************
- *                      SwTabPortion::PostFormat()
- *************************************************************************/
-
-
-
-sal_Bool SwTabPortion::PostFormat( SwTxtFormatInfo &rInf )
+bool SwTabPortion::PostFormat( SwTextFormatInfo &rInf )
 {
-    const bool bTabOverMargin = rInf.GetTxtFrm()->GetTxtNode()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::TAB_OVER_MARGIN);
+    const bool bTabOverMargin = rInf.GetTextFrame()->GetTextNode()->getIDocumentSettingAccess()->get(DocumentSettingId::TAB_OVER_MARGIN);
     // If the tab position is larger than the right margin, it gets scaled down by default.
     // However, if compat mode enabled, we allow tabs to go over the margin: the rest of the paragraph is not broken into lines.
-    const KSHORT nRight = bTabOverMargin ? GetTabPos() : std::min(GetTabPos(), rInf.Width());
+    const sal_uInt16 nRight = bTabOverMargin ? GetTabPos() : std::min(GetTabPos(), rInf.Width());
     const SwLinePortion *pPor = GetPortion();
 
-    KSHORT nPorWidth = 0;
+    sal_uInt16 nPorWidth = 0;
     while( pPor )
     {
         nPorWidth = nPorWidth + pPor->Width();
         pPor = pPor->GetPortion();
     }
 
-    const MSHORT nWhich = GetWhichPor();
+    const sal_uInt16 nWhich = GetWhichPor();
     OSL_ENSURE( POR_TABLEFT != nWhich, "SwTabPortion::PostFormat: already formatted" );
-    const bool bTabCompat = rInf.GetTxtFrm()->GetTxtNode()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::TAB_COMPAT);
+    const bool bTabCompat = rInf.GetTextFrame()->GetTextNode()->getIDocumentSettingAccess()->get(DocumentSettingId::TAB_COMPAT);
 
     // #127428# Abandon dec. tab position if line is full
     if ( bTabCompat && POR_TABDECIMAL == nWhich )
     {
-        KSHORT nPrePorWidth = static_cast<const SwTabDecimalPortion*>(this)->GetWidthOfPortionsUpToDecimalPosition();
+        sal_uInt16 nPrePorWidth = static_cast<const SwTabDecimalPortion*>(this)->GetWidthOfPortionsUpToDecimalPosition();
 
         // no value was set => no decimal character was found
         if ( USHRT_MAX != nPrePorWidth )
@@ -519,41 +468,38 @@ sal_Bool SwTabPortion::PostFormat( SwTxtFormatInfo &rInf )
     {
         // centered tabs are problematic:
         // We have to detect how much fits into the line.
-        KSHORT nNewWidth = nPorWidth /2;
+        sal_uInt16 nNewWidth = nPorWidth /2;
         if( nNewWidth > rInf.Width() - nRight )
             nNewWidth = nPorWidth - (rInf.Width() - nRight);
         nPorWidth = nNewWidth;
     }
 
-    const KSHORT nDiffWidth = nRight - Fix();
+    const sal_uInt16 nDiffWidth = nRight - GetFix();
 
     if( nDiffWidth > nPorWidth )
     {
-        const KSHORT nOldWidth = GetFixWidth();
-        const KSHORT nAdjDiff = nDiffWidth - nPorWidth;
+        const sal_uInt16 nOldWidth = GetFixWidth();
+        const sal_uInt16 nAdjDiff = nDiffWidth - nPorWidth;
         if( nAdjDiff > GetFixWidth() )
             PrtWidth( nAdjDiff );
-        // Dont be afraid: we have to move rInf further.
+        // Don't be afraid: we have to move rInf further.
         // The right-tab till now only had the width of one blank.
         // Now that we stretched, the difference had to be added to rInf.X() !
         rInf.X( rInf.X() + PrtWidth() - nOldWidth );
     }
     SetFixWidth( PrtWidth() );
     // reset last values
-    rInf.SetLastTab(0);
+    rInf.SetLastTab(nullptr);
     if( POR_TABDECIMAL == nWhich )
         rInf.SetTabDecimal(0);
 
     return rInf.Width() <= rInf.X();
 }
 
-/*************************************************************************
- *                virtual SwTabPortion::Paint()
- *
+/**
  * Ex: LineIter::DrawTab()
- *************************************************************************/
-
-void SwTabPortion::Paint( const SwTxtPaintInfo &rInf ) const
+ */
+void SwTabPortion::Paint( const SwTextPaintInfo &rInf ) const
 {
 #if OSL_DEBUG_LEVEL > 1
     // We want to view the fixed width
@@ -562,19 +508,17 @@ void SwTabPortion::Paint( const SwTxtPaintInfo &rInf ) const
         !rInf.GetOpt().IsReadonly() && \
         SwViewOption::IsFieldShadings()    )
     {
-        const KSHORT nTmpWidth = PrtWidth();
-        ((SwTabPortion*)this)->PrtWidth( GetFixWidth() );
+        const sal_uInt16 nTmpWidth = PrtWidth();
+        const_cast<SwTabPortion*>(this)->PrtWidth( GetFixWidth() );
         rInf.DrawViewOpt( *this, POR_TAB );
-        ((SwTabPortion*)this)->PrtWidth( nTmpWidth );
+        const_cast<SwTabPortion*>(this)->PrtWidth( nTmpWidth );
     }
 #endif
 
     // #i89179#
     // tab portion representing the list tab of a list label gets the
     // same font as the corresponding number portion
-    SAL_WNODEPRECATED_DECLARATIONS_PUSH
-    std::auto_ptr< SwFontSave > pSave( 0 );
-    SAL_WNODEPRECATED_DECLARATIONS_POP
+    std::unique_ptr< SwFontSave > pSave;
     bool bAfterNumbering = false;
     if ( GetLen() == 0 )
     {
@@ -608,54 +552,48 @@ void SwTabPortion::Paint( const SwTxtPaintInfo &rInf ) const
             rInf.DrawTab( *this );
     }
 
-    // 6842: Tabs should be underlined at once.
+    // Tabs should be underlined at once
     if( rInf.GetFont()->IsPaintBlank() )
     {
-        // tabs with filling / filled tabs
-        const KSHORT nCharWidth = rInf.GetTxtSize(OUString(' ')).Width();
-        // robust:
+        // Tabs with filling/filled tabs
+        const sal_uInt16 nCharWidth = rInf.GetTextSize(OUString(' ')).Width();
+
+        // Robust:
         if( nCharWidth )
         {
-            // 6864: always with kerning, also on printer!
-            KSHORT nChar = Width() / nCharWidth;
+            // Always with kerning, also on printer!
+            sal_uInt16 nChar = Width() / nCharWidth;
             OUStringBuffer aBuf;
             comphelper::string::padToLength(aBuf, nChar, ' ');
-            rInf.DrawText(aBuf.makeStringAndClear(), *this, 0, nChar, sal_True);
+            rInf.DrawText(aBuf.makeStringAndClear(), *this, 0, nChar, true);
         }
     }
 
     // Display fill characters
     if( IsFilled() )
     {
-        // tabs with filling / filled tabs
-        const KSHORT nCharWidth = rInf.GetTxtSize(OUString(cFill)).Width();
+        // Tabs with filling/filled tabs
+        const sal_uInt16 nCharWidth = rInf.GetTextSize(OUString(cFill)).Width();
         OSL_ENSURE( nCharWidth, "!SwTabPortion::Paint: sophisticated tabchar" );
-        // robust:
+
+        // Robust:
         if( nCharWidth )
         {
-            // 6864: always with kerning, also on printer!
-            KSHORT nChar = Width() / nCharWidth;
+            // Always with kerning, also on printer!
+            sal_uInt16 nChar = Width() / nCharWidth;
             if ( cFill == '_' )
-                ++nChar; // to avoid gaps (Bug 13430)
+                ++nChar; // to avoid gaps
             OUStringBuffer aBuf;
             comphelper::string::padToLength(aBuf, nChar, cFill);
-            rInf.DrawText(aBuf.makeStringAndClear(), *this, 0, nChar, sal_True);
+            rInf.DrawText(aBuf.makeStringAndClear(), *this, 0, nChar, true);
         }
     }
 }
 
-/*************************************************************************
- *                virtual SwAutoTabDecimalPortion::Paint()
- *************************************************************************/
-
-void SwAutoTabDecimalPortion::Paint( const SwTxtPaintInfo & ) const
+void SwAutoTabDecimalPortion::Paint( const SwTextPaintInfo & ) const
 {
 }
 
-/*************************************************************************
- *              virtual SwTabPortion::HandlePortion()
- *************************************************************************/
-
 void SwTabPortion::HandlePortion( SwPortionHandler& rPH ) const
 {
     rPH.Text( GetLen(), GetWhichPor(), Height(), Width() );
