@@ -34,8 +34,8 @@
 #include "app.hrc"
 #include "table.hrc"
 #include "swabstdlg.hxx"
-#include <boost/scoped_ptr.hpp>
 #include <swuiexp.hxx>
+#include <memory>
 
 //keep the state of the buttons on runtime
 static int nSaveButtonState = -1; // 0: tab, 1: semicolon, 2: paragraph, 3: other, -1: not yet used
@@ -43,8 +43,8 @@ static bool bIsKeepColumn = true;
 static sal_Unicode uOther = ',';
 
 void SwConvertTableDlg::GetValues(  sal_Unicode& rDelim,
-                                    SwInsertTableOptions& rInsTblOpts,
-                                    SwTableAutoFmt const*& prTAFmt )
+                                    SwInsertTableOptions& rInsTableOpts,
+                                    SwTableAutoFormat const*& prTAFormat )
 {
     if( mpTabBtn->IsChecked() )
     {
@@ -81,22 +81,22 @@ void SwConvertTableDlg::GetValues(  sal_Unicode& rDelim,
     if (mpHeaderCB->IsChecked())
         nInsMode |= tabopts::HEADLINE;
     if (mpRepeatHeaderCB->IsEnabled() && mpRepeatHeaderCB->IsChecked())
-        rInsTblOpts.mnRowsToRepeat = sal_uInt16( mpRepeatHeaderNF->GetValue() );
+        rInsTableOpts.mnRowsToRepeat = sal_uInt16( mpRepeatHeaderNF->GetValue() );
     else
-        rInsTblOpts.mnRowsToRepeat = 0;
+        rInsTableOpts.mnRowsToRepeat = 0;
     if (!mpDontSplitCB->IsChecked())
         nInsMode |= tabopts::SPLIT_LAYOUT;
 
-    if( pTAutoFmt )
-        prTAFmt = new SwTableAutoFmt( *pTAutoFmt );
+    if( pTAutoFormat )
+        prTAFormat = new SwTableAutoFormat( *pTAutoFormat );
 
-    rInsTblOpts.mnInsMode = nInsMode;
+    rInsTableOpts.mnInsMode = nInsMode;
 }
 
 SwConvertTableDlg::SwConvertTableDlg( SwView& rView, bool bToTable )
     : SfxModalDialog(&rView.GetViewFrame()->GetWindow(), "ConvertTextTableDialog", "modules/swriter/ui/converttexttable.ui" )
     , sConvertTextTable(SW_RES(STR_CONVERT_TEXT_TABLE))
-    , pTAutoFmt(0)
+    , pTAutoFormat(nullptr)
     , pShell(&rView.GetWrtShell())
 {
     get(mpTabBtn, "tabs");
@@ -112,7 +112,7 @@ SwConvertTableDlg::SwConvertTableDlg( SwView& rView, bool bToTable )
     get(mpRepeatHeaderNF, "repeatheadersb");
     get(mpDontSplitCB, "dontsplitcb");
     get(mpBorderCB, "bordercb");
-    get(mpAutoFmtBtn, "autofmt");
+    get(mpAutoFormatBtn, "autofmt");
 
     if(nSaveButtonState > -1)
     {
@@ -135,8 +135,8 @@ SwConvertTableDlg::SwConvertTableDlg( SwView& rView, bool bToTable )
     if( bToTable )
     {
         SetText( sConvertTextTable );
-        mpAutoFmtBtn->SetClickHdl(LINK(this, SwConvertTableDlg, AutoFmtHdl));
-        mpAutoFmtBtn->Show();
+        mpAutoFormatBtn->SetClickHdl(LINK(this, SwConvertTableDlg, AutoFormatHdl));
+        mpAutoFormatBtn->Show();
         mpKeepColumn->Show();
         mpKeepColumn->Enable( mpTabBtn->IsChecked() );
     }
@@ -147,7 +147,7 @@ SwConvertTableDlg::SwConvertTableDlg( SwView& rView, bool bToTable )
     }
     mpKeepColumn->SaveValue();
 
-    Link aLk( LINK(this, SwConvertTableDlg, BtnHdl) );
+    Link<Button*,void> aLk( LINK(this, SwConvertTableDlg, BtnHdl) );
     mpTabBtn->SetClickHdl( aLk );
     mpSemiBtn->SetClickHdl( aLk );
     mpParaBtn->SetClickHdl( aLk );
@@ -158,13 +158,13 @@ SwConvertTableDlg::SwConvertTableDlg( SwView& rView, bool bToTable )
 
     bool bHTMLMode = 0 != (::GetHtmlMode(rView.GetDocShell())&HTMLMODE_ON);
 
-    SwInsertTableOptions aInsOpts = pModOpt->GetInsTblFlags(bHTMLMode);
-    sal_uInt16 nInsTblFlags = aInsOpts.mnInsMode;
+    SwInsertTableOptions aInsOpts = pModOpt->GetInsTableFlags(bHTMLMode);
+    sal_uInt16 nInsTableFlags = aInsOpts.mnInsMode;
 
-    mpHeaderCB->Check( 0 != (nInsTblFlags & tabopts::HEADLINE) );
+    mpHeaderCB->Check( 0 != (nInsTableFlags & tabopts::HEADLINE) );
     mpRepeatHeaderCB->Check(aInsOpts.mnRowsToRepeat > 0);
-    mpDontSplitCB->Check( 0 == (nInsTblFlags & tabopts::SPLIT_LAYOUT));
-    mpBorderCB->Check( 0!= (nInsTblFlags & tabopts::DEFAULT_BORDER) );
+    mpDontSplitCB->Check( 0 == (nInsTableFlags & tabopts::SPLIT_LAYOUT));
+    mpBorderCB->Check( 0!= (nInsTableFlags & tabopts::DEFAULT_BORDER) );
 
     mpHeaderCB->SetClickHdl(LINK(this, SwConvertTableDlg, CheckBoxHdl));
     mpRepeatHeaderCB->SetClickHdl(LINK(this, SwConvertTableDlg, ReapeatHeaderCheckBoxHdl));
@@ -174,22 +174,41 @@ SwConvertTableDlg::SwConvertTableDlg( SwView& rView, bool bToTable )
 
 SwConvertTableDlg:: ~SwConvertTableDlg()
 {
-    delete pTAutoFmt;
+    disposeOnce();
 }
 
-IMPL_LINK( SwConvertTableDlg, AutoFmtHdl, PushButton*, pButton )
+void SwConvertTableDlg::dispose()
+{
+    delete pTAutoFormat;
+    mpTabBtn.clear();
+    mpSemiBtn.clear();
+    mpParaBtn.clear();
+    mpOtherBtn.clear();
+    mpOtherEd.clear();
+    mpKeepColumn.clear();
+    mpOptions.clear();
+    mpHeaderCB.clear();
+    mpRepeatHeaderCB.clear();
+    mpRepeatRows.clear();
+    mpRepeatHeaderNF.clear();
+    mpDontSplitCB.clear();
+    mpBorderCB.clear();
+    mpAutoFormatBtn.clear();
+    SfxModalDialog::dispose();
+}
+
+IMPL_LINK_TYPED( SwConvertTableDlg, AutoFormatHdl, Button*, pButton, void )
 {
     SwAbstractDialogFactory* pFact = swui::GetFactory();
     OSL_ENSURE(pFact, "SwAbstractDialogFactory fail!");
 
-    boost::scoped_ptr<AbstractSwAutoFormatDlg> pDlg(pFact->CreateSwAutoFormatDlg(pButton, pShell, false, pTAutoFmt));
+    std::unique_ptr<AbstractSwAutoFormatDlg> pDlg(pFact->CreateSwAutoFormatDlg(pButton, pShell, false, pTAutoFormat));
     OSL_ENSURE(pDlg, "Dialog creation failed!");
     if( RET_OK == pDlg->Execute())
-        pDlg->FillAutoFmtOfIndex( pTAutoFmt );
-    return 0;
+        pDlg->FillAutoFormatOfIndex( pTAutoFormat );
 }
 
-IMPL_LINK( SwConvertTableDlg, BtnHdl, Button*, pButton )
+IMPL_LINK_TYPED( SwConvertTableDlg, BtnHdl, Button*, pButton, void )
 {
     if( pButton == mpTabBtn )
         mpKeepColumn->SetState( mpKeepColumn->GetSavedValue() );
@@ -197,26 +216,22 @@ IMPL_LINK( SwConvertTableDlg, BtnHdl, Button*, pButton )
     {
         if( mpKeepColumn->IsEnabled() )
             mpKeepColumn->SaveValue();
-        mpKeepColumn->Check( true );
+        mpKeepColumn->Check();
     }
     mpKeepColumn->Enable( mpTabBtn->IsChecked() );
     mpOtherEd->Enable( mpOtherBtn->IsChecked() );
-    return 0;
 }
 
-IMPL_LINK_NOARG(SwConvertTableDlg, CheckBoxHdl)
+IMPL_LINK_NOARG_TYPED(SwConvertTableDlg, CheckBoxHdl, Button*, void)
 {
     mpRepeatHeaderCB->Enable(mpHeaderCB->IsChecked());
     ReapeatHeaderCheckBoxHdl();
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(SwConvertTableDlg, ReapeatHeaderCheckBoxHdl)
+IMPL_LINK_NOARG_TYPED(SwConvertTableDlg, ReapeatHeaderCheckBoxHdl, Button*, void)
 {
     bool bEnable = mpHeaderCB->IsChecked() && mpRepeatHeaderCB->IsChecked();
     mpRepeatRows->Enable(bEnable);
-    return 0;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
