@@ -73,14 +73,14 @@ void SwChapterNumRules::Save()
 
 SwChapterNumRules::~SwChapterNumRules()
 {
-    for( sal_uInt16 i = 0; i < nMaxRules; ++i )
-        delete pNumRules[i];
+    for(SwNumRulesWithName* pNumRule : pNumRules)
+        delete pNumRule;
 }
 
 void  SwChapterNumRules::Init()
 {
-    for(sal_uInt16 i = 0; i < nMaxRules; ++i )
-        pNumRules[i] = nullptr;
+    for(SwNumRulesWithName* & rpNumRule : pNumRules)
+        rpNumRule = nullptr;
 
     OUString sNm(CHAPTER_FILENAME);
     SvtPathOptions aOpt;
@@ -117,7 +117,7 @@ SwNumRulesWithName::SwNumRulesWithName( const SwNumRule &rCopy,
     {
         const SwNumFormat* pFormat = rCopy.GetNumFormat( n );
         if( pFormat )
-            aFormats[ n ] = new _SwNumFormatGlobal( *pFormat );
+            aFormats[ n ] = new SwNumFormatGlobal( *pFormat );
         else
             aFormats[ n ] = nullptr;
     }
@@ -136,11 +136,11 @@ SwNumRulesWithName::SwNumRulesWithName( const SwNumRulesWithName& rCopy )
 
 SwNumRulesWithName::~SwNumRulesWithName()
 {
-    for( int n = 0; n < MAXLEVEL; ++n )
-        delete aFormats[ n ];
+    for(SwNumFormatGlobal* p : aFormats)
+        delete p;
 }
 
-const SwNumRulesWithName& SwNumRulesWithName::operator=(const SwNumRulesWithName &rCopy)
+SwNumRulesWithName& SwNumRulesWithName::operator=(const SwNumRulesWithName &rCopy)
 {
     if( this != &rCopy )
     {
@@ -149,9 +149,9 @@ const SwNumRulesWithName& SwNumRulesWithName::operator=(const SwNumRulesWithName
         {
             delete aFormats[ n ];
 
-            _SwNumFormatGlobal* pFormat = rCopy.aFormats[ n ];
+            SwNumFormatGlobal* pFormat = rCopy.aFormats[ n ];
             if( pFormat )
-                aFormats[ n ] = new _SwNumFormatGlobal( *pFormat );
+                aFormats[ n ] = new SwNumFormatGlobal( *pFormat );
             else
                 aFormats[ n ] = nullptr;
         }
@@ -166,7 +166,7 @@ void SwNumRulesWithName::MakeNumRule( SwWrtShell& rSh, SwNumRule& rChg ) const
     rChg.SetAutoRule( false );
     for( sal_uInt16 n = 0; n < MAXLEVEL; ++n )
     {
-        _SwNumFormatGlobal* pFormat = aFormats[ n ];
+        SwNumFormatGlobal* pFormat = aFormats[ n ];
         if( nullptr != pFormat)
         {
             SwNumFormat aNew;
@@ -187,13 +187,13 @@ void SwNumRulesWithName::SetNumFormat(
         size_t const nIndex, SwNumFormat const& rNumFormat, OUString const& rName)
 {
     delete aFormats[nIndex];
-    aFormats[nIndex] = new _SwNumFormatGlobal(rNumFormat);
+    aFormats[nIndex] = new SwNumFormatGlobal(rNumFormat);
     aFormats[nIndex]->sCharFormatName = rName;
     aFormats[nIndex]->nCharPoolId = USHRT_MAX;
     aFormats[nIndex]->m_Items.clear();
 }
 
-SwNumRulesWithName::_SwNumFormatGlobal::_SwNumFormatGlobal( const SwNumFormat& rFormat )
+SwNumRulesWithName::SwNumFormatGlobal::SwNumFormatGlobal( const SwNumFormat& rFormat )
     : aFormat( rFormat ), nCharPoolId( USHRT_MAX )
 {
     // relative gaps?????
@@ -220,7 +220,7 @@ SwNumRulesWithName::_SwNumFormatGlobal::_SwNumFormatGlobal( const SwNumFormat& r
     }
 }
 
-SwNumRulesWithName::_SwNumFormatGlobal::_SwNumFormatGlobal( const _SwNumFormatGlobal& rFormat )
+SwNumRulesWithName::SwNumFormatGlobal::SwNumFormatGlobal( const SwNumFormatGlobal& rFormat )
     :
     aFormat( rFormat.aFormat ),
     sCharFormatName( rFormat.sCharFormatName ),
@@ -232,11 +232,11 @@ SwNumRulesWithName::_SwNumFormatGlobal::_SwNumFormatGlobal( const _SwNumFormatGl
     }
 }
 
-SwNumRulesWithName::_SwNumFormatGlobal::~_SwNumFormatGlobal()
+SwNumRulesWithName::SwNumFormatGlobal::~SwNumFormatGlobal()
 {
 }
 
-void SwNumRulesWithName::_SwNumFormatGlobal::ChgNumFormat( SwWrtShell& rSh,
+void SwNumRulesWithName::SwNumFormatGlobal::ChgNumFormat( SwWrtShell& rSh,
                             SwNumFormat& rNew ) const
 {
     SwCharFormat* pFormat = nullptr;
