@@ -41,11 +41,9 @@ namespace package_ucp
 {
 
 
-
 // class Package.
 
 
-
 class Package : public cppu::OWeakObject,
                 public container::XHierarchicalNameAccess
 {
@@ -144,36 +142,29 @@ css::uno::Any SAL_CALL ContentProvider::queryInterface( const css::uno::Type & r
 // XTypeProvider methods.
 
 
-
 XTYPEPROVIDER_IMPL_3( ContentProvider,
                       lang::XTypeProvider,
                       lang::XServiceInfo,
                       ucb::XContentProvider );
 
 
-
 // XServiceInfo methods.
 
 
-
 XSERVICEINFO_IMPL_1_CTX( ContentProvider,
                      OUString( "com.sun.star.comp.ucb.PackageContentProvider" ),
                      "com.sun.star.ucb.PackageContentProvider" );
 
 
-
 // Service factory implementation.
 
 
-
 ONE_INSTANCE_SERVICE_FACTORY_IMPL( ContentProvider );
 
 
-
 // XContentProvider methods.
 
 
-
 // virtual
 uno::Reference< ucb::XContent > SAL_CALL ContentProvider::queryContent(
             const uno::Reference< ucb::XContentIdentifier >& Identifier )
@@ -210,11 +201,9 @@ uno::Reference< ucb::XContent > SAL_CALL ContentProvider::queryContent(
 }
 
 
-
 // Other methods.
 
 
-
 uno::Reference< container::XHierarchicalNameAccess >
 ContentProvider::createPackage( const PackageUri & rURI )
 {
@@ -262,7 +251,7 @@ ContentProvider::createPackage( const PackageUri & rURI )
 }
 
 
-bool ContentProvider::removePackage( const OUString & rName )
+void ContentProvider::removePackage( const OUString & rName )
 {
     osl::MutexGuard aGuard( m_aMutex );
 
@@ -272,10 +261,9 @@ bool ContentProvider::removePackage( const OUString & rName )
         if ( it != m_pPackages->end() )
         {
             m_pPackages->erase( it );
-            return true;
+            return;
         }
     }
-    return false;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
