@@ -74,7 +74,6 @@ public:
 typedef std::pair< WildCard, WildCard > NoProxyListEntry;
 
 
-
 class HostnameCache
 {
     typedef std::pair< OUString, OUString > HostListEntry;
@@ -156,13 +155,9 @@ private:
 };
 
 
-
-
 // WildCard Implementation.
 
 
-
-
 bool WildCard::Matches( const OUString& rString ) const
 {
     OString aString
@@ -195,7 +190,7 @@ bool WildCard::Matches( const OUString& rString ) const
                 else
                     break;
 
-                // Note: fall-through are intended!
+                SAL_FALLTHROUGH;
 
             case '*':
                 while ( *pWild == '*' )
@@ -287,13 +282,9 @@ bool getConfigInt32Value(
 }
 
 
-
-
 // InternetProxyDecider_Impl Implementation.
 
 
-
-
 InternetProxyDecider_Impl::InternetProxyDecider_Impl(
     const uno::Reference< uno::XComponentContext >& rxContext )
     : m_nProxyType( 0 ),
@@ -529,7 +520,6 @@ const InternetProxyServer & InternetProxyDecider_Impl::getProxy(
         // in:   staroffice-doc.germany.sun.com -> full: xyz.germany.sun.com
 
 
-
         if ( !shouldUseProxy( aFullyQualifiedHost, nPort, true ) )
             return m_aEmptyProxy;
     }
@@ -777,13 +767,9 @@ void InternetProxyDecider_Impl::setNoProxyList(
 } // namespace proxydecider_impl
 
 
-
-
 // InternetProxyDecider Implementation.
 
 
-
-
 InternetProxyDecider::InternetProxyDecider(
     const uno::Reference< uno::XComponentContext>& rxContext )
 : m_pImpl( new proxydecider_impl::InternetProxyDecider_Impl( rxContext ) )
