@@ -21,14 +21,17 @@
 
 #include <vcl/opengl/OpenGLHelper.hxx>
 
-#include "vcl/bitmap.hxx"
-#include "vcl/checksum.hxx"
-#include "vcl/outdev.hxx"
-#include "vcl/salbtype.hxx"
+#include <vcl/bitmap.hxx>
+#include <vcl/checksum.hxx>
+#include <vcl/outdev.hxx>
+#include <vcl/salbtype.hxx>
 #include "svdata.hxx"
 #include "salgdi.hxx"
 #include "vcleventlisteners.hxx"
-#include "vcl/lazydelete.hxx"
+#include <vcl/lazydelete.hxx>
+
+#include <o3tl/make_unique.hxx>
+#include <o3tl/make_shared.hxx>
 
 #include "opengl/zone.hxx"
 #include "opengl/program.hxx"
@@ -52,7 +55,7 @@ inline bool determineTextureFormat(sal_uInt16 nBits, GLenum& nFormat, GLenum& nT
         nType = GL_UNSIGNED_BYTE;
         return true;
     case 16:
-#ifdef WNT
+#ifdef _WIN32
         nFormat = GL_BGR;
 #else
         nFormat = GL_RGB;
@@ -60,7 +63,7 @@ inline bool determineTextureFormat(sal_uInt16 nBits, GLenum& nFormat, GLenum& nT
         nType = GL_UNSIGNED_SHORT_5_6_5;
         return true;
     case 24:
-#ifdef WNT
+#ifdef _WIN32
         nFormat = GL_BGR;
 #else
         nFormat = GL_RGB;
@@ -68,7 +71,7 @@ inline bool determineTextureFormat(sal_uInt16 nBits, GLenum& nFormat, GLenum& nT
         nType = GL_UNSIGNED_BYTE;
         return true;
     case 32:
-#ifdef WNT
+#ifdef _WIN32
         nFormat = GL_BGRA;
 #else
         nFormat = GL_RGBA;
@@ -203,12 +206,12 @@ bool OpenGLSalBitmap::Create( const SalBitmap& rSalBmp, sal_uInt16 nNewBitCount
         mbDirtyTexture = false;
 
         // be careful here, we are share & reference-count the
-        // maUserBuffer, BUT this Create() is called from
+        // mpUserBuffer, BUT this Create() is called from
         // Bitmap::ImplMakeUnique().
         // Consequently, there might be cases when this needs to be made
         // unique later (when we don't do that right away here), like when
         // using the BitmapWriteAccess.
-        maUserBuffer = rSourceBitmap.maUserBuffer;
+        mpUserBuffer = rSourceBitmap.mpUserBuffer;
 
         return true;
     }
@@ -239,7 +242,7 @@ void OpenGLSalBitmap::Destroy()
     VCL_GL_INFO("Destroy OpenGLSalBitmap texture:" << maTexture.Id());
     maPendingOps.clear();
     maTexture = OpenGLTexture();
-    maUserBuffer.reset();
+    mpUserBuffer.reset();
 }
 
 bool OpenGLSalBitmap::AllocateUserData()
@@ -261,9 +264,9 @@ bool OpenGLSalBitmap::AllocateUserData()
 #if OSL_DEBUG_LEVEL > 0
             nToAllocate += sizeof(CANARY);
 #endif
-            maUserBuffer.reset( new sal_uInt8[nToAllocate] );
+            mpUserBuffer = o3tl::make_shared_array<sal_uInt8>(nToAllocate);
 #if OSL_DEBUG_LEVEL > 0
-            memcpy(maUserBuffer.get() + nToAllocate - sizeof(CANARY),
+            memcpy(mpUserBuffer.get() + nToAllocate - sizeof(CANARY),
                    CANARY, sizeof(CANARY));
 #endif
             alloc = true;
@@ -273,18 +276,18 @@ bool OpenGLSalBitmap::AllocateUserData()
     if (!alloc)
     {
         SAL_WARN("vcl.opengl", "bad alloc " << mnBytesPerRow << "x" << mnHeight);
-        maUserBuffer.reset( static_cast<sal_uInt8*>(nullptr) );
+        mpUserBuffer.reset();
         mnBytesPerRow = 0;
     }
 #ifdef DBG_UTIL
     else
     {
         for (size_t i = 0; i < size_t(mnBytesPerRow * mnHeight); i++)
-            maUserBuffer.get()[i] = (i & 0xFF);
+            mpUserBuffer.get()[i] = (i & 0xFF);
     }
 #endif
 
-    return maUserBuffer.get() != nullptr;
+    return mpUserBuffer.get() != nullptr;
 }
 
 namespace {
@@ -394,17 +397,17 @@ void lclInstantiateTexture(OpenGLTexture& rTexture, const int nWidth, const int
         TextureAtlasVector &sTextureAtlases = *gTextureAtlases.get();
         if (sTextureAtlases.empty())
         {
-            sTextureAtlases.push_back(std::unique_ptr<FixedTextureAtlasManager>(new FixedTextureAtlasManager(8, 8, 16)));
-            sTextureAtlases.push_back(std::unique_ptr<FixedTextureAtlasManager>(new FixedTextureAtlasManager(8, 8, 24)));
-            sTextureAtlases.push_back(std::unique_ptr<FixedTextureAtlasManager>(new FixedTextureAtlasManager(8, 8, 32)));
-            sTextureAtlases.push_back(std::unique_ptr<FixedTextureAtlasManager>(new FixedTextureAtlasManager(8, 8, 48)));
-            sTextureAtlases.push_back(std::unique_ptr<FixedTextureAtlasManager>(new FixedTextureAtlasManager(8, 8, 64)));
+            sTextureAtlases.push_back(o3tl::make_unique<FixedTextureAtlasManager>(8, 8, 16));
+            sTextureAtlases.push_back(o3tl::make_unique<FixedTextureAtlasManager>(8, 8, 24));
+            sTextureAtlases.push_back(o3tl::make_unique<FixedTextureAtlasManager>(8, 8, 32));
+            sTextureAtlases.push_back(o3tl::make_unique<FixedTextureAtlasManager>(8, 8, 48));
+            sTextureAtlases.push_back(o3tl::make_unique<FixedTextureAtlasManager>(8, 8, 64));
         }
-        for (size_t i = 0; i < sTextureAtlases.size(); i++)
+        for (std::unique_ptr<FixedTextureAtlasManager> & pTextureAtlas : sTextureAtlases)
         {
-            if (nWidth == sTextureAtlases[i]->GetSubtextureSize())
+            if (nWidth == pTextureAtlas->GetSubtextureSize())
             {
-                rTexture = sTextureAtlases[i]->InsertBuffer(nWidth, nHeight, nFormat, nType, pData);
+                rTexture = pTextureAtlas->InsertBuffer(nWidth, nHeight, nFormat, nType, pData);
                 return;
             }
         }
@@ -412,7 +415,48 @@ void lclInstantiateTexture(OpenGLTexture& rTexture, const int nWidth, const int
     rTexture = OpenGLTexture (nWidth, nHeight, nFormat, nType, pData);
 }
 
-}
+// Write color information for 1 and 4 bit palette bitmap scanlines.
+class ScanlineWriter
+{
+    BitmapPalette& maPalette;
+    sal_uInt8 mnColorsPerByte; // number of colors that are stored in one byte
+    sal_uInt8 mnColorBitSize;  // number of bits a color takes
+    sal_uInt8 mnColorBitMask;  // bit mask used to isolate the color
+    sal_uInt8* mpCurrentScanline;
+    long mnX;
+
+public:
+    ScanlineWriter(BitmapPalette& aPalette, sal_Int8 nColorsPerByte)
+        : maPalette(aPalette)
+        , mnColorsPerByte(nColorsPerByte)
+        , mnColorBitSize(8 / mnColorsPerByte) // bit size is number of bit in a byte divided by number of colors per byte (8 / 2 = 4 for 4-bit)
+        , mnColorBitMask((1 << mnColorBitSize) - 1) // calculate the bit mask from the bit size
+        , mpCurrentScanline(nullptr)
+        , mnX(0)
+    {}
+
+    inline void writeRGB(sal_uInt8 nR, sal_uInt8 nG, sal_uInt8 nB)
+    {
+        // calculate to which index we will write
+        long nScanlineIndex = mnX / mnColorsPerByte;
+
+        // calculate the number of shifts to get the color information to the right place
+        long nShift = (8 - mnColorBitSize) - ((mnX % mnColorsPerByte) * mnColorBitSize);
+
+        sal_uInt16 nColorIndex = maPalette.GetBestIndex(BitmapColor(nR, nG, nB));
+        mpCurrentScanline[nScanlineIndex] &= ~(mnColorBitMask << nShift); // clear
+        mpCurrentScanline[nScanlineIndex] |= (nColorIndex & mnColorBitMask) << nShift; // set
+        mnX++;
+    }
+
+    inline void nextLine(sal_uInt8* pScanline)
+    {
+        mnX = 0;
+        mpCurrentScanline = pScanline;
+    }
+};
+
+} // end anonymous namespace
 
 Size OpenGLSalBitmap::GetSize() const
 {
@@ -445,19 +489,19 @@ GLuint OpenGLSalBitmap::CreateTexture()
     sal_uInt8* pData( nullptr );
     bool bAllocated( false );
 
-    if( maUserBuffer.get() != nullptr )
+    if (mpUserBuffer.get() != nullptr)
     {
         if( mnBits == 16 || mnBits == 24 || mnBits == 32 )
         {
             // no conversion needed for truecolor
-            pData = maUserBuffer.get();
+            pData = mpUserBuffer.get();
 
             determineTextureFormat(mnBits, nFormat, nType);
         }
         else if( mnBits == 8 && maPalette.IsGreyPalette() )
         {
             // no conversion needed for grayscale
-            pData = maUserBuffer.get();
+            pData = mpUserBuffer.get();
             nFormat = GL_LUMINANCE;
             nType = GL_UNSIGNED_BYTE;
         }
@@ -472,7 +516,7 @@ GLuint OpenGLSalBitmap::CreateTexture()
 
             std::unique_ptr<ImplPixelFormat> pSrcFormat(ImplPixelFormat::GetFormat(mnBits, maPalette));
 
-            sal_uInt8* pSrcData = maUserBuffer.get();
+            sal_uInt8* pSrcData = mpUserBuffer.get();
             sal_uInt8* pDstData = pData;
 
             sal_uInt32 nY = mnHeight;
@@ -525,7 +569,7 @@ GLuint OpenGLSalBitmap::CreateTexture()
 
 bool OpenGLSalBitmap::ReadTexture()
 {
-    sal_uInt8* pData = maUserBuffer.get();
+    sal_uInt8* pData = mpUserBuffer.get();
 
     GLenum nFormat = GL_RGBA;
     GLenum nType = GL_UNSIGNED_BYTE;
@@ -545,9 +589,14 @@ bool OpenGLSalBitmap::ReadTexture()
     {
         determineTextureFormat(mnBits, nFormat, nType);
 
+#if OSL_DEBUG_LEVEL > 0
+        // help valgrind & drmemory rescue us - touch last and first bits.
+        pData[0] = 0;
+        pData[mnBits/8*mnWidth*mnHeight-1] = 0;
         // if this fails we can read too much into pData
         assert(mnWidth == maTexture.GetWidth() &&
                mnHeight == maTexture.GetHeight());
+#endif
 
         maTexture.Read(nFormat, nType, pData);
 
@@ -559,43 +608,43 @@ bool OpenGLSalBitmap::ReadTexture()
 #endif
         return true;
     }
-    else if (mnBits == 1)
-    {   // convert buffers from 24-bit RGB to 1-bit Mask
+    else if (mnBits == 1 || mnBits == 4)
+    {   // convert buffers from 24-bit RGB to 1 or 4-bit buffer
         std::vector<sal_uInt8> aBuffer(mnWidth * mnHeight * 3);
 
         sal_uInt8* pBuffer = aBuffer.data();
         determineTextureFormat(24, nFormat, nType);
         maTexture.Read(nFormat, nType, pBuffer);
+        sal_uInt16 nSourceBytesPerRow = lclBytesPerRow(24, mnWidth);
 
-        int nShift = 7;
-        size_t nIndex = 0;
-
-        sal_uInt8* pCurrent = pBuffer;
+        std::unique_ptr<ScanlineWriter> pWriter;
+        switch(mnBits)
+        {
+            case 1:
+                pWriter.reset(new ScanlineWriter(maPalette, 8));
+                break;
+            case 4:
+            default:
+                pWriter.reset(new ScanlineWriter(maPalette, 2));
+                break;
+        }
 
         for (int y = 0; y < mnHeight; ++y)
         {
+            sal_uInt8* pSource = &pBuffer[y * nSourceBytesPerRow];
+            sal_uInt8* pDestination = &pData[y * mnBytesPerRow];
+
+            pWriter->nextLine(pDestination);
+
             for (int x = 0; x < mnWidth; ++x)
             {
-                if (nShift < 0)
-                {
-                    nShift = 7;
-                    nIndex++;
-                    pData[nIndex] = 0;
-                }
+                // read source
+                sal_uInt8 nR = *pSource++;
+                sal_uInt8 nG = *pSource++;
+                sal_uInt8 nB = *pSource++;
 
-                sal_uInt8 nR = *pCurrent++;
-                sal_uInt8 nG = *pCurrent++;
-                sal_uInt8 nB = *pCurrent++;
-
-                if (nR > 0 && nG > 0 && nB > 0)
-                {
-                    pData[nIndex] |= (1 << nShift);
-                }
-                nShift--;
+                pWriter->writeRGB(nR, nG, nB);
             }
-            nShift = 7;
-            nIndex++;
-            pData[nIndex] = 0;
         }
         return true;
     }
@@ -604,7 +653,6 @@ bool OpenGLSalBitmap::ReadTexture()
              << mnWidth << "x" << mnHeight << "- unimplemented bit depth: "
              << mnBits);
     return false;
-
 }
 
 sal_uInt16 OpenGLSalBitmap::GetBitCount() const
@@ -719,9 +767,9 @@ BitmapBuffer* OpenGLSalBitmap::AcquireBuffer( BitmapAccessMode nMode )
 {
     OpenGLVCLContextZone aContextZone;
 
-    if( nMode != BITMAP_INFO_ACCESS )
+    if( nMode != BitmapAccessMode::Info )
     {
-        if( !maUserBuffer.get() )
+        if (!mpUserBuffer.get())
         {
             if( !AllocateUserData() )
                 return nullptr;
@@ -737,14 +785,14 @@ BitmapBuffer* OpenGLSalBitmap::AcquireBuffer( BitmapAccessMode nMode )
         }
     }
 
-    // maUserBuffer must be unique when we are doing the write access
-    if (nMode == BITMAP_WRITE_ACCESS && maUserBuffer && !maUserBuffer.unique())
+    // mpUserBuffer must be unique when we are doing the write access
+    if (nMode == BitmapAccessMode::Write && mpUserBuffer && !mpUserBuffer.unique())
     {
-        basebmp::RawMemorySharedArray aBuffer(maUserBuffer);
+        std::shared_ptr<sal_uInt8> aBuffer(mpUserBuffer);
 
-        maUserBuffer.reset();
+        mpUserBuffer.reset();
         AllocateUserData();
-        memcpy(maUserBuffer.get(), aBuffer.get(), static_cast<sal_uInt32>(mnBytesPerRow) * mnHeight);
+        memcpy(mpUserBuffer.get(), aBuffer.get(), static_cast<sal_uInt32>(mnBytesPerRow) * mnHeight);
     }
 
     BitmapBuffer* pBuffer = new BitmapBuffer;
@@ -752,24 +800,24 @@ BitmapBuffer* OpenGLSalBitmap::AcquireBuffer( BitmapAccessMode nMode )
     pBuffer->mnHeight = mnHeight;
     pBuffer->maPalette = maPalette;
     pBuffer->mnScanlineSize = mnBytesPerRow;
-    pBuffer->mpBits = maUserBuffer.get();
+    pBuffer->mpBits = mpUserBuffer.get();
     pBuffer->mnBitCount = mnBits;
 
     switch (mnBits)
     {
         case 1:
-            pBuffer->mnFormat = BMP_FORMAT_1BIT_MSB_PAL;
+            pBuffer->mnFormat = ScanlineFormat::N1BitMsbPal;
             break;
         case 4:
-            pBuffer->mnFormat = BMP_FORMAT_4BIT_MSN_PAL;
+            pBuffer->mnFormat = ScanlineFormat::N4BitMsnPal;
             break;
         case 8:
-            pBuffer->mnFormat = BMP_FORMAT_8BIT_PAL;
+            pBuffer->mnFormat = ScanlineFormat::N8BitPal;
             break;
         case 16:
         {
-#ifdef WNT
-            pBuffer->mnFormat = BMP_FORMAT_16BIT_TC_LSB_MASK;
+#ifdef _WIN32
+            pBuffer->mnFormat = ScanlineFormat::N16BitTcLsbMask;
             ColorMaskElement aRedMask(0x00007c00);
             aRedMask.CalcMaskShift();
             ColorMaskElement aGreenMask(0x000003e0);
@@ -778,7 +826,7 @@ BitmapBuffer* OpenGLSalBitmap::AcquireBuffer( BitmapAccessMode nMode )
             aBlueMask.CalcMaskShift();
             pBuffer->maColorMask = ColorMask(aRedMask, aGreenMask, aBlueMask);
 #else
-            pBuffer->mnFormat = BMP_FORMAT_16BIT_TC_MSB_MASK;
+            pBuffer->mnFormat = ScanlineFormat::N16BitTcMsbMask;
             ColorMaskElement aRedMask(0x0000f800);
             aRedMask.CalcMaskShift();
             ColorMaskElement aGreenMask(0x000007e0);
@@ -791,17 +839,17 @@ BitmapBuffer* OpenGLSalBitmap::AcquireBuffer( BitmapAccessMode nMode )
         }
         case 24:
         {
-#ifdef WNT
-            pBuffer->mnFormat = BMP_FORMAT_24BIT_TC_BGR;
+#ifdef _WIN32
+            pBuffer->mnFormat = ScanlineFormat::N24BitTcBgr;
 #else
-            pBuffer->mnFormat = BMP_FORMAT_24BIT_TC_RGB;
+            pBuffer->mnFormat = ScanlineFormat::N24BitTcRgb;
 #endif
             break;
         }
         case 32:
         {
-#ifdef WNT
-            pBuffer->mnFormat = BMP_FORMAT_32BIT_TC_BGRA;
+#ifdef _WIN32
+            pBuffer->mnFormat = ScanlineFormat::N32BitTcBgra;
             ColorMaskElement aRedMask(0x00ff0000);
             aRedMask.CalcMaskShift();
             ColorMaskElement aGreenMask(0x0000ff00);
@@ -810,7 +858,7 @@ BitmapBuffer* OpenGLSalBitmap::AcquireBuffer( BitmapAccessMode nMode )
             aBlueMask.CalcMaskShift();
             pBuffer->maColorMask = ColorMask(aRedMask, aGreenMask, aBlueMask);
 #else
-            pBuffer->mnFormat = BMP_FORMAT_32BIT_TC_RGBA;
+            pBuffer->mnFormat = ScanlineFormat::N32BitTcRgba;
             ColorMaskElement aRedMask(0xff000000);
             aRedMask.CalcMaskShift();
             ColorMaskElement aGreenMask(0x00ff0000);
@@ -830,7 +878,7 @@ void OpenGLSalBitmap::ReleaseBuffer( BitmapBuffer* pBuffer, BitmapAccessMode nMo
 {
     OpenGLVCLContextZone aContextZone;
 
-    if( nMode == BITMAP_WRITE_ACCESS )
+    if( nMode == BitmapAccessMode::Write )
     {
         maTexture = OpenGLTexture();
         mbDirtyTexture = true;
@@ -861,7 +909,7 @@ bool OpenGLSalBitmap::GetSystemData( BitmapSystemData& /*rData*/ )
     if( pBuffer == NULL )
         return false;
 
-    if( !maUserBuffer.get() )
+    if (!mpUserBuffer.get())
     {
         if( !AllocateUserData() || !ReadTexture() )
         {
@@ -872,7 +920,7 @@ bool OpenGLSalBitmap::GetSystemData( BitmapSystemData& /*rData*/ )
 
     // TODO Might be more efficient to add a static method to SalBitmap
     //      to get system data from a buffer
-    memcpy( pBuffer->mpBits, maUserBuffer.get(), mnBytesPerRow * mnHeight );
+    memcpy( pBuffer->mpBits, mpUserBuffer.get(), mnBytesPerRow * mnHeight );
 
     rBitmap.ReleaseBuffer( pBuffer, false );
     return rBitmap.GetSystemData( rData );
@@ -951,7 +999,7 @@ bool OpenGLSalBitmap::ConvertToGreyscale()
     maPalette = Bitmap::GetGreyPalette(256);
 
     // AllocateUserData will handle the rest.
-    maUserBuffer.reset();
+    mpUserBuffer.reset();
     mbDirtyTexture = false;
 
     CHECK_GL_ERROR();
