@@ -22,6 +22,7 @@
 #include <vcl/gfxlink.hxx>
 
 #include "jpeg/Exif.hxx"
+#include <memory>
 
 GraphicNativeMetadata::GraphicNativeMetadata() :
     mRotation(0)
@@ -30,29 +31,27 @@ GraphicNativeMetadata::GraphicNativeMetadata() :
 GraphicNativeMetadata::~GraphicNativeMetadata()
 {}
 
-sal_uInt16 GraphicNativeMetadata::getRotation()
-{
-    return mRotation;
-}
 
 bool GraphicNativeMetadata::read(Graphic& rGraphic)
 {
     GfxLink aLink = rGraphic.GetLink();
     if ( aLink.GetType() != GFX_LINK_TYPE_NATIVE_JPG )
         return false;
-    sal_uInt32 aDataSize = aLink.GetDataSize();
-    sal_uInt8* aBuffer = new sal_uInt8[aDataSize];
 
-    memcpy(aBuffer, aLink.GetData(), aDataSize);
-    SvMemoryStream aMemoryStream(aBuffer, aDataSize, STREAM_READ);
+    sal_uInt32 aDataSize = aLink.GetDataSize();
+    if (!aDataSize)
+        return false;
+
+    std::unique_ptr<sal_uInt8[]> aBuffer(new sal_uInt8[aDataSize]);
+
+    memcpy(aBuffer.get(), aLink.GetData(), aDataSize);
+    SvMemoryStream aMemoryStream(aBuffer.get(), aDataSize, StreamMode::READ);
 
     Exif aExif;
     aExif.read(aMemoryStream);
     mRotation = aExif.getRotation();
 
-    delete[] aBuffer;
     return true;
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
