@@ -56,8 +56,6 @@ DomainMapperTableHandler::DomainMapperTableHandler(
             DomainMapper_Impl& rDMapper_Impl)
     : m_xText(xText),
         m_rDMapper_Impl( rDMapper_Impl ),
-        m_nCellIndex(0),
-        m_nRowIndex(0),
         m_bHadFootOrEndnote(false)
 {
 }
@@ -66,17 +64,14 @@ DomainMapperTableHandler::~DomainMapperTableHandler()
 {
 }
 
-void DomainMapperTableHandler::startTable(unsigned int nRows,
-                                          unsigned int /*nDepth*/,
-                                          TablePropertyMapPtr pProps)
+void DomainMapperTableHandler::startTable(unsigned int /*nDepth*/,
+                                          const TablePropertyMapPtr& pProps)
 {
     m_aTableProperties = pProps;
-    m_pTableSeq = TableSequencePointer_t(new TableSequence_t(nRows));
-    m_nRowIndex = 0;
+    m_aTableRanges.clear();
 
 #ifdef DEBUG_WRITERFILTER
     TagLogger::getInstance().startElement("tablehandler.table");
-    TagLogger::getInstance().attribute("rows", nRows);
 
     if (pProps.get() != nullptr)
         pProps->dumpXml();
@@ -84,8 +79,7 @@ void DomainMapperTableHandler::startTable(unsigned int nRows,
 }
 
 
-
-PropertyMapPtr lcl_SearchParentStyleSheetAndMergeProperties(const StyleSheetEntryPtr& rStyleSheet, StyleSheetTablePtr pStyleSheetTable)
+PropertyMapPtr lcl_SearchParentStyleSheetAndMergeProperties(const StyleSheetEntryPtr& rStyleSheet, const StyleSheetTablePtr& pStyleSheetTable)
 {
     PropertyMapPtr pRet;
 
@@ -114,7 +108,7 @@ PropertyMapPtr lcl_SearchParentStyleSheetAndMergeProperties(const StyleSheetEntr
     return pRet;
 }
 
-void lcl_mergeBorder( PropertyIds nId, PropertyMapPtr pOrig, PropertyMapPtr pDest )
+void lcl_mergeBorder( PropertyIds nId, const PropertyMapPtr& pOrig, const PropertyMapPtr& pDest )
 {
     boost::optional<PropertyMap::Property> pOrigVal = pOrig->getProperty(nId);
 
@@ -124,7 +118,7 @@ void lcl_mergeBorder( PropertyIds nId, PropertyMapPtr pOrig, PropertyMapPtr pDes
     }
 }
 
-void lcl_computeCellBorders( PropertyMapPtr pTableBorders, PropertyMapPtr pCellProps,
+void lcl_computeCellBorders( const PropertyMapPtr& pTableBorders, const PropertyMapPtr& pCellProps,
         sal_Int32 nCell, sal_Int32 nRow, bool bIsEndCol, bool bIsEndRow )
 {
     boost::optional<PropertyMap::Property> pVerticalVal = pCellProps->getProperty(META_PROP_VERTICAL_BORDER);
@@ -268,7 +262,7 @@ struct TableInfo
 namespace
 {
 
-bool lcl_extractTableBorderProperty(PropertyMapPtr pTableProperties, const PropertyIds nId, TableInfo& rInfo, table::BorderLine2& rLine)
+bool lcl_extractTableBorderProperty(const PropertyMapPtr& pTableProperties, const PropertyIds nId, TableInfo& rInfo, table::BorderLine2& rLine)
 {
     if (!pTableProperties)
         return false;
@@ -290,11 +284,11 @@ bool lcl_extractTableBorderProperty(PropertyMapPtr pTableProperties, const Prope
 void lcl_extractHoriOrient(std::vector<beans::PropertyValue>& rFrameProperties, sal_Int32& nHoriOrient)
 {
     // Shifts the frame left by the given value.
-    for (size_t i = 0; i < rFrameProperties.size(); ++i)
+    for (beans::PropertyValue & rFrameProperty : rFrameProperties)
     {
-        if (rFrameProperties[i].Name == "HoriOrient")
+        if (rFrameProperty.Name == "HoriOrient")
         {
-            sal_Int32 nValue = rFrameProperties[i].Value.get<sal_Int32>();
+            sal_Int32 nValue = rFrameProperty.Value.get<sal_Int32>();
             if (nValue != text::HoriOrientation::NONE)
                 nHoriOrient = nValue;
             return;
@@ -307,9 +301,8 @@ void lcl_extractHoriOrient(std::vector<beans::PropertyValue>& rFrameProperties,
 void lcl_DecrementHoriOrientPosition(std::vector<beans::PropertyValue>& rFrameProperties, sal_Int32 nAmount)
 {
     // Shifts the frame left by the given value.
-    for (size_t i = 0; i < rFrameProperties.size(); ++i)
+    for (beans::PropertyValue & rPropertyValue : rFrameProperties)
     {
-        beans::PropertyValue& rPropertyValue = rFrameProperties[i];
         if (rPropertyValue.Name == "HoriOrientPosition")
         {
             sal_Int32 nValue = rPropertyValue.Value.get<sal_Int32>();
@@ -482,7 +475,7 @@ TableStyleSheetEntry * DomainMapperTableHandler::endTableGetTableStyle(TableInfo
         aDistances.IsTopDistanceValid =
         aDistances.IsBottomDistanceValid =
         aDistances.IsLeftDistanceValid =
-        aDistances.IsRightDistanceValid = sal_True;
+        aDistances.IsRightDistanceValid = true;
         aDistances.TopDistance = static_cast<sal_Int16>( rInfo.nTopBorderDistance );
         aDistances.BottomDistance = static_cast<sal_Int16>( rInfo.nBottomBorderDistance );
         aDistances.LeftDistance = static_cast<sal_Int16>( rInfo.nLeftBorderDistance );
@@ -504,17 +497,17 @@ TableStyleSheetEntry * DomainMapperTableHandler::endTableGetTableStyle(TableInfo
         if (lcl_extractTableBorderProperty(m_aTableProperties, PROP_TOP_BORDER, rInfo, aBorderLine))
         {
             aTableBorder.TopLine = aBorderLine;
-            aTableBorder.IsTopLineValid = sal_True;
+            aTableBorder.IsTopLineValid = true;
         }
         if (lcl_extractTableBorderProperty(m_aTableProperties, PROP_BOTTOM_BORDER, rInfo, aBorderLine))
         {
             aTableBorder.BottomLine = aBorderLine;
-            aTableBorder.IsBottomLineValid = sal_True;
+            aTableBorder.IsBottomLineValid = true;
         }
         if (lcl_extractTableBorderProperty(m_aTableProperties, PROP_LEFT_BORDER, rInfo, aLeftBorder))
         {
             aTableBorder.LeftLine = aLeftBorder;
-            aTableBorder.IsLeftLineValid = sal_True;
+            aTableBorder.IsLeftLineValid = true;
             // Only top level table position depends on border width
             if (rInfo.nNestLevel == 1)
             {
@@ -527,21 +520,21 @@ TableStyleSheetEntry * DomainMapperTableHandler::endTableGetTableStyle(TableInfo
         if (lcl_extractTableBorderProperty(m_aTableProperties, PROP_RIGHT_BORDER, rInfo, aBorderLine))
         {
             aTableBorder.RightLine = aBorderLine;
-            aTableBorder.IsRightLineValid = sal_True;
+            aTableBorder.IsRightLineValid = true;
         }
         if (lcl_extractTableBorderProperty(m_aTableProperties, META_PROP_HORIZONTAL_BORDER, rInfo, aBorderLine))
         {
             aTableBorder.HorizontalLine = aBorderLine;
-            aTableBorder.IsHorizontalLineValid = sal_True;
+            aTableBorder.IsHorizontalLineValid = true;
         }
         if (lcl_extractTableBorderProperty(m_aTableProperties, META_PROP_VERTICAL_BORDER, rInfo, aBorderLine))
         {
             aTableBorder.VerticalLine = aBorderLine;
-            aTableBorder.IsVerticalLineValid = sal_True;
+            aTableBorder.IsVerticalLineValid = true;
         }
 
         aTableBorder.Distance = 0;
-        aTableBorder.IsDistanceValid = sal_False;
+        aTableBorder.IsDistanceValid = false;
 
         m_aTableProperties->Insert( PROP_TABLE_BORDER, uno::makeAny( aTableBorder ) );
 
@@ -630,7 +623,6 @@ CellPropertyValuesSeq_t DomainMapperTableHandler::endTableGetCellProperties(Tabl
     PropertyMapVector2::const_iterator aLastRowIterator = m_aCellProperties.end() - 1;
     sal_Int32 nRow = 0;
 
-    //it's a uno::Sequence< beans::PropertyValues >*
     css::uno::Sequence<css::beans::PropertyValues>* pCellProperties = aCellProperties.getArray();
     PropertyMapVector1::const_iterator aRowIter = m_aRowProperties.begin();
     while( aRowOfCellsIterator != aRowOfCellsIteratorEnd )
@@ -727,10 +719,10 @@ CellPropertyValuesSeq_t DomainMapperTableHandler::endTableGetCellProperties(Tabl
                     {
                         PROP_TOP_BORDER, PROP_LEFT_BORDER, PROP_BOTTOM_BORDER, PROP_RIGHT_BORDER
                     };
-                    for (size_t i = 0; i < SAL_N_ELEMENTS(pBorders); ++i)
+                    for (const PropertyIds& rBorder : pBorders)
                     {
-                        boost::optional<PropertyMap::Property> oStyleCellBorder = pStyleProps->getProperty(pBorders[i]);
-                        boost::optional<PropertyMap::Property> oDirectCellBorder = (*aCellIterator)->getProperty(pBorders[i]);
+                        boost::optional<PropertyMap::Property> oStyleCellBorder = pStyleProps->getProperty(rBorder);
+                        boost::optional<PropertyMap::Property> oDirectCellBorder = (*aCellIterator)->getProperty(rBorder);
                         if (oStyleCellBorder && oDirectCellBorder)
                         {
                             // We have a cell border from the table style and as direct formatting as well.
@@ -740,12 +732,12 @@ CellPropertyValuesSeq_t DomainMapperTableHandler::endTableGetCellProperties(Tabl
                             {
                                 // The style one would be visible, but then cleared away as direct formatting.
                                 // Delete both, so that table formatting can become visible.
-                                pStyleProps->Erase(pBorders[i]);
-                                (*aCellIterator)->Erase(pBorders[i]);
+                                pStyleProps->Erase(rBorder);
+                                (*aCellIterator)->Erase(rBorder);
                             }
                             else
                             {
-                                boost::optional<PropertyMap::Property> oTableBorder = rInfo.pTableBorders->getProperty(pBorders[i]);
+                                boost::optional<PropertyMap::Property> oTableBorder = rInfo.pTableBorders->getProperty(rBorder);
                                 if (oTableBorder)
                                 {
                                     table::BorderLine2 aTableBorder = oTableBorder->second.get<table::BorderLine2>();
@@ -754,8 +746,8 @@ CellPropertyValuesSeq_t DomainMapperTableHandler::endTableGetCellProperties(Tabl
                                     if (aTableBorder.LineStyle != table::BorderLineStyle::NONE && bNoCellBorder)
                                     {
                                         // But at a table-level, there is a border, then again delete both cell properties.
-                                        pStyleProps->Erase(pBorders[i]);
-                                        (*aCellIterator)->Erase(pBorders[i]);
+                                        pStyleProps->Erase(rBorder);
+                                        (*aCellIterator)->Erase(rBorder);
                                     }
                                 }
                             }
@@ -795,7 +787,7 @@ CellPropertyValuesSeq_t DomainMapperTableHandler::endTableGetCellProperties(Tabl
                 const boost::optional<PropertyMap::Property> aHorizontalMergeVal = (*aCellIterator)->getProperty(PROP_HORIZONTAL_MERGE);
                 if (aHorizontalMergeVal)
                 {
-                    if (aHorizontalMergeVal->second.get<sal_Bool>())
+                    if (aHorizontalMergeVal->second.get<bool>())
                     {
                         // first cell in a merge
                         HorizontallyMergedCell aMerge(nRow, nCell);
@@ -818,7 +810,7 @@ CellPropertyValuesSeq_t DomainMapperTableHandler::endTableGetCellProperties(Tabl
                     if (aCellDirectionVal->second.get<sal_Int32>() == static_cast<sal_Int32>(NS_ooxml::LN_Value_ST_TextDirection_btLr))
                     {
                         // btLr, so map ParagraphAdjust_CENTER to VertOrientation::CENTER.
-                        uno::Reference<beans::XPropertySet> xPropertySet((*m_pTableSeq)[nRow][nCell][0], uno::UNO_QUERY);
+                        uno::Reference<beans::XPropertySet> xPropertySet(m_aTableRanges[nRow][nCell][0], uno::UNO_QUERY);
                         if (xPropertySet->getPropertyValue("ParaAdjust").get<sal_Int16>() == style::ParagraphAdjust_CENTER)
                             (*aCellIterator)->Insert(PROP_VERT_ORIENT, uno::makeAny(text::VertOrientation::CENTER));
                     }
@@ -869,25 +861,25 @@ CellPropertyValuesSeq_t DomainMapperTableHandler::endTableGetCellProperties(Tabl
 /// Do all cells in this row have a CellHideMark property?
 bool lcl_hideMarks(PropertyMapVector1& rCellProperties)
 {
-    for (size_t nCell = 0; nCell < rCellProperties.size(); ++nCell)
-        if (!rCellProperties[nCell]->isSet(PROP_CELL_HIDE_MARK))
+    for (PropertyMapPtr & p : rCellProperties)
+        if (!p->isSet(PROP_CELL_HIDE_MARK))
             return false;
     return true;
 }
 
 /// Are all cells in this row empty?
-bool lcl_emptyRow(TableSequence_t& rTableSeq, sal_Int32 nRow)
+bool lcl_emptyRow(std::vector<RowSequence_t>& rTableRanges, sal_Int32 nRow)
 {
-    if (nRow >= rTableSeq.getLength())
+    if (nRow >= static_cast<sal_Int32>(rTableRanges.size()))
     {
-        SAL_WARN("writerfilter", "m_aCellProperties not in sync with m_pTableSeq?");
+        SAL_WARN("writerfilter", "m_aCellProperties not in sync with rTableRanges?");
         return false;
     }
 
-    RowSequence_t rRowSeq = rTableSeq[nRow];
+    RowSequence_t rRowSeq = rTableRanges[nRow];
     if (rRowSeq.getLength() == 0)
     {
-        SAL_WARN("writerfilter", "m_aCellProperties not in sync with m_pTableSeq?");
+        SAL_WARN("writerfilter", "m_aCellProperties not in sync with rTableRanges?");
         return false;
     }
 
@@ -928,11 +920,11 @@ css::uno::Sequence<css::beans::PropertyValues> DomainMapperTableHandler::endTabl
         if( aRowIter->get() )
         {
             //set default to 'break across pages"
-            (*aRowIter)->Insert( PROP_IS_SPLIT_ALLOWED, uno::makeAny(sal_True ), false );
+            (*aRowIter)->Insert( PROP_IS_SPLIT_ALLOWED, uno::makeAny(true ), false );
             // tblHeader is only our property, remove before the property map hits UNO
             (*aRowIter)->Erase(PROP_TBL_HEADER);
 
-            if (lcl_hideMarks(m_aCellProperties[nRow]) && lcl_emptyRow(*m_pTableSeq, nRow))
+            if (lcl_hideMarks(m_aCellProperties[nRow]) && lcl_emptyRow(m_aTableRanges, nRow))
             {
                 // We have CellHideMark on all cells, and also all cells are empty:
                 // Set the row height to minimal as Word does.
@@ -1000,17 +992,17 @@ void DomainMapperTableHandler::endTable(unsigned int nestedTableLevel)
     lcl_DumpPropertyValueSeq(aRowProperties);
 #endif
 
-    if (m_pTableSeq->getLength() > 0)
+    if (!m_aTableRanges.empty())
     {
         uno::Reference<text::XTextRange> xStart;
         uno::Reference<text::XTextRange> xEnd;
 
         bool bFloating = !aFrameProperties.empty();
         // Additional checks: if we can do this.
-        if (bFloating && (*m_pTableSeq)[0].getLength() > 0 && (*m_pTableSeq)[0][0].getLength() > 0)
+        if (bFloating && m_aTableRanges[0].getLength() > 0 && m_aTableRanges[0][0].getLength() > 0)
         {
-            xStart = (*m_pTableSeq)[0][0][0];
-            uno::Sequence< uno::Sequence< uno::Reference<text::XTextRange> > >& rLastRow = (*m_pTableSeq)[m_pTableSeq->getLength() - 1];
+            xStart = m_aTableRanges[0][0][0];
+            uno::Sequence< uno::Sequence< uno::Reference<text::XTextRange> > >& rLastRow = m_aTableRanges[m_aTableRanges.size() - 1];
             uno::Sequence< uno::Reference<text::XTextRange> >& rLastCell = rLastRow[rLastRow.getLength() - 1];
             xEnd = rLastCell[1];
         }
@@ -1019,10 +1011,7 @@ void DomainMapperTableHandler::endTable(unsigned int nestedTableLevel)
         {
             if (m_xText.is())
             {
-                xTable = m_xText->convertToTable(*m_pTableSeq,
-                        aCellProperties,
-                        aRowProperties,
-                        aTableInfo.aTableProperties);
+                xTable = m_xText->convertToTable(comphelper::containerToSequence(m_aTableRanges), aCellProperties, aRowProperties, aTableInfo.aTableProperties);
 
                 if (xTable.is())
                 {
@@ -1142,35 +1131,30 @@ void DomainMapperTableHandler::endTable(unsigned int nestedTableLevel)
 #endif
 }
 
-void DomainMapperTableHandler::startRow(unsigned int nCells,
-                                        TablePropertyMapPtr pProps)
+void DomainMapperTableHandler::startRow(const TablePropertyMapPtr& pProps)
 {
     m_aRowProperties.push_back( pProps );
     m_aCellProperties.push_back( PropertyMapVector1() );
 
 #ifdef DEBUG_WRITERFILTER
     TagLogger::getInstance().startElement("table.row");
-    TagLogger::getInstance().attribute("cells", nCells);
     if (pProps != nullptr)
         pProps->dumpXml();
 #endif
 
-    m_pRowSeq = RowSequencePointer_t(new RowSequence_t(nCells));
-    m_nCellIndex = 0;
+    m_aRowRanges.clear();
 }
 
 void DomainMapperTableHandler::endRow()
 {
-    (*m_pTableSeq)[m_nRowIndex] = *m_pRowSeq;
-    ++m_nRowIndex;
-    m_nCellIndex = 0;
+    m_aTableRanges.push_back(comphelper::containerToSequence(m_aRowRanges));
 #ifdef DEBUG_WRITERFILTER
     TagLogger::getInstance().endElement();
 #endif
 }
 
 void DomainMapperTableHandler::startCell(const css::uno::Reference< css::text::XTextRange > & start,
-                                         TablePropertyMapPtr pProps )
+                                         const TablePropertyMapPtr& pProps )
 {
     sal_uInt32 nRow = m_aRowProperties.size();
     if ( pProps.get( ) )
@@ -1193,10 +1177,11 @@ void DomainMapperTableHandler::startCell(const css::uno::Reference< css::text::X
 #endif
 
     //add a new 'row' of properties
-    m_pCellSeq = CellSequencePointer_t(new CellSequence_t(2));
-    if (!start.get())
-        return;
-    (*m_pCellSeq)[0] = start->getStart();
+    m_aCellRange.clear();
+    uno::Reference<text::XTextRange> xStart;
+    if (start.get())
+        xStart = start->getStart();
+    m_aCellRange.push_back(xStart);
 }
 
 void DomainMapperTableHandler::endCell(const css::uno::Reference< css::text::XTextRange > & end)
@@ -1208,11 +1193,11 @@ void DomainMapperTableHandler::endCell(const css::uno::Reference< css::text::XTe
     TagLogger::getInstance().endElement();
 #endif
 
-    if (!end.get())
-        return;
-    (*m_pCellSeq)[1] = end->getEnd();
-    (*m_pRowSeq)[m_nCellIndex] = *m_pCellSeq;
-    ++m_nCellIndex;
+    uno::Reference<text::XTextRange> xEnd;
+    if (end.get())
+        xEnd = end->getEnd();
+    m_aCellRange.push_back(xEnd);
+    m_aRowRanges.push_back(comphelper::containerToSequence(m_aCellRange));
 }
 
 void DomainMapperTableHandler::setHadFootOrEndnote(bool bHadFootOrEndnote)
