@@ -342,7 +342,7 @@ public:
         return bYSizeValid;
     }
 
-    void applyMargins(uno::Reference< beans::XPropertySet > xGraphicObjectProperties) const
+    void applyMargins(const uno::Reference< beans::XPropertySet >& xGraphicObjectProperties) const
     {
         xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_LEFT_MARGIN ), uno::makeAny(nLeftMargin));
         xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_RIGHT_MARGIN ), uno::makeAny(nRightMargin));
@@ -350,7 +350,7 @@ public:
         xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_BOTTOM_MARGIN ), uno::makeAny(nBottomMargin));
     }
 
-    void applyPosition(uno::Reference< beans::XPropertySet > xGraphicObjectProperties) const
+    void applyPosition(const uno::Reference< beans::XPropertySet >& xGraphicObjectProperties) const
     {
         xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_HORI_ORIENT          ),
                 uno::makeAny(nHoriOrient));
@@ -358,7 +358,7 @@ public:
                 uno::makeAny(nVertOrient));
     }
 
-    void applyRelativePosition(uno::Reference< beans::XPropertySet > xGraphicObjectProperties, bool bRelativeOnly = false) const
+    void applyRelativePosition(const uno::Reference< beans::XPropertySet >& xGraphicObjectProperties, bool bRelativeOnly = false) const
     {
         if (!bRelativeOnly)
             xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_HORI_ORIENT_POSITION),
@@ -388,11 +388,12 @@ public:
     {
         try
         {
-            if( !sName.isEmpty() )
-            {
-                uno::Reference< container::XNamed > xNamed( xGraphicObjectProperties, uno::UNO_QUERY_THROW );
-                xNamed->setName( sName );
-            }
+            // Ask the graphic naming helper to find out the name for this
+            // object: It's around till the end of the import, so it remembers
+            // what's the first free name.
+            uno::Reference< container::XNamed > xNamed( xGraphicObjectProperties, uno::UNO_QUERY_THROW );
+            xNamed->setName(rDomainMapper.GetGraphicNamingHelper().NameGraphic(sName));
+
             xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_DESCRIPTION ),
                 uno::makeAny( sAlternativeText ));
             xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_TITLE ),
@@ -464,9 +465,9 @@ void GraphicImport::handleWrapTextValue(sal_uInt32 nVal)
 
 void GraphicImport::putPropertyToFrameGrabBag( const OUString& sPropertyName, const uno::Any& aPropertyValue )
 {
-    beans::PropertyValue pProperty;
-    pProperty.Name = sPropertyName;
-    pProperty.Value = aPropertyValue;
+    beans::PropertyValue aProperty;
+    aProperty.Name = sPropertyName;
+    aProperty.Value = aPropertyValue;
 
     if (!m_xShape.is())
         return;
@@ -492,7 +493,7 @@ void GraphicImport::putPropertyToFrameGrabBag( const OUString& sPropertyName, co
         uno::Sequence<beans::PropertyValue> aTmp;
         xSet->getPropertyValue(aGrabBagPropName) >>= aTmp;
         std::vector<beans::PropertyValue> aGrabBag(comphelper::sequenceToContainer<std::vector<beans::PropertyValue> >(aTmp));
-        aGrabBag.push_back(pProperty);
+        aGrabBag.push_back(aProperty);
 
         xSet->setPropertyValue(aGrabBagPropName, uno::makeAny(comphelper::containerToSequence(aGrabBag)));
     }
@@ -1162,8 +1163,8 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
                 PROP_BOTTOM_BORDER
             };
 
-            for( sal_Int32 nBorder = 0; nBorder < 4; ++nBorder )
-                xGraphicObjectProperties->setPropertyValue(getPropertyName( aBorderProps[nBorder]), uno::makeAny(aBorderLine));
+            for(PropertyIds & rBorderProp : aBorderProps)
+                xGraphicObjectProperties->setPropertyValue(getPropertyName(rBorderProp), uno::makeAny(aBorderLine));
 
             // setting graphic object shadow proerties
             if (m_pImpl->bShadow)
@@ -1361,7 +1362,6 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
 }
 
 
-
 void GraphicImport::data(const sal_uInt8* buf, size_t len, writerfilter::Reference<Properties>::Pointer_t /*ref*/)
 {
         beans::PropertyValues aMediaProperties( 1 );
