@@ -54,7 +54,6 @@ namespace writerfilter {
 namespace dmapper{
 
 
-
 PropertyMap::PropertyMap() :
     m_cFootnoteSymbol( 0 ),
     m_nFootnoteFontId( -1 )
@@ -497,7 +496,6 @@ OUString lcl_FindUnusedPageStyleName(const uno::Sequence< OUString >& rPageStyle
 }
 
 
-
 uno::Reference< beans::XPropertySet > SectionPropertyMap::GetPageStyle(
         const uno::Reference< container::XNameContainer >& xPageStyles,
         const uno::Reference < lang::XMultiServiceFactory >& xTextFactory,
@@ -704,7 +702,6 @@ void SectionPropertyMap::SetBorderDistance( uno::Reference< beans::XPropertySet
 }
 
 
-
 uno::Reference< text::XTextColumns > SectionPropertyMap::ApplyColumnProperties(
                             uno::Reference< beans::XPropertySet > const& xColumnContainer, DomainMapper_Impl& rDM_Impl )
 {
@@ -774,7 +771,6 @@ uno::Reference< text::XTextColumns > SectionPropertyMap::ApplyColumnProperties(
 }
 
 
-
 bool SectionPropertyMap::HasHeader(bool bFirstPage) const
 {
     bool bRet = false;
@@ -808,8 +804,8 @@ bool SectionPropertyMap::HasFooter(bool bFirstPage) const
 #define MIN_HEAD_FOOT_HEIGHT 100 //minimum header/footer height
 
 void SectionPropertyMap::CopyHeaderFooterTextProperty (
-    uno::Reference< beans::XPropertySet > xPrevStyle,
-    uno::Reference< beans::XPropertySet > xStyle,
+    const uno::Reference< beans::XPropertySet >& xPrevStyle,
+    const uno::Reference< beans::XPropertySet >& xStyle,
     PropertyIds ePropId )
 {
     try {
@@ -834,8 +830,8 @@ void SectionPropertyMap::CopyHeaderFooterTextProperty (
 
 // Copy headers and footers from the previous page style.
 void SectionPropertyMap::CopyHeaderFooter(
-    uno::Reference< beans::XPropertySet > xPrevStyle,
-    uno::Reference< beans::XPropertySet > xStyle,
+    const uno::Reference< beans::XPropertySet >& xPrevStyle,
+    const uno::Reference< beans::XPropertySet >& xStyle,
     bool bOmitRightHeader, bool bOmitLeftHeader,
     bool bOmitRightFooter, bool bOmitLeftFooter)
 {
@@ -851,7 +847,7 @@ void SectionPropertyMap::CopyHeaderFooter(
 
     if ( bHasPrevHeader )
     {
-        xStyle->setPropertyValue( sHeaderIsOn, uno::makeAny( sal_True ) );
+        xStyle->setPropertyValue( sHeaderIsOn, uno::makeAny( true ) );
         xStyle->setPropertyValue( sHeaderIsShared, uno::makeAny(bHeaderIsShared));
         if ( !bOmitRightHeader )
         {
@@ -877,7 +873,7 @@ void SectionPropertyMap::CopyHeaderFooter(
 
     if ( bHasPrevFooter )
     {
-        xStyle->setPropertyValue( sFooterIsOn, uno::makeAny( sal_True ) );
+        xStyle->setPropertyValue( sFooterIsOn, uno::makeAny( true ) );
         xStyle->setPropertyValue( sFooterIsShared, uno::makeAny(bFooterIsShared) );
         if ( !bOmitRightFooter )
         {
@@ -1105,10 +1101,8 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
     // Text area width is known at the end of a section: decide if tables should be converted or not.
     std::vector<FloatingTableInfo>& rPendingFloatingTables = rDM_Impl.m_aPendingFloatingTables;
     uno::Reference<text::XTextAppendAndConvert> xBodyText( rDM_Impl.GetBodyText(), uno::UNO_QUERY );
-    for (size_t i = 0; i < rPendingFloatingTables.size(); ++i)
+    for (FloatingTableInfo & rInfo : rPendingFloatingTables)
     {
-        FloatingTableInfo& rInfo = rPendingFloatingTables[i];
-
         if (FloatingTableConversion(rInfo))
             xBodyText->convertToTextFrame(rInfo.m_xStart, rInfo.m_xEnd, rInfo.m_aFrameProperties);
     }
@@ -1160,11 +1154,13 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
             {
                 try
                 {
-                    xRangeProperties->setPropertyValue(getPropertyName(PROP_PAGE_DESC_NAME), uno::makeAny(aName));
+                    if( m_bIsFirstSection )
+                        xRangeProperties->setPropertyValue(getPropertyName(PROP_PAGE_DESC_NAME), uno::makeAny(aName));
+
                     uno::Reference<beans::XPropertySet> xPageStyle (rDM_Impl.GetPageStyles()->getByName(aName), uno::UNO_QUERY_THROW);
                     HandleMarginsHeaderFooter(rDM_Impl);
                     if (rDM_Impl.IsNewDoc())
-                        _ApplyProperties(xPageStyle);
+                        ApplyProperties_(xPageStyle);
                 }
                 catch( const uno::Exception& )
                 {
@@ -1251,7 +1247,7 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
         if( pEntry.get( ) )
         {
             boost::optional<PropertyMap::Property> pPropHeight = pEntry->pProperties->getProperty(PROP_CHAR_HEIGHT_ASIAN);
-            if(pProp)
+            if (pPropHeight)
             {
                 double fHeight = 0;
                 if( pPropHeight->second >>= fHeight )
@@ -1298,7 +1294,7 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
         }
 
         if (rDM_Impl.IsNewDoc())
-            _ApplyProperties( xFollowPageStyle );
+            ApplyProperties_( xFollowPageStyle );
 
         //todo: creating a "First Page" style depends on HasTitlePage und _fFacingPage_
         if( m_bTitlePage )
@@ -1308,7 +1304,7 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
             uno::Reference< beans::XPropertySet > xFirstPageStyle = GetPageStyle(
                                 rDM_Impl.GetPageStyles(), rDM_Impl.GetTextFactory(), true );
             if (rDM_Impl.IsNewDoc())
-                _ApplyProperties( xFirstPageStyle );
+                ApplyProperties_( xFirstPageStyle );
 
             sal_Int32 nPaperBin = m_nFirstPaperBin >= 0 ? m_nFirstPaperBin : m_nPaperBin >= 0 ? m_nPaperBin : 0;
             if( nPaperBin )
@@ -1347,8 +1343,8 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
                     }
                     evenOddStyle->setPropertyValue("FollowStyle", uno::makeAny(*pageStyle));
                     rDM_Impl.GetPageStyles()->insertByName( evenOddStyleName, uno::makeAny( evenOddStyle ) );
-                    evenOddStyle->setPropertyValue("HeaderIsOn", uno::makeAny(sal_False));
-                    evenOddStyle->setPropertyValue("FooterIsOn", uno::makeAny(sal_False));
+                    evenOddStyle->setPropertyValue("HeaderIsOn", uno::makeAny(false));
+                    evenOddStyle->setPropertyValue("FooterIsOn", uno::makeAny(false));
                     CopyHeaderFooter( pageProperties, evenOddStyle );
                     *pageStyle = evenOddStyleName; // And use it instead of the original one (which is set as follow of this one).
                     if (m_nBreakType == static_cast<sal_Int32>(NS_ooxml::LN_Value_ST_SectionMark_evenPage))
@@ -1412,7 +1408,7 @@ public:
     bool operator() (beans::PropertyValue& aVal)
     {   return aVal.Name == m_aName;    }
 };
-void SectionPropertyMap::_ApplyProperties(
+void SectionPropertyMap::ApplyProperties_(
         uno::Reference< beans::XPropertySet > const& xStyle)
 {
     uno::Reference<beans::XMultiPropertySet> const xMultiSet(xStyle,
@@ -1441,15 +1437,15 @@ void SectionPropertyMap::_ApplyProperties(
                 vValues.push_back(pIter->Value);
             }
         }
-        for (beans::PropertyValue* iter = vCharVals.begin(); iter!=vCharVals.end(); ++iter)
+        for (beans::PropertyValue & v : vCharVals)
         {
-            vNames.push_back(iter->Name);
-            vValues.push_back(iter->Value);
+            vNames.push_back(v.Name);
+            vValues.push_back(v.Value);
         }
-        for (beans::PropertyValue* iter = vParaVals.begin(); iter!=vParaVals.end(); ++iter)
+        for (beans::PropertyValue & v : vParaVals)
         {
-            vNames.push_back(iter->Name);
-            vValues.push_back(iter->Value);
+            vNames.push_back(v.Name);
+            vValues.push_back(v.Value);
         }
     }
     if (xMultiSet.is())
@@ -1460,7 +1456,7 @@ void SectionPropertyMap::_ApplyProperties(
         }
         catch( const uno::Exception& )
         {
-            OSL_FAIL( "Exception in SectionPropertyMap::_ApplyProperties");
+            OSL_FAIL( "Exception in SectionPropertyMap::ApplyProperties_");
         }
         return;
     }
@@ -1473,7 +1469,7 @@ void SectionPropertyMap::_ApplyProperties(
         }
         catch( const uno::Exception& )
         {
-            OSL_FAIL( "Exception in SectionPropertyMap::_ApplyProperties");
+            OSL_FAIL( "Exception in SectionPropertyMap::ApplyProperties_");
         }
     }
 }
