@@ -30,6 +30,7 @@
 #include <xmloff/xmlnmspe.hxx>
 #include <xmloff/xmltoken.hxx>
 #include <xmloff/nmspmap.hxx>
+#include <comphelper/sequence.hxx>
 #include <com/sun/star/frame/XModel.hpp>
 #include <com/sun/star/chart2/XAnyDescriptionAccess.hpp>
 #include <com/sun/star/chart2/XDataSeriesContainer.hpp>
@@ -48,6 +49,7 @@
 
 #include <vector>
 #include <algorithm>
+#include <iterator>
 
 using namespace com::sun::star;
 using namespace ::xmloff::token;
@@ -65,7 +67,7 @@ typedef ::std::multimap< OUString, OUString >
 
 struct lcl_ApplyCellToData : public ::std::unary_function< SchXMLCell, void >
 {
-    lcl_ApplyCellToData( Sequence< double > & rOutData ) :
+    explicit lcl_ApplyCellToData( Sequence< double > & rOutData ) :
             m_rData( rOutData ),
             m_nIndex( 0 ),
             m_nSize( rOutData.getLength()),
@@ -205,8 +207,7 @@ template< typename T >
 ::std::vector< T > lcl_SequenceToVector( const uno::Sequence< T > & rSequence )
 {
     ::std::vector< T > aResult( rSequence.getLength());
-    ::std::copy( rSequence.getConstArray(), rSequence.getConstArray() + rSequence.getLength(),
-                 aResult.begin());
+    ::std::copy( rSequence.begin(), rSequence.end(), aResult.begin());
     return aResult;
 }
 
@@ -238,14 +239,14 @@ SvXMLImportContext *SchXMLTableContext::CreateChildContext(
     const OUString& rLocalName,
     const uno::Reference< xml::sax::XAttributeList >& )
 {
-    SvXMLImportContext* pContext = 0;
+    SvXMLImportContext* pContext = nullptr;
     const SvXMLTokenMap& rTokenMap = mrImportHelper.GetTableElemTokenMap();
 
     switch( rTokenMap.Get( nPrefix, rLocalName ))
     {
         case XML_TOK_TABLE_HEADER_COLS:
             mrTable.bHasHeaderColumn = true;
-            // fall through intended
+            SAL_FALLTHROUGH;
         case XML_TOK_TABLE_COLUMNS:
             pContext = new SchXMLTableColumnsContext( GetImport(), rLocalName, mrTable );
             break;
@@ -256,7 +257,7 @@ SvXMLImportContext *SchXMLTableContext::CreateChildContext(
 
         case XML_TOK_TABLE_HEADER_ROWS:
             mrTable.bHasHeaderRow = true;
-            // fall through intended
+            SAL_FALLTHROUGH;
         case XML_TOK_TABLE_ROWS:
             pContext = new SchXMLTableRowsContext( mrImportHelper, GetImport(), rLocalName, mrTable );
             break;
@@ -427,7 +428,7 @@ SvXMLImportContext* SchXMLTableColumnsContext::CreateChildContext(
     const OUString& rLocalName,
     const uno::Reference< xml::sax::XAttributeList >& )
 {
-    SvXMLImportContext* pContext = 0;
+    SvXMLImportContext* pContext = nullptr;
 
     if( nPrefix == XML_NAMESPACE_TABLE &&
         IsXMLToken( rLocalName, XML_TABLE_COLUMN ) )
@@ -521,7 +522,7 @@ SvXMLImportContext* SchXMLTableRowsContext::CreateChildContext(
     const OUString& rLocalName,
     const uno::Reference< xml::sax::XAttributeList >& )
 {
-    SvXMLImportContext* pContext = 0;
+    SvXMLImportContext* pContext = nullptr;
 
     if( nPrefix == XML_NAMESPACE_TABLE &&
         IsXMLToken( rLocalName, XML_TABLE_ROW ) )
@@ -564,7 +565,7 @@ SvXMLImportContext* SchXMLTableRowContext::CreateChildContext(
     const OUString& rLocalName,
     const uno::Reference< xml::sax::XAttributeList >& )
 {
-    SvXMLImportContext* pContext = 0;
+    SvXMLImportContext* pContext = nullptr;
 
     // <table:table-cell> element
     if( nPrefix == XML_NAMESPACE_TABLE &&
@@ -601,20 +602,19 @@ public:
     virtual SvXMLImportContext* CreateChildContext(
         sal_uInt16 nPrefix,
         const OUString& rLocalName,
-        const com::sun::star::uno::Reference< com::sun::star::xml::sax::XAttributeList >& xAttrList );
-    virtual void EndElement();
+        const css::uno::Reference< css::xml::sax::XAttributeList >& xAttrList ) override;
+    virtual void EndElement() override;
 };
 
 // classes for cells and their content
 // class SchXMLTableCellContext
 SchXMLTableCellContext::SchXMLTableCellContext(
-    SchXMLImportHelper& rImpHelper,
-    SvXMLImport& rImport,
-    const OUString& rLocalName,
-    SchXMLTable& aTable ) :
-        SvXMLImportContext( rImport, XML_NAMESPACE_TABLE, rLocalName ),
-        mrImportHelper( rImpHelper ),
-        mrTable( aTable )
+    SchXMLImportHelper& rImpHelper, SvXMLImport& rImport,
+    const OUString& rLocalName, SchXMLTable& aTable)
+    : SvXMLImportContext(rImport, XML_NAMESPACE_TABLE, rLocalName)
+    , mrImportHelper(rImpHelper)
+    , mrTable(aTable)
+    , mbReadText(false)
 {
 }
 
@@ -663,7 +663,7 @@ void SchXMLTableCellContext::StartElement( const uno::Reference< xml::sax::XAttr
         ::sax::Converter::convertDouble( fData, aCellContent );
 
         aCell.fValue = fData;
-        // dont read text from following <text:p> or <text:list> element
+        // don't read text from following <text:p> or <text:list> element
         mbReadText = false;
     }
 
@@ -678,7 +678,7 @@ SvXMLImportContext* SchXMLTableCellContext::CreateChildContext(
     const OUString& rLocalName,
     const uno::Reference< xml::sax::XAttributeList >& )
 {
-    SvXMLImportContext* pContext = 0;
+    SvXMLImportContext* pContext = nullptr;
 
     // <text:list> element
     if( nPrefix == XML_NAMESPACE_TEXT && IsXMLToken( rLocalName, XML_LIST ) && mbReadText )
@@ -690,7 +690,8 @@ SvXMLImportContext* SchXMLTableCellContext::CreateChildContext(
         mbReadText = false;//don't apply text from <text:p>
     }
     // <text:p> element - read text (and range from text:id old version)
-    else if( nPrefix == XML_NAMESPACE_TEXT && IsXMLToken( rLocalName, XML_P ) )
+    else if( (nPrefix == XML_NAMESPACE_TEXT ||
+                nPrefix == XML_NAMESPACE_LO_EXT) && IsXMLToken( rLocalName, XML_P ) )
     {
         pContext = new SchXMLParagraphContext( GetImport(), rLocalName, maCellContent, &maRangeId );
     }
@@ -740,7 +741,7 @@ static void lcl_ApplyCellToComplexLabel( const SchXMLCell& rCell, Sequence< uno:
 
 void SchXMLTableHelper::applyTableToInternalDataProvider(
     const SchXMLTable& rTable,
-    uno::Reference< chart2::XChartDocument > xChartDoc )
+    const uno::Reference< chart2::XChartDocument >& xChartDoc )
 {
     // apply all data read from the local table to the internal data provider
     if( !xChartDoc.is() || !xChartDoc->hasInternalDataProvider() )
@@ -771,7 +772,7 @@ void SchXMLTableHelper::applyTableToInternalDataProvider(
     for( sal_Int32 i=0; i<nNumRows; ++i )
         aDataInRows[i].realloc( nNumColumns );
 
-    if( rTable.aData.begin() != rTable.aData.end())
+    if( !rTable.aData.empty() )
     {
         //apply column labels
         if( rTable.bHasHeaderRow )
@@ -822,8 +823,8 @@ void SchXMLTableHelper::applyTableToInternalDataProvider(
         try
         {
             Reference< beans::XPropertySet > xProps( xChartDoc, uno::UNO_QUERY_THROW );
-            xProps->setPropertyValue( "DisableDataTableDialog", uno::makeAny( sal_True ) );
-            xProps->setPropertyValue( "DisableComplexChartTypes", uno::makeAny( sal_True ) );
+            xProps->setPropertyValue( "DisableDataTableDialog", uno::makeAny( true ) );
+            xProps->setPropertyValue( "DisableComplexChartTypes", uno::makeAny( true ) );
         }
         catch ( uno::Exception& )
         {
@@ -834,7 +835,7 @@ void SchXMLTableHelper::applyTableToInternalDataProvider(
 void SchXMLTableHelper::switchRangesFromOuterToInternalIfNecessary(
     const SchXMLTable& rTable,
     const tSchXMLLSequencesPerIndex & rLSequencesPerIndex,
-    uno::Reference< chart2::XChartDocument > xChartDoc,
+    const uno::Reference< chart2::XChartDocument >& xChartDoc,
     chart::ChartDataRowSource eDataRowSource )
 {
     if( ! (xChartDoc.is() && xChartDoc->hasInternalDataProvider()))
@@ -896,8 +897,7 @@ void SchXMLTableHelper::switchRangesFromOuterToInternalIfNecessary(
                         {
                             Reference< beans::XPropertySet > xOldSequenceProp( aLSeqIt->second->getValues(), uno::UNO_QUERY );
                             Reference< chart2::data::XDataSequence > xNewSequence(
-                                xDataProv->createDataSequenceByRangeRepresentation(
-                                    OUString("categories")));
+                                xDataProv->createDataSequenceByRangeRepresentation("categories"));
                             SchXMLTools::copyProperties(
                                 xOldSequenceProp, Reference< beans::XPropertySet >( xNewSequence, uno::UNO_QUERY ));
                             aLSeqIt->second->setValues( xNewSequence );
@@ -956,7 +956,7 @@ void SchXMLTableHelper::switchRangesFromOuterToInternalIfNecessary(
     if( ! bCategoriesApplied )
     {
         SchXMLTools::CreateCategories(
-            xDataProv, xChartDoc, OUString("categories"),
+            xDataProv, xChartDoc, "categories",
             0 /* nCooSysIndex */, 0 /* nDimension */ );
     }
 
@@ -1022,9 +1022,7 @@ void SchXMLTableHelper::switchRangesFromOuterToInternalIfNecessary(
                     if( static_cast<sal_Int32>(aRemainingSeries.size()) != aSeriesSeq.getLength() )
                     {
                         //remove the series that have only hidden data
-                        Sequence< Reference< chart2::XDataSeries > > aRemainingSeriesSeq( aRemainingSeries.size());
-                        ::std::copy( aRemainingSeries.begin(), aRemainingSeries.end(), aRemainingSeriesSeq.getArray());
-                        xSeriesContainer->setDataSeries( aRemainingSeriesSeq );
+                        xSeriesContainer->setDataSeries( comphelper::containerToSequence(aRemainingSeries) );
 
                         //remove unused sequences
                         Reference< chart2::data::XDataSource > xDataSource( xChartDoc, uno::UNO_QUERY );
