@@ -624,7 +624,7 @@ Any AnimationsImportHelperImpl::convertPath( const OUString& rValue )
 AnimationNodeContext::AnimationNodeContext(
         const Reference< XAnimationNode >& xParentNode,
         SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLocalName,
-        const com::sun::star::uno::Reference< com::sun::star::xml::sax::XAttributeList>& xAttrList,
+        const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList,
         AnimationsImportHelperImpl* pHelper /* = NULL */ )
 :   SvXMLImportContext(rImport, nPrfx, rLocalName),
     mpHelper( pHelper ),
@@ -726,7 +726,7 @@ AnimationNodeContext::~AnimationNodeContext()
         delete mpHelper;
 }
 
-void AnimationNodeContext::StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& )
+void AnimationNodeContext::StartElement( const css::uno::Reference< css::xml::sax::XAttributeList >& )
 {
     // code of StartElement is moved to init_node that is now called
     // in c'tor before appending this node to its parent.
@@ -734,7 +734,7 @@ void AnimationNodeContext::StartElement( const ::com::sun::star::uno::Reference<
     // set when child nodes are appended.
 }
 
-void AnimationNodeContext::init_node(  const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList )
+void AnimationNodeContext::init_node(  const css::uno::Reference< css::xml::sax::XAttributeList >& xAttrList )
 {
     if( mxNode.is() ) try
     {
@@ -875,9 +875,8 @@ void AnimationNodeContext::init_node(  const ::com::sun::star::uno::Reference< :
                     xAudio->setSource( makeAny( GetImport().GetAbsoluteReference( rValue ) ) );
                     break;
                 }
-
+                SAL_FALLTHROUGH;
             }
-            // fall through intended!
             case ANA_Target:
             {
                 {
@@ -1152,7 +1151,7 @@ void AnimationNodeContext::init_node(  const ::com::sun::star::uno::Reference< :
                     double fInterval = 0.0;
                     if( rValue.match("P") )
                     {
-                        ::com::sun::star::util::Duration aDuration;
+                        css::util::Duration aDuration;
                         if (::sax::Converter::convertDuration(aDuration, rValue))
                         {
                             fInterval = ((((aDuration.Hours * 60)
@@ -1240,7 +1239,7 @@ void AnimationNodeContext::init_node(  const ::com::sun::star::uno::Reference< :
 }
 
 SvXMLImportContext * AnimationNodeContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName,
-        const com::sun::star::uno::Reference< com::sun::star::xml::sax::XAttributeList>& xAttrList )
+        const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList )
 {
     if( mxNode.is())
         return new AnimationNodeContext( mxNode, GetImport(), nPrefix, rLocalName, xAttrList, mpHelper );
@@ -1385,7 +1384,7 @@ void AnimationNodeContext::postProcessRootNode( SvXMLImport& /*rImport*/, const
                             Reference< XCommand > xCommand( xChildNode, UNO_QUERY_THROW );
                             if( xCommand->getCommand() == EffectCommands::STOPAUDIO )
                             {
-                                xPageProps->setPropertyValue("Sound", Any(sal_True) );
+                                xPageProps->setPropertyValue("Sound", Any(true) );
                             }
                         }
                         break;
@@ -1400,7 +1399,7 @@ void AnimationNodeContext::postProcessRootNode( SvXMLImport& /*rImport*/, const
 
                                 Timing eTiming;
                                 if( (xAudio->getRepeatCount() >>= eTiming) && (eTiming == Timing_INDEFINITE) )
-                                    xPageProps->setPropertyValue("LoopSound", Any( sal_True ) );
+                                    xPageProps->setPropertyValue("LoopSound", Any( true ) );
                             }
                         }
                         break;
