@@ -19,15 +19,13 @@
 
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/xml/AttributeData.hpp>
-#include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/beans/XPropertyState.hpp>
-#include <com/sun/star/lang/XTypeProvider.hpp>
 #include <com/sun/star/beans/XMultiPropertySet.hpp>
 #include <com/sun/star/beans/XTolerantMultiPropertySet.hpp>
 #include <com/sun/star/beans/TolerantPropertySetResultType.hpp>
 #include <rtl/ustrbuf.hxx>
 #include <list>
-#include <boost/unordered_map.hpp>
+#include <map>
 
 #include <xmloff/xmlexppr.hxx>
 #include <xmloff/xmltoken.hxx>
@@ -36,8 +34,9 @@
 #include <xmloff/xmlnmspe.hxx>
 #include <xmloff/xmlexp.hxx>
 #include <xmloff/xmlprmap.hxx>
-#include <xmloff/PropertySetInfoHash.hxx>
-#include <comphelper/stl_types.hxx>
+#include <xmloff/maptype.hxx>
+#include <xmloff/xmltypes.hxx>
+#include <xmloff/xmlprhdl.hxx>
 
 using namespace ::std;
 using namespace ::com::sun::star;
@@ -110,7 +109,7 @@ void XMLPropertyStates_Impl::AddPropertyState(
         const XMLPropertyState& rPropState)
 {
     XMLPropertyStateList_Impl::iterator aItr = aPropStates.begin();
-    sal_Bool bInserted(sal_False);
+    bool bInserted(false);
     if (nCount)
     {
         if (aLastItr->mnIndex < rPropState.mnIndex)
@@ -122,13 +121,13 @@ void XMLPropertyStates_Impl::AddPropertyState(
         if (aItr == aPropStates.end())
         {
             aLastItr = aPropStates.insert(aPropStates.end(), rPropState);
-            bInserted = sal_True;
+            bInserted = true;
             nCount++;
         }
         else if (aItr->mnIndex > rPropState.mnIndex)
         {
             aLastItr = aPropStates.insert(aItr, rPropState);
-            bInserted = sal_True;
+            bInserted = true;
             nCount++;
         }
     }
@@ -159,7 +158,7 @@ public:
     std::list<sal_uInt32>& GetIndexes() { return aIndexes; }
 
     // for sort
-    sal_Bool operator< ( const FilterPropertyInfo_Impl& rArg ) const
+    bool operator< ( const FilterPropertyInfo_Impl& rArg ) const
     {
         return (GetApiName() < rArg.GetApiName());
     }
@@ -192,15 +191,15 @@ public:
     void FillPropertyStateArray(
             vector< XMLPropertyState >& rPropStates,
             const Reference< XPropertySet >& xPropSet,
-            const UniReference< XMLPropertySetMapper >& maPropMapper,
-            const sal_Bool bDefault = sal_False);
+            const rtl::Reference< XMLPropertySetMapper >& maPropMapper,
+            const bool bDefault = false);
     sal_uInt32 GetPropertyCount() const { return nCount; }
 };
 
 FilterPropertiesInfo_Impl::FilterPropertiesInfo_Impl() :
     nCount(0),
     aPropInfos(),
-    pApiNames( 0 )
+    pApiNames( nullptr )
 {
     aLastItr = aPropInfos.begin();
 }
@@ -216,11 +215,11 @@ void FilterPropertiesInfo_Impl::AddProperty(
     aPropInfos.push_back(FilterPropertyInfo_Impl(rApiName, nIndex));
     nCount++;
 
-    OSL_ENSURE( !pApiNames, "perfomance warning: API names already retrieved" );
+    OSL_ENSURE( !pApiNames, "performance warning: API names already retrieved" );
     if( pApiNames )
     {
         delete pApiNames;
-        pApiNames = NULL;
+        pApiNames = nullptr;
     }
 }
 
@@ -280,8 +279,8 @@ const uno::Sequence<OUString>& FilterPropertiesInfo_Impl::GetApiNames()
 void FilterPropertiesInfo_Impl::FillPropertyStateArray(
         vector< XMLPropertyState >& rPropStates,
         const Reference< XPropertySet >& rPropSet,
-        const UniReference< XMLPropertySetMapper >& rPropMapper,
-        const sal_Bool bDefault )
+        const rtl::Reference< XMLPropertySetMapper >& rPropMapper,
+        const bool bDefault )
 {
     XMLPropertyStates_Impl aPropStates;
 
@@ -355,7 +354,7 @@ void FilterPropertiesInfo_Impl::FillPropertyStateArray(
     else
     {
         Sequence < PropertyState > aStates;
-        const PropertyState *pStates = 0;
+        const PropertyState *pStates = nullptr;
         Reference< XPropertyState > xPropState( rPropSet, UNO_QUERY );
         if( xPropState.is() )
         {
@@ -461,12 +460,12 @@ void FilterPropertiesInfo_Impl::FillPropertyStateArray(
             FilterPropertyInfoList_Impl::iterator aItr = aPropInfos.begin();
             for(sal_uInt32 i = 0; i < nCount; ++i)
             {
-                sal_Bool bDirectValue =
+                bool bDirectValue =
                     !pStates || *pStates == PropertyState_DIRECT_VALUE;
                 if( bDirectValue || bDefault )
                 {
                     // The value is stored in the PropertySet itself, add to list.
-                    sal_Bool bGotValue = sal_False;
+                    bool bGotValue = false;
                     XMLPropertyState aNewProperty( -1 );
                     for( std::list<sal_uInt32>::const_iterator aIndexItr =
                             aItr->GetIndexes().begin();
@@ -483,7 +482,7 @@ void FilterPropertiesInfo_Impl::FillPropertyStateArray(
                                 {
                                     aNewProperty.maValue =
                                         rPropSet->getPropertyValue( aItr->GetApiName() );
-                                    bGotValue = sal_True;
+                                    bGotValue = true;
                                 }
                                 aNewProperty.mnIndex = *aIndexItr;
                                 aPropStates.AddPropertyState( aNewProperty );
@@ -491,7 +490,7 @@ void FilterPropertiesInfo_Impl::FillPropertyStateArray(
                             catch( UnknownPropertyException& )
                             {
                                 // might be a problem of getImplemenetationId
-                                OSL_ENSURE( !this, "unknown property in getPropertyValue" );
+                                OSL_ENSURE( false, "unknown property in getPropertyValue" );
                             }
 
                         }
@@ -511,11 +510,11 @@ void FilterPropertiesInfo_Impl::FillPropertyStateArray(
 
 struct SvXMLExportPropertyMapper::Impl
 {
-    typedef boost::unordered_map<PropertySetInfoKey, FilterPropertiesInfo_Impl*, PropertySetInfoHash, PropertySetInfoHash> CacheType;
+    typedef std::map<css::uno::Reference<css::beans::XPropertySetInfo>, FilterPropertiesInfo_Impl*> CacheType;
     CacheType maCache;
 
-    UniReference<SvXMLExportPropertyMapper> mxNextMapper;
-    UniReference<XMLPropertySetMapper> mxPropMapper;
+    rtl::Reference<SvXMLExportPropertyMapper> mxNextMapper;
+    rtl::Reference<XMLPropertySetMapper> mxPropMapper;
 
     OUString maStyleName;
 
@@ -530,7 +529,7 @@ struct SvXMLExportPropertyMapper::Impl
 // ctor/dtor , class SvXMLExportPropertyMapper
 
 SvXMLExportPropertyMapper::SvXMLExportPropertyMapper(
-        const UniReference< XMLPropertySetMapper >& rMapper ) :
+        const rtl::Reference< XMLPropertySetMapper >& rMapper ) :
     mpImpl(new Impl)
 {
     mpImpl->mxPropMapper = rMapper;
@@ -538,11 +537,10 @@ SvXMLExportPropertyMapper::SvXMLExportPropertyMapper(
 
 SvXMLExportPropertyMapper::~SvXMLExportPropertyMapper()
 {
-    delete mpImpl;
 }
 
 void SvXMLExportPropertyMapper::ChainExportMapper(
-        const UniReference< SvXMLExportPropertyMapper>& rMapper )
+        const rtl::Reference< SvXMLExportPropertyMapper>& rMapper )
 {
     // add map entries from rMapper to current map
     mpImpl->mxPropMapper->AddMapperEntry( rMapper->getPropertySetMapper() );
@@ -550,7 +548,7 @@ void SvXMLExportPropertyMapper::ChainExportMapper(
     rMapper->mpImpl->mxPropMapper = mpImpl->mxPropMapper;
 
     // set rMapper as last mapper in current chain
-    UniReference< SvXMLExportPropertyMapper > xNext = mpImpl->mxNextMapper;
+    rtl::Reference< SvXMLExportPropertyMapper > xNext = mpImpl->mxNextMapper;
     if( xNext.is())
     {
         while (xNext->mpImpl->mxNextMapper.is())
@@ -571,9 +569,20 @@ void SvXMLExportPropertyMapper::ChainExportMapper(
     }
 }
 
-vector< XMLPropertyState > SvXMLExportPropertyMapper::_Filter(
-        const Reference< XPropertySet > xPropSet,
-        bool bDefault, bool bEnableFoFontFamily) const
+std::vector<XMLPropertyState> SvXMLExportPropertyMapper::Filter(
+    const uno::Reference<beans::XPropertySet>& rPropSet, bool bEnableFoFontFamily ) const
+{
+    return Filter_(rPropSet, false, bEnableFoFontFamily);
+}
+
+std::vector<XMLPropertyState> SvXMLExportPropertyMapper::FilterDefaults(
+    const uno::Reference<beans::XPropertySet>& rPropSet ) const
+{
+    return Filter_(rPropSet, true, false/*bEnableFoFontFamily*/);
+}
+
+vector<XMLPropertyState> SvXMLExportPropertyMapper::Filter_(
+    const Reference<XPropertySet>& xPropSet, bool bDefault, bool bEnableFoFontFamily ) const
 {
     vector< XMLPropertyState > aPropStateArray;
 
@@ -584,27 +593,16 @@ vector< XMLPropertyState > SvXMLExportPropertyMapper::_Filter(
 
     sal_Int32 nProps = mpImpl->mxPropMapper->GetEntryCount();
 
-    FilterPropertiesInfo_Impl *pFilterInfo = 0;
+    FilterPropertiesInfo_Impl *pFilterInfo = nullptr;
 
-    Reference < XTypeProvider > xTypeProv( xPropSet, UNO_QUERY );
-    Sequence< sal_Int8 > aImplId;
-    if( xTypeProv.is() )
-    {
-        aImplId = xTypeProv->getImplementationId();
-        if( aImplId.getLength() == 16 )
-        {
-            // The key must not be created outside this block, because it
-            // keeps a reference to the property set info.
-            PropertySetInfoKey aKey( xInfo, aImplId );
-            Impl::CacheType::iterator aIter = mpImpl->maCache.find(aKey);
-            if (aIter != mpImpl->maCache.end())
-                pFilterInfo = (*aIter).second;
-        }
-    }
+    Impl::CacheType::iterator aIter = mpImpl->maCache.find(xInfo);
+    if (aIter != mpImpl->maCache.end())
+        pFilterInfo = (*aIter).second;
 
-    sal_Bool bDelInfo = sal_False;
+    bool bDelInfo = false;
     if( !pFilterInfo )
     {
+        const SvtSaveOptions::ODFDefaultVersion nCurrentVersion( SvtSaveOptions().GetODFDefaultVersion() );
         pFilterInfo = new FilterPropertiesInfo_Impl;
         for( sal_Int32 i=0; i < nProps; i++ )
         {
@@ -616,7 +614,6 @@ vector< XMLPropertyState > SvXMLExportPropertyMapper::_Filter(
                 ( (0 != (nFlags & MID_FLAG_MUST_EXIST)) ||
                   xInfo->hasPropertyByName( rAPIName ) ) )
             {
-                const SvtSaveOptions::ODFDefaultVersion nCurrentVersion( SvtSaveOptions().GetODFDefaultVersion() );
                 const SvtSaveOptions::ODFDefaultVersion nEarliestODFVersionForExport(
                         mpImpl->mxPropMapper->GetEarliestODFVersionForExport(i));
                 if( nCurrentVersion >= nEarliestODFVersionForExport
@@ -626,28 +623,19 @@ vector< XMLPropertyState > SvXMLExportPropertyMapper::_Filter(
             }
         }
 
-        if( xTypeProv.is() && aImplId.getLength() == 16 )
+        // Check whether the property set info is destroyed if it is assigned to
+        // a weak reference only; If it is destroyed, then every instance of
+        // getPropertySetInfo returns a new object; such property set infos must
+        // not be cached:
+        WeakReference < XPropertySetInfo > xWeakInfo( xInfo );
+        xInfo.clear();
+        xInfo = xWeakInfo;
+        if( xInfo.is() )
         {
-            // Check whether the property set info is destroyed if it is
-            // assigned to a weak reference only. If it is destroyed, then
-            // every instance of getPropertySetInfo returns a new object.
-            // Such property set infos must not be cached.
-            WeakReference < XPropertySetInfo > xWeakInfo( xInfo );
-            xInfo = 0;
-            xInfo = xWeakInfo;
-            if( xInfo.is() )
-            {
-                PropertySetInfoKey aKey( xInfo, aImplId );
-                mpImpl->maCache.insert(Impl::CacheType::value_type(aKey, pFilterInfo));
-            }
-            else
-                bDelInfo = true;
+            mpImpl->maCache.insert(Impl::CacheType::value_type(xInfo, pFilterInfo));
         }
         else
-        {
-            OSL_FAIL("here is no TypeProvider or the ImplId is wrong");
             bDelInfo = true;
-        }
     }
 
     if( pFilterInfo->GetPropertyCount() )
@@ -660,11 +648,11 @@ vector< XMLPropertyState > SvXMLExportPropertyMapper::_Filter(
         catch( UnknownPropertyException& )
         {
             // might be a problem of getImplemenetationId
-            OSL_ENSURE( !this, "unknown property in getPropertyStates" );
+            OSL_ENSURE( false, "unknown property in getPropertyStates" );
         }
     }
 
-    // Call centext-filter
+    // Call context-filter
     if( !aPropStateArray.empty() )
         ContextFilter(bEnableFoFontFamily, aPropStateArray, xPropSet);
 
@@ -679,7 +667,7 @@ vector< XMLPropertyState > SvXMLExportPropertyMapper::_Filter(
 void SvXMLExportPropertyMapper::ContextFilter(
         bool bEnableFoFontFamily,
         vector< XMLPropertyState >& rProperties,
-        Reference< XPropertySet > rPropSet ) const
+        const Reference< XPropertySet >& rPropSet ) const
 {
     // Derived class could implement this.
     if (mpImpl->mxNextMapper.is())
@@ -690,11 +678,11 @@ void SvXMLExportPropertyMapper::ContextFilter(
 //  1.Number of elements equal ?
 //  2.Index of each element equal ? (So I know whether the propertynames are the same)
 //  3.Value of each element equal ?
-sal_Bool SvXMLExportPropertyMapper::Equals(
+bool SvXMLExportPropertyMapper::Equals(
         const vector< XMLPropertyState >& aProperties1,
         const vector< XMLPropertyState >& aProperties2 ) const
 {
-    sal_Bool bRet = sal_True;
+    bool bRet = true;
     sal_uInt32 nCount = aProperties1.size();
 
     if( nCount == aProperties2.size() )
@@ -723,13 +711,13 @@ sal_Bool SvXMLExportPropertyMapper::Equals(
                 }
             }
             else
-                bRet = sal_False;
+                bRet = false;
 
             nIndex++;
         }
     }
     else
-        bRet = sal_False;
+        bRet = false;
 
     return bRet;
 }
@@ -760,16 +748,18 @@ void SvXMLExportPropertyMapper::exportXML( SvXMLAttributeList& rAttrList,
 void SvXMLExportPropertyMapper::exportXML(
         SvXMLExport& rExport,
         const ::std::vector< XMLPropertyState >& rProperties,
-        sal_uInt16 nFlags ) const
+        SvXmlExportFlags nFlags,
+        bool bUseExtensionNamespaceForGraphicProperties) const
 {
-    exportXML( rExport, rProperties, -1, -1,  nFlags );
+    exportXML(rExport, rProperties, -1, -1,  nFlags, bUseExtensionNamespaceForGraphicProperties);
 }
 
+
 void SvXMLExportPropertyMapper::exportXML(
         SvXMLExport& rExport,
         const ::std::vector< XMLPropertyState >& rProperties,
         sal_Int32 nPropMapStartIdx, sal_Int32 nPropMapEndIdx,
-        sal_uInt16 nFlags ) const
+        SvXmlExportFlags nFlags, bool bUseExtensionNamespaceForGraphicProperties) const
 {
     sal_uInt16 nPropTypeFlags = 0;
     for( sal_uInt16 i=0; i<MAX_PROP_TYPES; ++i )
@@ -777,6 +767,17 @@ void SvXMLExportPropertyMapper::exportXML(
         sal_uInt16 nPropType = aPropTokens[i].nType;
         if( 0==i || (nPropTypeFlags & (1 << nPropType)) != 0 )
         {
+            sal_uInt16 nNamespace = XML_NAMESPACE_STYLE;
+            if (bUseExtensionNamespaceForGraphicProperties &&
+                aPropTokens[i].eToken == xmloff::token::XML_GRAPHIC_PROPERTIES)
+            {
+                nNamespace = XML_NAMESPACE_LO_EXT;
+                if (rExport.getDefaultVersion() <= SvtSaveOptions::ODFVER_012)
+                {
+                    continue; // don't write for ODF <= 1.2
+                }
+            }
+
             std::vector<sal_uInt16> aIndexArray;
 
             _exportXML( nPropType, nPropTypeFlags,
@@ -787,13 +788,13 @@ void SvXMLExportPropertyMapper::exportXML(
                         nPropMapStartIdx, nPropMapEndIdx );
 
             if( rExport.GetAttrList().getLength() > 0L ||
-                (nFlags & XML_EXPORT_FLAG_EMPTY) != 0 ||
+                (nFlags & SvXmlExportFlags::EMPTY) ||
                 !aIndexArray.empty() )
             {
-                SvXMLElementExport aElem( rExport, XML_NAMESPACE_STYLE,
+                SvXMLElementExport aElem( rExport, nNamespace,
                                   aPropTokens[i].eToken,
-                                  (nFlags & XML_EXPORT_FLAG_IGN_WS) != 0,
-                                  sal_False );
+                                  bool(nFlags & SvXmlExportFlags::IGN_WS),
+                                  false );
 
                 exportElementItems( rExport, rProperties, nFlags, aIndexArray );
             }
@@ -822,7 +823,7 @@ void SvXMLExportPropertyMapper::handleSpecialItem(
 void SvXMLExportPropertyMapper::handleElementItem(
         SvXMLExport& rExport,
         const XMLPropertyState& rProperty,
-        sal_uInt16 nFlags,
+        SvXmlExportFlags nFlags,
         const ::std::vector< XMLPropertyState > *pProperties,
         sal_uInt32 nIdx ) const
 {
@@ -840,7 +841,7 @@ void SvXMLExportPropertyMapper::_exportXML(
         const ::std::vector< XMLPropertyState >& rProperties,
         const SvXMLUnitConverter& rUnitConverter,
         const SvXMLNamespaceMap& rNamespaceMap,
-        sal_uInt16 nFlags,
+        SvXmlExportFlags nFlags,
         std::vector<sal_uInt16>* pIndexArray,
         sal_Int32 nPropMapStartIdx, sal_Int32 nPropMapEndIdx ) const
 {
@@ -860,8 +861,8 @@ void SvXMLExportPropertyMapper::_exportXML(
         {
             sal_uInt32 nEFlags = mpImpl->mxPropMapper->GetEntryFlags(nPropMapIdx);
             sal_uInt16 nEPType = GET_PROP_TYPE(nEFlags);
-            OSL_ENSURE( nEPType >= (XML_TYPE_PROP_START>>XML_TYPE_PROP_SHIFT),
-                        "no prop type sepcified" );
+            OSL_ENSURE(nEPType >= (XML_TYPE_PROP_START >> XML_TYPE_PROP_SHIFT),
+                       "no prop type specified");
             rPropTypeFlags |= (1 << nEPType);
             if( nEPType == nPropType )
             {
@@ -892,7 +893,7 @@ void SvXMLExportPropertyMapper::_exportXML(
         const XMLPropertyState& rProperty,
         const SvXMLUnitConverter& rUnitConverter,
         const SvXMLNamespaceMap& rNamespaceMap,
-        sal_uInt16 /*nFlags*/,
+        SvXmlExportFlags /*nFlags*/,
         const ::std::vector< XMLPropertyState > *pProperties,
         sal_uInt32 nIdx ) const
 {
@@ -901,7 +902,7 @@ void SvXMLExportPropertyMapper::_exportXML(
         uno::Reference< container::XNameContainer > xAttrContainer;
         if( (rProperty.maValue >>= xAttrContainer) && xAttrContainer.is() )
         {
-            SvXMLNamespaceMap *pNewNamespaceMap = 0;
+            SvXMLNamespaceMap *pNewNamespaceMap = nullptr;
             const SvXMLNamespaceMap *pNamespaceMap = &rNamespaceMap;
 
             uno::Sequence< OUString > aAttribNames( xAttrContainer->getElementNames() );
@@ -932,12 +933,12 @@ void SvXMLExportPropertyMapper::_exportXML(
                     sal_uInt16 nKey = pNamespaceMap->GetKeyByPrefix( sPrefix );
                     if( USHRT_MAX == nKey || pNamespaceMap->GetNameByKey( nKey ) != sNamespace )
                     {
-                        sal_Bool bAddNamespace = sal_False;
+                        bool bAddNamespace = false;
                         if( USHRT_MAX == nKey )
                         {
                             // The prefix is unused, so it is sufficient
                             // to add it to the namespace map.
-                            bAddNamespace = sal_True;
+                            bAddNamespace = true;
                         }
                         else
                         {
@@ -959,7 +960,7 @@ void SvXMLExportPropertyMapper::_exportXML(
                                 }
                                 while( nKey != USHRT_MAX );
 
-                                bAddNamespace = sal_True;
+                                bAddNamespace = true;
                             }
                             else
                             {
@@ -1008,11 +1009,11 @@ void SvXMLExportPropertyMapper::_exportXML(
             mpImpl->mxPropMapper->GetEntryNameSpace(rProperty.mnIndex),
             mpImpl->mxPropMapper->GetEntryXMLName(rProperty.mnIndex));
 
-        sal_Bool bRemove = sal_False;
+        bool bRemove = false;
         if ((mpImpl->mxPropMapper->GetEntryFlags( rProperty.mnIndex ) & MID_FLAG_MERGE_ATTRIBUTE) != 0)
         {
             aValue = rAttrList.getValueByName( sName );
-            bRemove = sal_True;
+            bRemove = true;
         }
 
         if (mpImpl->mxPropMapper->exportXML(aValue, rProperty, rUnitConverter))
@@ -1027,12 +1028,12 @@ void SvXMLExportPropertyMapper::_exportXML(
 void SvXMLExportPropertyMapper::exportElementItems(
         SvXMLExport& rExport,
         const ::std::vector< XMLPropertyState >& rProperties,
-        sal_uInt16 nFlags,
+        SvXmlExportFlags nFlags,
         const std::vector<sal_uInt16>& rIndexArray ) const
 {
     const sal_uInt16 nCount = rIndexArray.size();
 
-    sal_Bool bItemsExported = sal_False;
+    bool bItemsExported = false;
     for( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
     {
         const sal_uInt16 nElement = rIndexArray[nIndex];
@@ -1044,14 +1045,14 @@ void SvXMLExportPropertyMapper::exportElementItems(
         rExport.IgnorableWhitespace();
         handleElementItem( rExport, rProperties[nElement],
                            nFlags, &rProperties, nElement );
-        bItemsExported = sal_True;
+        bItemsExported = true;
     }
 
     if( bItemsExported )
         rExport.IgnorableWhitespace();
 }
 
-const UniReference<XMLPropertySetMapper>& SvXMLExportPropertyMapper::getPropertySetMapper() const
+const rtl::Reference<XMLPropertySetMapper>& SvXMLExportPropertyMapper::getPropertySetMapper() const
 {
     return mpImpl->mxPropMapper;
 }
